(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   2936775,     104098]*)
(*NotebookOutlinePosition[   2937547,     104125]*)
(*  CellTagsIndexPosition[   2937503,     104121]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Spectral leackage and windowing", "Title"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " definitions"
}], "Section"],

Cell[CellGroupData[{

Cell["Load needed packages for this notebook", "Subsection"],

Cell[BoxData[{
    \(\(<< Graphics`Colors`;\)\), "\[IndentingNewLine]", 
    \(\(<< Calculus`FourierTransform`;\)\), "\[IndentingNewLine]", 
    \(\(<< Graphics`Graphics`;\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Set up defaults", "Subsection"],

Cell[CellGroupData[{

Cell["Turn off annoying warning messages", "Subsubsection"],

Cell[BoxData[{
    \(\(Off[General::spell];\)\), "\[IndentingNewLine]", 
    \(\(Off[General::spell1];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Set default options for specific functions", "Subsubsection"],

Cell[BoxData[{
    \(\(SetOptions[Plot, Frame \[Rule] True];\)\), "\[IndentingNewLine]", 
    \(\(SetOptions[ListPlot, Frame \[Rule] True, \ PlotJoined \[Rule] True, \ 
        Axes \[Rule] {True, False}];\)\), "\[IndentingNewLine]", 
    \(\(SetOptions[Fourier, 
        FourierParameters \[Rule] {1, \(-1\)}];\)\), "\[IndentingNewLine]", 
    \(\(SetOptions[InverseFourier, 
        FourierParameters \[Rule] {1, \(-1\)}];\)\), "\[IndentingNewLine]", 
    \(\(SetOptions[FourierTransform, \ 
        FourierParameters \[Rule] {0, \(-2\) \[Pi]}];\)\), "\
\[IndentingNewLine]", 
    \(\(SetOptions[FourierTransform, \ 
        FourierParameters \[Rule] {0, \(-2\) \[Pi]}];\)\), "\
\[IndentingNewLine]", 
    \(\(SetOptions[InverseFourierTransform, \ 
        FourierParameters \[Rule] {0, \(-2\) \[Pi]}];\)\)}], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualization functions", "Subsection"],

Cell[CellGroupData[{

Cell["Fix time variable for sampled signals", "Subsubsection"],

Cell[BoxData[
    \(\(FixTime[signal_, 
          sampleRate_] := \[IndentingNewLine]Module[{time, 
            data}, \[IndentingNewLine]time = 
            Table[i/sampleRate, {i, 1, 
                Length[signal]}]; \[IndentingNewLine]data\  = \ {time, 
                signal} // Transpose\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Generate periodic waveform from one period", "Subsubsection"],

Cell["\<\
PeriodicSignal[f, {dmin, dmax}, {t, min, max}] generates a periodic \
waveform for the interval [min, max]. It is assumed that one period of the \
function f(t) is defined over the interval [dmin, dmax].\
\>", "Text"],

Cell[BoxData[
    \(\(PeriodicSignal[
          f_, {dmin_, dmax_}, {t_, min_, 
            max_}] := \[IndentingNewLine]Module[{T, imin, 
            imax}, \[IndentingNewLine]T\  = \ 
            dmax\  - \ dmin; \[IndentingNewLine]imin = 
            Floor[\((min - dmin)\)/T]; \[IndentingNewLine]imax = 
            Ceiling[\((max - dmax)\)/T]; \ \[IndentingNewLine]Sum[
            f[t - i\ T]\ \((UnitStep[t - dmin - i\ T]\  - \ 
                  UnitStep[t - dmax - i\ T])\), {i, imin, 
              imax}]\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot periodic waveforms", "Subsubsection"],

Cell[TextData[{
  "PeriodicPlot[f, {dmin, dmax}, {t, min, max}, opts] plots a a periodic \
waveform for the interval [min, max]. It is assumed that one period of the \
function f(t) is defined over the interval [dmin, dmax]. The 'opts' argument \
passed plotting options to the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function Plot[ ]."
}], "Text"],

Cell[BoxData[
    \(\(PeriodicPlot[f_, {dmin_, dmax_}, {t_, min_, max_}, 
          opts___] := \[IndentingNewLine]Module[{fnc}, \[IndentingNewLine]fnc \
= PeriodicSignal[f, {dmin, dmax}, {t, min, max}]; \[IndentingNewLine]Plot[
            fnc, {t, min, max}, opts]\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot discrete-time signal as sequence of amplitude lines", \
"Subsubsection"],

Cell[BoxData[
    \(\(DiscreteListPlot[signal_, color_:  Black, 
          opts___] := \[IndentingNewLine]Module[{data, g1, 
            g2}, \[IndentingNewLine]If[
            Length[signal[\([1]\)]]\  \[Equal] \ 2, \[IndentingNewLine]data = 
              signal, \[IndentingNewLine]data = 
              FixTime[signal, 
                1]\[IndentingNewLine]]; \[IndentingNewLine]g1 = \
\(Line[{{#[\([1]\)], 0}, {#[\([1]\)], #[\([2]\)]}}] &\)\  /@ \ 
              data; \[IndentingNewLine]g2 = \({PointSize[ .015], 
                  Point[#]} &\)\  /@ \ data; \[IndentingNewLine]Show[
            Graphics[{color, g1, g2}], 
            opts]\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot discrete-time signal as sequence of amplitude lines", \
"Subsubsection"],

Cell[BoxData[
    \(\(DiscreteListPlot2[signal_, color_:  Black, 
          opts___] := \[IndentingNewLine]Module[{data, g1, 
            g2}, \[IndentingNewLine]If[
            Length[signal[\([1]\)]]\  \[Equal] \ 2, \[IndentingNewLine]data = 
              signal, \[IndentingNewLine]data = 
              FixTime[signal, 
                1]\[IndentingNewLine]]; \[IndentingNewLine]g1 = \
\(Line[{{#[\([1]\)], 0}, {#[\([1]\)], #[\([2]\)]}}] &\)\  /@ \ 
              data; \[IndentingNewLine]g2 = \({PointSize[ .005], 
                  Point[#]} &\)\  /@ \ data; \[IndentingNewLine]Show[
            Graphics[{color, g1, g2}], 
            opts]\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Fourier rearrange", "Subsection"],

Cell[TextData[{
  "FourierRearrange[fft] rearranges the result of an FFT (",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function Fourier[ ]), to a easier to visualize the spectrum represented \
by 'fft'. The length of the list 'fft' is assumed to be even; if it is not, \
the last term in 'fft' is dropped. "
}], "Text"],

Cell[BoxData[
    \(\(FourierRearrange[fft_, \ 
          samplingRate_] := \[IndentingNewLine]Module[{fft2, n, 
            n2}, \[IndentingNewLine]If[EvenQ[Length[fft]], \ 
            fft2\  = \ fft, \ 
            fft2\  = \ Drop[fft, \(-1\)]]; \ \[IndentingNewLine]n = 
            Length[fft]; 
          n2 = n/2; \[IndentingNewLine]{Table[\ 
                samplingRate\ i/n, {i, \(-n2\) + 1, n2}], 
              Take[fft2, {n2 + 2, n2*2}]~Join~Take[fft2, {1, n2 + 1}]} // 
            Transpose\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Short-cut functions", "Subsection"],

Cell[CellGroupData[{

Cell["Dirac delta function", "Subsubsection"],

Cell[BoxData[
    \(\(\[Delta][t_] := DiracDelta[t];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Unit step function", "Subsubsection"],

Cell[BoxData[
    \(\(u[t_] := UnitStep[t];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Pulse of width ",
  Cell[BoxData[
      \(TraditionalForm\`w\)]]
}], "Subsubsection"],

Cell[BoxData[
    \(\(p[t_, w_] := u[t + w/2] - u[t - w/2];\)\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Hack to plot ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta](t)\)]]
}], "Subsection"],

Cell[BoxData[
    \(PlotConvert[X_, 
        w_] := \[IndentingNewLine]X\  /. \ {\[Delta][a_] \[Rule] 
            p[a, w]}\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Sampler (CT to DT converter)", "Subsection"],

Cell[BoxData[
    \(\(sampler[xc_, fs_, 
          range_: {0, 5}] := \[IndentingNewLine]Table[{n, xc[n/fs]}, {n, 
            range[\([1]\)]*fs, range[\([2]\)]*fs}];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Sampled frequency spectrum", "Subsection"],

Cell[BoxData[
    \(\(SampledSpectrum[X_, f_, fs_, n_:  5] := \[IndentingNewLine]Sum[
          X[f - k\ fs], {k, \(-n\), n}];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Definition of DTFT", "Subsection"],

Cell[BoxData[
    \(\(DTFT[
          xd_, \[Theta]_] := \[IndentingNewLine]Module[{n, xn, n1, 
            n2}, \[IndentingNewLine]{n, xn}\  = \ 
            xd\  // \ Transpose; \[IndentingNewLine]n1\  = \ First[n]; \ 
          n2\  = \ Last[n]; \[IndentingNewLine]Sum[
            xn[\([k - n1 + 1]\)]\ Exp[\(-I\)\ k\ \[Theta]], {k, n1, 
              n2}]\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Definition of DFT", "Subsection"],

Cell[BoxData[
    \(\(DFT[
          x_] := \[IndentingNewLine]Module[{x2, \ k}, \[IndentingNewLine]If[
            Length[First[x]]\  > \ 1, \ x2\  = \ Last\  /@ \ x, \ 
            x2\  = \ x]; \[IndentingNewLine]{Table[
                k, {k, 0, Length[x2] - 1}], Fourier[x2]}\  // \ 
            Transpose];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Definition of spectral leakage window", "Subsection"],

Cell[BoxData[
    \(Window[t_, \ 
        interval_] := \((0.54\  - \  .46*\ 
            Cos[2  \[Pi]/interval\ t])\)\)], "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Windowing example #1 (single cosine wave  (2+1/6) Hz)", "Section"],

Cell[CellGroupData[{

Cell["Unwindowed example w/zero padding", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(x[t_] := Cos[\((4  \[Pi]\  + \ 2  \[Pi]\ \((1/6)\))\) t];\)\), "\n", 
    \(\(xda = \ sampler[x, fs = 20, {0, 3}];\)\), "\[IndentingNewLine]", 
    \(\(xd2 = \ 
        Table[{n, 0}, {n, \(-fs\), \(-1\)}]~Join~xda~Join~\ 
          Table[{n, 0}, {n, 3*fs + 1, 4*fs}];\)\), "\[IndentingNewLine]", 
    \(\ \(If[OddQ[Length[xda]], \ xda\  = \ Drop[xda, \(-1\)]];\)\), "\n", 
    \(\(gwa\  = \ 
        DiscreteListPlot2[xd2, \ Blue, \ Frame \[Rule] True, 
          Axes \[Rule] {True, False}, \ AspectRatio \[Rule] 1/3, \ 
          ImageSize \[Rule] 504, \ PlotRange \[Rule] All];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .33333 
%%ImageSize: 504 168 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.214286 0.00952381 0.166667 0.15873 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.21429 -0.0125 -3 -9 ]
[.21429 -0.0125 3 0 ]
[.40476 -0.0125 -6 -9 ]
[.40476 -0.0125 6 0 ]
[.59524 -0.0125 -6 -9 ]
[.59524 -0.0125 6 0 ]
[.78571 -0.0125 -6 -9 ]
[.78571 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00794 -12 -4.5 ]
[-0.0125 .00794 0 4.5 ]
[-0.0125 .0873 -24 -4.5 ]
[-0.0125 .0873 0 4.5 ]
[-0.0125 .16667 -6 -4.5 ]
[-0.0125 .16667 0 4.5 ]
[-0.0125 .24603 -18 -4.5 ]
[-0.0125 .24603 0 4.5 ]
[-0.0125 .3254 -6 -4.5 ]
[-0.0125 .3254 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .33333 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-20)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(0)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(20)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(40)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(60)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(80)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00794 m
.00625 .00794 L
s
[(-1)] -0.0125 .00794 1 0 Mshowa
0 .0873 m
.00625 .0873 L
s
[(-0.5)] -0.0125 .0873 1 0 Mshowa
0 .16667 m
.00625 .16667 L
s
[(0)] -0.0125 .16667 1 0 Mshowa
0 .24603 m
.00625 .24603 L
s
[(0.5)] -0.0125 .24603 1 0 Mshowa
0 .3254 m
.00625 .3254 L
s
[(1)] -0.0125 .3254 1 0 Mshowa
.125 Mabswid
0 .02381 m
.00375 .02381 L
s
0 .03968 m
.00375 .03968 L
s
0 .05556 m
.00375 .05556 L
s
0 .07143 m
.00375 .07143 L
s
0 .10317 m
.00375 .10317 L
s
0 .11905 m
.00375 .11905 L
s
0 .13492 m
.00375 .13492 L
s
0 .15079 m
.00375 .15079 L
s
0 .18254 m
.00375 .18254 L
s
0 .19841 m
.00375 .19841 L
s
0 .21429 m
.00375 .21429 L
s
0 .23016 m
.00375 .23016 L
s
0 .2619 m
.00375 .2619 L
s
0 .27778 m
.00375 .27778 L
s
0 .29365 m
.00375 .29365 L
s
0 .30952 m
.00375 .30952 L
s
.25 Mabswid
0 0 m
0 .33333 L
s
.02381 .32708 m
.02381 .33333 L
s
.21429 .32708 m
.21429 .33333 L
s
.40476 .32708 m
.40476 .33333 L
s
.59524 .32708 m
.59524 .33333 L
s
.78571 .32708 m
.78571 .33333 L
s
.97619 .32708 m
.97619 .33333 L
s
.125 Mabswid
.07143 .32958 m
.07143 .33333 L
s
.11905 .32958 m
.11905 .33333 L
s
.16667 .32958 m
.16667 .33333 L
s
.2619 .32958 m
.2619 .33333 L
s
.30952 .32958 m
.30952 .33333 L
s
.35714 .32958 m
.35714 .33333 L
s
.45238 .32958 m
.45238 .33333 L
s
.5 .32958 m
.5 .33333 L
s
.54762 .32958 m
.54762 .33333 L
s
.64286 .32958 m
.64286 .33333 L
s
.69048 .32958 m
.69048 .33333 L
s
.7381 .32958 m
.7381 .33333 L
s
.83333 .32958 m
.83333 .33333 L
s
.88095 .32958 m
.88095 .33333 L
s
.92857 .32958 m
.92857 .33333 L
s
.25 Mabswid
0 .33333 m
1 .33333 L
s
.99375 .00794 m
1 .00794 L
s
.99375 .0873 m
1 .0873 L
s
.99375 .16667 m
1 .16667 L
s
.99375 .24603 m
1 .24603 L
s
.99375 .3254 m
1 .3254 L
s
.125 Mabswid
.99625 .02381 m
1 .02381 L
s
.99625 .03968 m
1 .03968 L
s
.99625 .05556 m
1 .05556 L
s
.99625 .07143 m
1 .07143 L
s
.99625 .10317 m
1 .10317 L
s
.99625 .11905 m
1 .11905 L
s
.99625 .13492 m
1 .13492 L
s
.99625 .15079 m
1 .15079 L
s
.99625 .18254 m
1 .18254 L
s
.99625 .19841 m
1 .19841 L
s
.99625 .21429 m
1 .21429 L
s
.99625 .23016 m
1 .23016 L
s
.99625 .2619 m
1 .2619 L
s
.99625 .27778 m
1 .27778 L
s
.99625 .29365 m
1 .29365 L
s
.99625 .30952 m
1 .30952 L
s
.25 Mabswid
1 0 m
1 .33333 L
s
0 .16667 m
1 .16667 L
s
0 0 1 r
.5 Mabswid
.02381 .16667 m
.02381 .16667 L
s
.03333 .16667 m
.03333 .16667 L
s
.04286 .16667 m
.04286 .16667 L
s
.05238 .16667 m
.05238 .16667 L
s
.0619 .16667 m
.0619 .16667 L
s
.07143 .16667 m
.07143 .16667 L
s
.08095 .16667 m
.08095 .16667 L
s
.09048 .16667 m
.09048 .16667 L
s
.1 .16667 m
.1 .16667 L
s
.10952 .16667 m
.10952 .16667 L
s
.11905 .16667 m
.11905 .16667 L
s
.12857 .16667 m
.12857 .16667 L
s
.1381 .16667 m
.1381 .16667 L
s
.14762 .16667 m
.14762 .16667 L
s
.15714 .16667 m
.15714 .16667 L
s
.16667 .16667 m
.16667 .16667 L
s
.17619 .16667 m
.17619 .16667 L
s
.18571 .16667 m
.18571 .16667 L
s
.19524 .16667 m
.19524 .16667 L
s
.20476 .16667 m
.20476 .16667 L
s
.21429 .16667 m
.21429 .3254 L
s
.22381 .16667 m
.22381 .29002 L
s
.23333 .16667 m
.23333 .19967 L
s
.24286 .16667 m
.24286 .0946 L
s
.25238 .16667 m
.25238 .02166 L
s
.2619 .16667 m
.2619 .01335 L
s
.27143 .16667 m
.27143 .07337 L
s
.28095 .16667 m
.28095 .17497 L
s
.29048 .16667 m
.29048 .27288 L
s
.3 .16667 m
.3 .32344 L
s
.30952 .16667 m
.30952 .30413 L
s
.31905 .16667 m
.31905 .22355 L
s
.32857 .16667 m
.32857 .11762 L
s
.3381 .16667 m
.3381 .03354 L
s
.34762 .16667 m
.34762 .00881 L
s
.35714 .16667 m
.35714 .05443 L
s
.36667 .16667 m
.36667 .15007 L
s
.37619 .16667 m
.37619 .25312 L
s
.38571 .16667 m
.38571 .31763 L
s
.39524 .16667 m
.39524 .31485 L
s
.40476 .16667 m
.40476 .24603 L
s
.41429 .16667 m
.41429 .14184 L
s
.42381 .16667 m
.42381 .04871 L
s
.43333 .16667 m
.43333 .00815 L
s
.44286 .16667 m
.44286 .03825 L
s
.45238 .16667 m
.45238 .12558 L
s
.4619 .16667 m
.4619 .23123 L
s
.47143 .16667 m
.47143 .3081 L
s
.48095 .16667 m
.48095 .32193 L
s
.49048 .16667 m
.49048 .26656 L
s
.5 .16667 m
.5 .16667 L
s
.50952 .16667 m
.50952 .06677 L
s
.51905 .16667 m
.51905 .01141 L
s
.52857 .16667 m
.52857 .02524 L
s
.5381 .16667 m
.5381 .10211 L
s
.54762 .16667 m
.54762 .20775 L
s
.55714 .16667 m
.55714 .29508 L
s
.56667 .16667 m
.56667 .32518 L
s
.57619 .16667 m
.57619 .28463 L
s
.58571 .16667 m
.58571 .1915 L
s
.59524 .16667 m
.59524 .0873 L
s
.60476 .16667 m
.60476 .01848 L
s
.61429 .16667 m
.61429 .01571 L
s
.62381 .16667 m
.62381 .08022 L
s
.63333 .16667 m
.63333 .18326 L
s
.64286 .16667 m
.64286 .27891 L
s
.65238 .16667 m
.65238 .32453 L
s
.6619 .16667 m
.6619 .29979 L
s
.67143 .16667 m
.67143 .21572 L
s
.68095 .16667 m
.68095 .10978 L
s
.69048 .16667 m
.69048 .0292 L
s
.7 .16667 m
.7 .00989 L
s
.70952 .16667 m
.70952 .06046 L
s
.71905 .16667 m
.71905 .15836 L
s
.72857 .16667 m
.72857 .25997 L
s
.7381 .16667 m
.7381 .31999 L
s
.74762 .16667 m
.74762 .31167 L
s
.75714 .16667 m
.75714 .23873 L
s
.76667 .16667 m
.76667 .13366 L
s
.77619 .16667 m
.77619 .04331 L
s
.78571 .16667 m
.78571 .00794 L
s
.79524 .16667 m
.79524 .16667 L
s
.80476 .16667 m
.80476 .16667 L
s
.81429 .16667 m
.81429 .16667 L
s
.82381 .16667 m
.82381 .16667 L
s
.83333 .16667 m
.83333 .16667 L
s
.84286 .16667 m
.84286 .16667 L
s
.85238 .16667 m
.85238 .16667 L
s
.8619 .16667 m
.8619 .16667 L
s
.87143 .16667 m
.87143 .16667 L
s
.88095 .16667 m
.88095 .16667 L
s
.89048 .16667 m
.89048 .16667 L
s
.9 .16667 m
.9 .16667 L
s
.90952 .16667 m
.90952 .16667 L
s
.91905 .16667 m
.91905 .16667 L
s
.92857 .16667 m
.92857 .16667 L
s
.9381 .16667 m
.9381 .16667 L
s
.94762 .16667 m
.94762 .16667 L
s
.95714 .16667 m
.95714 .16667 L
s
.96667 .16667 m
.96667 .16667 L
s
.97619 .16667 m
.97619 .16667 L
s
.005 w
.02381 .16667 Mdot
.03333 .16667 Mdot
.04286 .16667 Mdot
.05238 .16667 Mdot
.0619 .16667 Mdot
.07143 .16667 Mdot
.08095 .16667 Mdot
.09048 .16667 Mdot
.1 .16667 Mdot
.10952 .16667 Mdot
.11905 .16667 Mdot
.12857 .16667 Mdot
.1381 .16667 Mdot
.14762 .16667 Mdot
.15714 .16667 Mdot
.16667 .16667 Mdot
.17619 .16667 Mdot
.18571 .16667 Mdot
.19524 .16667 Mdot
.20476 .16667 Mdot
.21429 .3254 Mdot
.22381 .29002 Mdot
.23333 .19967 Mdot
.24286 .0946 Mdot
.25238 .02166 Mdot
.2619 .01335 Mdot
.27143 .07337 Mdot
.28095 .17497 Mdot
.29048 .27288 Mdot
.3 .32344 Mdot
.30952 .30413 Mdot
.31905 .22355 Mdot
.32857 .11762 Mdot
.3381 .03354 Mdot
.34762 .00881 Mdot
.35714 .05443 Mdot
.36667 .15007 Mdot
.37619 .25312 Mdot
.38571 .31763 Mdot
.39524 .31485 Mdot
.40476 .24603 Mdot
.41429 .14184 Mdot
.42381 .04871 Mdot
.43333 .00815 Mdot
.44286 .03825 Mdot
.45238 .12558 Mdot
.4619 .23123 Mdot
.47143 .3081 Mdot
.48095 .32193 Mdot
.49048 .26656 Mdot
.5 .16667 Mdot
.50952 .06677 Mdot
.51905 .01141 Mdot
.52857 .02524 Mdot
.5381 .10211 Mdot
.54762 .20775 Mdot
.55714 .29508 Mdot
.56667 .32518 Mdot
.57619 .28463 Mdot
.58571 .1915 Mdot
.59524 .0873 Mdot
.60476 .01848 Mdot
.61429 .01571 Mdot
.62381 .08022 Mdot
.63333 .18326 Mdot
.64286 .27891 Mdot
.65238 .32453 Mdot
.6619 .29979 Mdot
.67143 .21572 Mdot
.68095 .10978 Mdot
.69048 .0292 Mdot
.7 .00989 Mdot
.70952 .06046 Mdot
.71905 .15836 Mdot
.72857 .25997 Mdot
.7381 .31999 Mdot
.74762 .31167 Mdot
.75714 .23873 Mdot
.76667 .13366 Mdot
.77619 .04331 Mdot
.78571 .00794 Mdot
.79524 .16667 Mdot
.80476 .16667 Mdot
.81429 .16667 Mdot
.82381 .16667 Mdot
.83333 .16667 Mdot
.84286 .16667 Mdot
.85238 .16667 Mdot
.8619 .16667 Mdot
.87143 .16667 Mdot
.88095 .16667 Mdot
.89048 .16667 Mdot
.9 .16667 Mdot
.90952 .16667 Mdot
.91905 .16667 Mdot
.92857 .16667 Mdot
.9381 .16667 Mdot
.94762 .16667 Mdot
.95714 .16667 Mdot
.96667 .16667 Mdot
.97619 .16667 Mdot
0 0 m
1 0 L
1 .33333 L
0 .33333 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{504, 168},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007h0000Z2000`400?l00000o`00003ooooooooi
ooooo`00;_ooool5o`0000?ooooo0_l0001?ooooo`;o0000D?ooool5o`0000?ooooo0_l0001>oooo
o`?o00000oooool2o`0004kooooo0ol00004ooooo`;o0000COooool3o`0000Cooooo0_l0000Boooo
o`00;oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0004gooooo00Co0000
oooooooooooo0000D?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0004ko
oooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo04[ooooo00Go0000oooo
ooooooooooooo`000002ooooo`04o`000?ooooooooooo`0004_ooooo00Go0000oooooooooooooooo
o`000002ooooo`04o`000?ooooooooooo`00017ooooo000Xooooo`Go00000oooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0004gooooo00Co0000oooooooooooo0000DOooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0004_ooooo1Ol00002ooooo`04o`000?oooooo
ooooo`0004cooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0004_o
oooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`00017ooooo000aoooo
o`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`1;ooooo`04o`000?oooooo
ooooo`0005;ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo04Wooooo
00Co0000oooooooooooo00000oooool01?l0003oooooooooool0001<ooooo`Co00000oooool01?l0
003oooooooooool0001<ooooo`?o00000oooool01?l0003oooooooooool0000Aooooo`00;_ooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000COooool01?l0003ooooo
ooooool0001?ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0001<
ooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooo0000C?ooool00ol0003ooooooooo
o`04ooooo`04o`000?ooooooooooo`0004_ooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`00017ooooo000^ooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0001=ooooo`04o`000?ooooooooooo`0004oooooo00Go0000oooooooooooooooo
o`000002ooooo`04o`000?ooooooooooo`0004gooooo0_l00003ooooo`04o`000?ooooooooooo`00
04gooooo00?o0000ooooooooool00oooool01?l0003oooooooooool0001;ooooo`05o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool0000Aooooo`00;oooool3o`0000Cooooo0_l0
001?ooooo`;o0000DOooool3o`0000Cooooo0_l0001?ooooo`03o`000?oooooooooo00;ooooo0_l0
001?ooooo`;o00001?ooool2o`0004gooooo0ol00004ooooo`;o00004_ooool00?oooooonOooool0
0?oooooonOooool00?oooooonOooool00?oooooonOooool00?oooooonOooool00?oooooonOooool0
0?oooooonOooool002Ooooooool00038o`0000[ooooo000Looooo`?o00002?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Sooooo000Mooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`005Oooool5o`0000?ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05Cooooo00?o0000
ooooooooool0E?ooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo05?ooooo0_l00?mE
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool001gooooo00?o0000oooo
ooooool01oooool3o`0009[ooooo0_l00?lUooooo`;o003oMoooool2o`00obGooooo0_l00?mMoooo
o`Co00002_ooool001gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2Jooooo`;o
003o9Oooool2o`00obGooooo0_l00?m@ooooo`;o003o9_ooool00ol00?ooooooooooo`1Nooooo`03
o`000?oooooooooo00Sooooo000Looooo`;o00002Oooool00ol0003oooooooooo`1cooooo`;o003o
9_ooool00ol00?ooooooooooo`0Sooooo`03o`00oooooooooooo02Cooooo0_l00?mAooooo`03o`00
oooooooooooo02Cooooo00?o003oooooooooool0G_ooool00ol0003oooooooooo`08ooooo`007Ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo07?ooooo0_l00?lVooooo`03o`00oooo
oooooooo02?ooooo00?o003oooooooooool09?ooool00ol00?ooooooooooo`0Xooooo`;o003o9_oo
ool00ol00?ooooooooooo`0Tooooo`03o`00oooooooooooo05kooooo00?o0000ooooooooool02?oo
ool002Oooooo00?o0000ooooooooool0M?ooool00ol00?ooooooooooo`0Tooooo`03o`00oooooooo
oooo02?ooooo00?o003oooooooooool09?ooool00ol00?ooooooooooo`0Tooooo`;o003o0_ooool2
o`00obKooooo00?o003oooooooooool09?ooool00ol00?ooooooooooo`1Nooooo`03o`000?oooooo
oooo00Sooooo000Wooooo`03o`000?oooooooooo07Cooooo00?o003oooooooooool09?ooool00ol0
0?ooooooooooo`0Sooooo`03o`00oooooooooooo02Cooooo00?o003oooooooooool09?ooool2o`00
o`?ooooo00?o003oooooooooool09?ooool00ol00?ooooooooooo`0Tooooo`03o`00oooooooooooo
05kooooo00?o0000ooooooooool02?ooool002Oooooo00?o0000ooooooooool0Koooool2o`00o`?o
oooo00?o003oooooooooool09?ooool00ol00?ooooooooooo`0Sooooo`03o`00oooooooooooo02Co
oooo00?o003oooooooooool09?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo02Co
oooo00?o003oooooooooool09?ooool00ol00?ooooooooooo`1Nooooo`03o`000?oooooooooo00So
oooo000Wooooo`;o0000L?ooool2o`00o`?ooooo00?o003oooooooooool09?ooool00ol00?oooooo
ooooo`0Sooooo`03o`00oooooooooooo02Cooooo00Co003ooooooooooooooooo0_l00?lQooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool09?ooool00ol00?ooooooooooo`0Tooooo`03
o`00oooooooooooo05cooooo0ol0000:ooooo`009oooool00ol0003oooooooooo`1_ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool09?ooool00ol00?ooooooooooo`0Sooooo`03o`00
oooooooooooo02Cooooo00Co003ooooooooooooooooo0_l00?lQooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool09?ooool00ol00?ooooooooooo`0Tooooo`03o`00oooooooooooo05ko
oooo00?o0000ooooooooool02?ooool002Oooooo00?o0000ooooooooool0Koooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo02Cooooo00?o003oooooooooool08oooool00ol00?oooooo
ooooo`0Tooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool07oooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo01oooooo0_l00?l3ooooo`03o`00oooooooooooo02Cooooo
00?o003oooooooooool0G_ooool00ol0003oooooooooo`08ooooo`009oooool00ol0003ooooooooo
o`1_ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool09?ooool00ol00?oooooooooo
o`0Sooooo`03o`00oooooooooooo02Cooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`0Oooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool07oooool2o`00o`?ooooo00?o
003oooooooooool09?ooool00ol00?ooooooooooo`1Nooooo`03o`000?oooooooooo00Sooooo000W
ooooo`03o`000?oooooooooo06oooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0O
ooooo`;o003o0oooool00ol00?ooooooooooo`0Sooooo`03o`00oooooooooooo02Cooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool07oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo02Cooooo00?o003o
ooooooooool0G_ooool00ol0003oooooooooo`08ooooo`009oooool00ol0003oooooooooo`1_oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool07oooool2o`00o`?ooooo00?o003ooooo
ooooool08oooool00ol00?ooooooooooo`0Tooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool07oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01oooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`0Tooooo`03o`00oooooooooooo05kooooo00?o0000oooo
ooooool02?ooool002Oooooo00?o0000ooooooooool0Koooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo01oooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Sooooo`04
o`00ooooooooooooooooo`;o003o8Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
01oooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool09?ooool00ol00?ooooooooooo`1Nooooo`03o`000?oooooooooo
00Sooooo000Wooooo`;o0000L?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01oo
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Sooooo`04o`00oooooooooooooooo
o`;o003o8Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01oooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool09?ooool00ol00?ooooooooooo`1Looooo`?o00002_ooool002Oooooo00?o0000oooooooo
ool0Koooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01oooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`0Sooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool07oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01oooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool07oooool2o`00o`?ooooo00?o003oooooooooool0G_ooool00ol0003oooooooooo`08ooooo`00
9oooool00ol0003oooooooooo`1_ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
7oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo02?ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
7oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`0Oooooo`;o003o0oooool00ol00?ooooooooooo`1Nooooo`03o`00
0?oooooooooo00Sooooo000Wooooo`03o`000?oooooooooo06oooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool08ooo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool07ooo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`1Nooooo`03o`000?oooooooooo00Sooooo000Wooooo`03o`000?oooooo
oooo06oooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool07oooool2o`00o`;ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool07oooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0G_ooool0
0ol0003oooooooooo`08ooooo`009oooool00ol0003oooooooooo`1_ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool07oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
01oooooo0_l00?l2ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool07oooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`0Oooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool07oooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo05kooooo00?o0000ooooooooool02?ooool002Oo
oooo00?o0000ooooooooool0Koooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01oo
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Oooooo`05o`00oooooooooooooooo
ool00?l01?ooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool07oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01oooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool0G_ooool00ol0003oooooooooo`08ooooo`009oooool2o`00073ooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool00_l00?lMooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`0Ooooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool07oooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo01oooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Ooooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool0G?ooool3o`0000[ooooo000Wooooo`03
o`000?oooooooooo06oooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Oooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool00_l00?lMooooo`05o`00oooooooooooooooo
ool00?l01?ooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool07oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01oooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool0G_ooool00ol0003oooooooooo`08ooooo`009oooool00ol0003oooooooooo`1_ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool07oooool00ol00?ooooooooooo`02ooooo`05
o`00ooooooooooooooooool00?l07Oooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003o
ooooooooool07oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01oooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool00_l00?lMooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0G_ooool0
0ol0003oooooooooo`08ooooo`009oooool00ol0003oooooooooo`1_ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool07oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooo
ooooool00?l07Oooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool07ooo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_l0
0?lMooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0G_ooool00ol0003ooooooooo
o`08ooooo`009oooool00ol0003oooooooooo`1_ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool07oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l07Ooo
ool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool07oooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`0Oooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`0Mooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool0G_ooool00ol0003oooooooooo`08ooooo`00
9oooool00ol0003oooooooooo`1_ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
7oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l07Oooool01Ol00?oo
oooooooooooooooo003o00Cooooo00?o003oooooooooool06_ooool2o`00o`?ooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool07oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l07Oooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo05kooooo00?o0000ooooooooool02?ooool0
02Oooooo00?o0000ooooooooool0Koooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
01oooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o01gooooo00Go003o
ooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo01[ooooo0_l00?l3ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool07oooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo01oooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o01gooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`1Nooooo`03o`000?oooooooooo00Sooooo
000Wooooo`03o`000?oooooooooo06oooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`0Oooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`0Mooooo`05o`00
ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`0Kooooo`05o`00oooooooooooooooo
ool00?l01?ooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool07oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l07Oooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo05kooooo00?o0000ooooooooool02?ooool0
02Oooooo0_l0001`ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_l00?lMoooo
o`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`0Mooooo`05o`00oooooooo
ooooooooool00?l01?ooool00ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l0
1?ooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
7oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l07Oooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo05cooooo0ol0000:ooooo`009oooool00ol0003ooooo
ooooo`1_ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_l00?lMooooo`03o`00
oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`0Mooooo`05o`00oooooooooooooooo
ool00?l01?ooool00ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l01?ooool0
0ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool07oooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l07Oooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo05kooooo00?o0000ooooooooool02?ooool002Oooooo00?o0000
ooooooooool0Koooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l07Ooo
ool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l07Oooool01Ol00?oooooo
oooooooooooo003o00Cooooo00?o003oooooooooool06oooool01Ol00?oooooooooooooooooo003o
00Cooooo00?o003oooooooooool07oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
01oooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o01gooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`1Nooooo`03o`000?oooooooooo00Sooooo000Woooo
o`03o`000?oooooooooo06oooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo
003o01gooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o01gooooo00Go
003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo01_ooooo00Go003ooooooooooooo
ooooo`00o`04ooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`02o`00oagooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
01gooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1Nooooo`03o`000?oooooooooo
00Sooooo000Aooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00002?ooool00ol0003o
ooooooooo`1_ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`0Moooo
o`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`0Mooooo`05o`00oooooooo
ooooooooool00?l01?ooool00ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l0
1?ooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
0_l00?lMooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`0Mooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool0G_ooool00ol0003oooooooooo`08ooooo`00
4?ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001oooool00ol0
003oooooooooo`1_ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`0M
ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`0Mooooo`05o`00oooo
ooooooooooooool00?l01?ooool00ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool0
0?l01?ooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooo
ooooooooo`00o`0Mooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`0M
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0G_ooool00ol0003oooooooooo`08
ooooo`002Oooool5o`0000;ooooo00Co0000oooooooooooo00002oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo06oooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooo
oooo003o01gooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o01gooooo
00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo01_ooooo00Go003ooooooooo
ooooooooo`00o`04ooooo`03o`00oooooooooooo01[ooooo0_l00?l3ooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`0Mooooo`03o`00oooooooooooo00;ooooo00Go003o
ooooooooooooooooo`00o`0Mooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0G_oo
ool00ol0003oooooooooo`08ooooo`004?ooool01?l0003oooooooooool0000;ooooo`03o`000?oo
oooooooo00Gooooo0ol0001_ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`0Mooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`0Mooooo`05
o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`0Kooooo`05o`00oooooooooooo
ooooool00?l01?ooool00ol00?ooooooooooo`0Jooooo`;o003o0oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l07Oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l07Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo05_ooooo
1?l0000:ooooo`004?ooool01?l0003oooooooooool00007ooooo`Co00002?ooool00ol0003ooooo
ooooo`1_ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`0Mooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`0Mooooo`05o`00oooooooooooo
ooooool00?l01?ooool00ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l01?oo
ool00ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooo
oooooooooooo003o01gooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
01gooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1Nooooo`03o`000?oooooooooo
00Sooooo000@ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`1_ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`0M
ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`0Mooooo`05o`00oooo
ooooooooooooool00?l01?ooool00ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool0
0?l01?ooool00ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol0
0?oooooooooooooooooo003o01gooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooo
oooo003o01gooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1Nooooo`03o`000?oo
oooooooo00Sooooo000Aooooo`;o00002?ooool5o`0000Oooooo00?o0000ooooooooool0J_ooool2
o`00o`?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o01gooooo00?o
003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o01gooooo00Go003ooooooooooooo
ooooo`00o`04ooooo`03o`00oooooooooooo01_ooooo00Go003oooooooooooooooooo`00o`04oooo
o`03o`00oooooooooooo01_ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooooooo
ooooooooool00?l07Oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0
7Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo05kooooo00?o0000ooooooooool0
2?ooool002Oooooo00?o0000ooooooooool0J_ooool2o`00o`?ooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o01gooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o01gooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo
01_ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo01_ooooo00Go003o
ooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l07Oooool00ol00?oooooo
ooooo`02ooooo`05o`00ooooooooooooooooool00?l07Oooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo05kooooo00?o0000ooooooooool02?ooool002Oooooo00?o0000ooooooooool0
Joooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`0Moooo
o`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`0Mooooo`05o`00oooooooo
ooooooooool00?l01?ooool00ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l0
1?ooool00ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oo
oooooooooooooooo003o01gooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo
003o01gooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1Nooooo`03o`000?oooooo
oooo00Sooooo000Wooooo`03o`000?oooooooooo06_ooooo00Go003oooooooooooooooooo`00o`04
ooooo`05o`00ooooooooooooooooool00?l07Oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l07Oooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003ooooooooo
ool06oooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool00_l00?lIoooo
o`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o01gooooo00?o
003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o01gooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`1Nooooo`03o`000?oooooooooo00Sooooo000Wooooo`;o0000K?oo
ool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`0Mooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`0Mooooo`05o`00oooooooooooo
ooooool00?l01?ooool00ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l01?oo
ool00ol00?ooooooooooo`02o`00oaWooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00
ooooooooooooooooool00?l07Oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooooooo
ool00?l07Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo05cooooo0ol0000:oooo
o`009oooool00ol0003oooooooooo`1[ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol0
0?oooooooooooooooooo003o01gooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooo
oooo003o01gooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo01_ooooo
00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l06Oooool01Ol0
0?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`0Mooooo`03o`00oooo
oooooooo00;ooooo00Go003oooooooooooooooooo`00o`0Mooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool0G_ooool00ol0003oooooooooo`08ooooo`009oooool00ol0003ooooooooo
o`1[ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o01go
oooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o01gooooo00Go003ooooo
ooooooooooooo`00o`04ooooo`03o`00oooooooooooo01_ooooo00Go003oooooooooooooooooo`00
o`04ooooo`05o`00ooooooooooooooooool00?l06Oooool01Ol00?oooooooooooooooooo003o00Co
oooo00Go003oooooooooooooooooo`00o`0Mooooo`03o`00oooooooooooo00;ooooo00Go003ooooo
ooooooooooooo`00o`0Mooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0G_ooool0
0ol0003oooooooooo`08ooooo`009oooool00ol0003oooooooooo`1[ooooo`05o`00oooooooooooo
ooooool00?l01?ooool01Ol00?oooooooooooooooooo003o01gooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o01gooooo00Go003oooooooooooooooooo`00o`04ooooo`03
o`00oooooooooooo01_ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooooooooooo
ooooool00?l06Oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooooooooooooooo
o`00o`0Hooooo`;o003o0oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l07Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo05kooooo00?o0000oooooooo
ool02?ooool002Oooooo00?o0000ooooooooool0Joooool01Ol00?oooooooooooooooooo003o00Co
oooo00Go003oooooooooooooooooo`00o`0Mooooo`03o`00oooooooooooo00;ooooo00Go003ooooo
ooooooooooooo`00o`0Mooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?oooooooooo
o`0Kooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o01Wo
oooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l06?ooool2
o`00o`?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o01gooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`1Nooooo`03o`000?oooooooooo00Sooooo000W
ooooo`03o`000?oooooooooo06_ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooo
ooooooooooooool00?l07Oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l07Oooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool06oooool01Ol0
0?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`0Iooooo`05o`00oooo
ooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o01Wooooo00Go003ooooooooo
ooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l07Oooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo05kooooo00?o0000ooooooooool02?ooool002Oooooo00?o0000oooo
ooooool0Joooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00
o`0Hooooo`;o003o0oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0
7Oooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool06oooool01Ol00?oo
oooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`0Iooooo`05o`00oooooooo
ooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o01Wooooo00Go003ooooooooooooo
ooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l07Oooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo05kooooo00?o0000ooooooooool02?ooool002Oooooo0_l0001/ooooo`05
o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o01Sooooo0_l00?l3
ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`0Mooooo`05o`00oooo
ooooooooooooool00?l01?ooool00ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool0
0?l01?ooool01Ol00?oooooooooooooooooo003o01Wooooo00Go003oooooooooooooooooo`00o`04
ooooo`05o`00ooooooooooooooooool00?l06Oooool01Ol00?oooooooooooooooooo003o00Cooooo
00Go003oooooooooooooooooo`00o`0Mooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool0G?ooool3o`0000[ooooo000Wooooo`03o`000?oooooooooo06_ooooo00Go003ooooooooooooo
ooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l06Oooool01Ol00?oooooooooooooooooo
003o00Cooooo00Go003oooooooooooooooooo`00o`0Mooooo`05o`00ooooooooooooooooool00?l0
1?ooool00ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oo
oooooooooooooooo003o01Wooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooooooo
ooooooooool00?l06Oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooooooooooo
ooooo`00o`0Mooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0G_ooool00ol0003o
ooooooooo`08ooooo`009oooool00ol0003oooooooooo`1[ooooo`05o`00ooooooooooooooooool0
0?l01?ooool01Ol00?oooooooooooooooooo003o01Wooooo00Go003oooooooooooooooooo`00o`04
ooooo`05o`00ooooooooooooooooool00?l07Oooool01Ol00?oooooooooooooooooo003o00Cooooo
00?o003oooooooooool06oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooooooo
ooooooooo`00o`0Iooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooo
oooo003o01Wooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool0
0?l07Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo05kooooo00?o0000oooooooo
ool02?ooool002Oooooo00?o0000ooooooooool0Joooool01Ol00?oooooooooooooooooo003o00Co
oooo00Go003oooooooooooooooooo`00o`0Iooooo`05o`00ooooooooooooooooool00?l01?ooool0
1Ol00?oooooooooooooooooo003o01gooooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00
ooooooooooooooooo`;o003o6?ooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooo
ooooooooooooo`00o`0Iooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooo
oooooooo003o01Wooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooooooooooooooo
ool00?l07Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo05kooooo00?o0000oooo
ooooool02?ooool002Oooooo00?o0000ooooooooool0Joooool01Ol00?oooooooooooooooooo003o
00Cooooo00Go003oooooooooooooooooo`00o`0Iooooo`05o`00ooooooooooooooooool00?l01?oo
ool01Ol00?oooooooooooooooooo003o01gooooo00Go003oooooooooooooooooo`00o`04ooooo`04
o`00ooooooooooooooooo`;o003o6?ooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003o
ooooooooooooooooo`00o`0Iooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooo
oooooooooooo003o01Wooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooooooooooo
ooooool00?l07Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo05kooooo00?o0000
ooooooooool02?ooool002Oooooo00?o0000ooooooooool0Joooool01Ol00?oooooooooooooooooo
003o00Cooooo00Go003oooooooooooooooooo`00o`0Iooooo`05o`00ooooooooooooooooool00?l0
1?ooool01Ol00?oooooooooooooooooo003o01gooooo00Go003oooooooooooooooooo`00o`04oooo
o`05o`00ooooooooooooooooool00?l06Oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go
003oooooooooooooooooo`00o`0Iooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oo
oooooooooooooooo003o01Wooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooooooo
ooooooooool00?l07Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo05kooooo00?o
0000ooooooooool02?ooool002Oooooo00?o0000ooooooooool0Joooool01Ol00?oooooooooooooo
oooo003o00Cooooo00Go003oooooooooooooooooo`00o`0Iooooo`05o`00ooooooooooooooooool0
0?l01?ooool01Ol00?oooooooooooooooooo003o01gooooo00Go003oooooooooooooooooo`00o`04
ooooo`05o`00ooooooooooooooooool00?l06Oooool01Ol00?oooooooooooooooooo003o00Cooooo
00Go003oooooooooooooooooo`00o`0Iooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol0
0?oooooooooooooooooo003o01Wooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooo
ooooooooooooool00?l07Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo05kooooo
00?o0000ooooooooool02?ooool002Oooooo0_l0001/ooooo`05o`00ooooooooooooooooool00?l0
1?ooool01Ol00?oooooooooooooooooo003o01Wooooo00Go003oooooooooooooooooo`00o`04oooo
o`05o`00ooooooooooooooooool00?l07Oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go
003oooooooooooooooooo`00o`0Iooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oo
oooooooooooooooo003o01Wooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooooooo
ooooooooool00?l06Oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooooooooooo
ooooo`00o`0Hooooo`;o003o0oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo05co
oooo0ol0000:ooooo`009oooool00ol0003oooooooooo`1[ooooo`05o`00ooooooooooooooooool0
0?l01?ooool01Ol00?oooooooooooooooooo003o01Wooooo00Go003oooooooooooooooooo`00o`04
ooooo`05o`00ooooooooooooooooool00?l07Oooool01Ol00?oooooooooooooooooo003o00Cooooo
00Go003oooooooooooooooooo`00o`0Iooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol0
0?oooooooooooooooooo003o01Wooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooo
ooooooooooooool00?l06Oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooooooo
ooooooooo`00o`0Hooooo`;o003o0oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
05kooooo00?o0000ooooooooool02?ooool002Oooooo00?o0000ooooooooool0Joooool01Ol00?oo
oooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`0Iooooo`05o`00oooooooo
ooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o01gooooo00Go003ooooooooooooo
ooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l06Oooool01Ol00?oooooooooooooooooo
003o00Cooooo00Go003oooooooooooooooooo`00o`0Iooooo`05o`00ooooooooooooooooool00?l0
1?ooool01Ol00?oooooooooooooooooo003o01Wooooo00Go003oooooooooooooooooo`00o`04oooo
o`05o`00ooooooooooooooooool00?l06Oooool01Ol00?oooooooooooooooooo003o00Cooooo00?o
003oooooooooool0G_ooool00ol0003oooooooooo`08ooooo`009oooool00ol0003oooooooooo`1[
ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o01Wooooo
00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l06?ooool2o`00
o`?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l06Ooo
ool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`0Iooooo`05
o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o01Wooooo00Go003o
ooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l06Oooool01Ol00?oooooo
oooooooooooo003o00Cooooo00?o003oooooooooool0G_ooool00ol0003oooooooooo`08ooooo`00
9oooool00ol0003oooooooooo`1[ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oo
oooooooooooooooo003o01Wooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooooooo
ooooooooool00?l06?ooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00
ooooooooooooooooool00?l06Oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooo
ooooooooooooo`00o`0Iooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooo
oooooooo003o01Wooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooooooooooooooo
ool00?l06Oooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool0G_ooool0
0ol0003oooooooooo`08ooooo`009oooool00ol0003oooooooooo`1[ooooo`05o`00oooooooooooo
ooooool00?l01?ooool01Ol00?oooooooooooooooooo003o01Wooooo00Go003ooooooooooooooooo
o`00o`04ooooo`05o`00ooooooooooooooooool00?l06Oooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o01Wooooo00Go003o
ooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l06Oooool01Ol00?oooooo
oooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`0Iooooo`05o`00oooooooooooo
ooooool00?l01?ooool01Ol00?oooooooooooooooooo003o01Wooooo00Go003ooooooooooooooooo
o`00o`04ooooo`03o`00oooooooooooo05kooooo00?o0000ooooooooool02?ooool002Oooooo00?o
0000ooooooooool0Joooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooooooooooo
ooooo`00o`0Iooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo
003o01Wooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go
003oooooooooooooooooo`00o`0Iooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oo
oooooooooooooooo003o01Wooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooooooo
ooooooooool00?l06Oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooooooooooo
ooooo`00o`0Iooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`1Noooo
o`03o`000?oooooooooo00Sooooo000Wooooo`03o`000?oooooooooo06_ooooo00Go003ooooooooo
ooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l06Oooool01Ol00?oooooooooooooo
oooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`;o003o5?ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
01Wooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l06Ooo
ool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`0Iooooo`05
o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o01Wooooo00Go003o
ooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo05kooooo00?o0000ooooooooool02?oo
ool002Oooooo0_l0001/ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooo
oooooooo003o01Wooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooooooooooooooo
ool00?l00oooool2o`00oaCooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo00;ooooo00Go003oooooooooooooooooo`00o`0Iooooo`05o`00ooooooooooooooooool00?l0
1?ooool01Ol00?oooooooooooooooooo003o01Wooooo00Go003oooooooooooooooooo`00o`04oooo
o`05o`00ooooooooooooooooool00?l06Oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go
003oooooooooooooooooo`00o`0Iooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?oo
ooooooooo`1Looooo`?o00002_ooool002Oooooo00?o0000ooooooooool0Joooool01Ol00?oooooo
oooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`0Iooooo`05o`00oooooooooooo
ooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool04ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o01Wooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooooooooooo
ooooool00?l06Oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooooooooooooooo
o`00o`0Iooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o
01Wooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo05kooooo00?o0000
ooooooooool02?ooool002Oooooo00?o0000ooooooooool0Joooool01Ol00?oooooooooooooooooo
003o00Cooooo00Go003oooooooooooooooooo`00o`0Iooooo`05o`00ooooooooooooooooool00?l0
1?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool04oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo
003o01Wooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l0
6Oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`0Ioooo
o`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o01Wooooo00Go
003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo05kooooo00?o0000ooooooooool0
2?ooool002Oooooo00?o0000ooooooooool0Joooool01Ol00?oooooooooooooooooo003o00Cooooo
00Go003oooooooooooooooooo`00o`0Iooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool04oooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o01Wooooo
00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l06Oooool01Ol0
0?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`0Iooooo`05o`00oooo
ooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo0_l00?lDooooo`05
o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`1Nooooo`03o`000?oooooooooo
00Sooooo000Mooooo`;o00002?ooool00ol0003oooooooooo`1[ooooo`05o`00oooooooooooooooo
ool00?l01?ooool01Ol00?oooooooooooooooooo003o01Wooooo00Go003oooooooooooooooooo`00
o`04ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Cooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooooooo
ool00?l06Oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00
o`0Iooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o01Wo
oooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool2
o`00oaCooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo05kooooo00?o
0000ooooooooool02?ooool001cooooo00Co0000oooooooooooo00001oooool00ol0003ooooooooo
o`1[ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o01Wo
oooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`0Cooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l06Oooool01Ol00?oooooooooooooooooo003o00Co
oooo00Go003oooooooooooooooooo`00o`0Iooooo`05o`00ooooooooooooooooool00?l01?ooool0
1Ol00?oooooooooooooooooo003o01Wooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Cooooo`05o`00oooooooooooooooo
ool00?l01?ooool00ol00?ooooooooooo`1Nooooo`03o`000?oooooooooo00Sooooo000Looooo`04
o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool0Joooool01Ol00?oooooooooooooooooo
003o00Cooooo00Go003oooooooooooooooooo`00o`0Iooooo`05o`00ooooooooooooooooool00?l0
1?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool04oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo
003o01Wooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l0
6Oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`0Ioooo
o`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool04oooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool0
G_ooool00ol0003oooooooooo`08ooooo`007?ooool01?l0003oooooooooool00007ooooo`[o0000
0_l00?l2o`0000;o003o0_l00002o`00o`?o00000_l00?l2o`0000;o003o0_l00002o`00o`?o0000
0_l00?l2o`0000;o003o0_l00002o`00o`?o00000_l00?l2o`0000;o003o0_l00002o`00o`?o0000
0_l00?l2o`0000;o003o0_l00002o`00o`?o00000_l00?l2o`0000;o003o0_l00002o`00o`?o0000
0_l00?l2o`0000;o003o0ol000001Ol00?oo0000o`000?l0003o003o00Co000000Go003oo`000?l0
003o0000o`00o`03o`000003o`00ool0003o000000;o000000Go003oo`000?l0003o0000o`00o`03
o`000003o`00ool0003o000000;o000000Go003oo`000?l0003o0000o`00o`03o`000003o`00ool0
003o000000;o000000Go003oo`000?l0003o0000o`00o`03o`000003o`00ool0003o000000;o0000
00Go003oo`000?l0003o0000o`00o`03o`000003o`00ool0003o000000;o000000Go003oo`000?l0
003o0000o`00o`03o`000003o`00ool0003o000000;o000000Go003oo`000?l0003o0000o`00o`03
o`000005o`00ool0003o0000o`000?l00?l01?l000001Ol00?oo0000o`000?l0003o003o00?o0000
00?o003oo`000?l000000_l000001Ol00?oo0000o`000?l0003o003o00?o000000Co003oo`000?l0
003o00000_l00?l3o`000005o`00ool0003o0000o`000?l00?l01?l000001Ol00?oo0000o`000?l0
003o003o00?o000000?o003oo`000?l000000_l000001Ol00?oo0000o`000?l0003o003o00?o0000
00?o003oo`000?l000000_l000001Ol00?oo0000o`000?l0003o003o00?o000000?o003oo`000?l0
00000_l000001Ol00?oo0000o`000?l0003o003o00?o000000?o003oo`000?l000000_l000001Ol0
0?oo0000o`000?l0003o003o00?o000000?o003oo`000?l000000_l000001Ol00?oo0000o`000?l0
003o003o00?o000000?o003oo`000?l000000_l000001Ol00?oo0000o`000?l0003o003o00?o0000
00?o003oo`000?l000000_l000001Ol00?oo0000o`000?l0003o003o00?o000000?o003oo`000?l0
00000_l000001Ol00?oo0000o`000?l0003o003o00?o000000?o003oo`000?l000000_l000000ol0
0?oo0000o`000002o`00o`?o00000_l00?l2o`0000;o003o0_l00002o`00o`?o00000_l00?l2o`00
00;o003o0_l00002o`00o`?o00000_l00?l2o`0000;o003o0_l00002o`00o`?o00000_l00?l2o`00
00;o003o0_l00002o`00o`?o00000_l00?l2o`0000;o003o0_l00002o`00o`;o00000_l00?l3o`00
00;o003o0_l00002o`00o`;o00000_l00?l;o`0000[ooooo000Looooo`04o`000?ooooooooooo`00
00Oooooo00?o0000ooooooooool01oooool2o`00o`;ooooo0_l00?l2ooooo`;o003o0oooool2o`00
o`;ooooo0_l00?l2ooooo`;o003o0oooool2o`00o`;ooooo0_l00?l2ooooo`;o003o0oooool2o`00
o`;ooooo0_l00?l2ooooo`;o003o0oooool2o`00o`;ooooo0_l00?l2ooooo`;o003o0oooool2o`00
o`;ooooo0_l00?l2ooooo`;o003o0oooool2o`00o`;ooooo0_l00?l3ooooo`05o`00oooooooooooo
ooooool00?l01?ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00;ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool05ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`0Fooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`04
o`00ooooooooooooooooo`;o003o5?ooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01;ooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`0Gooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00gooooo0_l00?l3ooooo`;o003o0_ooool2o`00o`;ooooo
0_l00?l3ooooo`;o003o0_ooool2o`00o`;ooooo0_l00?l3ooooo`;o003o0_ooool2o`00o`;ooooo
0_l00?l3ooooo`;o003o0_ooool2o`00o`;ooooo0_l00?l3ooooo`;o003o0_ooool2o`00o`;ooooo
0_l00?l2ooooo`;o003o0oooool2o`00o`;ooooo0_l00?l2ooooo`;o003o2_ooool00ol0003ooooo
ooooo`08ooooo`007?ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo05kooooo
00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo01;ooooo00?o003ooooooooo
ool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`0Gooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool05oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01;ooooo
00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`0Gooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo06_ooooo00?o0000ooooooooool02?ooool001go
oooo0_l00008ooooo`03o`000?oooooooooo05kooooo00Go003oooooooooooooooooo`00o`04oooo
o`03o`00oooooooooooo01;ooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01Oooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool05_ooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Gooooo`03o`00
oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01Oooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0Joooool0
0ol0003oooooooooo`08ooooo`009oooool00ol0003oooooooooo`1Nooooo`05o`00oooooooooooo
ooooool00?l01?ooool00ol00?ooooooooooo`0Booooo`;o003o0oooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Gooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01Kooooo
00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool05oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool00_ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0G
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo06_ooooo00?o0000ooooooooool02?ooool002Oooooo00?o0000ooooooooool0G_ooool0
1Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool05oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Gooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01Ko
oooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool05oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool00_ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`0Gooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo06_ooooo00?o0000ooooooooool02?ooool002Oooooo00?o0000ooooooooool0G_oo
ool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool05oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Gooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
01Kooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool05oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`0Gooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo06_ooooo00?o0000ooooooooool02?ooool002Oooooo0_l0001Oooooo`05o`00
ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`0Gooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01Oooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool05_ooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`0Gooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool04_ooool2o`00o`?ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool05oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1Yoooo
o`?o00002_ooool002Oooooo00?o0000ooooooooool0G_ooool01Ol00?oooooooooooooooooo003o
00Cooooo00?o003oooooooooool05oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`0Gooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool05oooool00ol00?oooooo
ooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo01;ooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo01Oooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0Joooool00ol0003oooooooooo`08
ooooo`009oooool00ol0003oooooooooo`1Nooooo`05o`00ooooooooooooooooool00?l01?ooool0
0ol00?ooooooooooo`0Gooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo01Oooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo00;o
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool05oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`0Gooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo06_ooooo00?o0000ooooooooool02?ooool002Oooooo00?o0000
ooooooooool0G_ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool05ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`0Gooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo01Kooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool05oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01Oooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool05ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`1[ooooo`03o`000?oooooooooo00Sooooo000Wooooo`03o`000?oooooooooo05kooooo00Go
003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo01Oooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool05oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Foooo
o`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo01Oooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Co
003ooooooooooooooooo0_l00?lIooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo01Oooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool0Joooool00ol0003oooooooooo`08oooo
o`009oooool00ol0003oooooooooo`1Nooooo`05o`00ooooooooooooooooool00?l01?ooool00ol0
0?ooooooooooo`0Gooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo01Oooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo00;ooooo
00Go003oooooooooooooooooo`00o`03ooooo`04o`00ooooooooooooooooo`;o003o6Oooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0G
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo06_ooooo00?o0000ooooooooool02?ooool002Oooooo00?o0000ooooooooool0G_ooool0
1Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool05oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Gooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01Ko
oooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool05oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`0Looooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo01Oooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool0Joooool00ol0003oooooooooo`08ooooo`009ooo
ool2o`0005oooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo01Oooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool05oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`0Fooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool07?ooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Gooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo06Wooooo0ol0000:ooooo`00
9oooool00ol0003oooooooooo`1Nooooo`05o`00ooooooooooooooooool00?l00oooool2o`00oaWo
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool05oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool00_ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool07?ooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Gooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo06_ooooo00?o0000oooo
ooooool02?ooool002Oooooo00?o0000ooooooooool0G_ooool01Ol00?oooooooooooooooooo003o
00?ooooo0_l00?lIooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo01Oooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo00;ooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01cooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool05oooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1[
ooooo`03o`000?oooooooooo00Sooooo000Wooooo`03o`000?oooooooooo05kooooo00Go003ooooo
ooooooooooooo`00o`0Nooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo01Oooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo00;o
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01cooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool05oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`1[ooooo`03o`000?oooooooooo00Sooooo000Wooooo`03o`000?oooooooooo05kooooo00Go003o
ooooooooooooooooo`00o`0Nooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo01Oooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`02ooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Gooooo`;o003o0oooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool07?ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Gooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo06_ooooo
00?o0000ooooooooool02?ooool002Oooooo00?o0000ooooooooool0G_ooool01Ol00?oooooooooo
oooooooo003o01kooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool05oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo00;ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo01Oooooo0_l00?l3ooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`0Looooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01Oooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0Joooool00ol0003o
ooooooooo`08ooooo`009oooool00ol0003oooooooooo`1Nooooo`05o`00ooooooooooooooooool0
0?l07_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`0Gooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool07?ooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool07?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`0Gooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo06_ooooo00?o0000ooooooooool02?ooool002Oo
oooo00?o0000ooooooooool0G_ooool01Ol00?oooooooooooooooooo003o01kooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool05oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`0Fooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo01cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01co
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool05oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`1[ooooo`03o`000?oooooooooo00Sooooo000Wooooo`;o0000Goooool01Ol0
0?oooooooooooooooooo003o01kooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool05oooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo00;ooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01cooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo01cooooo00Go003oooooooooooooooooo`00o`03
ooooo`04o`00ooooooooooooooooo`;o003o6Oooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`1Yooooo`?o00002_ooool002Oooooo00?o
0000ooooooooool0G_ooool01Ol00?oooooooooooooooooo003o01kooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool05oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Foooo
o`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo01cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01cooooo00Go
003oooooooooooooooooo`00o`03ooooo`04o`00ooooooooooooooooo`;o003o6Oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1[oooo
o`03o`000?oooooooooo00Sooooo000Wooooo`03o`000?oooooooooo05kooooo00Go003ooooooooo
ooooooooo`00o`0Nooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo01Oooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`0Looooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`0Looooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`0Looooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo06_ooooo00?o0000ooooooooool02?ooool002Oooooo00?o0000oooo
ooooool0G_ooool01Ol00?oooooooooooooooooo003o01kooooo00Go003oooooooooooooooooo`00
o`03ooooo`04o`00ooooooooooooooooo`;o003o6Oooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo00;o
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01cooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo01cooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo01cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool0Joooool00ol0003oooooooooo`08ooooo`009ooo
ool00ol0003oooooooooo`1Nooooo`05o`00ooooooooooooooooool00?l07_ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Co003ooooooooooooooooo0_l00?lIooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01Kooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool07?oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool07?ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool07?ooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1[ooooo`03o`000?oooooooooo
00Sooooo000Wooooo`03o`000?oooooooooo05kooooo00Go003oooooooooooooooooo`00o`0Noooo
o`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Looooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01Kooooo00?o
003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
7?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool07?ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool07?ooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1[ooooo`03o`000?oooooo
oooo00Sooooo000Wooooo`03o`000?oooooooooo05kooooo00Go003oooooooooooooooooo`00o`0N
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Looooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01Kooooo
00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool07?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool07?ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool07?ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1[ooooo`03o`000?oo
oooooooo00Sooooo000Wooooo`;o0000Goooool01Ol00?oooooooooooooooooo003o01kooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01cooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool05_ooool2o`00o`?o
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01cooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo01cooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo01cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool0JOooool3o`0000[ooooo000Wooooo`03o`000?oo
oooooooo05kooooo00Go003oooooooooooooooooo`00o`0Nooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`0Looooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo01Kooooo0_l00?l3ooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`0Looooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`0Looooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`0Looooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo06_ooooo00?o0000ooooooooool02?ooool002Oooooo00?o0000ooooooooool0
G_ooool01Ol00?oooooooooooooooooo003o01kooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo01cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool06oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool07?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
7?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool07?ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1[oooo
o`03o`000?oooooooooo00Sooooo000Wooooo`03o`000?oooooooooo05kooooo00Go003ooooooooo
ooooooooo`00o`0Nooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0L
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo01_ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01cooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01cooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo01cooooo00Go003oooooooooooooooooo`00o`03
ooooo`04o`00ooooooooooooooooo`;o003oKOooool00ol0003oooooooooo`08ooooo`004Oooool2
o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Sooooo00?o0000ooooooooool0G_ooool0
1Ol00?oooooooooooooooooo003o01kooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo01cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool06oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool07?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool07?ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool07?ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Co003ooooooooooooooooo0_l00?m]ooooo`03o`000?oooooooooo00So
oooo000@ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000007oooo
o`03o`000?oooooooooo05kooooo00Go003oooooooooooooooooo`00o`0Nooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`0Looooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01_ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo01cooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo01cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo01cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo073ooooo00?o
0000ooooooooool02?ooool0013ooooo00Co0000oooooooooooo00002oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo05kooooo00Go003oooooooooooooooooo`00o`0Nooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Looooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01_ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo01cooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo01cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo01cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo073o
oooo00?o0000ooooooooool02?ooool0013ooooo00Co0000oooooooooooo00002oooool00ol0003o
ooooooooo`05ooooo`?o0000G_ooool01Ol00?oooooooooooooooooo003o01kooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo01cooooo00Go003oooooooooooooooooo`00
o`03ooooo`04o`00ooooooooooooooooo`;o003o7Oooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool07?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool07?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool07?ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0KOooool4o`0000[ooooo000@
ooooo`04o`000?ooooooooooo`0000Oooooo1?l00008ooooo`03o`000?oooooooooo05kooooo00Go
003oooooooooooooooooo`00o`0Nooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`0Looooo`05o`00ooooooooooooooooool00?l00oooool01?l00?ooooooooooooooool2
o`00oagooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01cooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01cooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo01cooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo073ooooo00?o0000ooooooooool02?ooool0013ooooo00Co0000oooooooo
oooo00001oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo05kooooo00Go003ooooo
ooooooooooooo`00o`0Nooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`0Looooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Pooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Looooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`0Looooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`0Looooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`1`ooooo`03o`000?oooooooooo00Sooooo000Aooooo`;o00002?ooool5o`0000Oooooo00?o0000
ooooooooool0G_ooool01Ol00?oooooooooooooooooo003o01kooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo01_ooooo0_l00?l3ooooo`05o`00ooooooooooooooooool0
0?l08_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool07?ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool07?ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool07?ooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool0L?ooool00ol0003oooooooooo`08ooooo`009oooool00ol0003ooooooooo
o`1Nooooo`05o`00ooooooooooooooooool00?l07_ooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool06oooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`0Roooo
o`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Looooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`0Looooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`0Looooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`1`ooooo`03o`000?oooooooooo00Sooooo000Wooooo`03o`000?oooooooooo05kooooo
00Go003oooooooooooooooooo`00o`0Nooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`0Pooooo`05o`00ooooooooooooooooool00?l08_ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool07?ooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool07?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool07?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0L?ooool00ol0
003oooooooooo`08ooooo`009oooool00ol0003oooooooooo`1Nooooo`05o`00oooooooooooooooo
ool00?l07_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool08?ooool0
1Ol00?oooooooooooooooooo003o02;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo01cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01co
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01_ooooo0_l00?l3oooo
o`05o`00ooooooooooooooooool00?l0L_ooool00ol0003oooooooooo`08ooooo`009oooool2o`00
05oooooo00Go003oooooooooooooooooo`00o`0Nooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`0Pooooo`05o`00ooooooooooooooooool00?l08_ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool07?ooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool07?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool06oooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`1`ooooo`?o00002_oo
ool002Oooooo00?o0000ooooooooool0G_ooool01Ol00?oooooooooooooooooo003o01kooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo023ooooo00Go003ooooooooooooo
ooooo`00o`0Rooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Loooo
o`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Looooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`0Pooooo`05o`00ooooooooooooooooool00?l0
L_ooool00ol0003oooooooooo`08ooooo`009oooool00ol0003oooooooooo`1Nooooo`05o`00oooo
ooooooooooooool00?l07_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool08?ooool01Ol00?oooooooooooooooooo003o02;ooooo00Go003oooooooooooooooooo`00o`03
ooooo`;o003o7Oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool07?oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool08?ooool01Ol00?oooooo
oooooooooooo003o07;ooooo00?o0000ooooooooool02?ooool002Oooooo00?o0000ooooooooool0
G_ooool01Ol00?oooooooooooooooooo003o01kooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo023ooooo00Go003oooooooooooooooooo`00o`0Rooooo`05o`00oooooooo
ooooooooool00?l00oooool2o`00oagooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo01cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo023o
oooo00Go003oooooooooooooooooo`00o`1booooo`03o`000?oooooooooo00Sooooo000Wooooo`03
o`000?oooooooooo05kooooo00Go003oooooooooooooooooo`00o`0Nooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`0Pooooo`05o`00ooooooooooooooooool00?l08_oo
ool01Ol00?oooooooooooooooooo003o02;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo01cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
023ooooo00Go003oooooooooooooooooo`00o`1booooo`03o`000?oooooooooo00Sooooo000Woooo
o`03o`000?oooooooooo05kooooo00Go003oooooooooooooooooo`00o`0Mooooo`;o003o0oooool0
1Ol00?oooooooooooooooooo003o02;ooooo00Go003oooooooooooooooooo`00o`0Rooooo`05o`00
ooooooooooooooooool00?l08_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool07?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool08?ooool0
1Ol00?oooooooooooooooooo003o07;ooooo00?o0000ooooooooool02?ooool002Oooooo00?o0000
ooooooooool0G_ooool01Ol00?oooooooooooooooooo003o01gooooo0_l00?l3ooooo`05o`00oooo
ooooooooooooool00?l08_ooool01Ol00?oooooooooooooooooo003o02;ooooo00Go003ooooooooo
ooooooooo`00o`0Rooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0L
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Pooooo`05o`00oooo
ooooooooooooool00?l0L_ooool00ol0003oooooooooo`08ooooo`009oooool2o`0005oooooo00Go
003oooooooooooooooooo`00o`0Rooooo`05o`00ooooooooooooooooool00?l08_ooool01Ol00?oo
oooooooooooooooo003o02;ooooo00Go003oooooooooooooooooo`00o`0Rooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`0Looooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`0Pooooo`05o`00ooooooooooooooooool00?l0L?ooool3o`0000[o
oooo000Wooooo`03o`000?oooooooooo05kooooo00Go003oooooooooooooooooo`00o`0Rooooo`05
o`00ooooooooooooooooool00?l08_ooool01Ol00?oooooooooooooooooo003o02;ooooo00Go003o
ooooooooooooooooo`00o`0Rooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`0Kooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o02;ooooo00Go003ooooooooo
ooooooooo`00o`1booooo`03o`000?oooooooooo00Sooooo000Wooooo`03o`000?oooooooooo05ko
oooo00Go003oooooooooooooooooo`00o`0Rooooo`05o`00ooooooooooooooooool00?l08_ooool0
1Ol00?oooooooooooooooooo003o02;ooooo00Go003oooooooooooooooooo`00o`0Rooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Kooooo`;o003o0oooool01Ol00?oo
oooooooooooooooo003o02;ooooo00Go003oooooooooooooooooo`00o`1booooo`03o`000?oooooo
oooo00Sooooo000Wooooo`03o`000?oooooooooo05kooooo00Go003oooooooooooooooooo`00o`0R
ooooo`05o`00ooooooooooooooooool00?l08_ooool01Ol00?oooooooooooooooooo003o02;ooooo
00Go003oooooooooooooooooo`00o`0Rooooo`05o`00ooooooooooooooooool00?l00oooool2o`00
ob7ooooo00Go003oooooooooooooooooo`00o`0Rooooo`05o`00ooooooooooooooooool00?l0L_oo
ool00ol0003oooooooooo`08ooooo`009oooool00ol0003oooooooooo`1Nooooo`05o`00oooooooo
ooooooooool00?l08_ooool01Ol00?oooooooooooooooooo003o02;ooooo00Go003ooooooooooooo
ooooo`00o`0Rooooo`05o`00ooooooooooooooooool00?l08_ooool01Ol00?oooooooooooooooooo
003o00?ooooo0_l00?lQooooo`05o`00ooooooooooooooooool00?l08_ooool01Ol00?oooooooooo
oooooooo003o07;ooooo00?o0000ooooooooool02?ooool002Oooooo00?o0000ooooooooool0G_oo
ool01Ol00?oooooooooooooooooo003o02;ooooo00Go003oooooooooooooooooo`00o`0Rooooo`05
o`00ooooooooooooooooool00?l08_ooool01Ol00?oooooooooooooooooo003o02;ooooo00Go003o
ooooooooooooooooo`00o`0Vooooo`05o`00ooooooooooooooooool00?l08_ooool01Ol00?oooooo
oooooooooooo003o07;ooooo00?o0000ooooooooool02?ooool002Oooooo00?o0000ooooooooool0
G_ooool01?l00?ooooooooooooooool2o`00ob7ooooo00Go003oooooooooooooooooo`00o`0Roooo
o`05o`00ooooooooooooooooool00?l08_ooool01Ol00?oooooooooooooooooo003o02;ooooo00Go
003oooooooooooooooooo`00o`0Vooooo`05o`00ooooooooooooooooool00?l08_ooool01Ol00?oo
oooooooooooooooo003o07;ooooo00?o0000ooooooooool02?ooool002Oooooo00?o0000oooooooo
ool0G_ooool01?l00?ooooooooooooooool2o`00ob7ooooo00Go003oooooooooooooooooo`00o`0R
ooooo`05o`00ooooooooooooooooool00?l08_ooool01Ol00?oooooooooooooooooo003o02;ooooo
00Go003oooooooooooooooooo`00o`0Vooooo`05o`00ooooooooooooooooool00?l08_ooool01Ol0
0?oooooooooooooooooo003o07;ooooo00?o0000ooooooooool02?ooool002Oooooo0_l0001Ooooo
o`03o`00oooooooooooo02Cooooo00Go003oooooooooooooooooo`00o`0Rooooo`05o`00oooooooo
ooooooooool00?l08_ooool01Ol00?oooooooooooooooooo003o027ooooo0_l00?l3ooooo`03o`00
oooooooooooo02Cooooo00Go003oooooooooooooooooo`00o`0Rooooo`05o`00oooooooooooooooo
ool00?l0L?ooool3o`0000[ooooo000Wooooo`03o`000?oooooooooo05kooooo00?o003ooooooooo
ool09?ooool01Ol00?oooooooooooooooooo003o02;ooooo00Go003oooooooooooooooooo`00o`0R
ooooo`05o`00ooooooooooooooooool00?l08Oooool2o`00o`?ooooo00?o003oooooooooool09?oo
ool01Ol00?oooooooooooooooooo003o02;ooooo00Go003oooooooooooooooooo`00o`1booooo`03
o`000?oooooooooo00Sooooo000Wooooo`03o`000?oooooooooo05kooooo00?o003oooooooooool0
9?ooool01Ol00?oooooooooooooooooo003o02;ooooo00Go003oooooooooooooooooo`00o`0Roooo
o`05o`00ooooooooooooooooool00?l09_ooool00ol00?ooooooooooo`0Tooooo`04o`00oooooooo
ooooooooo`;o003o8Oooool01Ol00?oooooooooooooooooo003o07;ooooo00?o0000ooooooooool0
2?ooool002Oooooo00?o0000ooooooooool0G_ooool00ol00?ooooooooooo`0Tooooo`05o`00oooo
ooooooooooooool00?l08_ooool01Ol00?oooooooooooooooooo003o02;ooooo00Go003ooooooooo
ooooooooo`00o`0Vooooo`03o`00oooooooooooo02Cooooo00Co003ooooooooooooooooo0_l00?lQ
ooooo`05o`00ooooooooooooooooool00?l0L_ooool00ol0003oooooooooo`08ooooo`009oooool0
0ol0003oooooooooo`1Nooooo`03o`00oooooooooooo02Cooooo00Co003ooooooooooooooooo0_l0
0?lQooooo`05o`00ooooooooooooooooool00?l08_ooool01Ol00?oooooooooooooooooo003o02Ko
oooo00?o003oooooooooool09?ooool00ol00?ooooooooooo`0Tooooo`05o`00oooooooooooooooo
ool00?l0L_ooool00ol0003oooooooooo`08ooooo`009oooool00ol0003oooooooooo`1Nooooo`03
o`00oooooooooooo02Cooooo00Co003ooooooooooooooooo0_l00?lQooooo`05o`00oooooooooooo
ooooool00?l08_ooool01Ol00?oooooooooooooooooo003o02Kooooo00?o003oooooooooool09?oo
ool00ol00?ooooooooooo`0Tooooo`05o`00ooooooooooooooooool00?l0L_ooool00ol0003ooooo
ooooo`08ooooo`009oooool00ol0003oooooooooo`1Nooooo`03o`00oooooooooooo02Cooooo00?o
003oooooooooool09?ooool01Ol00?oooooooooooooooooo003o027ooooo0_l00?l3ooooo`03o`00
oooooooooooo02Cooooo00?o003oooooooooool09?ooool00ol00?ooooooooooo`0Tooooo`05o`00
ooooooooooooooooool00?l0L_ooool00ol0003oooooooooo`08ooooo`009oooool2o`0005oooooo
00?o003oooooooooool09?ooool00ol00?ooooooooooo`0Tooooo`05o`00ooooooooooooooooool0
0?l08Oooool2o`00o`?ooooo00?o003oooooooooool09?ooool00ol00?ooooooooooo`0Tooooo`03
o`00oooooooooooo02Cooooo00Co003ooooooooooooooooo0_l00?m_ooooo`?o00002_ooool002Oo
oooo00?o0000ooooooooool0G_ooool00ol00?ooooooooooo`0Tooooo`03o`00oooooooooooo02Co
oooo00Go003oooooooooooooooooo`00o`0Vooooo`03o`00oooooooooooo02Cooooo00?o003ooooo
ooooool09?ooool00ol00?ooooooooooo`0Tooooo`04o`00ooooooooooooooooo`;o003oLOooool0
0ol0003oooooooooo`08ooooo`009oooool00ol0003oooooooooo`1Nooooo`03o`00oooooooooooo
02Cooooo00?o003oooooooooool09?ooool01?l00?ooooooooooooooool2o`00obGooooo00?o003o
ooooooooool09?ooool00ol00?ooooooooooo`0Tooooo`03o`00oooooooooooo02Cooooo00?o003o
ooooooooool0M?ooool00ol0003oooooooooo`08ooooo`009oooool00ol0003oooooooooo`1Noooo
o`03o`00oooooooooooo02Cooooo00?o003oooooooooool08oooool2o`00o`?ooooo0_l00?lUoooo
o`03o`00oooooooooooo02Cooooo00?o003oooooooooool09?ooool00ol00?ooooooooooo`0Toooo
o`03o`00oooooooooooo07Cooooo00?o0000ooooooooool02?ooool001cooooo0ol00008ooooo`03
o`000?oooooooooo05kooooo00?o003oooooooooool09?ooool00ol00?ooooooooooo`0Sooooo`;o
003o:_ooool00ol00?ooooooooooo`0Tooooo`03o`00oooooooooooo02Cooooo00?o003ooooooooo
ool08oooool2o`00ogKooooo00?o0000ooooooooool02?ooool001gooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`1Nooooo`03o`00oooooooooooo02Cooooo00?o003oooooooooool0
C_ooool2o`00obKooooo00?o003oooooooooool09?ooool00ol00?ooooooooooo`0Sooooo`;o003o
M_ooool00ol0003oooooooooo`08ooooo`007Oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo05kooooo00?o003oooooooooool08oooool2o`00oe3ooooo0_l00?lVooooo`03o`00oooo
oooooooo02?ooooo0_l00?nMooooo`03o`000?oooooooooo00Sooooo000Mooooo`03o`000?oooooo
oooo00Oooooo0ol0001Mooooo`;o003o9Oooool2o`00ogOooooo0_l00?lUooooo`;o003oV_ooool4
o`0000[ooooo000Mooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`1Cooooo`;o003oE_ooool00ol0003oooooooooo`15ooooo`;o003o3?ooool00ol0
003oooooooooo`1Dooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`08ooooo`007?ooool2o`0000Wooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`08ooooo`007Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool02?ooool002Ooooooool00038o`0000[ooooo0000\
\>"],
  ImageRangeCache->{{{0, 503}, {167, 0}} -> {-31.547, -1.25358, 0.231139, \
0.0138684}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Plot windowing function", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(x[t_] := Window[t, \ 3];\)\), "\n", 
    \(\(xdb = \ sampler[x, fs, {0, 3}];\)\), "\[IndentingNewLine]", 
    \(\(xd2 = \ 
        Table[{n, 0}, {n, \(-fs\), \(-1\)}]~Join~xdb~Join~\ 
          Table[{n, 0}, {n, 3*fs + 1, 4*fs}];\)\), "\[IndentingNewLine]", 
    \(\ \(If[OddQ[Length[xdb]], \ xdb\  = \ Drop[xdb, \(-1\)]];\)\), "\n", 
    \(\(gwb\  = \ 
        DiscreteListPlot2[xd2, \ Blue, \ Frame \[Rule] True, 
          Axes \[Rule] {True, False}, \ AspectRatio \[Rule] 1/3, \ 
          ImageSize \[Rule] 504, \ PlotRange \[Rule] All];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .33333 
%%ImageSize: 504 168 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.214286 0.00952381 0.00793651 0.31746 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.21429 -0.0125 -3 -9 ]
[.21429 -0.0125 3 0 ]
[.40476 -0.0125 -6 -9 ]
[.40476 -0.0125 6 0 ]
[.59524 -0.0125 -6 -9 ]
[.59524 -0.0125 6 0 ]
[.78571 -0.0125 -6 -9 ]
[.78571 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00794 -6 -4.5 ]
[-0.0125 .00794 0 4.5 ]
[-0.0125 .07143 -18 -4.5 ]
[-0.0125 .07143 0 4.5 ]
[-0.0125 .13492 -18 -4.5 ]
[-0.0125 .13492 0 4.5 ]
[-0.0125 .19841 -18 -4.5 ]
[-0.0125 .19841 0 4.5 ]
[-0.0125 .2619 -18 -4.5 ]
[-0.0125 .2619 0 4.5 ]
[-0.0125 .3254 -6 -4.5 ]
[-0.0125 .3254 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .33333 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-20)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(0)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(20)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(40)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(60)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(80)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00794 m
.00625 .00794 L
s
[(0)] -0.0125 .00794 1 0 Mshowa
0 .07143 m
.00625 .07143 L
s
[(0.2)] -0.0125 .07143 1 0 Mshowa
0 .13492 m
.00625 .13492 L
s
[(0.4)] -0.0125 .13492 1 0 Mshowa
0 .19841 m
.00625 .19841 L
s
[(0.6)] -0.0125 .19841 1 0 Mshowa
0 .2619 m
.00625 .2619 L
s
[(0.8)] -0.0125 .2619 1 0 Mshowa
0 .3254 m
.00625 .3254 L
s
[(1)] -0.0125 .3254 1 0 Mshowa
.125 Mabswid
0 .02381 m
.00375 .02381 L
s
0 .03968 m
.00375 .03968 L
s
0 .05556 m
.00375 .05556 L
s
0 .0873 m
.00375 .0873 L
s
0 .10317 m
.00375 .10317 L
s
0 .11905 m
.00375 .11905 L
s
0 .15079 m
.00375 .15079 L
s
0 .16667 m
.00375 .16667 L
s
0 .18254 m
.00375 .18254 L
s
0 .21429 m
.00375 .21429 L
s
0 .23016 m
.00375 .23016 L
s
0 .24603 m
.00375 .24603 L
s
0 .27778 m
.00375 .27778 L
s
0 .29365 m
.00375 .29365 L
s
0 .30952 m
.00375 .30952 L
s
.25 Mabswid
0 0 m
0 .33333 L
s
.02381 .32708 m
.02381 .33333 L
s
.21429 .32708 m
.21429 .33333 L
s
.40476 .32708 m
.40476 .33333 L
s
.59524 .32708 m
.59524 .33333 L
s
.78571 .32708 m
.78571 .33333 L
s
.97619 .32708 m
.97619 .33333 L
s
.125 Mabswid
.07143 .32958 m
.07143 .33333 L
s
.11905 .32958 m
.11905 .33333 L
s
.16667 .32958 m
.16667 .33333 L
s
.2619 .32958 m
.2619 .33333 L
s
.30952 .32958 m
.30952 .33333 L
s
.35714 .32958 m
.35714 .33333 L
s
.45238 .32958 m
.45238 .33333 L
s
.5 .32958 m
.5 .33333 L
s
.54762 .32958 m
.54762 .33333 L
s
.64286 .32958 m
.64286 .33333 L
s
.69048 .32958 m
.69048 .33333 L
s
.7381 .32958 m
.7381 .33333 L
s
.83333 .32958 m
.83333 .33333 L
s
.88095 .32958 m
.88095 .33333 L
s
.92857 .32958 m
.92857 .33333 L
s
.25 Mabswid
0 .33333 m
1 .33333 L
s
.99375 .00794 m
1 .00794 L
s
.99375 .07143 m
1 .07143 L
s
.99375 .13492 m
1 .13492 L
s
.99375 .19841 m
1 .19841 L
s
.99375 .2619 m
1 .2619 L
s
.99375 .3254 m
1 .3254 L
s
.125 Mabswid
.99625 .02381 m
1 .02381 L
s
.99625 .03968 m
1 .03968 L
s
.99625 .05556 m
1 .05556 L
s
.99625 .0873 m
1 .0873 L
s
.99625 .10317 m
1 .10317 L
s
.99625 .11905 m
1 .11905 L
s
.99625 .15079 m
1 .15079 L
s
.99625 .16667 m
1 .16667 L
s
.99625 .18254 m
1 .18254 L
s
.99625 .21429 m
1 .21429 L
s
.99625 .23016 m
1 .23016 L
s
.99625 .24603 m
1 .24603 L
s
.99625 .27778 m
1 .27778 L
s
.99625 .29365 m
1 .29365 L
s
.99625 .30952 m
1 .30952 L
s
.25 Mabswid
1 0 m
1 .33333 L
s
0 .00794 m
1 .00794 L
s
0 0 1 r
.5 Mabswid
.02381 .00794 m
.02381 .00794 L
s
.03333 .00794 m
.03333 .00794 L
s
.04286 .00794 m
.04286 .00794 L
s
.05238 .00794 m
.05238 .00794 L
s
.0619 .00794 m
.0619 .00794 L
s
.07143 .00794 m
.07143 .00794 L
s
.08095 .00794 m
.08095 .00794 L
s
.09048 .00794 m
.09048 .00794 L
s
.1 .00794 m
.1 .00794 L
s
.10952 .00794 m
.10952 .00794 L
s
.11905 .00794 m
.11905 .00794 L
s
.12857 .00794 m
.12857 .00794 L
s
.1381 .00794 m
.1381 .00794 L
s
.14762 .00794 m
.14762 .00794 L
s
.15714 .00794 m
.15714 .00794 L
s
.16667 .00794 m
.16667 .00794 L
s
.17619 .00794 m
.17619 .00794 L
s
.18571 .00794 m
.18571 .00794 L
s
.19524 .00794 m
.19524 .00794 L
s
.20476 .00794 m
.20476 .00794 L
s
.21429 .00794 m
.21429 .03333 L
s
.22381 .00794 m
.22381 .03413 L
s
.23333 .00794 m
.23333 .03652 L
s
.24286 .00794 m
.24286 .04048 L
s
.25238 .00794 m
.25238 .04596 L
s
.2619 .00794 m
.2619 .0529 L
s
.27143 .00794 m
.27143 .06122 L
s
.28095 .00794 m
.28095 .07084 L
s
.29048 .00794 m
.29048 .08165 L
s
.3 .00794 m
.3 .09353 L
s
.30952 .00794 m
.30952 .10635 L
s
.31905 .00794 m
.31905 .11997 L
s
.32857 .00794 m
.32857 .13424 L
s
.3381 .00794 m
.3381 .149 L
s
.34762 .00794 m
.34762 .1641 L
s
.35714 .00794 m
.35714 .17937 L
s
.36667 .00794 m
.36667 .19463 L
s
.37619 .00794 m
.37619 .20973 L
s
.38571 .00794 m
.38571 .22449 L
s
.39524 .00794 m
.39524 .23876 L
s
.40476 .00794 m
.40476 .25238 L
s
.41429 .00794 m
.41429 .2652 L
s
.42381 .00794 m
.42381 .27708 L
s
.43333 .00794 m
.43333 .28789 L
s
.44286 .00794 m
.44286 .29751 L
s
.45238 .00794 m
.45238 .30583 L
s
.4619 .00794 m
.4619 .31277 L
s
.47143 .00794 m
.47143 .31825 L
s
.48095 .00794 m
.48095 .32221 L
s
.49048 .00794 m
.49048 .3246 L
s
.5 .00794 m
.5 .3254 L
s
.50952 .00794 m
.50952 .3246 L
s
.51905 .00794 m
.51905 .32221 L
s
.52857 .00794 m
.52857 .31825 L
s
.5381 .00794 m
.5381 .31277 L
s
.54762 .00794 m
.54762 .30583 L
s
.55714 .00794 m
.55714 .29751 L
s
.56667 .00794 m
.56667 .28789 L
s
.57619 .00794 m
.57619 .27708 L
s
.58571 .00794 m
.58571 .2652 L
s
.59524 .00794 m
.59524 .25238 L
s
.60476 .00794 m
.60476 .23876 L
s
.61429 .00794 m
.61429 .22449 L
s
.62381 .00794 m
.62381 .20973 L
s
.63333 .00794 m
.63333 .19463 L
s
.64286 .00794 m
.64286 .17937 L
s
.65238 .00794 m
.65238 .1641 L
s
.6619 .00794 m
.6619 .149 L
s
.67143 .00794 m
.67143 .13424 L
s
.68095 .00794 m
.68095 .11997 L
s
.69048 .00794 m
.69048 .10635 L
s
.7 .00794 m
.7 .09353 L
s
.70952 .00794 m
.70952 .08165 L
s
.71905 .00794 m
.71905 .07084 L
s
.72857 .00794 m
.72857 .06122 L
s
.7381 .00794 m
.7381 .0529 L
s
.74762 .00794 m
.74762 .04596 L
s
.75714 .00794 m
.75714 .04048 L
s
.76667 .00794 m
.76667 .03652 L
s
.77619 .00794 m
.77619 .03413 L
s
.78571 .00794 m
.78571 .03333 L
s
.79524 .00794 m
.79524 .00794 L
s
.80476 .00794 m
.80476 .00794 L
s
.81429 .00794 m
.81429 .00794 L
s
.82381 .00794 m
.82381 .00794 L
s
.83333 .00794 m
.83333 .00794 L
s
.84286 .00794 m
.84286 .00794 L
s
.85238 .00794 m
.85238 .00794 L
s
.8619 .00794 m
.8619 .00794 L
s
.87143 .00794 m
.87143 .00794 L
s
.88095 .00794 m
.88095 .00794 L
s
.89048 .00794 m
.89048 .00794 L
s
.9 .00794 m
.9 .00794 L
s
.90952 .00794 m
.90952 .00794 L
s
.91905 .00794 m
.91905 .00794 L
s
.92857 .00794 m
.92857 .00794 L
s
.9381 .00794 m
.9381 .00794 L
s
.94762 .00794 m
.94762 .00794 L
s
.95714 .00794 m
.95714 .00794 L
s
.96667 .00794 m
.96667 .00794 L
s
.97619 .00794 m
.97619 .00794 L
s
.005 w
.02381 .00794 Mdot
.03333 .00794 Mdot
.04286 .00794 Mdot
.05238 .00794 Mdot
.0619 .00794 Mdot
.07143 .00794 Mdot
.08095 .00794 Mdot
.09048 .00794 Mdot
.1 .00794 Mdot
.10952 .00794 Mdot
.11905 .00794 Mdot
.12857 .00794 Mdot
.1381 .00794 Mdot
.14762 .00794 Mdot
.15714 .00794 Mdot
.16667 .00794 Mdot
.17619 .00794 Mdot
.18571 .00794 Mdot
.19524 .00794 Mdot
.20476 .00794 Mdot
.21429 .03333 Mdot
.22381 .03413 Mdot
.23333 .03652 Mdot
.24286 .04048 Mdot
.25238 .04596 Mdot
.2619 .0529 Mdot
.27143 .06122 Mdot
.28095 .07084 Mdot
.29048 .08165 Mdot
.3 .09353 Mdot
.30952 .10635 Mdot
.31905 .11997 Mdot
.32857 .13424 Mdot
.3381 .149 Mdot
.34762 .1641 Mdot
.35714 .17937 Mdot
.36667 .19463 Mdot
.37619 .20973 Mdot
.38571 .22449 Mdot
.39524 .23876 Mdot
.40476 .25238 Mdot
.41429 .2652 Mdot
.42381 .27708 Mdot
.43333 .28789 Mdot
.44286 .29751 Mdot
.45238 .30583 Mdot
.4619 .31277 Mdot
.47143 .31825 Mdot
.48095 .32221 Mdot
.49048 .3246 Mdot
.5 .3254 Mdot
.50952 .3246 Mdot
.51905 .32221 Mdot
.52857 .31825 Mdot
.5381 .31277 Mdot
.54762 .30583 Mdot
.55714 .29751 Mdot
.56667 .28789 Mdot
.57619 .27708 Mdot
.58571 .2652 Mdot
.59524 .25238 Mdot
.60476 .23876 Mdot
.61429 .22449 Mdot
.62381 .20973 Mdot
.63333 .19463 Mdot
.64286 .17937 Mdot
.65238 .1641 Mdot
.6619 .149 Mdot
.67143 .13424 Mdot
.68095 .11997 Mdot
.69048 .10635 Mdot
.7 .09353 Mdot
.70952 .08165 Mdot
.71905 .07084 Mdot
.72857 .06122 Mdot
.7381 .0529 Mdot
.74762 .04596 Mdot
.75714 .04048 Mdot
.76667 .03652 Mdot
.77619 .03413 Mdot
.78571 .03333 Mdot
.79524 .00794 Mdot
.80476 .00794 Mdot
.81429 .00794 Mdot
.82381 .00794 Mdot
.83333 .00794 Mdot
.84286 .00794 Mdot
.85238 .00794 Mdot
.8619 .00794 Mdot
.87143 .00794 Mdot
.88095 .00794 Mdot
.89048 .00794 Mdot
.9 .00794 Mdot
.90952 .00794 Mdot
.91905 .00794 Mdot
.92857 .00794 Mdot
.9381 .00794 Mdot
.94762 .00794 Mdot
.95714 .00794 Mdot
.96667 .00794 Mdot
.97619 .00794 Mdot
0 0 m
1 0 L
1 .33333 L
0 .33333 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{504, 168},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007h0000Z2000`400?l00000o`00003ooooooooi
ooooo`00:oooool5o`0000?ooooo0_l0001?ooooo`;o0000D?ooool5o`0000?ooooo0_l0001>oooo
o`?o00000oooool2o`0004kooooo0ol00004ooooo`;o0000COooool3o`0000Cooooo0_l0000Eoooo
o`00;?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0004gooooo00Co0000
oooooooooooo0000D?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0004ko
oooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo04[ooooo00Go0000oooo
ooooooooooooo`000002ooooo`04o`000?ooooooooooo`0004_ooooo00Go0000oooooooooooooooo
o`000002ooooo`04o`000?ooooooooooo`0001Cooooo000Uooooo`Go00000oooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0004gooooo00Co0000oooooooooooo0000DOooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0004_ooooo1Ol00002ooooo`04o`000?oooooo
ooooo`0004cooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0004_o
oooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0001Cooooo000^oooo
o`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`1;ooooo`04o`000?oooooo
ooooo`0005;ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo04Wooooo
00Co0000oooooooooooo00000oooool01?l0003oooooooooool0001<ooooo`Co00000oooool01?l0
003oooooooooool0001<ooooo`?o00000oooool01?l0003oooooooooool0000Dooooo`00:oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000COooool01?l0003ooooo
ooooool0001?ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0001<
ooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooo0000C?ooool00ol0003ooooooooo
o`04ooooo`04o`000?ooooooooooo`0004_ooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0001Cooooo000[ooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0001=ooooo`04o`000?ooooooooooo`0004oooooo00Go0000oooooooooooooooo
o`000002ooooo`04o`000?ooooooooooo`0004gooooo0_l00003ooooo`04o`000?ooooooooooo`00
04gooooo00?o0000ooooooooool00oooool01?l0003oooooooooool0001;ooooo`05o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool0000Dooooo`00;?ooool3o`0000Cooooo0_l0
001?ooooo`;o0000DOooool3o`0000Cooooo0_l0001?ooooo`03o`000?oooooooooo00;ooooo0_l0
001?ooooo`;o00001?ooool2o`0004gooooo0ol00004ooooo`;o00005Oooool00?oooooonOooool0
0?oooooonOooool00?oooooonOooool00?oooooonOooool00?oooooonOooool00?oooooonOooool0
0?oooooonOooool002Coooooool00038o`0000gooooo000Jooooo`;o00002?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00_ooooo000Iooooo`04o`000?ooooooooooo`0000Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0;ooooo`006Oooool01?l0003ooooooooo
ool00007ooooo`03o`000?oooooooooo00Oooooo0_l00?l2ooooo`;o003o0_ooool2o`00o`?ooooo
0_l00?l2ooooo`;o003o0_ooool2o`00o`?ooooo0_l00?l2ooooo`;o003o0_ooool2o`00o`?ooooo
0_l00?l2ooooo`;o003o0_ooool2o`00o`?ooooo0_l00?l2ooooo`;o003o0_ooool2o`00o`?ooooo
0_l00?l2ooooo`;o003o0_ooool2o`00o`?ooooo0_l00?l2ooooo`;o003o0oooool00ol0003ooooo
ooooo`1Dooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool0E?ooool00ol0003ooooo
ooooo`02o`00o`?ooooo0_l00?l2ooooo`;o003o0_ooool2o`00o`?ooooo0_l00?l2ooooo`;o003o
0_ooool2o`00o`?ooooo0_l00?l2ooooo`;o003o0_ooool2o`00o`?ooooo0_l00?l2ooooo`;o003o
0_ooool2o`00o`?ooooo0_l00?l2ooooo`;o003o0_ooool2o`00o`;ooooo0_l00?l3ooooo`;o003o
0_ooool2o`00o`;ooooo0_l00?l:ooooo`03o`000?oooooooooo00_ooooo000Iooooo`04o`000?oo
ooooooooo`0000Oooooo2_l00002o`00o`;o00000_l00?l2o`0000;o003o0ol00002o`00o`;o0000
0_l00?l2o`0000;o003o0ol00002o`00o`;o00000_l00?l2o`0000;o003o0ol00002o`00o`;o0000
0_l00?l2o`0000;o003o0ol00002o`00o`;o00000_l00?l2o`0000;o003o0ol00002o`00o`;o0000
0_l00?l2o`0000;o003o0ol00002o`00o`;o00000_l00?l3o`000005o`00ool0003o0000o`000?l0
0?l01?l000001Ol00?oo0000o`000?l0003o003o00?o000000?o003oo`000?l000000_l000001Ol0
0?oo0000o`000?l0003o003o00?o000000?o003oo`000?l000000_l000001Ol00?oo0000o`000?l0
003o003o00?o000000?o003oo`000?l000000_l000001Ol00?oo0000o`000?l0003o003o00?o0000
00?o003oo`000?l000000_l000001Ol00?oo0000o`000?l0003o003o00?o000000?o003oo`000?l0
00000_l000001Ol00?oo0000o`000?l0003o003o00?o000000?o003oo`000?l000000_l000001Ol0
0?oo0000o`000?l0003o003o00?o000000Go003oo`000?l0003o0000o`00o`04o`000005o`00ool0
003o0000o`000?l00?l00ol000000ol00?oo0000o`000002o`000005o`00ool0003o0000o`000?l0
0?l00ol000000ol00?oo0000o`000002o`000005o`00ool0003o0000o`000?l00?l00ol000000ol0
0?oo0000o`000002o`000005o`00ool0003o0000o`000?l00?l00ol000000ol00?oo0000o`000002
o`000005o`00ool0003o0000o`000?l00?l00ol000000ol00?oo0000o`000002o`000005o`00ool0
003o0000o`000?l00?l00ol000000ol00?oo0000o`000002o`000005o`00ool0003o0000o`000?l0
0?l00ol000000ol00?oo0000o`000002o`000005o`00ool0003o0000o`000?l00?l00ol000000ol0
0?oo0000o`000002o`000005o`00ool0003o0000o`000?l00?l00ol000000ol00?oo0000o`000002
o`000005o`00ool0003o0000o`000?l00?l00ol000000ol00?oo0000o`000002o`000005o`00ool0
003o0000o`000?l00?l00ol000000ol00?oo0000o`000002o`000005o`00ool0003o0000o`000?l0
0?l00ol000000ol00?oo0000o`000002o`000003o`00ool0003o000000;o003o0ol00002o`00o`;o
00000_l00?l2o`0000;o003o0ol00002o`00o`;o00000_l00?l2o`0000;o003o0ol00002o`00o`;o
00000_l00?l2o`0000;o003o0ol00002o`00o`;o00000_l00?l2o`0000;o003o0ol00002o`00o`;o
00000_l00?l2o`0000;o003o0_l00002o`00o`?o00000_l00?l2o`0000;o003o0_l00002o`00o`_o
00003Oooool001Wooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`1Nooooo`05
o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
05kooooo00?o0000ooooooooool02oooool001Wooooo00Co0000oooooooooooo00001oooool00ol0
003oooooooooo`1Nooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo05kooooo00?o0000ooooooooool02oooool001[ooooo0_l00008oooo
o`03o`000?oooooooooo05kooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02oooo
o`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool0G_ooool00ol0003oooooooooo`0;ooooo`009?ooool00ol0
003oooooooooo`1Nooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo05kooooo00?o0000ooooooooool02oooool002Cooooo00?o0000oooo
ooooool0G_ooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;o
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`1Nooooo`03o`000?oooooooooo00_ooooo000Tooooo`03o`000?oooooooooo
05kooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool0G_ooool00ol0003oooooooooo`0;ooooo`009?ooool2o`0005oooooo00Go003ooooo
ooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Co
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;o
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;o
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0G?ooool3
o`0000gooooo000Tooooo`03o`000?oooooooooo05kooooo00Go003oooooooooooooooooo`00o`04
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooo
oooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooo
oooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0G_ooool00ol0003oooooooooo`0;
ooooo`009?ooool00ol0003oooooooooo`1Nooooo`05o`00ooooooooooooooooool00?l01?ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo05kooooo00?o0000ooooooooool02oooool0
02Cooooo00?o0000ooooooooool0G_ooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`1Nooooo`03o`000?oooooooooo00_ooooo000Toooo
o`03o`000?oooooooooo05gooooo0_l00?l3ooooo`;o003o0oooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
0_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02oooo
o`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02oooo
o`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool2o`00o`;ooooo0_l00?mPoooo
o`03o`000?oooooooooo00_ooooo000Tooooo`03o`000?oooooooooo05gooooo0_l00?l3ooooo`;o
003o0_ooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooo
ooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_l00?l3ooooo`;o003o
0_ooool2o`00of3ooooo00?o0000ooooooooool02oooool002Cooooo00?o0000ooooooooool0I_oo
ool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooo
oooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooo
oooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_l00?mYooooo`03o`000?oooooo
oooo00_ooooo000Tooooo`;o0000Joooool2o`00o`?ooooo00?o003oooooooooool00_ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool01?l00?ooooooooooooooool2o`00of_ooooo0ol0000=ooooo`00
9?ooool00ol0003oooooooooo`1Zooooo`;o003o0oooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;o
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;o
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`04o`00ooooooooooooooooo`;o003oKOooool00ol0003ooooooooo
o`0;ooooo`009?ooool00ol0003oooooooooo`1_ooooo`03o`00oooooooooooo00;ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool0L?ooool00ol0003oooooooooo`0;ooooo`00
9?ooool00ol0003oooooooooo`1_ooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool2
o`00og7ooooo00?o0000ooooooooool02oooool002Cooooo00?o0000ooooooooool0Koooool2o`00
o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00?ooooo0_l00?maooooo`03o`000?oooooooooo00_ooooo
000Tooooo`03o`000?oooooooooo07Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;o
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o07Kooooo00?o0000oooo
ooooool02oooool002Cooooo00?o0000ooooooooool0Loooool2o`00o`?ooooo00Go003ooooooooo
ooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol0
0?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooo
oooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooo
oooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_l00?mfooooo`03o`000?oooooo
oooo00_ooooo000Tooooo`;o0000M?ooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`04
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooo
oooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool00_l00?mdooooo`?o00003Oooool002Cooooo00?o0000
ooooooooool0N?ooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`1hooooo`03o`000?oooooooooo00_ooooo000Tooooo`03o`000?oooooooooo07Sooooo00Go
003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02oooo
o`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0N?ooool00ol0003o
ooooooooo`0;ooooo`009?ooool00ol0003oooooooooo`1gooooo`;o003o0oooool00ol00?oooooo
ooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`04
o`00ooooooooooooooooo`;o003oN_ooool00ol0003oooooooooo`0;ooooo`009?ooool00ol0003o
ooooooooo`1gooooo`;o003o0oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;o
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;o
oooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00ooooooooooooooooo`;o003oN_ooool0
0ol0003oooooooooo`0;ooooo`003_ooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol00007
ooooo`03o`000?oooooooooo07cooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`1mooooo`03o`000?oo
oooooooo00_ooooo000=ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000
1oooool00ol0003oooooooooo`1looooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
0_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
0_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0OOooool00ol0003o
ooooooooo`0;ooooo`003Oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0O?ooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
0_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
0_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oo
oooooooooooooooo003o00?ooooo0_l00?mnooooo`03o`000?oooooooooo00_ooooo000=ooooo`04
o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool01_ooool3o`0007cooooo0_l00?l3oooo
o`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`;o003oNoooool4
o`0000gooooo000=ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00
0007ooooo`03o`000?oooooooooo087ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;o
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooo
oooooooo003o08?ooooo00?o0000ooooooooool02oooool000gooooo00Co0000oooooooooooo0000
1oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool0POooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
0_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04oooo
o`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02oooo
o`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0Poooool00ol0003oooooooooo`0;oooo
o`003_ooool2o`0000Wooooo0ol00008ooooo`03o`000?oooooooooo087ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooo
oooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo
00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool00_ooool01Ol00?oooooooooooooooooo003o08?ooooo00?o0000ooooooooool02oooool002Co
oooo00?o0000ooooooooool0P?ooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`04oooo
o`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_l00?n3ooooo`03
o`000?oooooooooo00_ooooo000Tooooo`03o`000?oooooooooo083ooooo0_l00?l3ooooo`05o`00
ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo00;o003oPoooool00ol0003oooooooooo`0;ooooo`009?ooool00ol0003ooooooooo
o`25ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo08Gooooo00?o0000ooooooooool02oooool002Cooooo0_l00026
ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo08?ooooo0ol0000=ooooo`009?ooool00ol0003oooooooooo`25oooo
o`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
0_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02oooo
o`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo08Gooooo00?o0000ooooooooool02oooool002Cooooo00?o0000oooooooo
ool0Q?ooool2o`00o`?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01?l00?oooooo
ooooooooool2o`00ohOooooo00?o0000ooooooooool02oooool002Cooooo00?o0000ooooooooool0
Q?ooool2o`00o`?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01?l00?oooooooooo
ooooool2o`00ohOooooo00?o0000ooooooooool02oooool002Cooooo00?o0000ooooooooool0ROoo
ool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooo
ooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo08[ooooo00?o0000
ooooooooool02oooool002Cooooo00?o0000ooooooooool0ROooool00ol00?ooooooooooo`02oooo
o`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo08[ooooo00?o0000ooooooooool02oooool002Cooooo
00?o0000ooooooooool0ROooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooo
oooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooo
oooooooo08[ooooo00?o0000ooooooooool02oooool002Cooooo0_l0002:ooooo`03o`00oooooooo
oooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
0_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
0_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool0R?ooool3o`0000gooooo000Tooooo`03
o`000?oooooooooo08Wooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooo
oooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooo
oooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`;o003oRoooool00ol0003ooooo
ooooo`0;ooooo`009?ooool00ol0003oooooooooo`29ooooo`;o003o0oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`04ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool2
o`00oh_ooooo00?o0000ooooooooool02oooool002Cooooo00?o0000ooooooooool0S_ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l0T?ooool00ol0003oooooooooo`0;ooooo`009?ooool00ol0003oooooooooo`2>ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;o
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;o
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00
o`2@ooooo`03o`000?oooooooooo00_ooooo000Tooooo`03o`000?oooooooooo08kooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
093ooooo00?o0000ooooooooool02oooool002Cooooo00?o0000ooooooooool0S_ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02oooo
o`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02oooo
o`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0
T?ooool00ol0003oooooooooo`0;ooooo`009?ooool2o`0008kooooo0_l00?l3ooooo`05o`00oooo
ooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo00;o003oS_ooool3o`0000gooooo000Tooooo`03
o`000?oooooooooo08gooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo00;o003oT?ooool00ol0003oooooooooo`0;ooooo`009?ooool00ol0003oooooooooo`2B
ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo09;ooooo00?o0000oooooooo
ool02oooool002Cooooo00?o0000ooooooooool0T_ooool01Ol00?oooooooooooooooooo003o00Co
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`2Booooo`03o`000?oooooooooo00_ooooo000Tooooo`03o`000?oooooooooo
09;ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0T_ooool00ol0003ooooo
ooooo`0;ooooo`003_ooool2o`0000Cooooo00?o0000ooooooooool00oooool3o`0000Oooooo00?o
0000ooooooooool0T_ooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
0_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
0_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`2Boooo
o`03o`000?oooooooooo00_ooooo000=ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`2Booooo`05o`00ooooooooooooooooool00?l01?ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo09;ooooo00?o0000ooooooooool02oooool000gooooo00Co0000oooooooooooo0000
1oooool5o`0000Oooooo0ol0002Aooooo`;o003o0oooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;o
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;o
oooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00ooooooooooooooooo`;o003oTOooool4
o`0000gooooo000=ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00002?oo
ool00ol0003oooooooooo`2Aooooo`;o003o0oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol0
0?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooo
oooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooo
oooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo
00Go003oooooooooooooooooo`00o`03ooooo`04o`00ooooooooooooooooo`;o003oU?ooool00ol0
003oooooooooo`0;ooooo`003Oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo0000
00Sooooo00?o0000ooooooooool0U_ooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo09Oooooo00?o0000ooooooooool02ooo
ool000gooooo00Co0000oooooooooooo00002Oooool2o`0000Sooooo00?o0000ooooooooool0U_oo
ool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo09Oooooo00?o0000ooooooooool02oooool000kooooo0_l0000;ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0U_ooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;o
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;o
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo09Oooooo00?o0000oooo
ooooool02oooool002Cooooo00?o0000ooooooooool0U_ooool00ol00?ooooooooooo`02ooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo09Oooooo00?o0000
ooooooooool02oooool002Cooooo00?o0000ooooooooool0U_ooool2o`00o`?ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool0
1Ol00?oooooooooooooooooo003o00?ooooo0_l00?nHooooo`03o`000?oooooooooo00_ooooo000T
ooooo`03o`000?oooooooooo09Kooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`;o003oV?ooool00ol0003oooooooooo`0;ooooo`009?ooool2o`0009cooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
0_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
0_ooool01Ol00?oooooooooooooooooo003o09_ooooo0ol0000=ooooo`009?ooool00ol0003ooooo
ooooo`2Kooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooo
ooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`2Mooooo`03o`000?oooooooooo
00_ooooo000Tooooo`03o`000?oooooooooo09_ooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0
1?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
0_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo
003o09gooooo00?o0000ooooooooool02oooool002Cooooo00?o0000ooooooooool0Voooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l0WOooool00ol0003oooooooooo`0;ooooo`009?ooool0
0ol0003oooooooooo`2Kooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;o
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`2Mooooo`03o`00
0?oooooooooo00_ooooo000Tooooo`03o`000?oooooooooo09[ooooo0_l00?l3ooooo`05o`00oooo
ooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;o003o
WOooool00ol0003oooooooooo`0;ooooo`009?ooool00ol0003oooooooooo`2Jooooo`;o003o0ooo
ool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`02o`00oigooooo00?o0000ooooooooool02oooool002Cooooo0_l0002Pooooo`05o`00oooo
ooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo09gooooo
0ol0000=ooooo`009?ooool00ol0003oooooooooo`2Oooooo`05o`00ooooooooooooooooool00?l0
1?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02oooo
o`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo09oooooo00?o0000ooooooooool0
2oooool002Cooooo00?o0000ooooooooool0Woooool01Ol00?oooooooooooooooooo003o00Cooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`2Oooooo`03o`000?oooooooooo00_ooooo
000Tooooo`03o`000?oooooooooo09oooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;o
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool0Woooool00ol0003oooooooooo`0;ooooo`009?oo
ool00ol0003oooooooooo`2Oooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo09oooooo00?o0000ooooooooool02oooool002Cooooo00?o
0000ooooooooool0W_ooool2o`00o`?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01?l00?oooooooooo
ooooool2o`00oj7ooooo00?o0000ooooooooool02oooool002Cooooo00?o0000ooooooooool0W_oo
ool2o`00o`?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool01?l00?ooooooooooooooool2o`00oj7ooooo
00?o0000ooooooooool02oooool002Cooooo0_l0002Tooooo`03o`00oooooooooooo00;ooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
0_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool0X_ooool3o`0000gooooo000Tooooo`03o`000?oooooooooo0:?ooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`2Tooooo`03o`000?oooooooooo00_ooooo000Toooo
o`03o`000?oooooooooo0:?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02oooo
o`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`2Toooo
o`03o`000?oooooooooo00_ooooo000Tooooo`03o`000?oooooooooo0:?ooooo00?o003ooooooooo
ool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`2Tooooo`03o`000?oooooooooo00_ooooo000Tooooo`03o`00
0?oooooooooo0:?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`2Tooooo`03o`00
0?oooooooooo00_ooooo000>ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00002?oo
ool00ol0003oooooooooo`2Sooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool2o`00ojGooooo00?o0000ooooooooool02ooo
ool000gooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Oooooo
00?o0000ooooooooool0Xoooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00?ooooo0_l00?nUooooo`03o`000?oooooooooo00_ooooo
000=ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000007ooooo`?o
0000Z?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l0Yoooool4o`0000gooooo000=ooooo`04o`000?ooooooooooo`0000Oooooo1?l00008ooooo`03
o`000?oooooooooo0:Sooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o0:[ooooo00?o0000ooooooooool02oooool000gooooo00Co0000oooooooooooo
00001oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0:Sooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o0:[ooooo00?o0000oooooooo
ool02oooool000gooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo0:Sooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o0:[ooooo00?o0000ooooooooool02oooool000kooooo0_l0000:ooooo`;o0000
2?ooool00ol0003oooooooooo`2Xooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go
003oooooooooooooooooo`00o`2Zooooo`03o`000?oooooooooo00_ooooo000Tooooo`03o`000?oo
oooooooo0:Oooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;o003oZ_ooool0
0ol0003oooooooooo`0;ooooo`009?ooool00ol0003oooooooooo`2Wooooo`;o003o0oooool01Ol0
0?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`02o`00oj[ooooo00?o0000ooooooooool02oooool002Cooooo
00?o0000ooooooooool0[?ooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`2/ooooo`03o`000?oo
oooooooo00_ooooo000Tooooo`;o0000[Oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
0_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`2Zoooo
o`?o00003Oooool002Cooooo00?o0000ooooooooool0[?ooool01Ol00?oooooooooooooooooo003o
00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`2/ooooo`03o`000?oooooooooo00_ooooo000Tooooo`03o`000?oooooooooo0:cooooo00Go
003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool0[?ooool00ol0003oooooooooo`0;ooooo`009?ooool00ol0
003oooooooooo`2/ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo0:cooooo00?o0000oooooooo
ool02oooool002Cooooo00?o0000ooooooooool0Zoooool2o`00o`?ooooo00?o003oooooooooool0
0_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04oooo
o`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02oooo
o`05o`00ooooooooooooooooool00?l00oooool01?l00?ooooooooooooooool2o`00ojkooooo00?o
0000ooooooooool02oooool002Cooooo00?o0000ooooooooool0Zoooool2o`00o`?ooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01?l00?ooooooooooooooool2o`00
ojkooooo00?o0000ooooooooool02oooool002Cooooo00?o0000ooooooooool0/?ooool00ol00?oo
ooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo0;7ooooo00?o
0000ooooooooool02oooool002Cooooo0_l0002aooooo`03o`00oooooooooooo00;ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool0[oooool3o`0000gooooo000Tooooo`03o`00
0?oooooooooo0;3ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`2aooooo`03o`000?oooooooooo00_ooooo000Tooooo`03o`000?oooooooooo
0;3ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`2aooooo`03o`000?oooooooooo00_ooooo000Tooooo`03o`000?oooooooooo0;3ooooo0_l0
0?l3ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Co
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;o
oooo00Go003oooooooooooooooooo`00o`03ooooo`;o003o/_ooool00ol0003oooooooooo`0;oooo
o`009?ooool00ol0003oooooooooo`2`ooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00ooo
ool2o`00ok;ooooo00?o0000ooooooooool02oooool002Cooooo00?o0000ooooooooool0]Oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l0]oooool00ol0003oooooooooo`0;ooooo`009?ooool00ol0003ooooo
ooooo`2eooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`2gooooo`03o`000?oooooooooo00_ooooo000Toooo
o`;o0000]_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`04ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l0]Oooool3o`0000gooooo000Tooooo`03o`000?oo
oooooooo0;Gooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool0
0?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool00_ooool01Ol00?oooooooooooooooooo003o0;Oooooo00?o0000ooooooooool02oooool002Co
oooo00?o0000ooooooooool0]?ooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_l00?ngooooo`03o`000?oooooooooo
00_ooooo000Tooooo`03o`000?oooooooooo0;Cooooo0_l00?l3ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;o003o]oooool00ol0
003oooooooooo`0;ooooo`009?ooool00ol0003oooooooooo`2iooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo0;Wooooo00?o0000oooo
ooooool02oooool000kooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00008ooooo`03
o`000?oooooooooo0;Wooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool0^Oooool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003o
ooooooooool00007ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`2i
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo0;Wooooo00?o0000ooooooooool02oooool000gooooo00Co0000oooooooooooo00001ooo
ool01Ol0003ooooooooooooooooo000000Oooooo0ol0002iooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo0;Kooooo1?l0000=ooooo`00
3Oooool01?l0003oooooooooool00008ooooo`?o00002?ooool00ol0003oooooooooo`2hooooo`;o
003o0oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooo
oooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`04o`00ooooooooooooooooo`;o003o^oooool00ol0003oooooooooo`0;
ooooo`003Oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001ooo
ool00ol0003oooooooooo`2hooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00Cooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooo
oooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00ooooooooooooooooo`;o
003o^oooool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003oooooooooool00007ooooo`05
o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`2mooooo`05o`00oooooooooooo
ooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool0__ooool00ol0003oooooooooo`0;ooooo`003_ooool2o`0000Wooooo0ol00008oooo
o`03o`000?oooooooooo0;gooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02oooo
o`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`2nooooo`03o`000?oooooo
oooo00_ooooo000Tooooo`03o`000?oooooooooo0;gooooo00Go003oooooooooooooooooo`00o`04
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`2n
ooooo`03o`000?oooooooooo00_ooooo000Tooooo`03o`000?oooooooooo0;gooooo00Go003ooooo
ooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`2nooooo`03o`000?oooooooooo00_ooooo000Tooooo`;o0000__ooool2o`00
o`;ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
00?ooooo0_l00?nmooooo`?o00003Oooool002Cooooo00?o0000ooooooooool0_Oooool2o`00o`;o
oooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?o
oooo0_l00?noooooo`03o`000?oooooooooo00_ooooo000Tooooo`03o`000?oooooooooo0<7ooooo
00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o0<Cooooo
00?o0000ooooooooool02oooool002Cooooo00?o0000ooooooooool0`Oooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0a?ooool00ol0003ooooooooo
o`0;ooooo`009?ooool00ol0003oooooooooo`31ooooo`03o`00oooooooooooo00;ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`34ooooo`03o`000?oooooooooo00_ooooo000Toooo
o`03o`000?oooooooooo0<7ooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;o
003oa?ooool00ol0003oooooooooo`0;ooooo`009?ooool00ol0003oooooooooo`31ooooo`;o003o
0oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`02o`00olCooooo00?o0000ooooooooool02ooo
ool002Cooooo00?o0000ooooooooool0a_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
0_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`36oooo
o`03o`000?oooooooooo00_ooooo000Tooooo`;o0000aoooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`34ooooo`?o00003Oooool002Cooooo00?o0000ooooooooool0aOooool2o`00o`?ooooo00Go
003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02oooo
o`05o`00ooooooooooooooooool00?l00oooool01?l00?ooooooooooooooool2o`00olSooooo00?o
0000ooooooooool02oooool002Cooooo00?o0000ooooooooool0aOooool2o`00o`?ooooo00Go003o
ooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05
o`00ooooooooooooooooool00?l00oooool01?l00?ooooooooooooooool2o`00olSooooo00?o0000
ooooooooool02oooool002Cooooo00?o0000ooooooooool0b_ooool01Ol00?oooooooooooooooooo
003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo0<_ooooo00?o0000ooooooooool02oooool002Cooooo
00?o0000ooooooooool0b_ooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooo
oooooooo0<_ooooo00?o0000ooooooooool02oooool002Cooooo00?o0000ooooooooool0b_ooool2
o`00o`;ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
0_ooool01Ol00?oooooooooooooooooo003o00?ooooo0_l00?o<ooooo`03o`000?oooooooooo00_o
oooo000Tooooo`03o`000?oooooooooo0<[ooooo0_l00?l2ooooo`03o`00oooooooooooo00;ooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03
ooooo`;o003oc?ooool00ol0003oooooooooo`0;ooooo`009?ooool2o`000<oooooo00?o003ooooo
ooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooo
oooooooo003o0<oooooo0ol0000=ooooo`009?ooool00ol0003oooooooooo`3>ooooo`;o003o0ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02o`00om7o
oooo00?o0000ooooooooool02oooool002Cooooo00?o0000ooooooooool0c_ooool2o`00o`?ooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_l00?oAoooo
o`03o`000?oooooooooo00_ooooo000Tooooo`03o`000?oooooooooo0=;ooooo0_l00?l3ooooo`05
o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Co003o
oooooooooooooooo0_l00?oEooooo`03o`000?oooooooooo00_ooooo000Iooooo`?o00002?ooool0
0ol0003oooooooooo`3Booooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go
003oooooooooooooooooo`00o`03ooooo`04o`00ooooooooooooooooo`;o003oeOooool00ol0003o
ooooooooo`0;ooooo`006_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0=Kooooo
0_l00?l3ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`;o
003ofOooool00ol0003oooooooooo`0;ooooo`006_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0=Kooooo0_l00?l3ooooo`;o003o0oooool00ol00?ooooooooooo`02o`00o`?ooooo
0_l00?oIooooo`03o`000?oooooooooo00_ooooo000Jooooo`03o`000?oooooooooo00Oooooo0ol0
003Kooooo`;o003o0_ooool2o`00o`;ooooo0_l00?oKooooo`Co00003Oooool001[ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05Cooooo00?o0000
ooooooooool0E?ooool00ol0003oooooooooo`0Wooooo`;o003o:_ooool00ol0003oooooooooo`1D
ooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0;
ooooo`006Oooool2o`0000Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0;oooo
o`006_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool02oooool002Coooooool00038o`0000gooooo0000\
\>"],
  ImageRangeCache->{{{0, 503}, {167, 0}} -> {-30.8536, -0.126788, 0.231139, \
0.00693418}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Sampled and windowed sequence", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(x[t_] := \ 
        Cos[\((4  \[Pi]\  + \ 2  \[Pi]\ \((1/6)\))\) t] 
          Window[t, 3];\)\), "\n", 
    \(\(xdc = \ sampler[x, fs, {0, 3}];\)\), "\[IndentingNewLine]", 
    \(\(xd2 = \ 
        Table[{n, 0}, {n, \(-fs\), \(-1\)}]~Join~xdc~Join~\ 
          Table[{n, 0}, {n, 3*fs + 1, 4*fs}];\)\), "\[IndentingNewLine]", 
    \(\ \(If[OddQ[Length[xdc]], \ xdc\  = \ Drop[xdc, \(-1\)]];\)\), "\n", 
    \(\(gwc\  = \ 
        DiscreteListPlot2[xd2, \ Blue, \ Frame \[Rule] True, 
          Axes \[Rule] {True, False}, \ AspectRatio \[Rule] 1/3, \ 
          ImageSize \[Rule] 504, \ PlotRange \[Rule] All];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .33333 
%%ImageSize: 504 168 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.214286 0.00952381 0.166667 0.163924 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.21429 -0.0125 -3 -9 ]
[.21429 -0.0125 3 0 ]
[.40476 -0.0125 -6 -9 ]
[.40476 -0.0125 6 0 ]
[.59524 -0.0125 -6 -9 ]
[.59524 -0.0125 6 0 ]
[.78571 -0.0125 -6 -9 ]
[.78571 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00274 -12 -4.5 ]
[-0.0125 .00274 0 4.5 ]
[-0.0125 .0847 -24 -4.5 ]
[-0.0125 .0847 0 4.5 ]
[-0.0125 .16667 -6 -4.5 ]
[-0.0125 .16667 0 4.5 ]
[-0.0125 .24863 -18 -4.5 ]
[-0.0125 .24863 0 4.5 ]
[-0.0125 .33059 -6 -4.5 ]
[-0.0125 .33059 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .33333 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-20)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(0)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(20)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(40)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(60)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(80)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00274 m
.00625 .00274 L
s
[(-1)] -0.0125 .00274 1 0 Mshowa
0 .0847 m
.00625 .0847 L
s
[(-0.5)] -0.0125 .0847 1 0 Mshowa
0 .16667 m
.00625 .16667 L
s
[(0)] -0.0125 .16667 1 0 Mshowa
0 .24863 m
.00625 .24863 L
s
[(0.5)] -0.0125 .24863 1 0 Mshowa
0 .33059 m
.00625 .33059 L
s
[(1)] -0.0125 .33059 1 0 Mshowa
.125 Mabswid
0 .01914 m
.00375 .01914 L
s
0 .03553 m
.00375 .03553 L
s
0 .05192 m
.00375 .05192 L
s
0 .06831 m
.00375 .06831 L
s
0 .1011 m
.00375 .1011 L
s
0 .11749 m
.00375 .11749 L
s
0 .13388 m
.00375 .13388 L
s
0 .15027 m
.00375 .15027 L
s
0 .18306 m
.00375 .18306 L
s
0 .19945 m
.00375 .19945 L
s
0 .21584 m
.00375 .21584 L
s
0 .23224 m
.00375 .23224 L
s
0 .26502 m
.00375 .26502 L
s
0 .28141 m
.00375 .28141 L
s
0 .29781 m
.00375 .29781 L
s
0 .3142 m
.00375 .3142 L
s
.25 Mabswid
0 0 m
0 .33333 L
s
.02381 .32708 m
.02381 .33333 L
s
.21429 .32708 m
.21429 .33333 L
s
.40476 .32708 m
.40476 .33333 L
s
.59524 .32708 m
.59524 .33333 L
s
.78571 .32708 m
.78571 .33333 L
s
.97619 .32708 m
.97619 .33333 L
s
.125 Mabswid
.07143 .32958 m
.07143 .33333 L
s
.11905 .32958 m
.11905 .33333 L
s
.16667 .32958 m
.16667 .33333 L
s
.2619 .32958 m
.2619 .33333 L
s
.30952 .32958 m
.30952 .33333 L
s
.35714 .32958 m
.35714 .33333 L
s
.45238 .32958 m
.45238 .33333 L
s
.5 .32958 m
.5 .33333 L
s
.54762 .32958 m
.54762 .33333 L
s
.64286 .32958 m
.64286 .33333 L
s
.69048 .32958 m
.69048 .33333 L
s
.7381 .32958 m
.7381 .33333 L
s
.83333 .32958 m
.83333 .33333 L
s
.88095 .32958 m
.88095 .33333 L
s
.92857 .32958 m
.92857 .33333 L
s
.25 Mabswid
0 .33333 m
1 .33333 L
s
.99375 .00274 m
1 .00274 L
s
.99375 .0847 m
1 .0847 L
s
.99375 .16667 m
1 .16667 L
s
.99375 .24863 m
1 .24863 L
s
.99375 .33059 m
1 .33059 L
s
.125 Mabswid
.99625 .01914 m
1 .01914 L
s
.99625 .03553 m
1 .03553 L
s
.99625 .05192 m
1 .05192 L
s
.99625 .06831 m
1 .06831 L
s
.99625 .1011 m
1 .1011 L
s
.99625 .11749 m
1 .11749 L
s
.99625 .13388 m
1 .13388 L
s
.99625 .15027 m
1 .15027 L
s
.99625 .18306 m
1 .18306 L
s
.99625 .19945 m
1 .19945 L
s
.99625 .21584 m
1 .21584 L
s
.99625 .23224 m
1 .23224 L
s
.99625 .26502 m
1 .26502 L
s
.99625 .28141 m
1 .28141 L
s
.99625 .29781 m
1 .29781 L
s
.99625 .3142 m
1 .3142 L
s
.25 Mabswid
1 0 m
1 .33333 L
s
0 .16667 m
1 .16667 L
s
0 0 1 r
.5 Mabswid
.02381 .16667 m
.02381 .16667 L
s
.03333 .16667 m
.03333 .16667 L
s
.04286 .16667 m
.04286 .16667 L
s
.05238 .16667 m
.05238 .16667 L
s
.0619 .16667 m
.0619 .16667 L
s
.07143 .16667 m
.07143 .16667 L
s
.08095 .16667 m
.08095 .16667 L
s
.09048 .16667 m
.09048 .16667 L
s
.1 .16667 m
.1 .16667 L
s
.10952 .16667 m
.10952 .16667 L
s
.11905 .16667 m
.11905 .16667 L
s
.12857 .16667 m
.12857 .16667 L
s
.1381 .16667 m
.1381 .16667 L
s
.14762 .16667 m
.14762 .16667 L
s
.15714 .16667 m
.15714 .16667 L
s
.16667 .16667 m
.16667 .16667 L
s
.17619 .16667 m
.17619 .16667 L
s
.18571 .16667 m
.18571 .16667 L
s
.19524 .16667 m
.19524 .16667 L
s
.20476 .16667 m
.20476 .16667 L
s
.21429 .16667 m
.21429 .17978 L
s
.22381 .16667 m
.22381 .17718 L
s
.23333 .16667 m
.23333 .16974 L
s
.24286 .16667 m
.24286 .15904 L
s
.25238 .16667 m
.25238 .14873 L
s
.2619 .16667 m
.2619 .14424 L
s
.27143 .16667 m
.27143 .15049 L
s
.28095 .16667 m
.28095 .16837 L
s
.29048 .16667 m
.29048 .19214 L
s
.3 .16667 m
.3 .21032 L
s
.30952 .16667 m
.30952 .21068 L
s
.31905 .16667 m
.31905 .1874 L
s
.32857 .16667 m
.32857 .14651 L
s
.3381 .16667 m
.3381 .10558 L
s
.34762 .16667 m
.34762 .08647 L
s
.35714 .16667 m
.35714 .10407 L
s
.36667 .16667 m
.36667 .15659 L
s
.37619 .16667 m
.37619 .22342 L
s
.38571 .16667 m
.38571 .27301 L
s
.39524 .16667 m
.39524 .27794 L
s
.40476 .16667 m
.40476 .22978 L
s
.41429 .16667 m
.41429 .14589 L
s
.42381 .16667 m
.42381 .06339 L
s
.43333 .16667 m
.43333 .02231 L
s
.44286 .16667 m
.44286 .0457 L
s
.45238 .16667 m
.45238 .12685 L
s
.4619 .16667 m
.4619 .23069 L
s
.47143 .16667 m
.47143 .30944 L
s
.48095 .16667 m
.48095 .3254 L
s
.49048 .16667 m
.49048 .26957 L
s
.5 .16667 m
.5 .16667 L
s
.50952 .16667 m
.50952 .06377 L
s
.51905 .16667 m
.51905 .00794 L
s
.52857 .16667 m
.52857 .0239 L
s
.5381 .16667 m
.5381 .10264 L
s
.54762 .16667 m
.54762 .20648 L
s
.55714 .16667 m
.55714 .28763 L
s
.56667 .16667 m
.56667 .31102 L
s
.57619 .16667 m
.57619 .26995 L
s
.58571 .16667 m
.58571 .18745 L
s
.59524 .16667 m
.59524 .10356 L
s
.60476 .16667 m
.60476 .05539 L
s
.61429 .16667 m
.61429 .06032 L
s
.62381 .16667 m
.62381 .10992 L
s
.63333 .16667 m
.63333 .17674 L
s
.64286 .16667 m
.64286 .22926 L
s
.65238 .16667 m
.65238 .24686 L
s
.6619 .16667 m
.6619 .22776 L
s
.67143 .16667 m
.67143 .18682 L
s
.68095 .16667 m
.68095 .14594 L
s
.69048 .16667 m
.69048 .12266 L
s
.7 .16667 m
.7 .12301 L
s
.70952 .16667 m
.70952 .1412 L
s
.71905 .16667 m
.71905 .16497 L
s
.72857 .16667 m
.72857 .18284 L
s
.7381 .16667 m
.7381 .18909 L
s
.74762 .16667 m
.74762 .1846 L
s
.75714 .16667 m
.75714 .1743 L
s
.76667 .16667 m
.76667 .1636 L
s
.77619 .16667 m
.77619 .15615 L
s
.78571 .16667 m
.78571 .15355 L
s
.79524 .16667 m
.79524 .16667 L
s
.80476 .16667 m
.80476 .16667 L
s
.81429 .16667 m
.81429 .16667 L
s
.82381 .16667 m
.82381 .16667 L
s
.83333 .16667 m
.83333 .16667 L
s
.84286 .16667 m
.84286 .16667 L
s
.85238 .16667 m
.85238 .16667 L
s
.8619 .16667 m
.8619 .16667 L
s
.87143 .16667 m
.87143 .16667 L
s
.88095 .16667 m
.88095 .16667 L
s
.89048 .16667 m
.89048 .16667 L
s
.9 .16667 m
.9 .16667 L
s
.90952 .16667 m
.90952 .16667 L
s
.91905 .16667 m
.91905 .16667 L
s
.92857 .16667 m
.92857 .16667 L
s
.9381 .16667 m
.9381 .16667 L
s
.94762 .16667 m
.94762 .16667 L
s
.95714 .16667 m
.95714 .16667 L
s
.96667 .16667 m
.96667 .16667 L
s
.97619 .16667 m
.97619 .16667 L
s
.005 w
.02381 .16667 Mdot
.03333 .16667 Mdot
.04286 .16667 Mdot
.05238 .16667 Mdot
.0619 .16667 Mdot
.07143 .16667 Mdot
.08095 .16667 Mdot
.09048 .16667 Mdot
.1 .16667 Mdot
.10952 .16667 Mdot
.11905 .16667 Mdot
.12857 .16667 Mdot
.1381 .16667 Mdot
.14762 .16667 Mdot
.15714 .16667 Mdot
.16667 .16667 Mdot
.17619 .16667 Mdot
.18571 .16667 Mdot
.19524 .16667 Mdot
.20476 .16667 Mdot
.21429 .17978 Mdot
.22381 .17718 Mdot
.23333 .16974 Mdot
.24286 .15904 Mdot
.25238 .14873 Mdot
.2619 .14424 Mdot
.27143 .15049 Mdot
.28095 .16837 Mdot
.29048 .19214 Mdot
.3 .21032 Mdot
.30952 .21068 Mdot
.31905 .1874 Mdot
.32857 .14651 Mdot
.3381 .10558 Mdot
.34762 .08647 Mdot
.35714 .10407 Mdot
.36667 .15659 Mdot
.37619 .22342 Mdot
.38571 .27301 Mdot
.39524 .27794 Mdot
.40476 .22978 Mdot
.41429 .14589 Mdot
.42381 .06339 Mdot
.43333 .02231 Mdot
.44286 .0457 Mdot
.45238 .12685 Mdot
.4619 .23069 Mdot
.47143 .30944 Mdot
.48095 .3254 Mdot
.49048 .26957 Mdot
.5 .16667 Mdot
.50952 .06377 Mdot
.51905 .00794 Mdot
.52857 .0239 Mdot
.5381 .10264 Mdot
.54762 .20648 Mdot
.55714 .28763 Mdot
.56667 .31102 Mdot
.57619 .26995 Mdot
.58571 .18745 Mdot
.59524 .10356 Mdot
.60476 .05539 Mdot
.61429 .06032 Mdot
.62381 .10992 Mdot
.63333 .17674 Mdot
.64286 .22926 Mdot
.65238 .24686 Mdot
.6619 .22776 Mdot
.67143 .18682 Mdot
.68095 .14594 Mdot
.69048 .12266 Mdot
.7 .12301 Mdot
.70952 .1412 Mdot
.71905 .16497 Mdot
.72857 .18284 Mdot
.7381 .18909 Mdot
.74762 .1846 Mdot
.75714 .1743 Mdot
.76667 .1636 Mdot
.77619 .15615 Mdot
.78571 .15355 Mdot
.79524 .16667 Mdot
.80476 .16667 Mdot
.81429 .16667 Mdot
.82381 .16667 Mdot
.83333 .16667 Mdot
.84286 .16667 Mdot
.85238 .16667 Mdot
.8619 .16667 Mdot
.87143 .16667 Mdot
.88095 .16667 Mdot
.89048 .16667 Mdot
.9 .16667 Mdot
.90952 .16667 Mdot
.91905 .16667 Mdot
.92857 .16667 Mdot
.9381 .16667 Mdot
.94762 .16667 Mdot
.95714 .16667 Mdot
.96667 .16667 Mdot
.97619 .16667 Mdot
0 0 m
1 0 L
1 .33333 L
0 .33333 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{504, 168},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007h0000Z2000`400?l00000o`00003ooooooooi
ooooo`00<_ooool5o`0000?ooooo0_l0001=ooooo`;o0000C_ooool5o`0000?ooooo0_l0001=oooo
o`?o00000oooool2o`0004gooooo0ol00004ooooo`;o0000C?ooool3o`0000Cooooo0_l0000Eoooo
o`00<oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0004_ooooo00Co0000
oooooooooooo0000C_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0004go
oooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo04Wooooo00Go0000oooo
ooooooooooooo`000002ooooo`04o`000?ooooooooooo`0004[ooooo00Go0000oooooooooooooooo
o`000002ooooo`04o`000?ooooooooooo`0001Cooooo000/ooooo`Go00000oooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0004_ooooo00Co0000oooooooooooo0000Coooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0004[ooooo1Ol00002ooooo`04o`000?oooooo
ooooo`0004_ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0004[o
oooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0001Cooooo000eoooo
o`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`19ooooo`04o`000?oooooo
ooooo`00053ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo04Sooooo
00Co0000oooooooooooo00000oooool01?l0003oooooooooool0001;ooooo`Co00000oooool01?l0
003oooooooooool0001;ooooo`?o00000oooool01?l0003oooooooooool0000Dooooo`00<_ooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000Boooool01?l0003ooooo
ooooool0001=ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0001;
ooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooo0000Boooool00ol0003ooooooooo
o`04ooooo`04o`000?ooooooooooo`0004[ooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0001Cooooo000booooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0001;ooooo`04o`000?ooooooooooo`0004gooooo00Go0000oooooooooooooooo
o`000002ooooo`04o`000?ooooooooooo`0004cooooo0_l00003ooooo`04o`000?ooooooooooo`00
04cooooo00?o0000ooooooooool00oooool01?l0003oooooooooool0001:ooooo`05o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool0000Dooooo`00<oooool3o`0000Cooooo0_l0
001=ooooo`;o0000Coooool3o`0000Cooooo0_l0001>ooooo`03o`000?oooooooooo00;ooooo0_l0
001>ooooo`;o00001?ooool2o`0004cooooo0ol00004ooooo`;o00005Oooool00?oooooonOooool0
0?oooooonOooool00?oooooonOooool00?oooooonOooool00?oooooonOooool00?oooooonOooool0
01oooooo0ol0003oooooomOooooo000Pooooo`03o`000?oooooooooo00Ooooooool00031o`0000ko
oooo000Hooooo`Go00000oooool00ol0003oooooooooo`07ooooo`Co00001oooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01Oooool3o`0000kooooo
000Pooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0<ooooo`008?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool0D_ooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo033ooooo0_l00?lP
ooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00cooooo000Oooooo`;o00002Oooool00ol0003oooooooooo`3Uoooo
o`;o003oeOooool00ol0003oooooooooo`0<ooooo`008?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo0>Gooooo00?o003oooooooooool0e?ooool00ol0003oooooooooo`0<ooooo`00
:_ooool00ol0003oooooooooo`3Uooooo`03o`00oooooooooooo0=Cooooo00?o0000ooooooooool0
3?ooool002[ooooo00?o0000ooooooooool0iOooool00ol00?ooooooooooo`3Dooooo`03o`000?oo
oooooooo00cooooo000Zooooo`03o`000?oooooooooo0>Gooooo00?o003oooooooooool0e?ooool0
0ol0003oooooooooo`0<ooooo`00:_ooool3o`000>Gooooo00?o003oooooooooool0doooool2o`00
00kooooo000Zooooo`03o`000?oooooooooo0;kooooo0_l00?lUooooo`04o`00oooooooooooooooo
o`;o003odOooool00ol0003oooooooooo`0<ooooo`00:_ooool00ol0003oooooooooo`2nooooo`;o
003o9Oooool01?l00?ooooooooooooooool2o`00om7ooooo00?o0000ooooooooool03?ooool002[o
oooo00?o0000ooooooooool0_oooool00ol00?ooooooooooo`0Sooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool0coooool00ol0003oooooooooo`0<ooooo`00:_ooool00ol0003ooooo
ooooo`2oooooo`03o`00oooooooooooo02?ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`3?ooooo`03o`000?oooooooooo00cooooo000Zooooo`03o`000?oooooooooo0;oooooo00?o
003oooooooooool08oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo0<oooooo00?o
0000ooooooooool03?ooool002[ooooo00?o0000ooooooooool0_oooool00ol00?ooooooooooo`0S
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0coooool00ol0003oooooooooo`0<
ooooo`00:_ooool3o`000;oooooo00?o003oooooooooool08oooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo0<kooooo0_l0000>ooooo`00:_ooool00ol0003oooooooooo`2oooooo`03
o`00oooooooooooo02?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`3?ooooo`03
o`000?oooooooooo00cooooo000Zooooo`03o`000?oooooooooo0;oooooo00?o003oooooooooool0
8oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo0<oooooo00?o0000ooooooooool0
3?ooool002[ooooo00?o0000ooooooooool0_oooool00ol00?ooooooooooo`0Sooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool0coooool00ol0003oooooooooo`0<ooooo`00:_ooool0
0ol0003oooooooooo`2oooooo`04o`00ooooooooooooooooo`;o003o8?ooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo0<oooooo00?o0000ooooooooool03?ooool002[ooooo00?o0000
ooooooooool0_oooool01?l00?ooooooooooooooool2o`00ob3ooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`3?ooooo`03o`000?oooooooooo00cooooo000Zooooo`03o`000?oooooo
oooo0;oooooo00Go003oooooooooooooooooo`00o`0Qooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool0coooool00ol0003oooooooooo`0<ooooo`00:_ooool3o`000;oooooo00Go003o
ooooooooooooooooo`00o`0Qooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0c_oo
ool2o`0000kooooo000Zooooo`03o`000?oooooooooo0;oooooo00Go003oooooooooooooooooo`00
o`0Qooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool07_ooool2o`00ojoooooo00?o
0000ooooooooool03?ooool002[ooooo00?o0000ooooooooool0_oooool01Ol00?oooooooooooooo
oooo003o027ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Nooooo`;o003o[ooo
ool00ol0003oooooooooo`0<ooooo`00:_ooool00ol0003oooooooooo`2oooooo`05o`00oooooooo
ooooooooool00?l08Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01oooooo00?o
003oooooooooool0[Oooool00ol0003oooooooooo`0<ooooo`00:_ooool00ol0003oooooooooo`2o
ooooo`05o`00ooooooooooooooooool00?l08Oooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo01oooooo00?o003oooooooooool00_l00?n[ooooo`03o`000?oooooooooo00cooooo000Z
ooooo`03o`000?oooooooooo0;[ooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l07?oo
ool2o`00o`?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Oooooo`03o`00oooo
oooooooo00;o003oZoooool00ol0003oooooooooo`0<ooooo`00:_ooool00ol0003oooooooooo`2j
ooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o01cooooo0_l00?l3ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool07oooool01Ol00?oooooooooooooooooo003o0:_ooooo
00?o0000ooooooooool03?ooool002[ooooo00?o0000ooooooooool0^oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool06oooool01Ol00?oooooooooooooooooo003o00Co
oooo00?o003oooooooooool07oooool01Ol00?oooooooooooooooooo003o0:_ooooo00?o0000oooo
ooooool03?ooool002[ooooo0ol0002kooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`0O
ooooo`05o`00ooooooooooooooooool00?l0Z_ooool2o`0000kooooo000Zooooo`03o`000?oooooo
oooo0;_ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01_ooooo00Go
003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo01oooooo00Go003ooooooooooooo
ooooo`00o`2[ooooo`03o`000?oooooooooo00cooooo000Zooooo`03o`000?oooooooooo0;_ooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01_ooooo00Go003ooooooooo
ooooooooo`00o`04ooooo`03o`00oooooooooooo01oooooo00Go003oooooooooooooooooo`00o`2[
ooooo`03o`000?oooooooooo00cooooo000Zooooo`03o`000?oooooooooo0;_ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo01_ooooo00Go003oooooooooooooooooo`00
o`04ooooo`03o`00oooooooooooo01oooooo00Go003oooooooooooooooooo`00o`2[ooooo`03o`00
0?oooooooooo00cooooo000Dooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00002?oo
ool00ol0003oooooooooo`2kooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`0Kooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`0Oooooo`05
o`00ooooooooooooooooool00?l0Zoooool00ol0003oooooooooo`0<ooooo`004oooool01?l0003o
ooooooooool00007ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`2k
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Kooooo`05o`00oooo
ooooooooooooool00?l01?ooool00ol00?ooooooooooo`0Oooooo`05o`00ooooooooooooooooool0
0?l0Zoooool00ol0003oooooooooo`0<ooooo`003?ooool5o`0000;ooooo00Co0000oooooooooooo
00002oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;_ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo01_ooooo00Go003oooooooooooooooooo`00o`04
ooooo`03o`00oooooooooooo01oooooo00Go003oooooooooooooooooo`00o`2[ooooo`03o`000?oo
oooooooo00cooooo000Cooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool01Ooo
ool4o`0009Oooooo0_l00?lQooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`0Kooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`0Oooooo`05
o`00ooooooooooooooooool00?l0ZOooool3o`0000kooooo000Cooooo`04o`000?ooooooooooo`00
00Oooooo1?l00008ooooo`03o`000?oooooooooo09Sooooo0_l00?lQooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l01?oo
ool00ol00?ooooooooooo`0Oooooo`05o`00ooooooooooooooooool00?l0Zoooool00ol0003ooooo
ooooo`0<ooooo`004oooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool0VOooool00ol00?ooooooooooo`0Oooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l01?ooool00ol0
0?ooooooooooo`0Oooooo`05o`00ooooooooooooooooool00?l0Zoooool00ol0003oooooooooo`0<
ooooo`005?ooool2o`0000Sooooo1Ol00007ooooo`03o`000?oooooooooo09Wooooo00?o003ooooo
ooooool07oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool06oooool0
1Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool07oooool01Ol00?oooooooooo
oooooooo003o0:_ooooo00?o0000ooooooooool03?ooool002[ooooo00?o0000ooooooooool0VOoo
ool00ol00?ooooooooooo`0Oooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`0Kooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`0Oooooo`05
o`00ooooooooooooooooool00?l0Zoooool00ol0003oooooooooo`0<ooooo`00:_ooool00ol0003o
ooooooooo`2Iooooo`03o`00oooooooooooo01oooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo01_ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooo
oooo01oooooo00Go003oooooooooooooooooo`00o`2[ooooo`03o`000?oooooooooo00cooooo000Z
ooooo`03o`000?oooooooooo09Wooooo00?o003oooooooooool07oooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool06oooool01Ol00?oooooooooooooooooo003o00Cooooo
00?o003oooooooooool07oooool01Ol00?oooooooooooooooooo003o0:_ooooo00?o0000oooooooo
ool03?ooool002[ooooo0ol0002Iooooo`03o`00oooooooooooo01oooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo01_ooooo00Go003oooooooooooooooooo`00o`04oooo
o`03o`00oooooooooooo01oooooo00Go003oooooooooooooooooo`00o`2Zooooo`;o00003_ooool0
02[ooooo00?o0000ooooooooool0VOooool00ol00?ooooooooooo`02o`00oagooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo01_ooooo00Go003oooooooooooooooooo`00
o`04ooooo`03o`00oooooooooooo00;o003o6?ooool2o`00o`?ooooo00Go003ooooooooooooooooo
o`00o`2[ooooo`03o`000?oooooooooo00cooooo000Zooooo`03o`000?oooooooooo09Cooooo0_l0
0?l3ooooo`03o`00oooooooooooo00;o003o7Oooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool06oooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003ooooooooo
ool00_l00?lHooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o0:_ooooo00?o0000oooo
ooooool03?ooool002[ooooo00?o0000ooooooooool0U?ooool2o`00o`?ooooo00Go003ooooooooo
ooooooooo`00o`0Mooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0K
ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o01Sooooo
00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o0:_ooooo00?o0000oooooooo
ool03?ooool002[ooooo00?o0000ooooooooool0U?ooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l07Oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool06oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00
o`0Hooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`;o003o
Y_ooool00ol0003oooooooooo`0<ooooo`00:_ooool00ol0003oooooooooo`2Dooooo`03o`00oooo
oooooooo00;ooooo00Go003oooooooooooooooooo`00o`0Mooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol0
0?oooooooooooooooooo003o01Sooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooo
oooo003o00?ooooo0_l00?nVooooo`03o`000?oooooooooo00cooooo000Zooooo`03o`000?oooooo
oooo09Cooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o01gooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01_ooooo00Go003ooooooooooooo
ooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l06?ooool00ol00?ooooooooooo`02oooo
o`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`2Uooooo`03o`000?oooooo
oooo00cooooo000Zooooo`03o`000?oooooooooo09Cooooo00?o003oooooooooool00_ooool01Ol0
0?oooooooooooooooooo003o01gooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooo
oooooooo01_ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool0
0?l06?ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`2Uooooo`03o`000?oooooooooo00cooooo000Zooooo`?o0000U?ooool00ol00?oo
ooooooooo`02ooooo`05o`00ooooooooooooooooool00?l07Oooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o003oooooooooool06oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go
003oooooooooooooooooo`00o`0Hooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo0:Cooooo0_l0000>ooooo`00:_ooool00ol0003ooooo
ooooo`2Dooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`0Mooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Kooooo`05o`00oooooooooooo
ooooool00?l01?ooool01Ol00?oooooooooooooooooo003o01Sooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0YOooool00ol0003ooooo
ooooo`0<ooooo`00:_ooool00ol0003oooooooooo`2Dooooo`03o`00oooooooooooo00;ooooo00Go
003oooooooooooooooooo`00o`0Mooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo
003o01Sooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool06_ooool2o`00o`?ooooo0_l00?n4ooooo`03o`000?oooooooooo00cooooo000Z
ooooo`03o`000?oooooooooo09Cooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooo
oooo003o01gooooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00ooooooooooooooooo`;o
003o6?ooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`0H
ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooo
oooooooo01[ooooo0_l00?l3ooooo`;o003oQ?ooool00ol0003oooooooooo`0<ooooo`00:_ooool0
0ol0003oooooooooo`2Dooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00
o`0Mooooo`05o`00ooooooooooooooooool00?l00oooool01?l00?ooooooooooooooool2o`00oaSo
oooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l06?ooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`0Kooooo`05o`00ooooooooooooooooool00?l0QOooool00ol0003oooooooooo`0<ooooo`00:_oo
ool00ol0003oooooooooo`2Dooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`0Mooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
01Wooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l06?oo
ool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`0Kooooo`05o`00ooooooooooooooooool00?l0QOooool00ol0003oooooooooo`0<ooooo`00
:_ooool00ol0003oooooooooo`2Dooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooo
ooooo`00o`0Mooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o01Wooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l0
6?ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l0QOooool00ol0003oooooooooo`0<oooo
o`00:_ooool3o`0009Cooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
01gooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l06Ooo
ool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`0Hooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
01_ooooo00Go003oooooooooooooooooo`00o`24ooooo`;o00003_ooool002[ooooo00?o0000oooo
ooooool0U?ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l07Oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`0Iooooo`05o`00
ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o01Sooooo00?o003ooooo
ooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool06oooool0
1Ol00?oooooooooooooooooo003o08Gooooo00?o0000ooooooooool03?ooool002[ooooo00?o0000
ooooooooool0U?ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l07Ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`0Iooooo`05
o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o01Sooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool06ooo
ool01Ol00?oooooooooooooooooo003o08Gooooo00?o0000ooooooooool03?ooool002[ooooo00?o
0000ooooooooool0U?ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0
7Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`0Ioooo
o`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o01Sooooo00?o
003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
6oooool01Ol00?oooooooooooooooooo003o00?ooooo0_l00?n0ooooo`03o`000?oooooooooo00co
oooo000Zooooo`03o`000?oooooooooo07;ooooo0_l00?lPooooo`03o`00oooooooooooo00;ooooo
00Go003oooooooooooooooooo`00o`0Mooooo`05o`00ooooooooooooooooool00?l00oooool01Ol0
0?oooooooooooooooooo003o01Wooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooo
ooooooooooooool00?l06?ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l00oooool2o`00
oh3ooooo00?o0000ooooooooool03?ooool002[ooooo00?o0000ooooooooool0L_ooool2o`00oa_o
oooo0_l00?l3ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`0Hoooo
o`;o003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`0Iooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o01So
oooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool05_ooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo07oooooo00?o0000ooooooooool03?ooool002[ooooo00?o0000ooooooooool0KOooool2o`00
o`?ooooo00?o003oooooooooool06_ooool2o`00o`?ooooo00?o003oooooooooool00_ooool01Ol0
0?oooooooooooooooooo003o01Sooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o01Wooooo00Go003oooooooooooooooooo`00o`04ooooo`05
o`00ooooooooooooooooool00?l06?ooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`0Fooooo`;o003o0oooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool0Ooooool00ol0003oooooooooo`0<ooooo`00:_ooool3
o`0006gooooo0_l00?l3ooooo`04o`00ooooooooooooooooo`;o003o6?ooool01Ol00?oooooooooo
oooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`0Hooooo`03o`00oooooooooooo00;o
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l06Oooool0
1Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`0Hooooo`03o`00
oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01Oo
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0P?ooool2
o`0000kooooo000Zooooo`03o`000?oooooooooo06kooooo00Go003oooooooooooooooooo`00o`03
ooooo`;o003o6?ooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooooooooooooooo
o`00o`0Hooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l06Oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003o
ooooooooooooooooo`00o`0Hooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo01Oooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l08Oooool2o`00oekooooo00?o0000ooooooooool03?ooool002[o
oooo00?o0000ooooooooool0K_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool05oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00
o`0Hooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l06Oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooo
ooooooooooooo`00o`0Hooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo01Oooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l08Oooool2o`00oekooooo00?o0000ooooooooool03?ooool002[ooooo
00?o0000ooooooooool0K_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool05oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03
ooooo`;o003o4oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o01Wooooo00Go003oooooooooooooooooo`00o`04ooooo`05
o`00ooooooooooooooooool00?l06?ooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`0Gooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o01gooooo0_l00?l3ooooo`03o`00oooooooooooo05cooooo
00?o0000ooooooooool03?ooool002[ooooo00?o0000ooooooooool0JOooool2o`00o`?ooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01Oooooo00Go003ooooooooooooo
ooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool2o`00oa?ooooo00?o003ooooo
ooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`0Iooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o01So
oooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool05oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`0Mooooo`;o003o0oooool00ol00?ooooooooooo`1Looooo`03o`000?oooooooooo00cooooo000P
ooooo`;o00002?ooool00ol0003oooooooooo`1Yooooo`;o003o0oooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool05oooool01Ol00?oooooooooooooooooo003o00Cooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01;ooooo00?o003ooooooooo
ool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`0I
ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o01Sooooo
00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool05oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`0M
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0G?ooool00ol0003oooooooooo`0<
ooooo`007oooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo06[ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l06Oooool01Ol00?oooooo
oooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
01;ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`0Iooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooo
oooooooooooo003o01Sooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool05oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`;o003o4oooool2o`00o`?ooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`1Looooo`03o`000?oooooooooo00cooooo000Oooooo`04o`000?oooooo
ooooo`0000Oooooo00?o0000ooooooooool01oooool2o`00o`;ooooo0_l00?l3ooooo`;o003o0_oo
ool2o`00o`;ooooo0_l00?l2ooooo`;o003o0oooool2o`00o`;ooooo0_l00?l2ooooo`;o003o0_oo
ool2o`00o`?ooooo0_l00?l2ooooo`;o003o0_ooool2o`00o`?ooooo0_l00?l2ooooo`;o003o0_oo
ool2o`00o`;ooooo0_l00?l3ooooo`;o003o0_ooool2o`00o`;ooooo0_l00?l@ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o01Wooooo00Go003ooooooooo
ooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0B
ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l05?ooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05
o`00ooooooooooooooooool00?l06?ooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`0Gooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo0_l00?lCooooo`;o003o0oooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00;o003o0oooool2o`00o`;ooooo0_l00?l2ooooo`;o003o
0_ooool2o`00o`?ooooo0_l00?l2ooooo`;o003o0_ooool2o`00o`;ooooo0_l00?l3ooooo`;o003o
0_ooool2o`00o`;ooooo0_l00?l2ooooo`;o003o0oooool2o`00o`;ooooo0_l00?l2ooooo`;o003o
0_ooool2o`00o`?ooooo0_l00?l2ooooo`;o003o0_ooool2o`00o`Wooooo00?o0000ooooooooool0
3?ooool001oooooo00Co0000oooooooooooo00001oooool:o`0000;o003o0_l00002o`00o`?o0000
0_l00?l2o`0000;o003o0_l00002o`00o`;o00000_l00?l3o`0000;o003o0_l00002o`00o`;o0000
0_l00?l2o`0000;o003o0ol00002o`00o`;o00000_l00?l2o`0000;o003o0ol00002o`00o`;o0000
0_l00?l2o`0000;o003o0_l00002o`00o`?o00000_l00?l2o`0000;o003o0_l00002o`00o`?o0000
00Go003oo`000?l0003o0000o`00o`03o`000003o`00ool0003o000000;o000000Go003oo`000?l0
003o0000o`00o`03o`000005o`00ool0003o0000o`000?l00?l00ol00002o`00o`?o000000Go003o
o`000?l0003o0000o`00o`04o`000005o`00ool0003o0000o`000?l00?l00ol000001Ol00?oo0000
o`000?l0003o003o00Co000000Go003oo`000?l0003o0000o`00o`03o`000005o`00ool0003o0000
o`000?l00?l01?l000001Ol00?oo0000o`000?l0003o003o00?o000000Go003oo`000?l0003o0000
o`00o`04o`000005o`00ool0003o0000o`000?l00?l00ol000001Ol00?oo0000o`000?l0003o003o
00Co000000Go003oo`000?l0003o0000o`00o`03o`000005o`00ool0003o0000o`000?l00?l00ol0
0002o`00o`?o000000Go003oo`000?l0003o0000o`00o`04o`000005o`00ool0003o0000o`000?l0
0?l00ol000001Ol00?oo0000o`000?l0003o003o00Co000000Go003oo`000?l0003o0000o`00o`03
o`000005o`00ool0003o0000o`000?l00?l01?l000001Ol00?oo0000o`000?l0003o003o00?o0000
00Go003oo`000?l0003o0000o`00o`04o`000005o`00ool0003o0000o`000?l00?l00ol000001Ol0
0?oo0000o`000?l0003o003o00Co000000Go003oo`000?l0003o0000o`00o`03o`000005o`00ool0
003o0000o`000?l00?l01?l000001Ol00?oo0000o`000?l0003o003o00?o000000?o003oo`000?l0
00000_l000001Ol00?oo0000o`000?l0003o003o00?o000000Go003oo`000?l0003o0000o`00o`04
o`000003o`00ool0003o000000;o003o0ol00002o`00o`;o00000_l00?l2o`0000;o003o0_l00002
o`00o`?o00000_l00?l2o`0000;o003o0_l00002o`00o`;o00000_l00?l3o`0000;o003o0_l00002
o`00o`;o00000_l00?l2o`0000;o003o0ol00002o`00o`;o00000_l00?l2o`0000;o003o0_l00002
o`00o`?o00000_l00?l2o`0000;o003o0_l00002o`00o`[o00003_ooool001oooooo00Co0000oooo
oooooooo00001oooool00ol0003oooooooooo`1Mooooo`05o`00ooooooooooooooooool00?l00ooo
ool2o`00oa?ooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooo
oooooooooooo003o01Sooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool05oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`0Iooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`02ooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o01Wooooo00Go003o
ooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l0Joooool00ol0003ooooo
ooooo`0<ooooo`007oooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo05gooooo
00Go003oooooooooooooooooo`00o`03ooooo`;o003o6?ooool01Ol00?oooooooooooooooooo003o
00Cooooo00Go003oooooooooooooooooo`00o`0Hooooo`03o`00oooooooooooo00;ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01Oooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l06Oooool01Ol00?oooooooooooooooooo003o
00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01;ooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`0Iooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o
06_ooooo00?o0000ooooooooool03?ooool0023ooooo0_l00008ooooo`03o`000?oooooooooo05go
oooo00Go003oooooooooooooooooo`00o`0Mooooo`05o`00ooooooooooooooooool00?l01?ooool0
1Ol00?oooooooooooooooooo003o01Sooooo00?o003oooooooooool00_ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool05oooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`0Iooooo`05o`00ooooooooooooooooool00?l01?ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool04_ooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o01Wo
oooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo00;o003oJoooool00ol0
003oooooooooo`0<ooooo`00:_ooool00ol0003oooooooooo`1Mooooo`04o`00oooooooooooooooo
o`;o003o7?ooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00
o`0Hooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo01Oooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l06Oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo01;ooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o01Wooooo00Go003oooooooooooooooooo`00o`04oooo
o`03o`00oooooooooooo00;o003oJoooool00ol0003oooooooooo`0<ooooo`00:_ooool00ol0003o
ooooooooo`1Looooo`;o003o0oooool2o`00oacooooo00Go003oooooooooooooooooo`00o`04oooo
o`05o`00ooooooooooooooooool00?l06?ooool00ol00?ooooooooooo`02ooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`0Gooooo`05o`00ooooooooooooooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o01Wooooo00Go003oooooooooooooooooo`00o`04oooo
o`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Booooo`;o003o0oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`0Iooooo`05o`00
ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`1]ooooo`03o`000?oooooooooo00co
oooo000Zooooo`03o`000?oooooooooo05cooooo0_l00?lQooooo`05o`00ooooooooooooooooool0
0?l01?ooool01Ol00?oooooooooooooooooo003o01Sooooo00?o003oooooooooool00_ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool05oooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`0Iooooo`05o`00ooooooooooooooooool0
0?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool05oooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`0Hooooo`;o003o0ooo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo06gooooo00?o0000ooooooooool03?oo
ool002[ooooo0ol0001oooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooo
oooooooo003o01Sooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool05oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`0Iooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool05oooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`0Hooooo`;o003o0oooool01?l00?ooooooooooooooool2
o`00ofkooooo0_l0000>ooooo`00:_ooool00ol0003oooooooooo`1oooooo`05o`00oooooooooooo
ooooool00?l01?ooool00ol00?ooooooooooo`02o`00oaSooooo00?o003oooooooooool00_ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool05oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`0Iooooo`05o`00oooooooooooooooo
ool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool05oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Co003ooooooooooooooooo0_l00?lLooooo`04o`00
ooooooooooooooooo`;o003oKoooool00ol0003oooooooooo`0<ooooo`00:_ooool00ol0003ooooo
ooooo`1oooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`02o`00oaSo
oooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool05oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`0Iooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?o
oooo0_l00?lHooooo`05o`00ooooooooooooooooool00?l00oooool01?l00?ooooooooooooooool2
o`00oacooooo0_l00?mcooooo`03o`000?oooooooooo00cooooo000Zooooo`03o`000?oooooooooo
07oooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo01[ooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool05ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`0Iooooo`05
o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo0_l00?lH
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Oooooo`;o003oLooo
ool00ol0003oooooooooo`0<ooooo`00:_ooool00ol0003oooooooooo`1nooooo`;o003o0oooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01[ooooo00?o003oooooooooool00_ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool05oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`0Iooooo`05o`00oooooooooooooooo
ool00?l01?ooool01Ol00?oooooooooooooooooo003o01gooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo09Cooooo00?o0000ooooooooool03?ooool002[ooooo00?o0000
ooooooooool0O_ooool2o`00o`?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0J
ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooo
oooooooo01Oooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool0
0?l06Oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`0M
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`2Dooooo`03o`000?oo
oooooooo00cooooo000Zooooo`03o`000?oooooooooo08?ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo01Oooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l06Oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooo
ooooooooooooo`00o`0Mooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`2Dooooo`03o`000?oooooooooo00cooooo000Zooooo`?o0000Poooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo01[ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool05oooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`0Iooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol0
0?oooooooooooooooooo003o01gooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooo
oooooooo09?ooooo0_l0000>ooooo`00:_ooool00ol0003oooooooooo`23ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool06_ooool00ol00?ooooooooooo`02ooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`0Gooooo`05o`00ooooooooooooooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o01Wooooo00Go003oooooooooooooooooo`00o`04oooo
o`05o`00ooooooooooooooooool00?l07Oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool0U?ooool00ol0003oooooooooo`0<ooooo`00:_ooool00ol0003oooooooooo`23
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool06_ooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Gooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o01Wooooo00Go003ooooooooo
ooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l07Oooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool0U?ooool00ol0003oooooooooo`0<ooooo`00:_ooool0
0ol0003oooooooooo`23ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool06_ooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`0Gooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o01So
oooo0_l00?l3ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`0Moooo
o`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`2Dooooo`03o`000?oooooo
oooo00cooooo000Zooooo`03o`000?oooooooooo08?ooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`0Jooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo01Oooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l06?ooool2o`00o`?ooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o01gooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
09Cooooo00?o0000ooooooooool03?ooool002[ooooo00?o0000ooooooooool0Poooool2o`00o`;o
oooo0_l00?lLooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo01Oooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l07Oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0
7Oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0U?ooool00ol0003o
ooooooooo`0<ooooo`00:_ooool00ol0003oooooooooo`23ooooo`;o003o0_ooool2o`00oacooooo
00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool05oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`0M
ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`0Mooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`2Dooooo`03o`000?oooooooooo00cooooo
000Zooooo`03o`000?oooooooooo0:Gooooo00?o003oooooooooool00_ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool05oooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`0Mooooo`03o`00oooooooooooo00;ooooo00Go003ooooo
ooooooooooooo`00o`0Mooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`2Dooooo`03o`000?oooooooooo00cooooo000Zooooo`?o0000YOooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Gooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o01gooooo00?o003ooooooooo
ool00_ooool01Ol00?oooooooooooooooooo003o01gooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo09?ooooo0_l0000>ooooo`00:_ooool00ol0003oooooooooo`2Uoooo
o`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo01Oooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0
7Oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l07Oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool0U?ooool00ol0003oooooooooo`0<oooo
o`00:_ooool00ol0003oooooooooo`2Uooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo01Oooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l07Oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l07Oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool0U?ooool00ol0003oooooooooo`0<ooooo`00:_ooool00ol0003oooooooooo`2Uooooo`;o003o
0oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool05oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`0Mooooo`03o`00oooooooo
oooo00;ooooo00Go003oooooooooooooooooo`00o`0Mooooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`2Dooooo`03o`000?oooooooooo00cooooo000Zooooo`03o`000?oo
oooooooo0:Gooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`0Gooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
01gooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o01gooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo09Cooooo00?o0000ooooooooool03?oo
ool002[ooooo00?o0000ooooooooool0Z_ooool01Ol00?oooooooooooooooooo003o00?ooooo0_l0
0?lHooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o01go
oooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o01cooooo0_l00?l3oooo
o`04o`00ooooooooooooooooo`;o003oUOooool00ol0003oooooooooo`0<ooooo`00:_ooool00ol0
003oooooooooo`2Zooooo`05o`00ooooooooooooooooool00?l00oooool2o`00oaOooooo0_l00?l3
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Kooooo`03o`00oooo
oooooooo00;ooooo00Go003oooooooooooooooooo`00o`0Looooo`;o003o0oooool01?l00?oooooo
ooooooooool2o`00oiGooooo00?o0000ooooooooool03?ooool002[ooooo0ol0002Zooooo`05o`00
ooooooooooooooooool00?l07?ooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo01_ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo
003o027ooooo00?o003oooooooooool0Uoooool2o`0000kooooo000Zooooo`03o`000?oooooooooo
0:[ooooo00Go003oooooooooooooooooo`00o`0Qooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`0Qooooo`03o`00oooooooooooo09Sooooo00?o0000ooooooooool03?ooool002[ooooo00?o
0000ooooooooool0Z_ooool01Ol00?oooooooooooooooooo003o027ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool00_ooool01Ol00?oo
oooooooooooooooo003o027ooooo00?o003oooooooooool0V?ooool00ol0003oooooooooo`0<oooo
o`00:_ooool00ol0003oooooooooo`2Zooooo`05o`00ooooooooooooooooool00?l08Oooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l08Oooool00ol00?ooooooooooo`2Hooooo`03o`000?oo
oooooooo00cooooo000Zooooo`03o`000?oooooooooo0:[ooooo00Go003oooooooooooooooooo`00
o`0Qooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Kooooo`03o`00
oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`0Qooooo`03o`00oooooooooooo09So
oooo00?o0000ooooooooool03?ooool001Cooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo
0ol00008ooooo`03o`000?oooooooooo0:[ooooo00Go003oooooooooooooooooo`00o`0Qooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`0Qooooo`03o`00oooooooooooo09Sooooo00?o0000
ooooooooool03?ooool001?ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooo
oooo000000Oooooo00?o0000ooooooooool0Z_ooool01Ol00?oooooooooooooooooo003o027ooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01_ooooo00?o003ooooooooo
ool00_ooool01Ol00?oooooooooooooooooo003o023ooooo0_l00?nJooooo`03o`000?oooooooooo
00cooooo000Cooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool01Oooool4o`00
0:Wooooo00Go003oooooooooooooooooo`00o`0Qooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`0Pooooo`;o003oV?ooool3o`0000kooooo000Cooooo`04o`000?ooooooooooo`0000_ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`2Zooooo`05o`00ooooooooooooooooool0
0?l08Oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool06oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0_?ooool00ol0003oooooooooo`0<
ooooo`004oooool01?l0003oooooooooool00007ooooo`Co00002?ooool00ol0003oooooooooo`2Z
ooooo`05o`00ooooooooooooooooool00?l08Oooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool06oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l0_?ooool00ol0003oooooooooo`0<ooooo`004oooool01?l0003oooooooooool00007ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool0Z_ooool01Ol00?oooooooooooooooooo003o
027ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01_ooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o0;cooooo00?o0000ooooooooool03?oo
ool001Cooooo0_l00008ooooo`Go00001oooool00ol0003oooooooooo`2Zooooo`05o`00oooooooo
ooooooooool00?l08Oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
6oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0_?ooool00ol0003o
ooooooooo`0<ooooo`00:_ooool00ol0003oooooooooo`2Zooooo`05o`00ooooooooooooooooool0
0?l08Oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool06oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0_?ooool00ol0003oooooooooo`0<
ooooo`00:_ooool00ol0003oooooooooo`2Zooooo`05o`00ooooooooooooooooool00?l08Oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool06oooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l0_?ooool00ol0003oooooooooo`0<ooooo`00:_oo
ool00ol0003oooooooooo`2Zooooo`05o`00ooooooooooooooooool00?l08Oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`02ooooo`05
o`00ooooooooooooooooool00?l0_?ooool00ol0003oooooooooo`0<ooooo`00:_ooool3o`000:[o
oooo00Go003oooooooooooooooooo`00o`0Qooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00
o`2kooooo`;o00003_ooool002[ooooo00?o0000ooooooooool0Z_ooool01Ol00?oooooooooooooo
oooo003o027ooooo00Go003oooooooooooooooooo`00o`03ooooo`;o003o7?ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00;o003o_?ooool00ol0003oooooooooo`0<ooooo`00:_oo
ool00ol0003oooooooooo`2Zooooo`05o`00ooooooooooooooooool00?l08Oooool01Ol00?oooooo
oooooooooooo003o00?ooooo0_l00?lLooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool00_l00?nlooooo`03o`000?oooooooooo00cooooo000Zooooo`03o`000?oooooooooo0:Wooooo
0_l00?l3ooooo`03o`00oooooooooooo01oooooo00Go003oooooooooooooooooo`00o`0Qooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool0__ooool00ol0003oooooooooo`0<ooooo`00
:_ooool00ol0003oooooooooo`2Yooooo`;o003o0oooool00ol00?ooooooooooo`0Oooooo`05o`00
ooooooooooooooooool00?l08Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo0;ko
oooo00?o0000ooooooooool03?ooool002[ooooo00?o0000ooooooooool0[Oooool2o`00ob7ooooo
00Go003oooooooooooooooooo`00o`0Qooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool0__ooool00ol0003oooooooooo`0<ooooo`00:_ooool00ol0003oooooooooo`2]ooooo`;o003o
8Oooool01Ol00?oooooooooooooooooo003o027ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`2nooooo`03o`000?oooooooooo00cooooo000Zooooo`?o0000d?ooool01Ol00?oooooo
oooooooooooo003o027ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`2mooooo`;o
00003_ooool002[ooooo00?o0000ooooooooool0d?ooool01Ol00?oooooooooooooooooo003o027o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`2nooooo`03o`000?oooooooooo00co
oooo000Zooooo`03o`000?oooooooooo0=3ooooo00Go003oooooooooooooooooo`00o`0Qooooo`;o
003o0oooool00ol00?ooooooooooo`2nooooo`03o`000?oooooooooo00cooooo000Zooooo`03o`00
0?oooooooooo0=3ooooo00Go003oooooooooooooooooo`00o`0Qooooo`;o003o0oooool00ol00?oo
ooooooooo`2nooooo`03o`000?oooooooooo00cooooo000Zooooo`03o`000?oooooooooo0=3ooooo
00Go003oooooooooooooooooo`00o`0Vooooo`03o`00oooooooooooo0;kooooo00?o0000oooooooo
ool03?ooool002[ooooo00?o0000ooooooooool0d?ooool01Ol00?oooooooooooooooooo003o02Ko
oooo00?o003oooooooooool0__ooool00ol0003oooooooooo`0<ooooo`00:_ooool00ol0003ooooo
ooooo`3@ooooo`05o`00ooooooooooooooooool00?l09_ooool00ol00?ooooooooooo`2nooooo`03
o`000?oooooooooo00cooooo000Zooooo`?o0000d?ooool01Ol00?oooooooooooooooooo003o02Ko
oooo00?o003oooooooooool0_Oooool2o`0000kooooo000Zooooo`03o`000?oooooooooo0=3ooooo
00Go003oooooooooooooooooo`00o`0Vooooo`03o`00oooooooooooo0;kooooo00?o0000oooooooo
ool03?ooool002[ooooo00?o0000ooooooooool0d?ooool01Ol00?oooooooooooooooooo003o02Ko
oooo00?o003oooooooooool0__ooool00ol0003oooooooooo`0<ooooo`00:_ooool00ol0003ooooo
ooooo`3@ooooo`05o`00ooooooooooooooooool00?l09_ooool00ol00?ooooooooooo`2nooooo`03
o`000?oooooooooo00cooooo000Zooooo`03o`000?oooooooooo0=3ooooo00Go003ooooooooooooo
ooooo`00o`0Vooooo`03o`00oooooooooooo0;kooooo00?o0000ooooooooool03?ooool002[ooooo
00?o0000ooooooooool0coooool2o`00o`?ooooo00?o003oooooooooool09?ooool00ol00?oooooo
ooooo`2nooooo`03o`000?oooooooooo00cooooo000Zooooo`03o`000?oooooooooo0<oooooo0_l0
0?l3ooooo`03o`00oooooooooooo02?ooooo0_l00?o0ooooo`03o`000?oooooooooo00cooooo000Z
ooooo`03o`000?oooooooooo0=Cooooo00?o003oooooooooool08oooool2o`00ol3ooooo00?o0000
ooooooooool03?ooool002[ooooo0ol0003Dooooo`03o`00oooooooooooo0>Cooooo0_l0000>oooo
o`00:_ooool00ol0003oooooooooo`3Dooooo`03o`00oooooooooooo0>Gooooo00?o0000oooooooo
ool03?ooool002[ooooo00?o0000ooooooooool0e?ooool00ol00?ooooooooooo`3Uooooo`03o`00
0?oooooooooo00cooooo000Zooooo`03o`000?oooooooooo0=Cooooo00?o003oooooooooool0iOoo
ool00ol0003oooooooooo`0<ooooo`007oooool3o`0000Sooooo00?o0000ooooooooool0e?ooool2
o`00onKooooo00?o0000ooooooooool03?ooool0023ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0D_ooool00ol0
003oooooooooo`0Oooooo`;o003o<Oooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo
05;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0<ooooo`008?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0D_ooool00ol0003o
ooooooooo`1Booooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0Doooool00ol0003o
ooooooooo`1Booooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03?ooool0023ooooo
00?o0000ooooooooool01oooool4o`0000Oooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo00Gooooo0ol0000>ooooo`008?ooool00ol0003ooooooooo
o`07oooooooo0000`Ol0000>ooooo`007oooool2o`000?oooooof?ooool0023ooooo00?o0000oooo
ooooool0oooooooFooooo`00oooooooiooooo`00\
\>"],
  ImageRangeCache->{{{0, 503}, {167, 0}} -> {-32.4822, -1.21572, 0.234689, \
0.0136352}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Show together", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[GraphicsArray[{{gwa}, {gwb}, {gwc}}], \ 
        ImageSize \[Rule] 504];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.06667 
%%ImageSize: 504 537.6 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0253968 0.952381 [
[ 0 0 0 0 ]
[ 1 1.06667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.06667 L
0 1.06667 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0253968 0.97619 0.342857 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.214286 0.00952381 0.166667 0.163924 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.21429 -0.0125 -3 -9 ]
[.21429 -0.0125 3 0 ]
[.40476 -0.0125 -6 -9 ]
[.40476 -0.0125 6 0 ]
[.59524 -0.0125 -6 -9 ]
[.59524 -0.0125 6 0 ]
[.78571 -0.0125 -6 -9 ]
[.78571 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00274 -12 -4.5 ]
[-0.0125 .00274 0 4.5 ]
[-0.0125 .0847 -24 -4.5 ]
[-0.0125 .0847 0 4.5 ]
[-0.0125 .16667 -6 -4.5 ]
[-0.0125 .16667 0 4.5 ]
[-0.0125 .24863 -18 -4.5 ]
[-0.0125 .24863 0 4.5 ]
[-0.0125 .33059 -6 -4.5 ]
[-0.0125 .33059 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .33333 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-20)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(0)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(20)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(40)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(60)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(80)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00274 m
.00625 .00274 L
s
[(-1)] -0.0125 .00274 1 0 Mshowa
0 .0847 m
.00625 .0847 L
s
[(-0.5)] -0.0125 .0847 1 0 Mshowa
0 .16667 m
.00625 .16667 L
s
[(0)] -0.0125 .16667 1 0 Mshowa
0 .24863 m
.00625 .24863 L
s
[(0.5)] -0.0125 .24863 1 0 Mshowa
0 .33059 m
.00625 .33059 L
s
[(1)] -0.0125 .33059 1 0 Mshowa
.125 Mabswid
0 .01914 m
.00375 .01914 L
s
0 .03553 m
.00375 .03553 L
s
0 .05192 m
.00375 .05192 L
s
0 .06831 m
.00375 .06831 L
s
0 .1011 m
.00375 .1011 L
s
0 .11749 m
.00375 .11749 L
s
0 .13388 m
.00375 .13388 L
s
0 .15027 m
.00375 .15027 L
s
0 .18306 m
.00375 .18306 L
s
0 .19945 m
.00375 .19945 L
s
0 .21584 m
.00375 .21584 L
s
0 .23224 m
.00375 .23224 L
s
0 .26502 m
.00375 .26502 L
s
0 .28141 m
.00375 .28141 L
s
0 .29781 m
.00375 .29781 L
s
0 .3142 m
.00375 .3142 L
s
.25 Mabswid
0 0 m
0 .33333 L
s
.02381 .32708 m
.02381 .33333 L
s
.21429 .32708 m
.21429 .33333 L
s
.40476 .32708 m
.40476 .33333 L
s
.59524 .32708 m
.59524 .33333 L
s
.78571 .32708 m
.78571 .33333 L
s
.97619 .32708 m
.97619 .33333 L
s
.125 Mabswid
.07143 .32958 m
.07143 .33333 L
s
.11905 .32958 m
.11905 .33333 L
s
.16667 .32958 m
.16667 .33333 L
s
.2619 .32958 m
.2619 .33333 L
s
.30952 .32958 m
.30952 .33333 L
s
.35714 .32958 m
.35714 .33333 L
s
.45238 .32958 m
.45238 .33333 L
s
.5 .32958 m
.5 .33333 L
s
.54762 .32958 m
.54762 .33333 L
s
.64286 .32958 m
.64286 .33333 L
s
.69048 .32958 m
.69048 .33333 L
s
.7381 .32958 m
.7381 .33333 L
s
.83333 .32958 m
.83333 .33333 L
s
.88095 .32958 m
.88095 .33333 L
s
.92857 .32958 m
.92857 .33333 L
s
.25 Mabswid
0 .33333 m
1 .33333 L
s
.99375 .00274 m
1 .00274 L
s
.99375 .0847 m
1 .0847 L
s
.99375 .16667 m
1 .16667 L
s
.99375 .24863 m
1 .24863 L
s
.99375 .33059 m
1 .33059 L
s
.125 Mabswid
.99625 .01914 m
1 .01914 L
s
.99625 .03553 m
1 .03553 L
s
.99625 .05192 m
1 .05192 L
s
.99625 .06831 m
1 .06831 L
s
.99625 .1011 m
1 .1011 L
s
.99625 .11749 m
1 .11749 L
s
.99625 .13388 m
1 .13388 L
s
.99625 .15027 m
1 .15027 L
s
.99625 .18306 m
1 .18306 L
s
.99625 .19945 m
1 .19945 L
s
.99625 .21584 m
1 .21584 L
s
.99625 .23224 m
1 .23224 L
s
.99625 .26502 m
1 .26502 L
s
.99625 .28141 m
1 .28141 L
s
.99625 .29781 m
1 .29781 L
s
.99625 .3142 m
1 .3142 L
s
.25 Mabswid
1 0 m
1 .33333 L
s
0 .16667 m
1 .16667 L
s
0 0 1 r
.5 Mabswid
.02381 .16667 m
.02381 .16667 L
s
.03333 .16667 m
.03333 .16667 L
s
.04286 .16667 m
.04286 .16667 L
s
.05238 .16667 m
.05238 .16667 L
s
.0619 .16667 m
.0619 .16667 L
s
.07143 .16667 m
.07143 .16667 L
s
.08095 .16667 m
.08095 .16667 L
s
.09048 .16667 m
.09048 .16667 L
s
.1 .16667 m
.1 .16667 L
s
.10952 .16667 m
.10952 .16667 L
s
.11905 .16667 m
.11905 .16667 L
s
.12857 .16667 m
.12857 .16667 L
s
.1381 .16667 m
.1381 .16667 L
s
.14762 .16667 m
.14762 .16667 L
s
.15714 .16667 m
.15714 .16667 L
s
.16667 .16667 m
.16667 .16667 L
s
.17619 .16667 m
.17619 .16667 L
s
.18571 .16667 m
.18571 .16667 L
s
.19524 .16667 m
.19524 .16667 L
s
.20476 .16667 m
.20476 .16667 L
s
.21429 .16667 m
.21429 .17978 L
s
.22381 .16667 m
.22381 .17718 L
s
.23333 .16667 m
.23333 .16974 L
s
.24286 .16667 m
.24286 .15904 L
s
.25238 .16667 m
.25238 .14873 L
s
.2619 .16667 m
.2619 .14424 L
s
.27143 .16667 m
.27143 .15049 L
s
.28095 .16667 m
.28095 .16837 L
s
.29048 .16667 m
.29048 .19214 L
s
.3 .16667 m
.3 .21032 L
s
.30952 .16667 m
.30952 .21068 L
s
.31905 .16667 m
.31905 .1874 L
s
.32857 .16667 m
.32857 .14651 L
s
.3381 .16667 m
.3381 .10558 L
s
.34762 .16667 m
.34762 .08647 L
s
.35714 .16667 m
.35714 .10407 L
s
.36667 .16667 m
.36667 .15659 L
s
.37619 .16667 m
.37619 .22342 L
s
.38571 .16667 m
.38571 .27301 L
s
.39524 .16667 m
.39524 .27794 L
s
.40476 .16667 m
.40476 .22978 L
s
.41429 .16667 m
.41429 .14589 L
s
.42381 .16667 m
.42381 .06339 L
s
.43333 .16667 m
.43333 .02231 L
s
.44286 .16667 m
.44286 .0457 L
s
.45238 .16667 m
.45238 .12685 L
s
.4619 .16667 m
.4619 .23069 L
s
.47143 .16667 m
.47143 .30944 L
s
.48095 .16667 m
.48095 .3254 L
s
.49048 .16667 m
.49048 .26957 L
s
.5 .16667 m
.5 .16667 L
s
.50952 .16667 m
.50952 .06377 L
s
.51905 .16667 m
.51905 .00794 L
s
.52857 .16667 m
.52857 .0239 L
s
.5381 .16667 m
.5381 .10264 L
s
.54762 .16667 m
.54762 .20648 L
s
.55714 .16667 m
.55714 .28763 L
s
.56667 .16667 m
.56667 .31102 L
s
.57619 .16667 m
.57619 .26995 L
s
.58571 .16667 m
.58571 .18745 L
s
.59524 .16667 m
.59524 .10356 L
s
.60476 .16667 m
.60476 .05539 L
s
.61429 .16667 m
.61429 .06032 L
s
.62381 .16667 m
.62381 .10992 L
s
.63333 .16667 m
.63333 .17674 L
s
.64286 .16667 m
.64286 .22926 L
s
.65238 .16667 m
.65238 .24686 L
s
.6619 .16667 m
.6619 .22776 L
s
.67143 .16667 m
.67143 .18682 L
s
.68095 .16667 m
.68095 .14594 L
s
.69048 .16667 m
.69048 .12266 L
s
.7 .16667 m
.7 .12301 L
s
.70952 .16667 m
.70952 .1412 L
s
.71905 .16667 m
.71905 .16497 L
s
.72857 .16667 m
.72857 .18284 L
s
.7381 .16667 m
.7381 .18909 L
s
.74762 .16667 m
.74762 .1846 L
s
.75714 .16667 m
.75714 .1743 L
s
.76667 .16667 m
.76667 .1636 L
s
.77619 .16667 m
.77619 .15615 L
s
.78571 .16667 m
.78571 .15355 L
s
.79524 .16667 m
.79524 .16667 L
s
.80476 .16667 m
.80476 .16667 L
s
.81429 .16667 m
.81429 .16667 L
s
.82381 .16667 m
.82381 .16667 L
s
.83333 .16667 m
.83333 .16667 L
s
.84286 .16667 m
.84286 .16667 L
s
.85238 .16667 m
.85238 .16667 L
s
.8619 .16667 m
.8619 .16667 L
s
.87143 .16667 m
.87143 .16667 L
s
.88095 .16667 m
.88095 .16667 L
s
.89048 .16667 m
.89048 .16667 L
s
.9 .16667 m
.9 .16667 L
s
.90952 .16667 m
.90952 .16667 L
s
.91905 .16667 m
.91905 .16667 L
s
.92857 .16667 m
.92857 .16667 L
s
.9381 .16667 m
.9381 .16667 L
s
.94762 .16667 m
.94762 .16667 L
s
.95714 .16667 m
.95714 .16667 L
s
.96667 .16667 m
.96667 .16667 L
s
.97619 .16667 m
.97619 .16667 L
s
.005 w
.02381 .16667 Mdot
.03333 .16667 Mdot
.04286 .16667 Mdot
.05238 .16667 Mdot
.0619 .16667 Mdot
.07143 .16667 Mdot
.08095 .16667 Mdot
.09048 .16667 Mdot
.1 .16667 Mdot
.10952 .16667 Mdot
.11905 .16667 Mdot
.12857 .16667 Mdot
.1381 .16667 Mdot
.14762 .16667 Mdot
.15714 .16667 Mdot
.16667 .16667 Mdot
.17619 .16667 Mdot
.18571 .16667 Mdot
.19524 .16667 Mdot
.20476 .16667 Mdot
.21429 .17978 Mdot
.22381 .17718 Mdot
.23333 .16974 Mdot
.24286 .15904 Mdot
.25238 .14873 Mdot
.2619 .14424 Mdot
.27143 .15049 Mdot
.28095 .16837 Mdot
.29048 .19214 Mdot
.3 .21032 Mdot
.30952 .21068 Mdot
.31905 .1874 Mdot
.32857 .14651 Mdot
.3381 .10558 Mdot
.34762 .08647 Mdot
.35714 .10407 Mdot
.36667 .15659 Mdot
.37619 .22342 Mdot
.38571 .27301 Mdot
.39524 .27794 Mdot
.40476 .22978 Mdot
.41429 .14589 Mdot
.42381 .06339 Mdot
.43333 .02231 Mdot
.44286 .0457 Mdot
.45238 .12685 Mdot
.4619 .23069 Mdot
.47143 .30944 Mdot
.48095 .3254 Mdot
.49048 .26957 Mdot
.5 .16667 Mdot
.50952 .06377 Mdot
.51905 .00794 Mdot
.52857 .0239 Mdot
.5381 .10264 Mdot
.54762 .20648 Mdot
.55714 .28763 Mdot
.56667 .31102 Mdot
.57619 .26995 Mdot
.58571 .18745 Mdot
.59524 .10356 Mdot
.60476 .05539 Mdot
.61429 .06032 Mdot
.62381 .10992 Mdot
.63333 .17674 Mdot
.64286 .22926 Mdot
.65238 .24686 Mdot
.6619 .22776 Mdot
.67143 .18682 Mdot
.68095 .14594 Mdot
.69048 .12266 Mdot
.7 .12301 Mdot
.70952 .1412 Mdot
.71905 .16497 Mdot
.72857 .18284 Mdot
.7381 .18909 Mdot
.74762 .1846 Mdot
.75714 .1743 Mdot
.76667 .1636 Mdot
.77619 .15615 Mdot
.78571 .15355 Mdot
.79524 .16667 Mdot
.80476 .16667 Mdot
.81429 .16667 Mdot
.82381 .16667 Mdot
.83333 .16667 Mdot
.84286 .16667 Mdot
.85238 .16667 Mdot
.8619 .16667 Mdot
.87143 .16667 Mdot
.88095 .16667 Mdot
.89048 .16667 Mdot
.9 .16667 Mdot
.90952 .16667 Mdot
.91905 .16667 Mdot
.92857 .16667 Mdot
.9381 .16667 Mdot
.94762 .16667 Mdot
.95714 .16667 Mdot
.96667 .16667 Mdot
.97619 .16667 Mdot
0 0 m
1 0 L
1 .33333 L
0 .33333 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.374603 0.97619 0.692063 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.214286 0.00952381 0.00793651 0.31746 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.21429 -0.0125 -3 -9 ]
[.21429 -0.0125 3 0 ]
[.40476 -0.0125 -6 -9 ]
[.40476 -0.0125 6 0 ]
[.59524 -0.0125 -6 -9 ]
[.59524 -0.0125 6 0 ]
[.78571 -0.0125 -6 -9 ]
[.78571 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00794 -6 -4.5 ]
[-0.0125 .00794 0 4.5 ]
[-0.0125 .07143 -18 -4.5 ]
[-0.0125 .07143 0 4.5 ]
[-0.0125 .13492 -18 -4.5 ]
[-0.0125 .13492 0 4.5 ]
[-0.0125 .19841 -18 -4.5 ]
[-0.0125 .19841 0 4.5 ]
[-0.0125 .2619 -18 -4.5 ]
[-0.0125 .2619 0 4.5 ]
[-0.0125 .3254 -6 -4.5 ]
[-0.0125 .3254 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .33333 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-20)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(0)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(20)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(40)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(60)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(80)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00794 m
.00625 .00794 L
s
[(0)] -0.0125 .00794 1 0 Mshowa
0 .07143 m
.00625 .07143 L
s
[(0.2)] -0.0125 .07143 1 0 Mshowa
0 .13492 m
.00625 .13492 L
s
[(0.4)] -0.0125 .13492 1 0 Mshowa
0 .19841 m
.00625 .19841 L
s
[(0.6)] -0.0125 .19841 1 0 Mshowa
0 .2619 m
.00625 .2619 L
s
[(0.8)] -0.0125 .2619 1 0 Mshowa
0 .3254 m
.00625 .3254 L
s
[(1)] -0.0125 .3254 1 0 Mshowa
.125 Mabswid
0 .02381 m
.00375 .02381 L
s
0 .03968 m
.00375 .03968 L
s
0 .05556 m
.00375 .05556 L
s
0 .0873 m
.00375 .0873 L
s
0 .10317 m
.00375 .10317 L
s
0 .11905 m
.00375 .11905 L
s
0 .15079 m
.00375 .15079 L
s
0 .16667 m
.00375 .16667 L
s
0 .18254 m
.00375 .18254 L
s
0 .21429 m
.00375 .21429 L
s
0 .23016 m
.00375 .23016 L
s
0 .24603 m
.00375 .24603 L
s
0 .27778 m
.00375 .27778 L
s
0 .29365 m
.00375 .29365 L
s
0 .30952 m
.00375 .30952 L
s
.25 Mabswid
0 0 m
0 .33333 L
s
.02381 .32708 m
.02381 .33333 L
s
.21429 .32708 m
.21429 .33333 L
s
.40476 .32708 m
.40476 .33333 L
s
.59524 .32708 m
.59524 .33333 L
s
.78571 .32708 m
.78571 .33333 L
s
.97619 .32708 m
.97619 .33333 L
s
.125 Mabswid
.07143 .32958 m
.07143 .33333 L
s
.11905 .32958 m
.11905 .33333 L
s
.16667 .32958 m
.16667 .33333 L
s
.2619 .32958 m
.2619 .33333 L
s
.30952 .32958 m
.30952 .33333 L
s
.35714 .32958 m
.35714 .33333 L
s
.45238 .32958 m
.45238 .33333 L
s
.5 .32958 m
.5 .33333 L
s
.54762 .32958 m
.54762 .33333 L
s
.64286 .32958 m
.64286 .33333 L
s
.69048 .32958 m
.69048 .33333 L
s
.7381 .32958 m
.7381 .33333 L
s
.83333 .32958 m
.83333 .33333 L
s
.88095 .32958 m
.88095 .33333 L
s
.92857 .32958 m
.92857 .33333 L
s
.25 Mabswid
0 .33333 m
1 .33333 L
s
.99375 .00794 m
1 .00794 L
s
.99375 .07143 m
1 .07143 L
s
.99375 .13492 m
1 .13492 L
s
.99375 .19841 m
1 .19841 L
s
.99375 .2619 m
1 .2619 L
s
.99375 .3254 m
1 .3254 L
s
.125 Mabswid
.99625 .02381 m
1 .02381 L
s
.99625 .03968 m
1 .03968 L
s
.99625 .05556 m
1 .05556 L
s
.99625 .0873 m
1 .0873 L
s
.99625 .10317 m
1 .10317 L
s
.99625 .11905 m
1 .11905 L
s
.99625 .15079 m
1 .15079 L
s
.99625 .16667 m
1 .16667 L
s
.99625 .18254 m
1 .18254 L
s
.99625 .21429 m
1 .21429 L
s
.99625 .23016 m
1 .23016 L
s
.99625 .24603 m
1 .24603 L
s
.99625 .27778 m
1 .27778 L
s
.99625 .29365 m
1 .29365 L
s
.99625 .30952 m
1 .30952 L
s
.25 Mabswid
1 0 m
1 .33333 L
s
0 .00794 m
1 .00794 L
s
0 0 1 r
.5 Mabswid
.02381 .00794 m
.02381 .00794 L
s
.03333 .00794 m
.03333 .00794 L
s
.04286 .00794 m
.04286 .00794 L
s
.05238 .00794 m
.05238 .00794 L
s
.0619 .00794 m
.0619 .00794 L
s
.07143 .00794 m
.07143 .00794 L
s
.08095 .00794 m
.08095 .00794 L
s
.09048 .00794 m
.09048 .00794 L
s
.1 .00794 m
.1 .00794 L
s
.10952 .00794 m
.10952 .00794 L
s
.11905 .00794 m
.11905 .00794 L
s
.12857 .00794 m
.12857 .00794 L
s
.1381 .00794 m
.1381 .00794 L
s
.14762 .00794 m
.14762 .00794 L
s
.15714 .00794 m
.15714 .00794 L
s
.16667 .00794 m
.16667 .00794 L
s
.17619 .00794 m
.17619 .00794 L
s
.18571 .00794 m
.18571 .00794 L
s
.19524 .00794 m
.19524 .00794 L
s
.20476 .00794 m
.20476 .00794 L
s
.21429 .00794 m
.21429 .03333 L
s
.22381 .00794 m
.22381 .03413 L
s
.23333 .00794 m
.23333 .03652 L
s
.24286 .00794 m
.24286 .04048 L
s
.25238 .00794 m
.25238 .04596 L
s
.2619 .00794 m
.2619 .0529 L
s
.27143 .00794 m
.27143 .06122 L
s
.28095 .00794 m
.28095 .07084 L
s
.29048 .00794 m
.29048 .08165 L
s
.3 .00794 m
.3 .09353 L
s
.30952 .00794 m
.30952 .10635 L
s
.31905 .00794 m
.31905 .11997 L
s
.32857 .00794 m
.32857 .13424 L
s
.3381 .00794 m
.3381 .149 L
s
.34762 .00794 m
.34762 .1641 L
s
.35714 .00794 m
.35714 .17937 L
s
.36667 .00794 m
.36667 .19463 L
s
.37619 .00794 m
.37619 .20973 L
s
.38571 .00794 m
.38571 .22449 L
s
.39524 .00794 m
.39524 .23876 L
s
.40476 .00794 m
.40476 .25238 L
s
.41429 .00794 m
.41429 .2652 L
s
.42381 .00794 m
.42381 .27708 L
s
.43333 .00794 m
.43333 .28789 L
s
.44286 .00794 m
.44286 .29751 L
s
.45238 .00794 m
.45238 .30583 L
s
.4619 .00794 m
.4619 .31277 L
s
.47143 .00794 m
.47143 .31825 L
s
.48095 .00794 m
.48095 .32221 L
s
.49048 .00794 m
.49048 .3246 L
s
.5 .00794 m
.5 .3254 L
s
.50952 .00794 m
.50952 .3246 L
s
.51905 .00794 m
.51905 .32221 L
s
.52857 .00794 m
.52857 .31825 L
s
.5381 .00794 m
.5381 .31277 L
s
.54762 .00794 m
.54762 .30583 L
s
.55714 .00794 m
.55714 .29751 L
s
.56667 .00794 m
.56667 .28789 L
s
.57619 .00794 m
.57619 .27708 L
s
.58571 .00794 m
.58571 .2652 L
s
.59524 .00794 m
.59524 .25238 L
s
.60476 .00794 m
.60476 .23876 L
s
.61429 .00794 m
.61429 .22449 L
s
.62381 .00794 m
.62381 .20973 L
s
.63333 .00794 m
.63333 .19463 L
s
.64286 .00794 m
.64286 .17937 L
s
.65238 .00794 m
.65238 .1641 L
s
.6619 .00794 m
.6619 .149 L
s
.67143 .00794 m
.67143 .13424 L
s
.68095 .00794 m
.68095 .11997 L
s
.69048 .00794 m
.69048 .10635 L
s
.7 .00794 m
.7 .09353 L
s
.70952 .00794 m
.70952 .08165 L
s
.71905 .00794 m
.71905 .07084 L
s
.72857 .00794 m
.72857 .06122 L
s
.7381 .00794 m
.7381 .0529 L
s
.74762 .00794 m
.74762 .04596 L
s
.75714 .00794 m
.75714 .04048 L
s
.76667 .00794 m
.76667 .03652 L
s
.77619 .00794 m
.77619 .03413 L
s
.78571 .00794 m
.78571 .03333 L
s
.79524 .00794 m
.79524 .00794 L
s
.80476 .00794 m
.80476 .00794 L
s
.81429 .00794 m
.81429 .00794 L
s
.82381 .00794 m
.82381 .00794 L
s
.83333 .00794 m
.83333 .00794 L
s
.84286 .00794 m
.84286 .00794 L
s
.85238 .00794 m
.85238 .00794 L
s
.8619 .00794 m
.8619 .00794 L
s
.87143 .00794 m
.87143 .00794 L
s
.88095 .00794 m
.88095 .00794 L
s
.89048 .00794 m
.89048 .00794 L
s
.9 .00794 m
.9 .00794 L
s
.90952 .00794 m
.90952 .00794 L
s
.91905 .00794 m
.91905 .00794 L
s
.92857 .00794 m
.92857 .00794 L
s
.9381 .00794 m
.9381 .00794 L
s
.94762 .00794 m
.94762 .00794 L
s
.95714 .00794 m
.95714 .00794 L
s
.96667 .00794 m
.96667 .00794 L
s
.97619 .00794 m
.97619 .00794 L
s
.005 w
.02381 .00794 Mdot
.03333 .00794 Mdot
.04286 .00794 Mdot
.05238 .00794 Mdot
.0619 .00794 Mdot
.07143 .00794 Mdot
.08095 .00794 Mdot
.09048 .00794 Mdot
.1 .00794 Mdot
.10952 .00794 Mdot
.11905 .00794 Mdot
.12857 .00794 Mdot
.1381 .00794 Mdot
.14762 .00794 Mdot
.15714 .00794 Mdot
.16667 .00794 Mdot
.17619 .00794 Mdot
.18571 .00794 Mdot
.19524 .00794 Mdot
.20476 .00794 Mdot
.21429 .03333 Mdot
.22381 .03413 Mdot
.23333 .03652 Mdot
.24286 .04048 Mdot
.25238 .04596 Mdot
.2619 .0529 Mdot
.27143 .06122 Mdot
.28095 .07084 Mdot
.29048 .08165 Mdot
.3 .09353 Mdot
.30952 .10635 Mdot
.31905 .11997 Mdot
.32857 .13424 Mdot
.3381 .149 Mdot
.34762 .1641 Mdot
.35714 .17937 Mdot
.36667 .19463 Mdot
.37619 .20973 Mdot
.38571 .22449 Mdot
.39524 .23876 Mdot
.40476 .25238 Mdot
.41429 .2652 Mdot
.42381 .27708 Mdot
.43333 .28789 Mdot
.44286 .29751 Mdot
.45238 .30583 Mdot
.4619 .31277 Mdot
.47143 .31825 Mdot
.48095 .32221 Mdot
.49048 .3246 Mdot
.5 .3254 Mdot
.50952 .3246 Mdot
.51905 .32221 Mdot
.52857 .31825 Mdot
.5381 .31277 Mdot
.54762 .30583 Mdot
.55714 .29751 Mdot
.56667 .28789 Mdot
.57619 .27708 Mdot
.58571 .2652 Mdot
.59524 .25238 Mdot
.60476 .23876 Mdot
.61429 .22449 Mdot
.62381 .20973 Mdot
.63333 .19463 Mdot
.64286 .17937 Mdot
.65238 .1641 Mdot
.6619 .149 Mdot
.67143 .13424 Mdot
.68095 .11997 Mdot
.69048 .10635 Mdot
.7 .09353 Mdot
.70952 .08165 Mdot
.71905 .07084 Mdot
.72857 .06122 Mdot
.7381 .0529 Mdot
.74762 .04596 Mdot
.75714 .04048 Mdot
.76667 .03652 Mdot
.77619 .03413 Mdot
.78571 .03333 Mdot
.79524 .00794 Mdot
.80476 .00794 Mdot
.81429 .00794 Mdot
.82381 .00794 Mdot
.83333 .00794 Mdot
.84286 .00794 Mdot
.85238 .00794 Mdot
.8619 .00794 Mdot
.87143 .00794 Mdot
.88095 .00794 Mdot
.89048 .00794 Mdot
.9 .00794 Mdot
.90952 .00794 Mdot
.91905 .00794 Mdot
.92857 .00794 Mdot
.9381 .00794 Mdot
.94762 .00794 Mdot
.95714 .00794 Mdot
.96667 .00794 Mdot
.97619 .00794 Mdot
0 0 m
1 0 L
1 .33333 L
0 .33333 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.72381 0.97619 1.04127 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.214286 0.00952381 0.166667 0.15873 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.21429 -0.0125 -3 -9 ]
[.21429 -0.0125 3 0 ]
[.40476 -0.0125 -6 -9 ]
[.40476 -0.0125 6 0 ]
[.59524 -0.0125 -6 -9 ]
[.59524 -0.0125 6 0 ]
[.78571 -0.0125 -6 -9 ]
[.78571 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00794 -12 -4.5 ]
[-0.0125 .00794 0 4.5 ]
[-0.0125 .0873 -24 -4.5 ]
[-0.0125 .0873 0 4.5 ]
[-0.0125 .16667 -6 -4.5 ]
[-0.0125 .16667 0 4.5 ]
[-0.0125 .24603 -18 -4.5 ]
[-0.0125 .24603 0 4.5 ]
[-0.0125 .3254 -6 -4.5 ]
[-0.0125 .3254 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .33333 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-20)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(0)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(20)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(40)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(60)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(80)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00794 m
.00625 .00794 L
s
[(-1)] -0.0125 .00794 1 0 Mshowa
0 .0873 m
.00625 .0873 L
s
[(-0.5)] -0.0125 .0873 1 0 Mshowa
0 .16667 m
.00625 .16667 L
s
[(0)] -0.0125 .16667 1 0 Mshowa
0 .24603 m
.00625 .24603 L
s
[(0.5)] -0.0125 .24603 1 0 Mshowa
0 .3254 m
.00625 .3254 L
s
[(1)] -0.0125 .3254 1 0 Mshowa
.125 Mabswid
0 .02381 m
.00375 .02381 L
s
0 .03968 m
.00375 .03968 L
s
0 .05556 m
.00375 .05556 L
s
0 .07143 m
.00375 .07143 L
s
0 .10317 m
.00375 .10317 L
s
0 .11905 m
.00375 .11905 L
s
0 .13492 m
.00375 .13492 L
s
0 .15079 m
.00375 .15079 L
s
0 .18254 m
.00375 .18254 L
s
0 .19841 m
.00375 .19841 L
s
0 .21429 m
.00375 .21429 L
s
0 .23016 m
.00375 .23016 L
s
0 .2619 m
.00375 .2619 L
s
0 .27778 m
.00375 .27778 L
s
0 .29365 m
.00375 .29365 L
s
0 .30952 m
.00375 .30952 L
s
.25 Mabswid
0 0 m
0 .33333 L
s
.02381 .32708 m
.02381 .33333 L
s
.21429 .32708 m
.21429 .33333 L
s
.40476 .32708 m
.40476 .33333 L
s
.59524 .32708 m
.59524 .33333 L
s
.78571 .32708 m
.78571 .33333 L
s
.97619 .32708 m
.97619 .33333 L
s
.125 Mabswid
.07143 .32958 m
.07143 .33333 L
s
.11905 .32958 m
.11905 .33333 L
s
.16667 .32958 m
.16667 .33333 L
s
.2619 .32958 m
.2619 .33333 L
s
.30952 .32958 m
.30952 .33333 L
s
.35714 .32958 m
.35714 .33333 L
s
.45238 .32958 m
.45238 .33333 L
s
.5 .32958 m
.5 .33333 L
s
.54762 .32958 m
.54762 .33333 L
s
.64286 .32958 m
.64286 .33333 L
s
.69048 .32958 m
.69048 .33333 L
s
.7381 .32958 m
.7381 .33333 L
s
.83333 .32958 m
.83333 .33333 L
s
.88095 .32958 m
.88095 .33333 L
s
.92857 .32958 m
.92857 .33333 L
s
.25 Mabswid
0 .33333 m
1 .33333 L
s
.99375 .00794 m
1 .00794 L
s
.99375 .0873 m
1 .0873 L
s
.99375 .16667 m
1 .16667 L
s
.99375 .24603 m
1 .24603 L
s
.99375 .3254 m
1 .3254 L
s
.125 Mabswid
.99625 .02381 m
1 .02381 L
s
.99625 .03968 m
1 .03968 L
s
.99625 .05556 m
1 .05556 L
s
.99625 .07143 m
1 .07143 L
s
.99625 .10317 m
1 .10317 L
s
.99625 .11905 m
1 .11905 L
s
.99625 .13492 m
1 .13492 L
s
.99625 .15079 m
1 .15079 L
s
.99625 .18254 m
1 .18254 L
s
.99625 .19841 m
1 .19841 L
s
.99625 .21429 m
1 .21429 L
s
.99625 .23016 m
1 .23016 L
s
.99625 .2619 m
1 .2619 L
s
.99625 .27778 m
1 .27778 L
s
.99625 .29365 m
1 .29365 L
s
.99625 .30952 m
1 .30952 L
s
.25 Mabswid
1 0 m
1 .33333 L
s
0 .16667 m
1 .16667 L
s
0 0 1 r
.5 Mabswid
.02381 .16667 m
.02381 .16667 L
s
.03333 .16667 m
.03333 .16667 L
s
.04286 .16667 m
.04286 .16667 L
s
.05238 .16667 m
.05238 .16667 L
s
.0619 .16667 m
.0619 .16667 L
s
.07143 .16667 m
.07143 .16667 L
s
.08095 .16667 m
.08095 .16667 L
s
.09048 .16667 m
.09048 .16667 L
s
.1 .16667 m
.1 .16667 L
s
.10952 .16667 m
.10952 .16667 L
s
.11905 .16667 m
.11905 .16667 L
s
.12857 .16667 m
.12857 .16667 L
s
.1381 .16667 m
.1381 .16667 L
s
.14762 .16667 m
.14762 .16667 L
s
.15714 .16667 m
.15714 .16667 L
s
.16667 .16667 m
.16667 .16667 L
s
.17619 .16667 m
.17619 .16667 L
s
.18571 .16667 m
.18571 .16667 L
s
.19524 .16667 m
.19524 .16667 L
s
.20476 .16667 m
.20476 .16667 L
s
.21429 .16667 m
.21429 .3254 L
s
.22381 .16667 m
.22381 .29002 L
s
.23333 .16667 m
.23333 .19967 L
s
.24286 .16667 m
.24286 .0946 L
s
.25238 .16667 m
.25238 .02166 L
s
.2619 .16667 m
.2619 .01335 L
s
.27143 .16667 m
.27143 .07337 L
s
.28095 .16667 m
.28095 .17497 L
s
.29048 .16667 m
.29048 .27288 L
s
.3 .16667 m
.3 .32344 L
s
.30952 .16667 m
.30952 .30413 L
s
.31905 .16667 m
.31905 .22355 L
s
.32857 .16667 m
.32857 .11762 L
s
.3381 .16667 m
.3381 .03354 L
s
.34762 .16667 m
.34762 .00881 L
s
.35714 .16667 m
.35714 .05443 L
s
.36667 .16667 m
.36667 .15007 L
s
.37619 .16667 m
.37619 .25312 L
s
.38571 .16667 m
.38571 .31763 L
s
.39524 .16667 m
.39524 .31485 L
s
.40476 .16667 m
.40476 .24603 L
s
.41429 .16667 m
.41429 .14184 L
s
.42381 .16667 m
.42381 .04871 L
s
.43333 .16667 m
.43333 .00815 L
s
.44286 .16667 m
.44286 .03825 L
s
.45238 .16667 m
.45238 .12558 L
s
.4619 .16667 m
.4619 .23123 L
s
.47143 .16667 m
.47143 .3081 L
s
.48095 .16667 m
.48095 .32193 L
s
.49048 .16667 m
.49048 .26656 L
s
.5 .16667 m
.5 .16667 L
s
.50952 .16667 m
.50952 .06677 L
s
.51905 .16667 m
.51905 .01141 L
s
.52857 .16667 m
.52857 .02524 L
s
.5381 .16667 m
.5381 .10211 L
s
.54762 .16667 m
.54762 .20775 L
s
.55714 .16667 m
.55714 .29508 L
s
.56667 .16667 m
.56667 .32518 L
s
.57619 .16667 m
.57619 .28463 L
s
.58571 .16667 m
.58571 .1915 L
s
.59524 .16667 m
.59524 .0873 L
s
.60476 .16667 m
.60476 .01848 L
s
.61429 .16667 m
.61429 .01571 L
s
.62381 .16667 m
.62381 .08022 L
s
.63333 .16667 m
.63333 .18326 L
s
.64286 .16667 m
.64286 .27891 L
s
.65238 .16667 m
.65238 .32453 L
s
.6619 .16667 m
.6619 .29979 L
s
.67143 .16667 m
.67143 .21572 L
s
.68095 .16667 m
.68095 .10978 L
s
.69048 .16667 m
.69048 .0292 L
s
.7 .16667 m
.7 .00989 L
s
.70952 .16667 m
.70952 .06046 L
s
.71905 .16667 m
.71905 .15836 L
s
.72857 .16667 m
.72857 .25997 L
s
.7381 .16667 m
.7381 .31999 L
s
.74762 .16667 m
.74762 .31167 L
s
.75714 .16667 m
.75714 .23873 L
s
.76667 .16667 m
.76667 .13366 L
s
.77619 .16667 m
.77619 .04331 L
s
.78571 .16667 m
.78571 .00794 L
s
.79524 .16667 m
.79524 .16667 L
s
.80476 .16667 m
.80476 .16667 L
s
.81429 .16667 m
.81429 .16667 L
s
.82381 .16667 m
.82381 .16667 L
s
.83333 .16667 m
.83333 .16667 L
s
.84286 .16667 m
.84286 .16667 L
s
.85238 .16667 m
.85238 .16667 L
s
.8619 .16667 m
.8619 .16667 L
s
.87143 .16667 m
.87143 .16667 L
s
.88095 .16667 m
.88095 .16667 L
s
.89048 .16667 m
.89048 .16667 L
s
.9 .16667 m
.9 .16667 L
s
.90952 .16667 m
.90952 .16667 L
s
.91905 .16667 m
.91905 .16667 L
s
.92857 .16667 m
.92857 .16667 L
s
.9381 .16667 m
.9381 .16667 L
s
.94762 .16667 m
.94762 .16667 L
s
.95714 .16667 m
.95714 .16667 L
s
.96667 .16667 m
.96667 .16667 L
s
.97619 .16667 m
.97619 .16667 L
s
.005 w
.02381 .16667 Mdot
.03333 .16667 Mdot
.04286 .16667 Mdot
.05238 .16667 Mdot
.0619 .16667 Mdot
.07143 .16667 Mdot
.08095 .16667 Mdot
.09048 .16667 Mdot
.1 .16667 Mdot
.10952 .16667 Mdot
.11905 .16667 Mdot
.12857 .16667 Mdot
.1381 .16667 Mdot
.14762 .16667 Mdot
.15714 .16667 Mdot
.16667 .16667 Mdot
.17619 .16667 Mdot
.18571 .16667 Mdot
.19524 .16667 Mdot
.20476 .16667 Mdot
.21429 .3254 Mdot
.22381 .29002 Mdot
.23333 .19967 Mdot
.24286 .0946 Mdot
.25238 .02166 Mdot
.2619 .01335 Mdot
.27143 .07337 Mdot
.28095 .17497 Mdot
.29048 .27288 Mdot
.3 .32344 Mdot
.30952 .30413 Mdot
.31905 .22355 Mdot
.32857 .11762 Mdot
.3381 .03354 Mdot
.34762 .00881 Mdot
.35714 .05443 Mdot
.36667 .15007 Mdot
.37619 .25312 Mdot
.38571 .31763 Mdot
.39524 .31485 Mdot
.40476 .24603 Mdot
.41429 .14184 Mdot
.42381 .04871 Mdot
.43333 .00815 Mdot
.44286 .03825 Mdot
.45238 .12558 Mdot
.4619 .23123 Mdot
.47143 .3081 Mdot
.48095 .32193 Mdot
.49048 .26656 Mdot
.5 .16667 Mdot
.50952 .06677 Mdot
.51905 .01141 Mdot
.52857 .02524 Mdot
.5381 .10211 Mdot
.54762 .20775 Mdot
.55714 .29508 Mdot
.56667 .32518 Mdot
.57619 .28463 Mdot
.58571 .1915 Mdot
.59524 .0873 Mdot
.60476 .01848 Mdot
.61429 .01571 Mdot
.62381 .08022 Mdot
.63333 .18326 Mdot
.64286 .27891 Mdot
.65238 .32453 Mdot
.6619 .29979 Mdot
.67143 .21572 Mdot
.68095 .10978 Mdot
.69048 .0292 Mdot
.7 .00989 Mdot
.70952 .06046 Mdot
.71905 .15836 Mdot
.72857 .25997 Mdot
.7381 .31999 Mdot
.74762 .31167 Mdot
.75714 .23873 Mdot
.76667 .13366 Mdot
.77619 .04331 Mdot
.78571 .00794 Mdot
.79524 .16667 Mdot
.80476 .16667 Mdot
.81429 .16667 Mdot
.82381 .16667 Mdot
.83333 .16667 Mdot
.84286 .16667 Mdot
.85238 .16667 Mdot
.8619 .16667 Mdot
.87143 .16667 Mdot
.88095 .16667 Mdot
.89048 .16667 Mdot
.9 .16667 Mdot
.90952 .16667 Mdot
.91905 .16667 Mdot
.92857 .16667 Mdot
.9381 .16667 Mdot
.94762 .16667 Mdot
.95714 .16667 Mdot
.96667 .16667 Mdot
.97619 .16667 Mdot
0 0 m
1 0 L
1 .33333 L
0 .33333 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{504, 537.562},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007h00026B000`400?l00000o`00003ooooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00??ooool5o`0000?ooooo0_l0
0019ooooo`;o0000B_ooool5o`0000?ooooo0_l00019ooooo`?o00000oooool2o`0004Sooooo0ol0
0004ooooo`;o0000B?ooool3o`0000Cooooo0_l0000Pooooo`00?Oooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0004Oooooo00Co0000oooooooooooo0000B_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0004Wooooo00Go0000ooooooooooooooooo`00
0002ooooo`03o`000?oooooooooo04Cooooo00Go0000ooooooooooooooooo`000002ooooo`04o`00
0?ooooooooooo`0004Kooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooooooo
o`0001oooooo000fooooo`Go00000oooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0004Oooooo00Co0000oooooooooooo0000Boooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0004Kooooo1Ol00002ooooo`04o`000?ooooooooooo`0004Kooooo00Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooo`0004Kooooo00Go0000ooooooooooooooooo`00
0002ooooo`04o`000?ooooooooooo`0001oooooo000oooooo`05o`000?ooooooooooooooool00000
0_ooool00ol0003oooooooooo`15ooooo`04o`000?ooooooooooo`0004cooooo00Go0000oooooooo
ooooooooo`000002ooooo`03o`000?oooooooooo04Cooooo00Co0000oooooooooooo00000oooool0
1?l0003oooooooooool00016ooooo`Co00000oooool01?l0003oooooooooool00017ooooo`?o0000
0oooool01?l0003oooooooooool0000Oooooo`00??ooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo0000Aoooool01?l0003oooooooooool00019ooooo`05o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool00017ooooo`03o`000?oooooo000000?ooooo
00Co0000oooooooooooo0000A_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`00
04Kooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0001oooooo000l
ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00017ooooo`04o`00
0?ooooooooooo`0004Wooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooooooo
o`0004Sooooo0_l00003ooooo`04o`000?ooooooooooo`0004Oooooo00?o0000ooooooooool00ooo
ool01?l0003oooooooooool00016ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool0000Oooooo`00?Oooool3o`0000Cooooo0_l00019ooooo`;o0000Boooool3o`0000Co
oooo0_l0001:ooooo`03o`000?oooooooooo00;ooooo0_l00019ooooo`;o00001?ooool2o`0004So
oooo0ol00004ooooo`;o00008?ooool00?oooooonOooool00?oooooonOooool00?oooooonOooool0
0?oooooonOooool00?oooooonOooool002[ooooo0ol0003oooooolcooooo000[ooooo`03o`000?oo
oooooooo00Ooooooool0002/o`0001Sooooo000Sooooo`Go00000oooool00ol0003oooooooooo`07
ooooo`?o00001oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool01Oooool4o`0001Sooooo000[ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0Fooooo`00:oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`1>ooooo`03
o`000?oooooooooo02gooooo0_l00?lOooooo`03o`000?oooooooooo04kooooo00?o0000oooooooo
ool0C_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Kooooo000Zooooo`;o0000
2Oooool00ol0003oooooooooo`3Iooooo`;o003oc?ooool00ol0003oooooooooo`0Fooooo`00:ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0=[ooooo00?o003oooooooooool0b_oo
ool00ol0003oooooooooo`0Fooooo`00=Oooool00ol0003oooooooooo`3Jooooo`03o`00oooooooo
oooo0<[ooooo00?o0000ooooooooool05_ooool003Gooooo00?o0000ooooooooool0f_ooool00ol0
0?ooooooooooo`3:ooooo`03o`000?oooooooooo01Kooooo000eooooo`;o0000foooool00ol00?oo
ooooooooo`38ooooo`?o00006?ooool003Gooooo00?o0000ooooooooool0]Oooool2o`00ob?ooooo
00?o003oooooooooool0b_ooool00ol0003oooooooooo`0Fooooo`00=Oooool00ol0003ooooooooo
o`2eooooo`;o003o8oooool00ol00?ooooooooooo`02o`00olSooooo00?o0000ooooooooool05_oo
ool003Gooooo00?o0000ooooooooool0]Oooool00ol00?ooooooooooo`0Rooooo`03o`00oooooooo
oooo00;o003ob?ooool00ol0003oooooooooo`0Fooooo`00=Oooool00ol0003oooooooooo`2eoooo
o`03o`00oooooooooooo02;ooooo00Go003oooooooooooooooooo`00o`38ooooo`03o`000?oooooo
oooo01Kooooo000eooooo`03o`000?oooooooooo0;Gooooo00?o003oooooooooool08_ooool01Ol0
0?oooooooooooooooooo003o0<Sooooo00?o0000ooooooooool05_ooool003Gooooo00?o0000oooo
ooooool0]Oooool00ol00?ooooooooooo`0Rooooo`05o`00ooooooooooooooooool00?l0b?ooool0
0ol0003oooooooooo`0Fooooo`00=Oooool2o`000;Kooooo00?o003oooooooooool08_ooool01Ol0
0?oooooooooooooooooo003o0<Kooooo0ol0000Hooooo`00=Oooool00ol0003oooooooooo`2eoooo
o`03o`00oooooooooooo02;ooooo00Go003oooooooooooooooooo`00o`38ooooo`03o`000?oooooo
oooo01Kooooo000eooooo`03o`000?oooooooooo0;Gooooo00?o003oooooooooool08_ooool01Ol0
0?oooooooooooooooooo003o0<Sooooo00?o0000ooooooooool05_ooool003Gooooo00?o0000oooo
ooooool0]Oooool00ol00?ooooooooooo`0Rooooo`05o`00ooooooooooooooooool00?l0b?ooool0
0ol0003oooooooooo`0Fooooo`00=Oooool00ol0003oooooooooo`2eooooo`04o`00oooooooooooo
ooooo`;o003o7oooool01Ol00?oooooooooooooooooo003o0<Sooooo00?o0000ooooooooool05_oo
ool003Gooooo00?o0000ooooooooool0]Oooool01?l00?ooooooooooooooool2o`00oaoooooo00Go
003oooooooooooooooooo`00o`38ooooo`03o`000?oooooooooo01Kooooo000eooooo`03o`000?oo
oooooooo0;Gooooo00Go003oooooooooooooooooo`00o`0Pooooo`05o`00ooooooooooooooooool0
0?l0b?ooool00ol0003oooooooooo`0Fooooo`00=Oooool2o`000;Kooooo00Go003ooooooooooooo
ooooo`00o`0Pooooo`05o`00ooooooooooooooooool00?l0a_ooool3o`0001Sooooo000eooooo`03
o`000?oooooooooo0;Gooooo00Go003oooooooooooooooooo`00o`0Pooooo`05o`00oooooooooooo
ooooool00?l07oooool2o`00ojOooooo00?o0000ooooooooool05_ooool003Gooooo00?o0000oooo
ooooool0]Oooool01Ol00?oooooooooooooooooo003o023ooooo00Go003oooooooooooooooooo`00
o`0Oooooo`;o003oYoooool00ol0003oooooooooo`0Fooooo`00=Oooool00ol0003oooooooooo`2e
ooooo`05o`00ooooooooooooooooool00?l08?ooool01Ol00?oooooooooooooooooo003o01oooooo
00Co003ooooooooooooooooo0_l00?nSooooo`03o`000?oooooooooo01Kooooo000eooooo`03o`00
0?oooooooooo0;Gooooo00Go003oooooooooooooooooo`00o`0Pooooo`05o`00oooooooooooooooo
ool00?l07oooool01?l00?ooooooooooooooool2o`00oj?ooooo00?o0000ooooooooool05_ooool0
03Gooooo00?o0000ooooooooool0/Oooool2o`00o`;ooooo00Go003oooooooooooooooooo`00o`0K
ooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o01oooooo00Go003ooooooooooooooooo
o`00o`2Tooooo`03o`000?oooooooooo01Kooooo000eooooo`03o`000?oooooooooo0;7ooooo0_l0
0?l2ooooo`05o`00ooooooooooooooooool00?l06oooool2o`00o`?ooooo00Go003ooooooooooooo
ooooo`00o`0Oooooo`05o`00ooooooooooooooooool00?l0Y?ooool00ol0003oooooooooo`0Foooo
o`00=Oooool2o`000;;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
01[ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01gooooo00Go003o
ooooooooooooooooo`00o`2Rooooo`?o00006?ooool003Gooooo00?o0000ooooooooool0/Oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool06_ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool07Oooool01Ol00?oooooooooooooooooo003o0:Co
oooo00?o0000ooooooooool05_ooool003Gooooo00?o0000ooooooooool0/Oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool06_ooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool07Oooool01Ol00?oooooooooooooooooo003o0:Cooooo00?o0000
ooooooooool05_ooool003Gooooo00?o0000ooooooooool0/Oooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o003oooooooooool06_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool07Oooool01Ol00?oooooooooooooooooo003o0:Cooooo00?o0000ooooooooool0
5_ooool003Gooooo00?o0000ooooooooool0/Oooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool06_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool07Oooool01Ol00?oooooooooooooooooo003o0:Cooooo00?o0000ooooooooool05_ooool001oo
oooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00008ooooo`03o`000?oooooooooo0;7o
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01[ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo01gooooo00Go003oooooooooooooooooo`00
o`2Tooooo`03o`000?oooooooooo01Kooooo000Nooooo`04o`000?ooooooooooo`0000Oooooo00Go
0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo0;7ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo01[ooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo01gooooo00Go003oooooooooooooooooo`00o`2Tooooo`03o`000?oooooo
oooo01Kooooo000Gooooo`Go00000_ooool01?l0003oooooooooool0000;ooooo`03o`000?oooooo
oooo00Gooooo0ol0002@ooooo`;o003o7oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool06_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
7Oooool01Ol00?oooooooooooooooooo003o0:7ooooo1?l0000Hooooo`007_ooool01?l0003ooooo
ooooool0000;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0T?ooool2o`00oaoo
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01[ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo01gooooo00Go003oooooooooooooooooo`00
o`2Tooooo`03o`000?oooooooooo01Kooooo000Nooooo`04o`000?ooooooooooo`0000Oooooo1?l0
0008ooooo`03o`000?oooooooooo097ooooo00?o003oooooooooool07Oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool06_ooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool07Oooool01Ol00?oooooooooooooooooo003o0:Cooooo00?o0000oooo
ooooool05_ooool001kooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo097ooooo00?o003oooooooooool07Oooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o003oooooooooool06_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool07Oooool01Ol00?oooooooooooooooooo003o0:Cooooo00?o0000ooooooooool0
5_ooool001oooooo0_l00008ooooo`Go00001oooool00ol0003oooooooooo`2Aooooo`03o`00oooo
oooooooo01gooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01[ooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01gooooo00Go003ooooooooo
ooooooooo`00o`2Tooooo`03o`000?oooooooooo01Kooooo000eooooo`03o`000?oooooooooo097o
oooo00?o003oooooooooool07Oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool06_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool07Oooool0
1Ol00?oooooooooooooooooo003o0:Cooooo00?o0000ooooooooool05_ooool003Gooooo00?o0000
ooooooooool0TOooool00ol00?ooooooooooo`0Mooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`0Jooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`0Mooooo`05o`00ooooooooooooooooool00?l0Y?ooool00ol0003oooooooooo`0Fooooo`00
=Oooool2o`0009;ooooo00?o003oooooooooool07Oooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool06_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool00_l00?lKooooo`05o`00ooooooooooooooooool00?l0X_ooool3o`0001Sooooo000eoooo
o`03o`000?oooooooooo097ooooo00?o003oooooooooool00_l00?lKooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`0Jooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`02o`00oaOooooo0_l00?l2ooooo`05o`00ooooooooooooooooool00?l0
Y?ooool00ol0003oooooooooo`0Fooooo`00=Oooool00ol0003oooooooooo`2<ooooo`;o003o0ooo
ool00ol00?ooooooooooo`02o`00oa_ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo01[ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l05oooool2o`00o`;ooooo00Go003oooooooooooooooooo`00o`2Tooooo`03o`000?oooooo
oooo01Kooooo000eooooo`03o`000?oooooooooo08cooooo0_l00?l3ooooo`05o`00oooooooooooo
ooooool00?l06oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool06_oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`0Gooooo`05
o`00ooooooooooooooooool00?l00oooool01?l00?ooooooooooooooool2o`00oioooooo00?o0000
ooooooooool05_ooool003Gooooo00?o0000ooooooooool0SOooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o003oooooooooool06Oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool06_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`0Gooooo`05o`00ooooooooooooooooool00?l00oooool01?l00?ooooooooooooooool2
o`00oioooooo00?o0000ooooooooool05_ooool003Gooooo00?o0000ooooooooool0SOooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool06Oooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool06_ooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`0Gooooo`05o`00ooooooooooooooooool00?l00oooool01Ol0
0?oooooooooooooooooo003o0:3ooooo00?o0000ooooooooool05_ooool003Gooooo00?o0000oooo
ooooool0SOooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool06Oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool06_ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`0Gooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o0:3ooooo00?o0000ooooooooool05_ooool0
03Gooooo0_l0002>ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0I
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Jooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o01Oooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0W_ooool3o`0001Sooooo000eoooo
o`03o`000?oooooooooo08gooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo01Wooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01[ooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l05oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`2Pooooo`03o`000?oooooo
oooo01Kooooo000eooooo`03o`000?oooooooooo08gooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo01Wooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooo
oooooooo01[ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool0
0?l05oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`0K
ooooo`;o003o0_ooool2o`00ogoooooo00?o0000ooooooooool05_ooool003Gooooo00?o0000oooo
ooooool0SOooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool06Oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool06_ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`0Gooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o01_ooooo0_l00?l2ooooo`;o003oOoooool0
0ol0003oooooooooo`0Fooooo`00=Oooool00ol0003oooooooooo`2=ooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`0Iooooo`05o`00ooooooooooooooooool00?l00ooo
ool01?l00?ooooooooooooooool2o`00oaOooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l05oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`0Looooo`05o`00ooooooooooooooooool00?l0Ooooool00ol0003ooooo
ooooo`0Fooooo`00=Oooool00ol0003oooooooooo`2=ooooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`0Iooooo`05o`00ooooooooooooooooool00?l00oooool01?l00?oo
ooooooooooooool2o`00oaOooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l05oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`0Looooo`05o`00ooooooooooooooooool00?l0Ooooool00ol0003oooooooooo`0Foooo
o`00=Oooool00ol0003oooooooooo`2=ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`0Iooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o01Sooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool0
0?l05oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`0L
ooooo`05o`00ooooooooooooooooool00?l0Ooooool00ol0003oooooooooo`0Fooooo`00=Oooool2
o`0008kooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01Wooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l06?ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`0Gooooo`05o`00oooooooo
ooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o01cooooo00Go003ooooooooooooo
ooooo`00o`1mooooo`?o00006?ooool003Gooooo00?o0000ooooooooool0SOooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool06Oooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`0Hooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o01Oooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l07?ooool01Ol00?oooooooooooooooooo003o07oooooo00?o0000
ooooooooool05_ooool003Gooooo00?o0000ooooooooool0SOooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o003oooooooooool06Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`0Hooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o01Oooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l07?ooool01Ol00?oooooooooooooooooo003o07oooooo00?o0000ooooooooool0
5_ooool003Gooooo00?o0000ooooooooool0SOooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool06Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`0Hooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o01Oooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool0
0?l07?ooool01Ol00?oooooooooooooooooo003o00;ooooo0_l00?mkooooo`03o`000?oooooooooo
01Kooooo000eooooo`03o`000?oooooooooo06cooooo0_l00?lOooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`0Iooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o01Sooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l05oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`0Looooo`05o`00ooooooooooooooooool00?l00_ooool2o`00og_ooooo00?o
0000ooooooooool05_ooool003Gooooo00?o0000ooooooooool0K?ooool2o`00oa[ooooo0_l00?l3
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Dooooo`;o003o0ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`0Hooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o01Oooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l05oooool2o`00o`?ooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo07Wooooo00?o0000oooooooo
ool05_ooool003Gooooo00?o0000ooooooooool0J?ooool2o`00o`;ooooo00?o003oooooooooool0
6Oooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01Co
oooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o01Sooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0
5oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`0Goooo
o`;o003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0NOooool0
0ol0003oooooooooo`0Fooooo`00=Oooool2o`0006Wooooo0_l00?l2ooooo`04o`00oooooooooooo
ooooo`;o003o5oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`0Gooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool05_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`0Gooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o01Sooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l0NOooool3o`0001Sooooo000eooooo`03o`000?oooooooooo06Sooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`;o003o5oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`0Gooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool05_ooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`0Gooooo`05o`00ooooooooooooooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o01Sooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l07oooool2o`00oe[ooooo00?o0000ooooooooool05_ooool0
03Gooooo00?o0000ooooooooool0J?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool05_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`02ooooo`;o003o4oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo01Kooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l05oooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`0Hooooo`05o`00ooooooooooooooooool00?l00oooool01Ol0
0?oooooooooooooooooo003o01_ooooo0_l00?l2ooooo`;o003oF_ooool00ol0003oooooooooo`0F
ooooo`00=Oooool00ol0003oooooooooo`1Sooooo`;o003o0oooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o003oooooooooool05_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`02ooooo`;o003o4oooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01Kooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l05oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`0Hooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o01_ooooo0_l00?l2ooooo`03o`00oooooooo
oooo05Wooooo00?o0000ooooooooool05_ooool003Gooooo00?o0000ooooooooool0Hoooool2o`00
o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01Kooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`0Aooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool05_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`0Gooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o01Sooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l06oooool01Ol00?oooooooooooooooooo003o05_ooooo00?o0000ooooooooool05_oo
ool002_ooooo0_l00008ooooo`03o`000?oooooooooo06Cooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l06?ooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo017ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`0Fooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o01Oo
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l06?ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`0Gooooo`;o003o
0_ooool01Ol00?oooooooooooooooooo003o05_ooooo00?o0000ooooooooool05_ooool002[ooooo
00Co0000oooooooooooo00001oooool00ol0003oooooooooo`1Tooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o01Sooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Aooooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool05_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`0Gooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o01So
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00_ooool2
o`00oa?ooooo0_l00?l2ooooo`05o`00ooooooooooooooooool00?l0Foooool00ol0003ooooooooo
o`0Fooooo`00:_ooool01?l0003oooooooooool00007ooooo`Wo00000_l00?l2o`0000;o003o0_l0
0002o`00o`;o00000_l00?l2o`0000;o003o0_l00002o`00o`;o00000_l00?l3o`0000;o003o0_l0
0002o`00o`;o00000_l00?l2o`0000;o003o0_l00002o`00o`;o00000_l00?l2o`0000;o003o0_l0
0002o`00o`;o00000_l00?l2o`0000;o003o0_l00002o`00o`;o00000_l00?l2o`0000;o003o0ol0
00001Ol00?oo0000o`000?l0003o003o00?o000000Go003oo`000?l0003o0000o`00o`03o`000005
o`00ool0003o0000o`000?l00?l00ol000001?l00?oo0000o`000?l00002o`00o`;o000000Go003o
o`000?l0003o0000o`00o`03o`000005o`00ool0003o0000o`000?l00?l01?l000001Ol00?oo0000
o`000?l0003o003o00?o000000Go003oo`000?l0003o0000o`00o`03o`000005o`00ool0003o0000
o`000?l00?l00ol000001Ol00?oo0000o`000?l0003o003o00?o000000Go003oo`000?l0003o0000
o`00o`03o`000005o`00ool0003o0000o`000?l00?l00ol000001Ol00?oo0000o`000?l0003o003o
00?o000000Go003oo`000?l0003o0000o`00o`03o`000003o`00ool0003o000000;o000000?o003o
o`000?l000000_l00?l3o`000005o`00ool0003o0000o`000?l00?l00ol000001Ol00?oo0000o`00
0?l0003o003o00?o000000Go003oo`000?l0003o0000o`00o`03o`000005o`00ool0003o0000o`00
0?l00?l00ol000001Ol00?oo0000o`000?l0003o003o00?o000000Go003oo`000?l0003o0000o`00
o`03o`000005o`00ool0003o0000o`000?l00?l00ol000001Ol00?oo0000o`000?l0003o003o00Co
000000Go003oo`000?l0003o0000o`00o`03o`000005o`00ool0003o0000o`000?l00?l00ol00000
1Ol00?oo0000o`000?l0003o003o00;o00000_l00?l3o`000005o`00ool0003o0000o`000?l00?l0
0ol000001Ol00?oo0000o`000?l0003o003o00?o000000Go003oo`000?l0003o0000o`00o`03o`00
0004o`00ool0003o0000o`0000;o003o0_l00002o`00o`;o00000_l00?l2o`0000;o003o0_l00002
o`00o`;o00000_l00?l2o`0000;o003o0_l00002o`00o`;o00000_l00?l2o`0000;o003o0_l00002
o`00o`;o00000_l00?l2o`0000;o003o0ol00002o`00o`;o00000_l00?l2o`0000;o003o0_l00002
o`00o`;o00000_l00?l2o`0000;o003o0_l00002o`00o`[o00006?ooool002[ooooo00Co0000oooo
oooooooo00001oooool00ol0003oooooooooo`06ooooo`;o003o0_ooool2o`00o`;ooooo0_l00?l2
ooooo`;o003o0_ooool2o`00o`;ooooo0_l00?l2ooooo`;o003o0oooool2o`00o`;ooooo0_l00?l2
ooooo`;o003o0_ooool2o`00o`;ooooo0_l00?l2ooooo`;o003o0_ooool2o`00o`;ooooo0_l00?l2
ooooo`;o003o0_ooool2o`00o`;ooooo0_l00?l2ooooo`;o003o0_ooool2o`00o`?ooooo00Go003o
ooooooooooooooooo`00o`02ooooo`;o003o4oooool2o`00o`;ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l06?ooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`0Gooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;o003o4oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo017o
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooo
ooooooooooooo`00o`0Gooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00oooooo0_l00?l2ooooo`;o003o0_ooool2o`00o`;ooooo0_l00?l2ooooo`;o003o
0_ooool2o`00o`;ooooo0_l00?l2ooooo`;o003o0_ooool2o`00o`;ooooo0_l00?l2ooooo`;o003o
0_ooool2o`00o`;ooooo0_l00?l3ooooo`;o003o0_ooool2o`00o`;ooooo0_l00?l2ooooo`;o003o
0_ooool2o`00o`;ooooo0_l00?l2ooooo`;o003o2Oooool00ol0003oooooooooo`0Fooooo`00:_oo
ool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo05Sooooo00Go003ooooooooooooo
ooooo`00o`02ooooo`;o003o5oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`0Hooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o01Oooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool05Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo017ooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`0Gooooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o06Oooooo00?o0000oooo
ooooool05_ooool002[ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`1Hoooo
o`05o`00ooooooooooooooooool00?l06oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`0Hooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o01Oooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool05Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo017ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`0Goooo
o`05o`00ooooooooooooooooool00?l00oooool01?l00?ooooooooooooooool2o`00ofKooooo00?o
0000ooooooooool05_ooool002_ooooo0_l00008ooooo`03o`000?oooooooooo05Sooooo00?o003o
ooooooooool00_l00?lKooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o01Sooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l05oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`0Eooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool04Oooool2o`00o`;ooooo00Go003ooooooooooooo
ooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l05oooool01Ol00?oooooooooooooooooo
003o00?ooooo00Co003ooooooooooooooooo0_l00?mVooooo`03o`000?oooooooooo01Kooooo000e
ooooo`03o`000?oooooooooo05Oooooo0_l00?l2ooooo`;o003o6oooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`0Hooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o01Oooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool05Oooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo017ooooo
0_l00?l2ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o
01Oooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo06Wooooo00?o0000
ooooooooool05_ooool003Gooooo00?o0000ooooooooool0Eoooool2o`00oaoooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l06?ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`0Gooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01Gooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`0Eooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o01Oo
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo06Wooooo00?o0000oooo
ooooool05_ooool003Gooooo0_l0001iooooo`05o`00ooooooooooooooooool00?l00oooool01Ol0
0?oooooooooooooooooo003o01Sooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l05oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`0Eooooo`05o`00ooooooooooooooooool00?l00oooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool05Oooool01Ol00?oooooooooooooo
oooo003o00Cooooo00Go003oooooooooooooooooo`00o`0Fooooo`;o003o0oooool01?l00?oooooo
ooooooooool2o`00ofSooooo0ol0000Hooooo`00=Oooool00ol0003oooooooooo`1hooooo`05o`00
ooooooooooooooooool00?l00oooool01?l00?ooooooooooooooool2o`00oaOooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l05oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Eooooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool05Oooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool00_l00?lF
ooooo`;o003o0oooool01?l00?ooooooooooooooool2o`00of[ooooo00?o0000ooooooooool05_oo
ool003Gooooo00?o0000ooooooooool0N?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Co
003ooooooooooooooooo0_l00?lGooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o01Oooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool05Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`03ooooo`;o003o5_ooool01Ol00?oooooooooooooooooo003o00Co
oooo00?o003oooooooooool00_l00?lJooooo`;o003oKoooool00ol0003oooooooooo`0Fooooo`00
=Oooool00ol0003oooooooooo`1hooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`0Jooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o01Oooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool05Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`;o003o5_ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003ooooo
ooooool07?ooool2o`00ofoooooo00?o0000ooooooooool05_ooool003Gooooo00?o0000oooooooo
ool0N?ooool2o`00o`;ooooo00Go003oooooooooooooooooo`00o`0Looooo`05o`00oooooooooooo
ooooool00?l00oooool01Ol00?oooooooooooooooooo003o01Oooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool05Oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`0Kooooo`05o`00oooooooooooo
ooooool00?l01?ooool00ol00?ooooooooooo`2=ooooo`03o`000?oooooooooo01Kooooo000eoooo
o`03o`000?oooooooooo07Sooooo0_l00?l2ooooo`05o`00ooooooooooooooooool00?l07?ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`0Gooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01Go
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l06oooool0
1Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool0SOooool00ol0003ooooooooo
o`0Fooooo`00=Oooool00ol0003oooooooooo`1looooo`05o`00ooooooooooooooooool00?l07?oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`0Gooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
01Gooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l06ooo
ool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool0SOooool00ol0003ooooo
ooooo`0Fooooo`00=Oooool2o`0007gooooo00Go003oooooooooooooooooo`00o`0Looooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o01Oooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool05Oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`0Kooooo`05o`00
ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`2;ooooo`?o00006?ooool003Gooooo
00?o0000ooooooooool0O?ooool01Ol00?oooooooooooooooooo003o01cooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l05oooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Eooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o01_ooooo00Go003ooooooooo
ooooooooo`00o`04ooooo`03o`00oooooooooooo08gooooo00?o0000ooooooooool05_ooool003Go
oooo00?o0000ooooooooool0O?ooool01Ol00?oooooooooooooooooo003o01cooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l05oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Eooooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o01_ooooo00Go003ooooo
ooooooooooooo`00o`04ooooo`03o`00oooooooooooo08gooooo00?o0000ooooooooool05_ooool0
03Gooooo00?o0000ooooooooool0O?ooool01Ol00?oooooooooooooooooo003o01cooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l05oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Dooooo`;o
003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool06Oooool01Ol0
0?oooooooooooooooooo003o00Cooooo00?o003oooooooooool0SOooool00ol0003oooooooooo`0F
ooooo`00=Oooool00ol0003oooooooooo`1looooo`;o003o0_ooool2o`00oa_ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l05oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Dooooo`;o003o
0oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool06Oooool01Ol00?oo
oooooooooooooooo003o00Cooooo00?o003oooooooooool0SOooool00ol0003oooooooooo`0Foooo
o`00=Oooool00ol0003oooooooooo`1looooo`;o003o0_ooool2o`00oa_ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l05oooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Iooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`0Iooooo`05o`00ooooooooooooooooool0
0?l01?ooool00ol00?ooooooooooo`2=ooooo`03o`000?oooooooooo01Kooooo000eooooo`03o`00
0?oooooooooo09gooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l05oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`0Iooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`0Iooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`2=ooooo`03o`00
0?oooooooooo01Kooooo000eooooo`;o0000W_ooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`0Gooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo01Wooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo01Wooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooo
oooooooo08_ooooo0ol0000Hooooo`00=Oooool00ol0003oooooooooo`2Mooooo`05o`00oooooooo
ooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o01Oooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool06Oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool06Oooool01Ol00?oooooooooooooooooo
003o00Cooooo00?o003oooooooooool0SOooool00ol0003oooooooooo`0Fooooo`00=Oooool00ol0
003oooooooooo`2Mooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o01Oooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool06Oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool06Oooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool0SOooool00ol0
003oooooooooo`0Fooooo`00=Oooool00ol0003oooooooooo`2Looooo`;o003o0oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool05Oooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Iooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`0Iooooo`05o`00ooooooooooooooooool00?l0
1?ooool00ol00?ooooooooooo`2=ooooo`03o`000?oooooooooo01Kooooo000eooooo`03o`000?oo
oooooooo09cooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`0Eooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo01Wooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
01Wooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo08gooooo00?o0000
ooooooooool05_ooool003Gooooo00?o0000ooooooooool0XOooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o003oooooooooool05Oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`0Iooooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`0Iooooo`;o003o0_ooool01?l00?ooooooooooooooool2o`00ohoo
oooo00?o0000ooooooooool05_ooool003Gooooo00?o0000ooooooooool0XOooool01Ol00?oooooo
oooooooooooo003o00;ooooo0_l00?lGooooo`;o003o0_ooool01Ol00?oooooooooooooooooo003o
00Cooooo00?o003oooooooooool06Oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool06Oooool2o`00o`;ooooo00Co003ooooooooooooooooo0_l00?n?ooooo`03o`000?oo
oooooooo01Kooooo000eooooo`;o0000X_ooool01Ol00?oooooooooooooooooo003o00;ooooo0_l0
0?lGooooo`;o003o0_ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool0
6Oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool07Oooool00ol00?oo
ooooooooo`2@ooooo`?o00006?ooool003Gooooo00?o0000ooooooooool0XOooool01Ol00?oooooo
oooooooooooo003o01oooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo
01Wooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01gooooo00?o003o
ooooooooool0T_ooool00ol0003oooooooooo`0Fooooo`00=Oooool00ol0003oooooooooo`2Qoooo
o`05o`00ooooooooooooooooool00?l07oooool01Ol00?oooooooooooooooooo003o00Cooooo00?o
003oooooooooool06Oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
7Oooool00ol00?ooooooooooo`2Booooo`03o`000?oooooooooo01Kooooo000eooooo`03o`000?oo
oooooooo0:7ooooo00Go003oooooooooooooooooo`00o`0Oooooo`05o`00ooooooooooooooooool0
0?l01?ooool00ol00?ooooooooooo`0Iooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`0Mooooo`03o`00oooooooooooo09;ooooo00?o0000ooooooooool05_ooool003Go
oooo00?o0000ooooooooool0XOooool01Ol00?oooooooooooooooooo003o01oooooo00Go003ooooo
ooooooooooooo`00o`04ooooo`03o`00oooooooooooo01Wooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo01gooooo00?o003oooooooooool0T_ooool00ol0003ooooooooo
o`0Fooooo`007oooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Sooooo00?o0000
ooooooooool0XOooool01Ol00?oooooooooooooooooo003o01oooooo00Go003ooooooooooooooooo
o`00o`04ooooo`03o`00oooooooooooo01Wooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo01gooooo00?o003oooooooooool0T_ooool00ol0003oooooooooo`0Fooooo`00
7_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001oooool00ol0
003oooooooooo`2Qooooo`05o`00ooooooooooooooooool00?l07oooool01Ol00?oooooooooooooo
oooo003o00Cooooo00?o003oooooooooool06Oooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool07Oooool2o`00oi?ooooo00?o0000ooooooooool05_ooool001kooooo00Co
0000oooooooooooo00002oooool00ol0003oooooooooo`05ooooo`?o0000XOooool01Ol00?oooooo
oooooooooooo003o01oooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo
01Wooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01gooooo0_l00?n@
ooooo`Co00006?ooool001kooooo00Co0000oooooooooooo00002oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0:7ooooo00Go003oooooooooooooooooo`00o`0Oooooo`05o`00oooo
ooooooooooooool00?l01?ooool00ol00?ooooooooooo`0Iooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`2booooo`03o`000?oooooooooo01Kooooo000Nooooo`04o`00
0?ooooooooooo`0000Oooooo1?l00008ooooo`03o`000?oooooooooo0:7ooooo00Go003ooooooooo
ooooooooo`00o`0Oooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`0I
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`2booooo`03o`000?oo
oooooooo01Kooooo000Nooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`2Qooooo`05o`00ooooooooooooooooool00?l07oooool01Ol00?oooooo
oooooooooooo003o00Cooooo00?o003oooooooooool06Oooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool0/_ooool00ol0003oooooooooo`0Fooooo`007oooool2o`0000So
oooo1Ol00007ooooo`03o`000?oooooooooo0:7ooooo00Go003oooooooooooooooooo`00o`0Ooooo
o`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`0Iooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`2booooo`03o`000?oooooooooo01Kooooo000e
ooooo`03o`000?oooooooooo0:7ooooo00Go003oooooooooooooooooo`00o`0Oooooo`05o`00oooo
ooooooooooooool00?l01?ooool00ol00?ooooooooooo`0Iooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`2booooo`03o`000?oooooooooo01Kooooo000eooooo`03o`00
0?oooooooooo0:7ooooo00Go003oooooooooooooooooo`00o`0Oooooo`05o`00oooooooooooooooo
ool00?l01?ooool00ol00?ooooooooooo`0Iooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`2booooo`03o`000?oooooooooo01Kooooo000eooooo`;o0000X_ooool01Ol0
0?oooooooooooooooooo003o01oooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooo
oooooooo01Wooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo0;3ooooo
0ol0000Hooooo`00=Oooool00ol0003oooooooooo`2Qooooo`05o`00ooooooooooooooooool00?l0
7oooool01Ol00?oooooooooooooooooo003o00?ooooo0_l00?lKooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`2booooo`03o`000?oooooooooo01Kooooo000eooooo`03
o`000?oooooooooo0:7ooooo00Go003oooooooooooooooooo`00o`0Oooooo`05o`00oooooooooooo
ooooool00?l00oooool2o`00oa_ooooo00Go003oooooooooooooooooo`00o`02ooooo`;o003o]?oo
ool00ol0003oooooooooo`0Fooooo`00=Oooool00ol0003oooooooooo`2Pooooo`;o003o0oooool0
0ol00?ooooooooooo`0Mooooo`05o`00ooooooooooooooooool00?l08?ooool01Ol00?oooooooooo
oooooooo003o00;ooooo0_l00?ndooooo`03o`000?oooooooooo01Kooooo000eooooo`03o`000?oo
oooooooo0:3ooooo0_l00?l3ooooo`03o`00oooooooooooo01gooooo00Go003ooooooooooooooooo
o`00o`0Pooooo`05o`00ooooooooooooooooool00?l0^?ooool00ol0003oooooooooo`0Fooooo`00
=Oooool00ol0003oooooooooo`2Tooooo`;o003o7oooool01Ol00?oooooooooooooooooo003o023o
oooo00Go003oooooooooooooooooo`00o`2hooooo`03o`000?oooooooooo01Kooooo000eooooo`03
o`000?oooooooooo0:Cooooo0_l00?lOooooo`05o`00ooooooooooooooooool00?l08?ooool01Ol0
0?oooooooooooooooooo003o0;Sooooo00?o0000ooooooooool05_ooool003Gooooo0_l00036oooo
o`05o`00ooooooooooooooooool00?l08?ooool01Ol00?oooooooooooooooooo003o0;Kooooo0ol0
000Hooooo`00=Oooool00ol0003oooooooooo`35ooooo`05o`00ooooooooooooooooool00?l08?oo
ool01Ol00?oooooooooooooooooo003o0;Sooooo00?o0000ooooooooool05_ooool003Gooooo00?o
0000ooooooooool0aOooool01Ol00?oooooooooooooooooo003o01oooooo0_l00?l3ooooo`03o`00
oooooooooooo0;Kooooo00?o0000ooooooooool05_ooool003Gooooo00?o0000ooooooooool0aOoo
ool01Ol00?oooooooooooooooooo003o01oooooo0_l00?l3ooooo`03o`00oooooooooooo0;Kooooo
00?o0000ooooooooool05_ooool003Gooooo00?o0000ooooooooool0aOooool01Ol00?oooooooooo
oooooooo003o02Cooooo00?o003oooooooooool0]_ooool00ol0003oooooooooo`0Fooooo`00=Ooo
ool00ol0003oooooooooo`35ooooo`05o`00ooooooooooooooooool00?l09?ooool00ol00?oooooo
ooooo`2fooooo`03o`000?oooooooooo01Kooooo000eooooo`03o`000?oooooooooo0<Gooooo00Go
003oooooooooooooooooo`00o`0Tooooo`03o`00oooooooooooo0;Kooooo00?o0000ooooooooool0
5_ooool003Gooooo0_l00036ooooo`05o`00ooooooooooooooooool00?l09?ooool00ol00?oooooo
ooooo`2dooooo`?o00006?ooool003Gooooo00?o0000ooooooooool0aOooool01Ol00?oooooooooo
oooooooo003o02Cooooo00?o003oooooooooool0]_ooool00ol0003oooooooooo`0Fooooo`00=Ooo
ool00ol0003oooooooooo`35ooooo`05o`00ooooooooooooooooool00?l09?ooool00ol00?oooooo
ooooo`2fooooo`03o`000?oooooooooo01Kooooo000eooooo`03o`000?oooooooooo0<Gooooo00Go
003oooooooooooooooooo`00o`0Tooooo`03o`00oooooooooooo0;Kooooo00?o0000ooooooooool0
5_ooool003Gooooo00?o0000ooooooooool0aOooool2o`00o`;ooooo00?o003oooooooooool08_oo
ool00ol00?ooooooooooo`2fooooo`03o`000?oooooooooo01Kooooo000eooooo`03o`000?oooooo
oooo0<Gooooo0_l00?l2ooooo`03o`00oooooooooooo027ooooo0_l00?nhooooo`03o`000?oooooo
oooo01Kooooo000eooooo`03o`000?oooooooooo0<Wooooo00?o003oooooooooool08Oooool2o`00
okSooooo00?o0000ooooooooool05_ooool003Gooooo0_l0003:ooooo`03o`00oooooooooooo0=Wo
oooo0ol0000Hooooo`00=Oooool00ol0003oooooooooo`39ooooo`03o`00oooooooooooo0=_ooooo
00?o0000ooooooooool05_ooool003Gooooo00?o0000ooooooooool0bOooool00ol00?oooooooooo
o`3Kooooo`03o`000?oooooooooo01Kooooo000eooooo`03o`000?oooooooooo0<Wooooo00?o003o
ooooooooool0foooool00ol0003oooooooooo`0Fooooo`00:_ooool3o`0000Sooooo00?o0000oooo
ooooool0bOooool2o`00omcooooo00?o0000ooooooooool05_ooool002_ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04kooooo00?o0000oooooooo
ool0C_ooool00ol0003oooooooooo`0Mooooo`;o003o;oooool00ol0003oooooooooo`1>ooooo`03
o`000?oooooooooo04kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Fooooo`00
:oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
C_ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0
C_ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
5_ooool002_ooooo00?o0000ooooooooool01oooool3o`0000Oooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Gooooo1?l0000Hooooo`00:oooool0
0ol0003oooooooooo`07oooooooo0000[?l0000Hooooo`00:_ooool2o`000?oooooocOooool002_o
oooo00?o0000ooooooooool0ooooooo;ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00=_ooool5
o`0000?ooooo0_l0001:ooooo`;o0000Boooool5o`0000?ooooo0_l0001;ooooo`?o00000oooool2
o`0004Wooooo0ol00004ooooo`;o0000B_ooool3o`0000Cooooo0_l0000Oooooo`00=oooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0004Sooooo00Co0000oooooooooooo0000
Boooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0004_ooooo00Go0000oooo
ooooooooooooo`000002ooooo`03o`000?oooooooooo04Gooooo00Go0000ooooooooooooooooo`00
0002ooooo`04o`000?ooooooooooo`0004Sooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0001kooooo000`ooooo`Go00000oooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0004Sooooo00Co0000oooooooooooo0000C?ooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0004Sooooo1Ol00002ooooo`04o`000?ooooooooooo`0004Oooooo
00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0004Sooooo00Go0000oooo
ooooooooooooo`000002ooooo`04o`000?ooooooooooo`0001kooooo000iooooo`05o`000?oooooo
ooooooooool000000_ooool00ol0003oooooooooo`16ooooo`04o`000?ooooooooooo`0004gooooo
00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo04Kooooo00Co0000oooooooo
oooo00000oooool01?l0003oooooooooool00017ooooo`Co00000oooool01?l0003oooooooooool0
0019ooooo`?o00000oooool01?l0003oooooooooool0000Nooooo`00=_ooool01Ol0003ooooooooo
oooooooo000000;ooooo00Co0000oooooooooooo0000B?ooool01?l0003oooooooooool0001:oooo
o`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00019ooooo`03o`000?oo
oooo000000?ooooo00Co0000oooooooooooo0000Aoooool00ol0003oooooooooo`04ooooo`04o`00
0?ooooooooooo`0004Sooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooooooo
o`0001kooooo000fooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0
0018ooooo`04o`000?ooooooooooo`0004[ooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0004[ooooo0_l00003ooooo`04o`000?ooooooooooo`0004Sooooo00?o0000
ooooooooool00oooool01?l0003oooooooooool00018ooooo`05o`000?ooooooooooooooool00000
0_ooool01?l0003oooooooooool0000Nooooo`00=oooool3o`0000Cooooo0_l0001:ooooo`;o0000
C?ooool3o`0000Cooooo0_l0001<ooooo`03o`000?oooooooooo00;ooooo0_l0001:ooooo`;o0000
1?ooool2o`0004[ooooo0ol00004ooooo`;o00007oooool00?oooooonOooool00?oooooonOooool0
0?oooooonOooool00?oooooonOooool00?oooooonOooool00?oooooonOooool00?oooooonOooool0
02koooooool0002co`0001Sooooo000Uooooo`;o00001oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo01Kooooo000Tooooo`04o`000?ooooooooooo`0000Kooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo04oooooo00?o0000oooooooo
ool0D?ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo053ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Fooooo`009?ooool01?l0003oooooooooool00006ooooo`[o
00000_l00?l2o`0000;o003o0_l00002o`00o`;o00000_l00?l3o`0000;o003o0_l00002o`00o`;o
00000_l00?l2o`0000;o003o0_l00002o`00o`;o00000_l00?l2o`0000;o003o0_l00002o`00o`?o
00000_l00?l2o`0000;o003o0_l00002o`00o`;o00000_l00?l2o`0000;o003o0_l00002o`00o`;o
00000_l00?l2o`0000;o003o0ol000001Ol00?oo0000o`000?l0003o003o00?o000000Go003oo`00
0?l0003o0000o`00o`04o`000005o`00ool0003o0000o`000?l00?l00ol000001Ol00?oo0000o`00
0?l0003o003o00?o000000Go003oo`000?l0003o0000o`00o`03o`000005o`00ool0003o0000o`00
0?l00?l00ol000000ol00?oo0000o`000002o`000005o`00ool0003o0000o`000?l00?l00ol00000
1Ol00?oo0000o`000?l0003o003o00?o000000Go003oo`000?l0003o0000o`00o`03o`000005o`00
ool0003o0000o`000?l00?l01?l000001Ol00?oo0000o`000?l0003o003o00?o000000Go003oo`00
0?l0003o0000o`00o`03o`000005o`00ool0003o0000o`000?l00?l00ol000001Ol00?oo0000o`00
0?l0003o003o00?o000000?o003oo`000?l000000_l000001Ol00?oo0000o`000?l0003o003o00?o
000000Go003oo`000?l0003o0000o`00o`03o`000005o`00ool0003o0000o`000?l00?l00ol00000
1Ol00?oo0000o`000?l0003o003o00Co000000Go003oo`000?l0003o0000o`00o`03o`000005o`00
ool0003o0000o`000?l00?l00ol000001Ol00?oo0000o`000?l0003o003o00?o000000Go003oo`00
0?l0003o0000o`00o`04o`000005o`00ool0003o0000o`000?l00?l00ol000001Ol00?oo0000o`00
0?l0003o003o00?o000000Go003oo`000?l0003o0000o`00o`03o`000005o`00ool0003o0000o`00
0?l00?l00ol000000ol00?oo0000o`000002o`000005o`00ool0003o0000o`000?l00?l00ol00000
1Ol00?oo0000o`000?l0003o003o00?o000000Go003oo`000?l0003o0000o`00o`03o`0000;o003o
0_l00002o`00o`;o00000_l00?l2o`0000;o003o0_l00002o`00o`;o00000_l00?l2o`0000;o003o
0ol00002o`00o`;o00000_l00?l2o`0000;o003o0_l00002o`00o`;o00000_l00?l2o`0000;o003o
0_l00002o`00o`;o00000_l00?l3o`0000;o003o0_l00002o`00o`;o00000_l00?l2o`0000;o003o
0_l00002o`00o`[o00006?ooool002Cooooo00Co0000oooooooooooo00001_ooool00ol0003ooooo
ooooo`07ooooo`;o003o0_ooool2o`00o`;ooooo0_l00?l2ooooo`;o003o0oooool2o`00o`;ooooo
0_l00?l2ooooo`;o003o0_ooool2o`00o`;ooooo0_l00?l2ooooo`;o003o0_ooool2o`00o`;ooooo
0_l00?l3ooooo`;o003o0_ooool2o`00o`;ooooo0_l00?l2ooooo`;o003o0_ooool2o`00o`;ooooo
0_l00?l2ooooo`;o003o0_ooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00ooo
ool2o`00o`;ooooo0_l00?l2ooooo`;o003o0_ooool2o`00o`;ooooo0_l00?l2ooooo`;o003o0_oo
ool2o`00o`?ooooo0_l00?l2ooooo`;o003o0_ooool2o`00o`;ooooo0_l00?l2ooooo`;o003o0_oo
ool2o`00o`;ooooo0_l00?l2ooooo`;o003o0oooool2o`00o`;ooooo0_l00?l2ooooo`;o003o0_oo
ool2o`00o`;ooooo0_l00?l9ooooo`03o`000?oooooooooo01Kooooo000Tooooo`04o`000?oooooo
ooooo`0000Kooooo00?o0000ooooooooool0F_ooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`1L
ooooo`03o`000?oooooooooo01Kooooo000Tooooo`04o`000?ooooooooooo`0000Kooooo00?o0000
ooooooooool0F_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`1Looooo`03o`000?oooooooooo
01Kooooo000Uooooo`;o00001oooool00ol0003oooooooooo`1Jooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o05cooooo00?o0000ooooooooool05_ooool002kooooo00?o0000ooooooooool0F_oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`1Looooo`03o`000?oooooooooo01Kooooo000^oooo
o`03o`000?oooooooooo05[ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0G?ooool00ol0003o
ooooooooo`0Fooooo`00;_ooool3o`0005[ooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0F_oo
ool3o`0001Sooooo000^ooooo`03o`000?oooooooooo05[ooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l0G?ooool00ol0003oooooooooo`0Fooooo`00;_ooool00ol0003oooooooooo`1Jooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o05cooooo00?o0000ooooooooool05_ooool002kooooo00?o
0000ooooooooool0F_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`1Looooo`03o`000?oooooo
oooo01Kooooo000^ooooo`03o`000?oooooooooo05Wooooo0_l00?l3ooooo`;o003o0_ooool01Ol0
0?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol0
0?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l00_ooool2o`00o`?ooooo0_l00?mKooooo`03o`000?oo
oooooooo01Kooooo000^ooooo`03o`000?oooooooooo05Wooooo0_l00?l3ooooo`;o003o0_ooool2
o`00o`;ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o003oooooooooool00_l00?l2ooooo`;o003o0oooool2o`00oe_ooooo00?o0000
ooooooooool05_ooool002kooooo00?o0000ooooooooool0H_ooool2o`00o`;ooooo00?o003ooooo
ooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool00_l00?mTooooo`03o`000?oooooooooo01Kooooo000^ooooo`?o0000I_ooool2o`00o`?o
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Co
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`02ooooo`;o003oI_ooool3o`0001So
oooo000^ooooo`03o`000?oooooooooo06Kooooo0_l00?l3ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00_ooool2o`00ofSooooo00?o0000ooooooooool05_ooool002kooooo00?o
0000ooooooooool0J_ooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;o003oK?ooool00ol0003oooooooooo`0F
ooooo`00;_ooool00ol0003oooooooooo`1Zooooo`;o003o0oooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_l00?m/ooooo`03
o`000?oooooooooo01Kooooo000^ooooo`03o`000?oooooooooo06oooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo06kooooo00?o
0000ooooooooool05_ooool002kooooo00?o0000ooooooooool0K_ooool2o`00o`?ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Co003ooooooooooooooooo0_l00?m`ooooo`03o`000?oooooooooo
01Kooooo000^ooooo`03o`000?oooooooooo06kooooo0_l00?l3ooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`03ooooo`04o`00ooooooooooooooooo`;o003oL?ooool00ol0003oooooooooo`0Fooooo`00;_oo
ool3o`0007?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo
00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0LOooool3o`00
01Sooooo000^ooooo`03o`000?oooooooooo07?ooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0
1?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool0Loooool00ol0003oooooooooo`0Fooooo`00;_ooool00ol0003oooooooooo`1b
ooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00?ooooo0_l00?mdooooo`03o`000?oooooooooo01Kooooo000^ooooo`03o`00
0?oooooooooo07;ooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooooooo
ooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l00oooool2o`00ogCooooo00?o0000ooooooooool05_ooool0
01Wooooo0_l00004ooooo`04o`000?ooooooooooooooo`Go00001_ooool00ol0003oooooooooo`1g
ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol0
0?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool0
0?l0NOooool00ol0003oooooooooo`0Fooooo`006?ooool01?l0003oooooooooool00008ooooo`04
o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool0Moooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0
1?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o07Wooooo00?o0000ooooooooool0
5_ooool001Sooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo07Kooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01?l00?oo
ooooooooooooool2o`00ogSooooo00?o0000ooooooooool05_ooool001Sooooo00Co0000oooooooo
oooo00002_ooool00ol0003oooooooooo`05ooooo`Co0000MOooool2o`00o`?ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Co
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`04o`00ooooooooooooooooo`;o003oMOooool4o`0001Sooooo000H
ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo07_ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo07_o
oooo00?o0000ooooooooool05_ooool001Sooooo00Co0000oooooooooooo00001oooool01Ol0003o
oooooooooooooooo000000Kooooo00?o0000ooooooooool0Noooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooooooo
ooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o003oooooooooool0Noooool00ol0003oooooooooo`0Fooooo`006Oooool2o`00
00Wooooo0ol00007ooooo`03o`000?oooooooooo07_ooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo07_ooooo00?o0000ooooooooool05_ooool002kooooo00?o0000oooo
ooooool0N_ooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0
1?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l00oooool2o`00ogcooooo00?o0000ooooooooool05_ooool0
02kooooo00?o0000ooooooooool0N_ooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol0
0?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool2o`00ogcooooo00?o0000
ooooooooool05_ooool002kooooo00?o0000ooooooooool0Ooooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`21ooooo`03o`000?oooooo
oooo01Kooooo000^ooooo`?o0000Ooooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`1oooooo`?o00006?ooool002kooooo00?o0000oooo
ooooool0Ooooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Co
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`21ooooo`03o`000?oooooooooo01Kooooo000^ooooo`03o`000?oooooooooo
07oooooo0_l00?l2ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo
00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Co003ooooooooo
oooooooo0_l00?n0ooooo`03o`000?oooooooooo01Kooooo000^ooooo`03o`000?oooooooooo07oo
oooo0_l00?l2ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
0_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooooooo
ooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Co003ooooooooooooo
oooo0_l00?n0ooooo`03o`000?oooooooooo01Kooooo000^ooooo`03o`000?oooooooooo08?ooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`23ooooo`03o`000?oo
oooooooo01Kooooo000^ooooo`03o`000?oooooooooo08?ooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`23ooooo`03o`000?oooooooooo01Kooooo000^ooooo`?o
0000Poooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo
00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo087ooooo
0ol0000Hooooo`00;_ooool00ol0003oooooooooo`23ooooo`;o003o0_ooool01Ol00?oooooooooo
oooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Co
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00_ooool2
o`00ohGooooo00?o0000ooooooooool05_ooool002kooooo00?o0000ooooooooool0Poooool2o`00
o`;ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00;ooooo0_l00?n5ooooo`03o`000?oooooooooo01Kooooo000^ooooo`03o`00
0?oooooooooo08Oooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o08Wooooo00?o0000ooooooooool05_ooool002kooooo00?o0000
ooooooooool0Qoooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooo
ooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l0ROooool00ol0003oooooooooo`0Fooooo`00;_ooool00ol0003o
ooooooooo`27ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`29ooooo`03o`000?oooooooooo01Kooooo000^ooooo`03o`000?oo
oooooooo08Oooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol0
0?oooooooooooooooooo003o08Wooooo00?o0000ooooooooool05_ooool002kooooo0ol00027oooo
o`;o003o0_ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02o`00ohOooooo0ol0000Hooooo`00;_ooool00ol0003oooooooooo`27ooooo`;o003o0_ooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`04ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02o`00ohWooooo
00?o0000ooooooooool05_ooool002kooooo00?o0000ooooooooool0Roooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Co
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`2;ooooo`03o`000?oooooooooo01Ko
oooo000^ooooo`03o`000?oooooooooo08_ooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooooooooooo
ooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool0Roooool00ol0003oooooooooo`0Fooooo`00;_ooool00ol0003o
ooooooooo`2;ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo08_ooooo00?o0000ooooooooool05_ooool001Wooooo0_l00004ooooo`03o`000?oooooooooo
00?ooooo0ol00006ooooo`03o`000?oooooooooo08_ooooo00?o003oooooooooool00_ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo
00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool0Roooool00ol0003oooooooooo`0Fooooo`006?ooool0
1?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Rooo
ool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04
ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool0
0?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo
00Go003oooooooooooooooooo`00o`02ooooo`;o003oSOooool00ol0003oooooooooo`0Fooooo`00
6?ooool01?l0003oooooooooool00007ooooo`Go00001_ooool4o`0008[ooooo0_l00?l3ooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooooooooooo
ooooool00?l00_ooool2o`00oh[ooooo1?l0000Hooooo`006?ooool01?l0003oooooooooool00007
ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool0T?ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o097o
oooo00?o0000ooooooooool05_ooool001Sooooo00Co0000oooooooooooo00002?ooool00ol0003o
ooooo`000007ooooo`03o`000?oooooooooo093ooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`2Aooooo`03o`000?oooooo
oooo01Kooooo000Hooooo`04o`000?ooooooooooo`0000Wooooo0_l00007ooooo`03o`000?oooooo
oooo093ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0
1?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go
003oooooooooooooooooo`00o`2Aooooo`03o`000?oooooooooo01Kooooo000Iooooo`;o00002ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo093ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooo
ooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`2Aooooo`03
o`000?oooooooooo01Kooooo000^ooooo`03o`000?oooooooooo093ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooo
ooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`2Aoooo
o`03o`000?oooooooooo01Kooooo000^ooooo`03o`000?oooooooooo08oooooo0_l00?l3ooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooooooooooo
ooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`02o`00oi7o
oooo00?o0000ooooooooool05_ooool002kooooo0ol0002?ooooo`;o003o0oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooo
ooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool00_l00?n?ooooo`?o0000
6?ooool002kooooo00?o0000ooooooooool0U?ooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o00Cooooo00?o003oooooooooool0Toooool00ol0003oooooooooo`0Fooooo`00;_ooool0
0ol0003oooooooooo`2Dooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;o
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool0
0ol00?ooooooooooo`2Cooooo`03o`000?oooooooooo01Kooooo000^ooooo`03o`000?oooooooooo
09Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo
09?ooooo00?o0000ooooooooool05_ooool002kooooo00?o0000ooooooooool0U?ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooo
ooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool0Toooool00ol0003o
ooooooooo`0Fooooo`00;_ooool00ol0003oooooooooo`2Cooooo`;o003o0oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`;o003oUOooool00ol0003oooooooooo`0Fooooo`00;_ooool00ol0003ooooooooo
o`2Cooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`;o003oUOooool00ol0003ooooooooo
o`0Fooooo`00;_ooool3o`0009Sooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo
00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0V?ooool3o`0001Sooooo000^oooo
o`03o`000?oooooooooo09Sooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooooooo
ooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0V_ooool00ol0003oooooooooo`0Foooo
o`00;_ooool00ol0003oooooooooo`2Hooooo`05o`00ooooooooooooooooool00?l00oooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o09[ooooo00?o0000oooooooo
ool05_ooool002kooooo00?o0000ooooooooool0V?ooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Co
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`2Jooooo`03o`00
0?oooooooooo01Kooooo000^ooooo`03o`000?oooooooooo09Sooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0V_oo
ool00ol0003oooooooooo`0Fooooo`00;_ooool00ol0003oooooooooo`2Gooooo`;o003o0oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00oooooooooooooooo
o`;o003oVOooool00ol0003oooooooooo`0Fooooo`00;_ooool00ol0003oooooooooo`2Gooooo`;o
003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00oooo
ooooooooooooo`;o003oVOooool00ol0003oooooooooo`0Fooooo`00;_ooool3o`0009cooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`2Joooo
o`?o00006?ooool002kooooo00?o0000ooooooooool0W?ooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo09cooooo00?o0000ooooooooool05_oo
ool002kooooo00?o0000ooooooooool0W?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooooooo
ooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo09cooooo00?o0000ooooooooool05_ooool002kooooo
00?o0000ooooooooool0W?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo09cooooo00?o0000ooooooooool05_ooool001Wooooo0_l00004oooo
o`03o`000?oooooooooo00;ooooo0ol00007ooooo`03o`000?oooooooooo09cooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`2Looooo`03o`00
0?oooooooooo01Kooooo000Hooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooooooo
ooooo`000006ooooo`03o`000?oooooooooo09_ooooo0_l00?l3ooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`03ooooo`;o003oWOooool00ol0003oooooooooo`0Fooooo`006?ooool01?l0003oooooooooool0
0007ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`2Kooooo`;o003o
0oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0
1?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l00oooool2o`00oigooooo00?o0000ooooooooool05_ooool0
01Sooooo00Co0000oooooooooooo00001oooool4o`0000Oooooo1?l0002Oooooo`05o`00oooooooo
ooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooooooo
ooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`2Oooooo`Co00006?ooool001Sooooo00Co0000oooooooooooo00001oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo0:3ooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o0:;ooooo00?o
0000ooooooooool05_ooool001Sooooo00Co0000oooooooooooo00002?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo0:3ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o0:;ooooo00?o0000oooo
ooooool05_ooool001Wooooo0_l0000:ooooo`;o00001oooool00ol0003oooooooooo`2Pooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`2Rooooo`03o`000?oooooooooo01Kooooo000^ooooo`03o`000?oooooo
oooo0:3ooooo0_l00?l2ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`03ooooo`04o`00ooooooooooooooooo`;o003oXOooool00ol0003oooooooooo`0Fooooo`00;_oo
ool00ol0003oooooooooo`2Pooooo`;o003o0_ooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol0
0?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l00oooool01?l00?ooooooooooooooool2o`00oj7ooooo00?o0000oooooooo
ool05_ooool002kooooo00?o0000ooooooooool0Y?ooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`2Tooooo`03o`000?oooooooooo01Ko
oooo000^ooooo`?o0000Y?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`2Rooooo`?o00006?ooool002kooooo00?o0000ooooooooool0
Y?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
0_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`2Tooooo`03o`000?oooooooooo01Kooooo000^ooooo`03o`000?oooooooooo0:Cooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo
00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool0Y?ooool00ol0003oooooooooo`0Fooooo`00;_ooool00ol0003oooooooooo`2Tooooo`;o003o
0_ooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o00;ooooo0_l00?nVooooo`03o`000?oooooooooo01Ko
oooo000^ooooo`03o`000?oooooooooo0:Cooooo0_l00?l2ooooo`05o`00ooooooooooooooooool0
0?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool0
0?l00_ooool2o`00ojKooooo00?o0000ooooooooool05_ooool002kooooo00?o0000ooooooooool0
Z?ooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o0:[ooooo00?o0000ooooooooool05_ooool002kooooo
0ol0002Xooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l0Z?ooool3o`0001Sooooo000^ooooo`03o`00
0?oooooooooo0:Sooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`2Zooooo`03o`000?oooooooooo01Ko
oooo000^ooooo`03o`000?oooooooooo0:Sooooo00Go003oooooooooooooooooo`00o`04ooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`2Zooooo`03
o`000?oooooooooo01Kooooo000^ooooo`03o`000?oooooooooo0:Sooooo00Go003ooooooooooooo
ooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`2Zooooo`03o`000?oooooooooo01Kooooo000^ooooo`03o`000?oooooooooo0:Sooooo
0_l00?l2ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`02o`00oj[ooooo00?o0000ooooooooool05_ooool002kooooo00?o0000
ooooooooool0Z?ooool2o`00o`;ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo00;o003oZ_ooool00ol0003oooooooooo`0Foooo
o`00;_ooool00ol0003oooooooooo`2/ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo
00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`2/ooooo`03o`000?oooooooooo01Kooooo
000^ooooo`?o0000[?ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooo
ooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o003oooooooooool0Z_ooool3o`0001Sooooo000^ooooo`03o`000?oooooooooo
0:cooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo0:cooooo00?o0000ooooooooool05_ooool002kooooo00?o0000ooooooooool0
[?ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool0[?ooool00ol0003oooooooooo`0Fooooo`00;_ooool00ol0003oooooooooo`2/
ooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`02ooooo`;o003o[_ooool00ol0
003oooooooooo`0Fooooo`00;_ooool00ol0003oooooooooo`2/ooooo`;o003o0oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
0_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go
003oooooooooooooooooo`00o`02ooooo`;o003o[_ooool00ol0003oooooooooo`0Fooooo`006Ooo
ool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Oooooo00?o0000ooooooooool0/Ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00Cooooo00Go003oooooooooooooooooo`00o`2booooo`03o`000?oooooooooo01Kooooo000Hoooo
o`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oo
oooooooo0;7ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l0/_ooool00ol0003oooooooooo`0F
ooooo`006?ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001_oo
ool4o`000;3ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l0[oooool4o`0001Sooooo000Hoooo
o`04o`000?ooooooooooo`0000Sooooo0ol00007ooooo`03o`000?oooooooooo0;3ooooo0_l00?l3
ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003ooooooooo
ool00_l00?nbooooo`03o`000?oooooooooo01Kooooo000Hooooo`04o`000?ooooooooooo`0000Oo
oooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0;3ooooo0_l00?l3oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool0
0_l00?nbooooo`03o`000?oooooooooo01Kooooo000Hooooo`04o`000?ooooooooooo`0000Oooooo
00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0;Gooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`2dooooo`03o`000?oo
oooooooo01Kooooo000Iooooo`;o00002Oooool3o`0000Oooooo00?o0000ooooooooool0]Oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo0;Co
oooo00?o0000ooooooooool05_ooool002kooooo00?o0000ooooooooool0]Oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo0;Cooooo00?o0000
ooooooooool05_ooool002kooooo00?o0000ooooooooool0]?ooool2o`00o`?ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o00?ooooo0_l00?nfooooo`03o`000?oooooooooo01Kooooo000^
ooooo`?o0000]?ooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo
0_l00?ndooooo`?o00006?ooool002kooooo00?o0000ooooooooool0^Oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l0^oooool00ol0003oooooooooo`0Fooooo`00;_ooool00ol0003ooooo
ooooo`2iooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`2kooooo`03o`000?oooooooooo
01Kooooo000^ooooo`03o`000?oooooooooo0;Wooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o0;_ooooo00?o0000ooooooooool05_ooool002kooooo00?o0000ooooooooool0^?ooool2o`00
o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Co003o
oooooooooooooooo0_l00?njooooo`03o`000?oooooooooo01Kooooo000^ooooo`03o`000?oooooo
oooo0;Sooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`03ooooo`04o`00ooooooooooooooooo`;o003o^_ooool00ol0003oooooooooo`0Fooooo`00;_oo
ool00ol0003oooooooooo`2mooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooooooooooo
ooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo0;gooooo00?o0000ooooooooool05_ooool002kooooo0ol0
002mooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo0;_ooooo0ol0000Hooooo`00;_ooool00ol0003oooooooooo`2looooo`;o003o0ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo0_l00?nnooooo`03o`000?oo
oooooooo01Kooooo000^ooooo`03o`000?oooooooooo0;cooooo0_l00?l3ooooo`05o`00oooooooo
ooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
0_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l00oooool2o`00okkooooo00?o0000ooooooooool05_ooool0
02kooooo00?o0000ooooooooool0`Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
0<?ooooo00?o0000ooooooooool05_ooool002kooooo00?o0000ooooooooool0`Oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o0<?ooooo00?o0000ooooooooool05_ooool002kooooo
00?o0000ooooooooool0`?ooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`04o`00ooooooooooooooooo`;o003o`_ooool00ol0003ooooo
ooooo`0Fooooo`00;_ooool00ol0003oooooooooo`30ooooo`;o003o0oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Co003ooooooooooooooooo0_l0
0?o2ooooo`03o`000?oooooooooo01Kooooo000^ooooo`?o0000aOooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0`oooool3o`00
01Sooooo000^ooooo`03o`000?oooooooooo0<Gooooo0_l00?l2ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o00?ooooo0_l00?o6ooooo`03o`000?oooooooooo01Kooooo000^
ooooo`03o`000?oooooooooo0<Gooooo0_l00?l2ooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00?ooooo0_l00?o6ooooo`03o`000?oooooooooo01Kooooo000^ooooo`03o`00
0?oooooooooo0<Wooooo0_l00?l2ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool00_l00?o;ooooo`03o`000?oooooooooo
01Kooooo000Tooooo`?o00001oooool00ol0003oooooooooo`39ooooo`;o003o0_ooool01Ol00?oo
oooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo00;o003oboooool00ol0003oooooooooo`0Fooooo`009Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo0<gooooo0_l00?l2ooooo`03o`00oooooooooooo00;ooooo00Go003ooooo
ooooooooooooo`00o`02ooooo`;o003ocoooool00ol0003oooooooooo`0Fooooo`009Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo0<gooooo0_l00?l2ooooo`;o003o0_ooool2o`00
o`;ooooo0_l00?l2ooooo`;o003ocoooool00ol0003oooooooooo`0Fooooo`009Oooool00ol0003o
ooooooooo`06ooooo`Co00001oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo04oo
oooo00?o0000ooooooooool08_ooool2o`00o`;ooooo0_l00?l2ooooo`;o003o9?ooool00ol0003o
ooooooooo`1?ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool01?ooool4o`0001So
oooo000Uooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0Fooooo`009?ooool2o`0000Sooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0Fooooo`009Oooool00ol0003oooooooooo`06oooooooo0000/ol0000Hooooo`00oooooooioooo
o`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooioooo
o`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooioooo
o`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooioooo
o`00oooooooiooooo`00>Oooool5o`0000?ooooo0_l0001:ooooo`;o0000Boooool5o`0000?ooooo
0_l0001;ooooo`?o00000oooool2o`0004Wooooo0ol00004ooooo`;o0000B_ooool3o`0000Cooooo
0_l0000Looooo`00>_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0004So
oooo00Co0000oooooooooooo0000Boooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0004_ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo04Gooooo
00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0004Sooooo00Go0000oooo
ooooooooooooo`000002ooooo`04o`000?ooooooooooo`0001_ooooo000cooooo`Go00000oooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0004Sooooo00Co0000oooooooooooo0000
C?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0004Sooooo1Ol00002ooooo`04
o`000?ooooooooooo`0004Oooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo
ooooo`0004Sooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0001_o
oooo000looooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`16ooooo`04
o`000?ooooooooooo`0004gooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo
oooo04Kooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool00017ooooo`Co0000
0oooool01?l0003oooooooooool00019ooooo`?o00000oooool01?l0003oooooooooool0000Koooo
o`00>Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000B?ooool0
1?l0003oooooooooool0001:ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooo
ooooool00019ooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooo0000Aoooool00ol0
003oooooooooo`04ooooo`04o`000?ooooooooooo`0004Sooooo00Go0000ooooooooooooooooo`00
0002ooooo`04o`000?ooooooooooo`0001_ooooo000iooooo`05o`000?ooooooooooooooool00000
0_ooool01?l0003oooooooooool00018ooooo`04o`000?ooooooooooo`0004[ooooo00Go0000oooo
ooooooooooooo`000002ooooo`04o`000?ooooooooooo`0004[ooooo0_l00003ooooo`04o`000?oo
ooooooooo`0004Sooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00018ooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000Kooooo`00>_ooool3o`00
00Cooooo0_l0001:ooooo`;o0000C?ooool3o`0000Cooooo0_l0001<ooooo`03o`000?oooooooooo
00;ooooo0_l0001:ooooo`;o00001?ooool2o`0004[ooooo0ol00004ooooo`;o00007?ooool00?oo
oooonOooool00?oooooonOooool00?oooooonOooool00?oooooonOooool00?oooooonOooool00?oo
oooonOooool0037oooooool0002co`0001Gooooo000Wooooo`?o00001oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo01?ooooo000Xooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0Cooooo`008?ooool5o`0000?ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo04oooooo00?o0000oooo
ooooool0Coooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo04oooooo0_l00?mAoooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04oooool002Sooooo00?o0000oooooooo
ool01_ooool4o`0009;ooooo0_l00?lSooooo`;o003oL_ooool2o`00ob?ooooo0_l00?mHooooo`Co
00005Oooool002Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2Cooooo`;o003o
8oooool2o`00ob?ooooo0_l00?m=ooooo`;o003o8oooool00ol00?ooooooooooo`1Jooooo`03o`00
0?oooooooooo01?ooooo000Wooooo`;o00002?ooool00ol0003oooooooooo`1^ooooo`;o003o9?oo
ool00ol00?ooooooooooo`0Rooooo`03o`00oooooooooooo027ooooo0_l00?m=ooooo`03o`00oooo
oooooooo02;ooooo00?o003oooooooooool0F_ooool00ol0003oooooooooo`0Cooooo`00:?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo06kooooo0_l00?lTooooo`03o`00oooooooo
oooo02;ooooo00?o003oooooooooool08_ooool00ol00?ooooooooooo`0Uooooo`;o003o9?ooool0
0ol00?ooooooooooo`0Rooooo`03o`00oooooooooooo05[ooooo00?o0000ooooooooool04oooool0
037ooooo00?o0000ooooooooool0Koooool00ol00?ooooooooooo`0Rooooo`03o`00oooooooooooo
02;ooooo00?o003oooooooooool08_ooool00ol00?ooooooooooo`0Qooooo`;o003o0_ooool2o`00
obCooooo00?o003oooooooooool08_ooool00ol00?ooooooooooo`1Jooooo`03o`000?oooooooooo
01?ooooo000aooooo`03o`000?oooooooooo06[ooooo0_l00?l3ooooo`03o`00oooooooooooo02;o
oooo00?o003oooooooooool08_ooool00ol00?ooooooooooo`0Rooooo`03o`00oooooooooooo027o
oooo0_l00?l3ooooo`03o`00oooooooooooo02;ooooo00?o003oooooooooool08_ooool00ol00?oo
ooooooooo`1Jooooo`03o`000?oooooooooo01?ooooo000aooooo`03o`000?oooooooooo06[ooooo
0_l00?l3ooooo`03o`00oooooooooooo02;ooooo00?o003oooooooooool08_ooool00ol00?oooooo
ooooo`0Rooooo`03o`00oooooooooooo02;ooooo00Go003oooooooooooooooooo`00o`0Tooooo`03
o`00oooooooooooo02;ooooo00?o003oooooooooool0F_ooool00ol0003oooooooooo`0Cooooo`00
<Oooool3o`0006[ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Rooooo`03o`00
oooooooooooo02;ooooo00?o003oooooooooool08_ooool00ol00?ooooooooooo`02o`00ob3ooooo
00Go003oooooooooooooooooo`00o`0Tooooo`03o`00oooooooooooo02;ooooo00?o003ooooooooo
ool0F?ooool3o`0001Gooooo000aooooo`03o`000?oooooooooo06[ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`0Rooooo`03o`00oooooooooooo02;ooooo00?o003oooooooooool0
8_ooool00ol00?ooooooooooo`02o`00ob3ooooo00Go003oooooooooooooooooo`00o`0Tooooo`03
o`00oooooooooooo02;ooooo00?o003oooooooooool0F_ooool00ol0003oooooooooo`0Cooooo`00
<Oooool00ol0003oooooooooo`1Zooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
8_ooool00ol00?ooooooooooo`0Rooooo`03o`00oooooooooooo02;ooooo00Go003ooooooooooooo
ooooo`00o`0Pooooo`05o`00ooooooooooooooooool00?l07oooool2o`00o`?ooooo00?o003ooooo
ooooool08_ooool00ol00?ooooooooooo`1Jooooo`03o`000?oooooooooo01?ooooo000aooooo`03
o`000?oooooooooo06[ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Rooooo`03
o`00oooooooooooo02;ooooo00?o003oooooooooool08_ooool01Ol00?oooooooooooooooooo003o
023ooooo00Go003oooooooooooooooooo`00o`0Oooooo`;o003o0oooool00ol00?ooooooooooo`0R
ooooo`03o`00oooooooooooo05[ooooo00?o0000ooooooooool04oooool0037ooooo00?o0000oooo
ooooool0J_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01gooooo0_l00?l3oooo
o`03o`00oooooooooooo02;ooooo00?o003oooooooooool08_ooool01Ol00?oooooooooooooooooo
003o023ooooo00Go003oooooooooooooooooo`00o`0Pooooo`05o`00ooooooooooooooooool00?l0
9?ooool00ol00?ooooooooooo`1Jooooo`03o`000?oooooooooo01?ooooo000aooooo`03o`000?oo
oooooooo06[ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Mooooo`;o003o0ooo
ool00ol00?ooooooooooo`0Rooooo`03o`00oooooooooooo02;ooooo00Go003ooooooooooooooooo
o`00o`0Pooooo`05o`00ooooooooooooooooool00?l08?ooool01Ol00?oooooooooooooooooo003o
02Cooooo00?o003oooooooooool0F_ooool00ol0003oooooooooo`0Cooooo`00<Oooool00ol0003o
ooooooooo`1Zooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool07_ooool01Ol00?oo
oooooooooooooooo003o02Cooooo00?o003oooooooooool00_l00?lPooooo`05o`00oooooooooooo
ooooool00?l08?ooool01Ol00?oooooooooooooooooo003o023ooooo00Go003ooooooooooooooooo
o`00o`0Tooooo`03o`00oooooooooooo05[ooooo00?o0000ooooooooool04oooool0037ooooo0ol0
001Zooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool07_ooool01Ol00?oooooooooo
oooooooo003o02Cooooo00?o003oooooooooool00_l00?lPooooo`05o`00ooooooooooooooooool0
0?l08?ooool01Ol00?oooooooooooooooooo003o023ooooo00Go003oooooooooooooooooo`00o`0T
ooooo`03o`00oooooooooooo05Sooooo0ol0000Eooooo`00<Oooool00ol0003oooooooooo`1Zoooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool07_ooool01Ol00?oooooooooooooooooo
003o02Cooooo00Go003oooooooooooooooooo`00o`0Pooooo`05o`00ooooooooooooooooool00?l0
8?ooool01Ol00?oooooooooooooooooo003o023ooooo00Go003oooooooooooooooooo`00o`0Poooo
o`;o003o0_ooool00ol00?ooooooooooo`1Jooooo`03o`000?oooooooooo01?ooooo000aooooo`03
o`000?oooooooooo06[ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Nooooo`05
o`00ooooooooooooooooool00?l09?ooool01Ol00?oooooooooooooooooo003o023ooooo00Go003o
ooooooooooooooooo`00o`0Pooooo`05o`00ooooooooooooooooool00?l08?ooool01Ol00?oooooo
oooooooooooo003o023ooooo0_l00?l2ooooo`03o`00oooooooooooo05[ooooo00?o0000oooooooo
ool04oooool0037ooooo00?o0000ooooooooool0J_ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo01kooooo00Go003oooooooooooooooooo`00o`0Oooooo`;o003o0oooool01Ol00?oo
oooooooooooooooo003o023ooooo00Go003oooooooooooooooooo`00o`0Pooooo`05o`00oooooooo
ooooooooool00?l08?ooool01Ol00?oooooooooooooooooo003o023ooooo00Go003ooooooooooooo
ooooo`00o`1Looooo`03o`000?oooooooooo01?ooooo000aooooo`03o`000?oooooooooo06[ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Nooooo`05o`00ooooooooooooooooool0
0?l07oooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`0Pooooo`05o`00oooooooooooo
ooooool00?l08?ooool01Ol00?oooooooooooooooooo003o023ooooo00Go003ooooooooooooooooo
o`00o`0Pooooo`05o`00ooooooooooooooooool00?l0G?ooool00ol0003oooooooooo`0Cooooo`00
<Oooool00ol0003oooooooooo`1Zooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
7_ooool01Ol00?oooooooooooooooooo003o023ooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo01kooooo00Go003oooooooooooooooooo`00o`0Pooooo`05o`00oooooooo
ooooooooool00?l08?ooool01Ol00?oooooooooooooooooo003o023ooooo00Go003ooooooooooooo
ooooo`00o`1Looooo`03o`000?oooooooooo01?ooooo000aooooo`03o`000?oooooooooo06[ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Nooooo`05o`00ooooooooooooooooool0
0?l00_ooool2o`00oacooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
01kooooo00Go003oooooooooooooooooo`00o`0Pooooo`05o`00ooooooooooooooooool00?l08?oo
ool01Ol00?oooooooooooooooooo003o023ooooo00Go003oooooooooooooooooo`00o`1Looooo`03
o`000?oooooooooo01?ooooo000aooooo`?o0000J_ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo01kooooo00Go003oooooooooooooooooo`00o`02ooooo`;o003o7?ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool07_ooool01Ol00?oooooooooooooooooo
003o023ooooo00Go003oooooooooooooooooo`00o`0Pooooo`05o`00ooooooooooooooooool00?l0
8?ooool01Ol00?oooooooooooooooooo003o05[ooooo0ol0000Eooooo`00<Oooool00ol0003ooooo
ooooo`1Zooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool07_ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool06_ooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool07_ooool01Ol00?oooooooooooooooooo003o023ooooo00Go003o
ooooooooooooooooo`00o`0Pooooo`05o`00ooooooooooooooooool00?l00oooool2o`00oa_ooooo
00Go003oooooooooooooooooo`00o`1Looooo`03o`000?oooooooooo01?ooooo000aooooo`03o`00
0?oooooooooo06[ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Nooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Jooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`0Nooooo`05o`00ooooooooooooooooool00?l08?ooool0
1Ol00?oooooooooooooooooo003o023ooooo00Go003oooooooooooooooooo`00o`03ooooo`;o003o
6oooool01Ol00?oooooooooooooooooo003o05cooooo00?o0000ooooooooool04oooool0037ooooo
00?o0000ooooooooool0J_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01kooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01[ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo01kooooo00Go003oooooooooooooooooo`00o`0P
ooooo`05o`00ooooooooooooooooool00?l08?ooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool06_ooool01Ol00?oooooooooooooooooo003o05cooooo00?o0000oooooooo
ool04oooool0037ooooo00?o0000ooooooooool0J_ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo01kooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01[o
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01Wooooo0_l00?l3oooo
o`05o`00ooooooooooooooooool00?l08?ooool01Ol00?oooooooooooooooooo003o023ooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01[ooooo00Go003ooooooooooooo
ooooo`00o`1Looooo`03o`000?oooooooooo01?ooooo000aooooo`03o`000?oooooooooo06[ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Nooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`0Jooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`0Iooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o023ooooo00Go003o
ooooooooooooooooo`00o`0Pooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`0Jooooo`05o`00ooooooooooooooooool00?l0G?ooool00ol0003oooooooooo`0Cooooo`00
<Oooool3o`0006[ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Nooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Jooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`0Jooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`0Nooooo`05o`00ooooooooooooooooool00?l08?ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool06_ooool01Ol00?oooooooooooooooooo003o05[o
oooo0ol0000Eooooo`00<Oooool00ol0003oooooooooo`1Zooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool00_l00?lLooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`0Jooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Joooo
o`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Nooooo`05o`00oooooooo
ooooooooool00?l08?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
6_ooool01Ol00?oooooooooooooooooo003o05cooooo00?o0000ooooooooool04oooool0037ooooo
00?o0000ooooooooool0J_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;o003o
7?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool06_ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool06_ooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o003oooooooooool07_ooool01Ol00?oooooooooooooooooo003o023ooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01[ooooo00Go003ooooooooooooo
ooooo`00o`1Looooo`03o`000?oooooooooo01?ooooo000aooooo`03o`000?oooooooooo06[ooooo
00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o01cooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo01[ooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo01[ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooo
oooooooo01kooooo00Go003oooooooooooooooooo`00o`0Pooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`0Jooooo`05o`00ooooooooooooooooool00?l0G?ooool00ol0
003oooooooooo`0Cooooo`00<Oooool00ol0003oooooooooo`1Zooooo`03o`00oooooooooooo00;o
oooo00Go003oooooooooooooooooo`00o`0Looooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`0Jooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`0Jooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Nooooo`05o`00
ooooooooooooooooool00?l00oooool2o`00oa_ooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo01[ooooo00Go003oooooooooooooooooo`00o`1Looooo`03o`000?oooooo
oooo01?ooooo000Looooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001oooool00ol0
003oooooooooo`1Zooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`0L
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Jooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`0Jooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`0Nooooo`05o`00ooooooooooooooooool00?l00oooool2o`00
oa_ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01[ooooo00Go003o
ooooooooooooooooo`00o`1Looooo`03o`000?oooooooooo01?ooooo000Kooooo`04o`000?oooooo
ooooo`0000Oooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo06[ooooo
00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o01cooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo01[ooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo01[ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooo
oooooooo01kooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01[ooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01[ooooo00Go003ooooooooo
ooooooooo`00o`1Looooo`03o`000?oooooooooo01?ooooo000Dooooo`Go00000_ooool01?l0003o
ooooooooool0000;ooooo`03o`000?oooooooooo00Cooooo1?l0001Yooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`0Looooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`0Jooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`0Jooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Iooooo`;o
003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool06_ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool06_ooool01Ol00?oooooooooooooo
oooo003o05Wooooo1?l0000Eooooo`006oooool01?l0003oooooooooool0000;ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0J_ooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l07?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool06_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool06_ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool06Oooool2o`00o`?ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01[ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo01[ooooo00Go003oooooooooooooooooo`00o`1Looooo`03
o`000?oooooooooo01?ooooo000Kooooo`04o`000?ooooooooooo`0000Oooooo1?l00007ooooo`03
o`000?oooooooooo06[ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
01cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01[ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01[ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo01[ooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l07?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool06_ooool01Ol00?oooooooooooooooooo003o05cooooo00?o0000ooooooooool04ooo
ool001_ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo06Kooooo0_l00?l2ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`0Looooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Jooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Jooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`0Jooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o01cooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo01[ooooo00Go003oooooooooooooooooo`00o`1Looooo`03o`000?oooooooooo
01?ooooo000Looooo`;o00002?ooool5o`0000Kooooo00?o0000ooooooooool0I_ooool2o`00o`;o
oooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o01cooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo01[ooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo01[ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo01[ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l07?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool06_ooool0
1Ol00?oooooooooooooooooo003o05cooooo00?o0000ooooooooool04oooool0037ooooo00?o0000
ooooooooool0I_ooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooooooooooooooo
o`00o`0Looooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Jooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Jooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`0Jooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o01cooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo01[ooooo00Go003oooooooooooooooooo`00o`1Looooo`03o`000?oooooooooo
01?ooooo000aooooo`03o`000?oooooooooo06Kooooo00Go003oooooooooooooooooo`00o`04oooo
o`05o`00ooooooooooooooooool00?l07?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool06_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
6_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Co003ooooooooooooooooo0_l00?lGoooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o01cooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01[ooooo00Go003ooooooooooooo
ooooo`00o`1Looooo`03o`000?oooooooooo01?ooooo000aooooo`?o0000I_ooool01Ol00?oooooo
oooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`0Looooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`0Jooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`0Jooooo`05o`00ooooooooooooooooool00?l00oooool01?l00?oooooo
ooooooooool2o`00oaOooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l07?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool06_oo
ool01Ol00?oooooooooooooooooo003o05[ooooo0ol0000Eooooo`00<Oooool00ol0003ooooooooo
o`1Vooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o01co
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01[ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo01[ooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l06?ooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`0Looooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`0Jooooo`05o`00ooooooooooooooooool00?l0G?ooool00ol0003ooooooooo
o`0Cooooo`00<Oooool00ol0003oooooooooo`1Vooooo`05o`00ooooooooooooooooool00?l01?oo
ool01Ol00?oooooooooooooooooo003o01cooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo01[ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
01[ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l06?oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`0Looooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Jooooo`05o`00oooooooooooo
ooooool00?l0G?ooool00ol0003oooooooooo`0Cooooo`00<Oooool00ol0003oooooooooo`1Voooo
o`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o01cooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01[ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo01[ooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l06?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`0Gooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool06_ooool01Ol00?oooooooooooooooooo003o05cooooo00?o0000oooo
ooooool04oooool0037ooooo00?o0000ooooooooool0I_ooool01Ol00?oooooooooooooooooo003o
00Cooooo00Go003oooooooooooooooooo`00o`0Looooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`0Jooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`0Jooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
01Sooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l05ooo
ool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01[ooooo
00Go003oooooooooooooooooo`00o`1Looooo`03o`000?oooooooooo01?ooooo000aooooo`03o`00
0?oooooooooo06Kooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooooooooooooooo
ool00?l07?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool06_ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool06_ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`0Hooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o01Sooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l07?ooool01Ol00?oooooooooooooooooo003o05co
oooo00?o0000ooooooooool04oooool0037ooooo00?o0000ooooooooool0I_ooool01Ol00?oooooo
oooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`0Gooooo`;o003o0oooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool06_ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool06_ooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`0Hooooo`05o`00ooooooooooooooooool00?l00oooool01Ol0
0?oooooooooooooooooo003o01Sooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l07?ooool01Ol00?oooooooooooooooooo003o05cooooo00?o0000oooooooo
ool04oooool0037ooooo0ol0001Vooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oo
oooooooooooooooo003o01Oooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`0Jooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`0Jooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o01So
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l06?ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`0Looooo`05o`00
ooooooooooooooooool00?l0F_ooool3o`0001Gooooo000aooooo`03o`000?oooooooooo06Kooooo
00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l05oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0J
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Jooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o01Sooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l06?ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`0Looooo`05o`00ooooooooooooooooool0
0?l0G?ooool00ol0003oooooooooo`0Cooooo`00<Oooool00ol0003oooooooooo`1Vooooo`05o`00
ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o01Oooooo00?o003ooooo
ooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool06_ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_l00?lHooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o01Sooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l06?ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`0Looooo`05o`00ooooooooooooooooool0
0?l0G?ooool00ol0003oooooooooo`0Cooooo`00<Oooool00ol0003oooooooooo`1Vooooo`05o`00
ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o01Oooooo00?o003ooooo
ooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool06_ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_l00?lHooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o01Sooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l06?ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`0Looooo`05o`00ooooooooooooooooool0
0?l0G?ooool00ol0003oooooooooo`0Cooooo`00<Oooool00ol0003oooooooooo`1Vooooo`05o`00
ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o01Oooooo00?o003ooooo
ooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool06_ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`0Hooooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o01Sooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l06?ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`0Looooo`05o`00oooooooooooooooo
ool00?l0G?ooool00ol0003oooooooooo`0Cooooo`00<Oooool00ol0003oooooooooo`1Vooooo`05
o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o01Oooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool06_oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`0Hooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o01Sooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l06?ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`0Looooo`05o`00oooooooooooo
ooooool00?l0G?ooool00ol0003oooooooooo`0Cooooo`00<Oooool00ol0003oooooooooo`1Voooo
o`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o01Oooooo00?o
003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
6_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`0Hoooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o01Sooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l06?ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`0Gooooo`;o003o0oooool0
1Ol00?oooooooooooooooooo003o05cooooo00?o0000ooooooooool04oooool0037ooooo0ol0001V
ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o01Oooooo
00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool06_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`0H
ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o01Sooooo
00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l06?ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`0Gooooo`;o003o0ooo
ool01Ol00?oooooooooooooooooo003o05[ooooo0ol0000Eooooo`00<Oooool00ol0003ooooooooo
o`1Vooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o01Oo
oooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool06_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`0Hooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o01So
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l06?ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`0Hooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`1Jooooo`03o`000?oooooooooo01?o
oooo000aooooo`03o`000?oooooooooo06Kooooo00Go003oooooooooooooooooo`00o`04ooooo`05
o`00ooooooooooooooooool00?l05oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`0Eooooo`;o003o0oooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`0Hooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o01Sooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l06?ooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`0Hooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`1Jooooo`03o`000?oooooooooo01?ooooo000aooooo`03o`000?oooooooooo06Ko
oooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l05oooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`0Eooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`0Hooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o01Sooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0
6?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`0Hoooo
o`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`1Jooooo`03o`000?oooooo
oooo01?ooooo000aooooo`03o`000?oooooooooo06Kooooo00Go003oooooooooooooooooo`00o`04
ooooo`05o`00ooooooooooooooooool00?l05oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`0Fooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool05_ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`0Hooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o01Sooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l06?ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool0F_ooool00ol0003oooooooooo`0Cooooo`00<Oooool0
0ol0003oooooooooo`1Vooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooo
oooooooo003o01Oooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool05_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo01Kooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l06?ooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`0Hooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o01Sooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo05[ooooo00?o0000ooooooooool04oooool0037ooooo00?o0000ooooooooool0I_oo
ool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`0Gooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00;o003o5?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo01Kooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l06?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`0Hooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o01Sooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo05[o
oooo00?o0000ooooooooool04oooool0037ooooo0ol0001Vooooo`05o`00ooooooooooooooooool0
0?l01?ooool01Ol00?oooooooooooooooooo003o01Oooooo00?o003oooooooooool00_ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_l00?lDooooo`05o`00oooooooo
ooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
5_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`0Hoooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o01Sooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l06?ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool0F?ooool3o`0001Gooooo000aooooo`03
o`000?oooooooooo06Kooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooooooooooo
ooooool00?l05oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o01Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Fooooo`05o`00oooooooooooo
ooooool00?l00oooool01Ol00?oooooooooooooooooo003o01Sooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l06?ooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`0Hooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`1Jooooo`03o`000?oooooooooo01?ooooo000aooooo`03o`000?oooooo
oooo06Kooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l0
5oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o01Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`0Fooooo`05o`00ooooooooooooooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o01Sooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l06?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`0Hooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`1Jooooo`03o`000?oooooooooo01?ooooo000aooooo`03o`000?oooooooooo06Kooooo
00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l05oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o01Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`0Fooooo`05o`00ooooooooooooooooool00?l00oooool01Ol0
0?oooooooooooooooooo003o01Sooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l06?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`;o003o4oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool0F_ooool00ol0003oooooooooo`0Cooooo`00:?ooool2o`0000Oooooo00?o0000oooo
ooooool0I_ooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00
o`0Gooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l05?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo01Kooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l06?ooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`0Hooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o00?ooooo0_l00?lCooooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`1Jooooo`03o`000?oooooooooo01?ooooo000Wooooo`04o`000?oo
ooooooooo`0000Kooooo00?o0000ooooooooool0I_ooool01Ol00?oooooooooooooooooo003o00Co
oooo00Go003oooooooooooooooooo`00o`0Gooooo`03o`00oooooooooooo00;ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l05?ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01Ko
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l06?ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`0Hooooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool04_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0F_ooool0
0ol0003oooooooooo`0Cooooo`009oooool01?l0003oooooooooool00006ooooo`03o`000?oooooo
oooo00Oooooo0_l00?l2ooooo`;o003o0_ooool2o`00o`;ooooo0_l00?l3ooooo`;o003o0_ooool2
o`00o`;ooooo0_l00?l2ooooo`;o003o0_ooool2o`00o`;ooooo0_l00?l2ooooo`;o003o0_ooool2
o`00o`;ooooo0_l00?l3ooooo`;o003o0_ooool2o`00o`;ooooo0_l00?l2ooooo`;o003o0_ooool2
o`00o`;ooooo0_l00?l2ooooo`;o003o3oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go
003oooooooooooooooooo`00o`0Gooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l05?ooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo017ooooo0_l0
0?l3ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o01So
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l06?ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo01;ooooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00oooooooooooooooo
o`;o003o0_ooool2o`00o`;ooooo0_l00?l2ooooo`;o003o0_ooool2o`00o`;ooooo0_l00?l3oooo
o`;o003o0_ooool2o`00o`;ooooo0_l00?l2ooooo`;o003o0_ooool2o`00o`;ooooo0_l00?l2oooo
o`;o003o0_ooool2o`00o`;ooooo0_l00?l3ooooo`;o003o0_ooool2o`00o`;ooooo0_l00?l2oooo
o`;o003o0_ooool2o`00o`Wooooo00?o0000ooooooooool04oooool002Oooooo00Co0000oooooooo
oooo00001_ooool:o`0000;o003o0_l00002o`00o`;o00000_l00?l2o`0000;o003o0ol00002o`00
o`;o00000_l00?l2o`0000;o003o0_l00002o`00o`;o00000_l00?l2o`0000;o003o0_l00002o`00
o`;o00000_l00?l2o`0000;o003o0ol00002o`00o`;o00000_l00?l2o`0000;o003o0_l00002o`00
o`;o00000_l00?l2o`0000;o003o0_l00002o`00o`?o000000Go003oo`000?l0003o0000o`00o`03
o`000005o`00ool0003o0000o`000?l00?l00ol000000ol00?oo0000o`000002o`000005o`00ool0
003o0000o`000?l00?l00ol000001Ol00?oo0000o`000?l0003o003o00?o000000Go003oo`000?l0
003o0000o`00o`03o`000005o`00ool0003o0000o`000?l00?l01?l000001Ol00?oo0000o`000?l0
003o003o00?o000000Go003oo`000?l0003o0000o`00o`03o`000005o`00ool0003o0000o`000?l0
0?l00ol000001Ol00?oo0000o`000?l0003o003o00Co000000Go003oo`000?l0003o0000o`00o`03
o`000005o`00ool0003o0000o`000?l00?l00ol000001Ol00?oo0000o`000?l0003o003o00?o0000
00Go003oo`000?l0003o0000o`00o`03o`000004o`00ool0003o0000o`0000;o003o0ol000001Ol0
0?oo0000o`000?l0003o003o00?o000000Go003oo`000?l0003o0000o`00o`03o`000005o`00ool0
003o0000o`000?l00?l00ol000000ol00?oo0000o`000002o`000005o`00ool0003o0000o`000?l0
0?l00ol000001Ol00?oo0000o`000?l0003o003o00?o000000Go003oo`000?l0003o0000o`00o`03
o`000005o`00ool0003o0000o`000?l00?l01?l000001Ol00?oo0000o`000?l0003o003o00?o0000
00Go003oo`000?l0003o0000o`00o`03o`000005o`00ool0003o0000o`000?l00?l00ol000001Ol0
0?oo0000o`000?l0003o003o00?o000000?o003oo`000?l000000_l000001Ol00?oo0000o`000?l0
003o003o00?o000000Go003oo`000?l0003o0000o`00o`03o`000005o`00ool0003o0000o`000?l0
0?l00ol00002o`00o`;o00000_l00?l2o`0000;o003o0_l00002o`00o`;o00000_l00?l2o`0000;o
003o0ol00002o`00o`;o00000_l00?l2o`0000;o003o0_l00002o`00o`;o00000_l00?l2o`0000;o
003o0_l00002o`00o`;o00000_l00?l2o`0000;o003o0ol00002o`00o`;o00000_l00?l2o`0000;o
003o0_l00002o`00o`;o00000_l00?l:o`0001Gooooo000Wooooo`04o`000?ooooooooooo`0000Ko
oooo00?o0000ooooooooool0F_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool04_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo01Kooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l06?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`0Hooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l04oooool01Ol00?oooooooooooooooooo003o00Co
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01Gooooo00?o003ooooo
ooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0I_ooool0
0ol0003oooooooooo`0Cooooo`009oooool01?l0003oooooooooool00006ooooo`03o`000?oooooo
oooo05[ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01;ooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`0Fooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o01Sooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0
6?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oo
oooooooooooooooo003o01?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo00;ooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo06Kooooo00?o0000ooooooooool0
4oooool002Sooooo0_l00007ooooo`03o`000?oooooooooo05[ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo017ooooo0_l00?l3ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o01Sooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l06?ooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`0Hooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l04oooool01Ol00?oooooooooooooo
oooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01Gooooo
00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool0I_ooool00ol0003oooooooooo`0Cooooo`00<Oooool00ol0003oooooooooo`1Jooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Aooooo`;o003o0oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`0Hooooo`05o`00oooooooo
ooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o01Sooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l06?ooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o01?ooooo00Go
003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`0Eooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo06Kooooo00?o0000ooooooooool04oooool0037ooooo00?o0000oooooooo
ool0F_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool05_ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`0Hooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o01Sooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l06?ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o01?ooooo
00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`0Eooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo06Kooooo00?o0000ooooooooool04oooool0037ooooo0ol0001Joooo
o`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Fooooo`05o`00oooooooo
ooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o01Sooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l06?ooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`0Hooooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l04oooool2o`00o`;o
oooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool05Oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`1Tooooo`?o00005Oooool0037ooooo00?o0000ooooooooool0F_ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool05_ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`0Hooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o01Sooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l06?ooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o01?ooooo0_l00?l2ooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
01Gooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool0I_ooool00ol0003oooooooooo`0Cooooo`00<Oooool00ol0003oooooooooo`1Joooo
o`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Fooooo`05o`00oooooooo
ooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o01Sooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l06?ooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`0Hooooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l05oooool00ol00?oo
ooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Eoooo
o`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo06Kooooo00?o0000ooooooooool04oooool0037ooooo00?o0000ooooooooool0F_ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool05_ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`0Hooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o01Sooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l06?ooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o01Oooooo00?o003ooooooooo
ool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool05Oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`1V
ooooo`03o`000?oooooooooo01?ooooo000aooooo`03o`000?oooooooooo05[ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo01Kooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l06?ooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`0Hooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o01Sooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool00_l00?lGooooo`03o`00oooooooooooo00;ooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01Gooooo00?o003ooooooooo
ool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0I_ooool00ol0
003oooooooooo`0Cooooo`00<Oooool00ol0003oooooooooo`1Jooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`0Fooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o01Sooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l06?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`0Hooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo00;o003o5oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo00;ooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo06Kooooo00?o0000oooooooo
ool04oooool0037ooooo00?o0000ooooooooool0F_ooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool05_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`0Hooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o01Sooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l06?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`0Iooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool00_ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool0I_ooool00ol0003oooooooooo`0Cooooo`00<Ooo
ool3o`0005[ooooo00Go003oooooooooooooooooo`00o`03ooooo`;o003o5oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`0Hooooo`05o`00oooooooooooo
ooooool00?l00oooool01Ol00?oooooooooooooooooo003o01Sooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l06?ooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Iooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01Gooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0I?oo
ool3o`0001Gooooo000aooooo`03o`000?oooooooooo05[ooooo00Go003oooooooooooooooooo`00
o`03ooooo`;o003o5oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`0Hooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o01Sooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0
6?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`0Iooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo01Gooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o003oooooooooool0I_ooool00ol0003oooooooooo`0Cooooo`00<Oooool00ol0
003oooooooooo`1Jooooo`05o`00ooooooooooooooooool00?l07?ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`0Hooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o01Sooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l06?ooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Iooooo`03o`00oooooooooooo00;ooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01Gooooo00?o003ooooooooo
ool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0I_ooool00ol0
003oooooooooo`0Cooooo`00<Oooool00ol0003oooooooooo`1Jooooo`05o`00oooooooooooooooo
ool00?l07?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`0Hooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o01So
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l06?ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`0Iooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo01Gooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool0I_ooool00ol0003oooooooooo`0Cooooo`00<Oooool00ol0003ooooo
ooooo`1Jooooo`05o`00ooooooooooooooooool00?l07?ooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`0Hooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o01Sooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l06?ooool2o`00o`;ooooo00Go003oooooooooooooooooo`00o`04
ooooo`03o`00oooooooooooo01Wooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`1Vooooo`03o`000?oooooooooo01?ooooo
000aooooo`03o`000?oooooooooo05[ooooo00Go003oooooooooooooooooo`00o`0Looooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o01Sooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l06?ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`0Hooooo`;o003o0_ooool01Ol00?oo
oooooooooooooooo003o00Cooooo00?o003oooooooooool06Oooool00ol00?ooooooooooo`02oooo
o`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooo
oooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo06Kooooo00?o
0000ooooooooool04oooool0037ooooo00?o0000ooooooooool0F_ooool01Ol00?oooooooooooooo
oooo003o01cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool0
0?l06?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`0H
ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o01cooooo
00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo01Wooooo00?o003ooooooooo
ool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool05Oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`1V
ooooo`03o`000?oooooooooo01?ooooo000aooooo`?o0000F_ooool01Ol00?oooooooooooooooooo
003o01cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0
6?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`0Hoooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o01cooooo00Go
003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo01Wooooo00?o003oooooooooool0
0_ooool01Ol00?oooooooooooooooooo003o00;ooooo0_l00?lGooooo`03o`00oooooooooooo00;o
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo06Cooooo0ol0000Eoooo
o`00<Oooool00ol0003oooooooooo`1Jooooo`05o`00ooooooooooooooooool00?l07?ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`0Hooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o01Sooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l07?ooool01Ol00?oooooooooooooo
oooo003o00Cooooo00?o003oooooooooool06Oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00_ooool2o`00oaOooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool0I_ooool00ol0003oooooooooo`0Cooooo`00
<Oooool00ol0003oooooooooo`1Jooooo`05o`00ooooooooooooooooool00?l07?ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`0Hooooo`05o`00oooooooo
ooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o01Sooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l07?ooool01Ol00?oooooooooooooooooo
003o00Cooooo00?o003oooooooooool06Oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooo
ooooooooool00?l06oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`1Vooooo`03o`000?oooooooooo01?ooooo000aooooo`03o`000?oo
oooooooo05[ooooo00Go003oooooooooooooooooo`00o`0Looooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o01Sooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l06?ooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`0Looooo`05o`00ooooooooooooooooool00?l01?ooool00ol0
0?ooooooooooo`0Iooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`0K
ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooo
oooooooo06Kooooo00?o0000ooooooooool04oooool0037ooooo00?o0000ooooooooool0F_ooool0
1Ol00?oooooooooooooooooo003o01cooooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00
ooooooooooooooooo`;o003o5oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`0Hooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o01cooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo01Wo
oooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o01_ooooo00?o003ooooo
ooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0I_ooool0
0ol0003oooooooooo`0Cooooo`00<Oooool00ol0003oooooooooo`1Jooooo`05o`00oooooooooooo
ooooool00?l07?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Co003ooooooooooooooooo
0_l00?lGooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
01Sooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l07?oo
ool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool06Oooool00ol00?oooooo
ooooo`02ooooo`05o`00ooooooooooooooooool00?l06oooool00ol00?ooooooooooo`02ooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`1Vooooo`03o`000?oooooooooo
01?ooooo000aooooo`03o`000?oooooooooo05[ooooo00Go003oooooooooooooooooo`00o`0Loooo
o`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Jooooo`05o`00oooooooo
ooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o01Sooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l07?ooool01Ol00?oooooooooooooooooo
003o00Cooooo00?o003oooooooooool06Oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooo
ooooooooool00?l06oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`1Vooooo`03o`000?oooooooooo01?ooooo000aooooo`?o0000F_oo
ool01Ol00?oooooooooooooooooo003o01cooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo01[ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l06?ooool2o`00o`;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooo
oooooooo01[ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo01Wooooo
00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o01_ooooo00?o003ooooooooo
ool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0I?ooool3o`00
01Gooooo000aooooo`03o`000?oooooooooo05[ooooo00Go003oooooooooooooooooo`00o`0Loooo
o`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Jooooo`05o`00oooooooo
ooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o01Sooooo0_l00?l2ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Jooooo`05o`00oooooooooooooooo
ool00?l01?ooool00ol00?ooooooooooo`0Iooooo`03o`00oooooooooooo00;ooooo00Go003ooooo
ooooooooooooo`00o`0Kooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo06Kooooo00?o0000ooooooooool04oooool0037ooooo00?o0000
ooooooooool0F_ooool01Ol00?oooooooooooooooooo003o01cooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo01[ooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l07?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool06_ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool06Ooo
ool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l06oooool00ol00?oooooo
ooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`1Vooooo`03
o`000?oooooooooo01?ooooo000aooooo`03o`000?oooooooooo05[ooooo00Go003ooooooooooooo
ooooo`00o`0Looooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Joooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o01cooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01[ooooo00Go003ooooooooooooo
ooooo`00o`04ooooo`03o`00oooooooooooo01Wooooo00?o003oooooooooool00_ooool01Ol00?oo
oooooooooooooooo003o01_ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo
003o00;ooooo0_l00?mXooooo`03o`000?oooooooooo01?ooooo000Looooo`;o00001?ooool00ol0
003oooooooooo`02ooooo`?o00001oooool00ol0003oooooooooo`1Jooooo`05o`00oooooooooooo
ooooool00?l07?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool06_oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`0Looooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Jooooo`05o`00oooooooooooo
ooooool00?l01?ooool00ol00?ooooooooooo`0Iooooo`03o`00oooooooooooo00;ooooo00Go003o
ooooooooooooooooo`00o`0Kooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`02ooooo`;o003oJ?ooool00ol0003oooooooooo`0Cooooo`006oooool01?l0003ooooooooo
ool00007ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`1Jooooo`05
o`00ooooooooooooooooool00?l07?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool06_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`0Looooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Jooooo`05
o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`0Iooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`0Kooooo`03o`00oooooooooooo00;ooooo00Go003o
ooooooooooooooooo`00o`1/ooooo`03o`000?oooooooooo01?ooooo000Kooooo`04o`000?oooooo
ooooo`0000_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Jooooo`05o`00oooo
ooooooooooooool00?l07?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool06_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Co003ooooooooooooooooo0_l00?lK
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Jooooo`05o`00oooo
ooooooooooooool00?l01?ooool00ol00?ooooooooooo`0Iooooo`03o`00oooooooooooo00;ooooo
00Go003oooooooooooooooooo`00o`0Kooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooo
ooooooooo`00o`1/ooooo`03o`000?oooooooooo01?ooooo000Kooooo`04o`000?ooooooooooo`00
00_ooooo00?o0000ooooooooool01?ooool4o`0005Wooooo00Go003oooooooooooooooooo`00o`0L
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Jooooo`05o`00oooo
ooooooooooooool00?l00oooool01?l00?ooooooooooooooool2o`00oa_ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo01[ooooo00Go003oooooooooooooooooo`00o`04
ooooo`03o`00oooooooooooo01Wooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooo
oooo003o01_ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o06Wooooo
1?l0000Eooooo`006oooool01?l0003oooooooooool00007ooooo`Co00001oooool00ol0003ooooo
ooooo`1Jooooo`05o`00ooooooooooooooooool00?l07?ooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool06_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool07_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool06_oo
ool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool06Oooool00ol00?oooooo
ooooo`02ooooo`05o`00ooooooooooooooooool00?l06oooool00ol00?ooooooooooo`02ooooo`05
o`00ooooooooooooooooool00?l0K?ooool00ol0003oooooooooo`0Cooooo`006oooool01?l0003o
ooooooooool00007ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0F_ooool01Ol0
0?oooooooooooooooooo003o01cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooo
oooooooo01[ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01kooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01[ooooo00Go003ooooooooo
ooooooooo`00o`04ooooo`03o`00oooooooooooo01Wooooo00?o003oooooooooool00_ooool01Ol0
0?oooooooooooooooooo003o01_ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooo
oooo003o06cooooo00?o0000ooooooooool04oooool001cooooo0_l00008ooooo`Go00001_ooool0
0ol0003oooooooooo`1Jooooo`05o`00ooooooooooooooooool00?l07?ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool06Oooool2o`00o`?ooooo00Go003ooooooooooooo
ooooo`00o`0Pooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Joooo
o`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`0Iooooo`03o`00oooooooo
oooo00;ooooo00Go003oooooooooooooooooo`00o`0Kooooo`03o`00oooooooooooo00;ooooo00Go
003oooooooooooooooooo`00o`1/ooooo`03o`000?oooooooooo01?ooooo000aooooo`03o`000?oo
oooooooo05[ooooo00Go003oooooooooooooooooo`00o`0Looooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`0Iooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o
023ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01[ooooo00Go003o
ooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo01Wooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o01_ooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o06cooooo00?o0000ooooooooool04oooool0037ooooo00?o0000ooooooooool0
F_ooool01Ol00?oooooooooooooooooo003o01cooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo01kooooo00Go003oooooooooooooooooo`00o`0Pooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`0Jooooo`05o`00ooooooooooooooooool00?l0
1?ooool00ol00?ooooooooooo`0Iooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooo
ooooo`00o`0Kooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`1/oooo
o`03o`000?oooooooooo01?ooooo000aooooo`03o`000?oooooooooo05[ooooo00Go003ooooooooo
ooooooooo`00o`0Looooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0N
ooooo`05o`00ooooooooooooooooool00?l08?ooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool06_ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003ooooooooo
ool06Oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l06oooool2o`00
o`?ooooo00Go003oooooooooooooooooo`00o`1/ooooo`03o`000?oooooooooo01?ooooo000aoooo
o`?o0000F_ooool01Ol00?oooooooooooooooooo003o01cooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo01kooooo00Go003oooooooooooooooooo`00o`0Pooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Jooooo`05o`00oooooooooooooooo
ool00?l01?ooool00ol00?ooooooooooo`0Iooooo`03o`00oooooooooooo00;ooooo00Go003ooooo
ooooooooooooo`00o`0Kooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o06[ooooo0ol0
000Eooooo`00<Oooool00ol0003oooooooooo`1Jooooo`05o`00ooooooooooooooooool00?l07?oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool07_ooool01Ol00?oooooo
oooooooooooo003o023ooooo00Go003oooooooooooooooooo`00o`03ooooo`;o003o6oooool01Ol0
0?oooooooooooooooooo003o00Cooooo00?o003oooooooooool06Oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l08?ooool01Ol00?oooooooooooooooooo003o06cooooo
00?o0000ooooooooool04oooool0037ooooo00?o0000ooooooooool0F_ooool01Ol00?oooooooooo
oooooooo003o01cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01ko
oooo00Go003oooooooooooooooooo`00o`0Pooooo`05o`00ooooooooooooooooool00?l00oooool2
o`00oa_ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo01Wooooo00?o
003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o023ooooo00Go003ooooooooooooo
ooooo`00o`1/ooooo`03o`000?oooooooooo01?ooooo000aooooo`03o`000?oooooooooo05[ooooo
00Go003oooooooooooooooooo`00o`0Looooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`0Nooooo`05o`00ooooooooooooooooool00?l08?ooool01Ol00?oooooooooooooo
oooo003o023ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo01Wooooo
00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o023ooooo00Go003ooooooooo
ooooooooo`00o`1/ooooo`03o`000?oooooooooo01?ooooo000aooooo`03o`000?oooooooooo05[o
oooo00Go003oooooooooooooooooo`00o`0Kooooo`;o003o0oooool01Ol00?oooooooooooooooooo
003o023ooooo00Go003oooooooooooooooooo`00o`0Pooooo`05o`00ooooooooooooooooool00?l0
8?ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool06Oooool00ol00?oo
ooooooooo`02ooooo`05o`00ooooooooooooooooool00?l08?ooool01Ol00?oooooooooooooooooo
003o06cooooo00?o0000ooooooooool04oooool0037ooooo00?o0000ooooooooool0F_ooool01Ol0
0?oooooooooooooooooo003o01_ooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l08?oo
ool01Ol00?oooooooooooooooooo003o023ooooo00Go003oooooooooooooooooo`00o`0Pooooo`05
o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`0Iooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`0Pooooo`05o`00ooooooooooooooooool00?l0K?oo
ool00ol0003oooooooooo`0Cooooo`00<Oooool00ol0003oooooooooo`1Jooooo`05o`00oooooooo
ooooooooool00?l08?ooool01Ol00?oooooooooooooooooo003o023ooooo00Go003ooooooooooooo
ooooo`00o`0Pooooo`05o`00ooooooooooooooooool00?l08?ooool01Ol00?oooooooooooooooooo
003o00Cooooo00?o003oooooooooool06Oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooo
ooooooooool00?l08?ooool01Ol00?oooooooooooooooooo003o06cooooo00?o0000ooooooooool0
4oooool0037ooooo0ol0001Jooooo`05o`00ooooooooooooooooool00?l08?ooool01Ol00?oooooo
oooooooooooo003o023ooooo00Go003oooooooooooooooooo`00o`0Pooooo`05o`00oooooooooooo
ooooool00?l08?ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool06Ooo
ool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`0Pooooo`05o`00ooooooooooooooooool0
0?l0J_ooool3o`0001Gooooo000aooooo`03o`000?oooooooooo05[ooooo00Go003ooooooooooooo
ooooo`00o`0Pooooo`05o`00ooooooooooooooooool00?l08?ooool01Ol00?oooooooooooooooooo
003o023ooooo00Go003oooooooooooooooooo`00o`0Pooooo`05o`00ooooooooooooooooool00?l0
1?ooool00ol00?ooooooooooo`0Iooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o023o
oooo00Go003oooooooooooooooooo`00o`1/ooooo`03o`000?oooooooooo01?ooooo000aooooo`03
o`000?oooooooooo05[ooooo00Go003oooooooooooooooooo`00o`0Pooooo`05o`00oooooooooooo
ooooool00?l08?ooool01Ol00?oooooooooooooooooo003o023ooooo00Go003ooooooooooooooooo
o`00o`0Pooooo`05o`00ooooooooooooooooool00?l00oooool2o`00ob3ooooo00Go003ooooooooo
ooooooooo`00o`0Pooooo`05o`00ooooooooooooooooool00?l0K?ooool00ol0003oooooooooo`0C
ooooo`00<Oooool00ol0003oooooooooo`1Jooooo`05o`00ooooooooooooooooool00?l08?ooool0
1Ol00?oooooooooooooooooo003o023ooooo00Go003oooooooooooooooooo`00o`0Pooooo`05o`00
ooooooooooooooooool00?l08?ooool01Ol00?oooooooooooooooooo003o00?ooooo0_l00?lPoooo
o`05o`00ooooooooooooooooool00?l08?ooool01Ol00?oooooooooooooooooo003o06cooooo00?o
0000ooooooooool04oooool0037ooooo00?o0000ooooooooool0F_ooool01Ol00?oooooooooooooo
oooo003o023ooooo00Go003oooooooooooooooooo`00o`0Pooooo`05o`00ooooooooooooooooool0
0?l08?ooool01Ol00?oooooooooooooooooo003o023ooooo00Go003oooooooooooooooooo`00o`0U
ooooo`05o`00ooooooooooooooooool00?l08?ooool01Ol00?oooooooooooooooooo003o06cooooo
00?o0000ooooooooool04oooool0037ooooo00?o0000ooooooooool0F_ooool01?l00?oooooooooo
ooooool2o`00oaoooooo00Go003oooooooooooooooooo`00o`0Pooooo`05o`00oooooooooooooooo
ool00?l08?ooool01Ol00?oooooooooooooooooo003o023ooooo00Go003oooooooooooooooooo`00
o`0Uooooo`05o`00ooooooooooooooooool00?l08?ooool01Ol00?oooooooooooooooooo003o06co
oooo00?o0000ooooooooool04oooool0037ooooo00?o0000ooooooooool0F_ooool01?l00?oooooo
ooooooooool2o`00oaoooooo00Go003oooooooooooooooooo`00o`0Pooooo`05o`00oooooooooooo
ooooool00?l08?ooool01Ol00?oooooooooooooooooo003o023ooooo00Go003ooooooooooooooooo
o`00o`0Uooooo`05o`00ooooooooooooooooool00?l08?ooool01Ol00?oooooooooooooooooo003o
06cooooo00?o0000ooooooooool04oooool0037ooooo0ol0001Jooooo`03o`00oooooooooooo02;o
oooo00Go003oooooooooooooooooo`00o`0Pooooo`05o`00ooooooooooooooooool00?l08?ooool0
1Ol00?oooooooooooooooooo003o023ooooo0_l00?l2ooooo`03o`00oooooooooooo02?ooooo00Go
003oooooooooooooooooo`00o`0Pooooo`05o`00ooooooooooooooooool00?l0J_ooool3o`0001Go
oooo000aooooo`03o`000?oooooooooo05[ooooo00?o003oooooooooool08_ooool01Ol00?oooooo
oooooooooooo003o023ooooo00Go003oooooooooooooooooo`00o`0Pooooo`05o`00oooooooooooo
ooooool00?l08?ooool2o`00o`;ooooo00?o003oooooooooool08oooool01Ol00?oooooooooooooo
oooo003o023ooooo00Go003oooooooooooooooooo`00o`1/ooooo`03o`000?oooooooooo01?ooooo
000aooooo`03o`000?oooooooooo05[ooooo00?o003oooooooooool08_ooool01Ol00?oooooooooo
oooooooo003o023ooooo00Go003oooooooooooooooooo`00o`0Pooooo`05o`00oooooooooooooooo
ool00?l09?ooool00ol00?ooooooooooo`0Sooooo`03o`00oooooooooooo00;o003o8?ooool01Ol0
0?oooooooooooooooooo003o06cooooo00?o0000ooooooooool04oooool0037ooooo00?o0000oooo
ooooool0F_ooool00ol00?ooooooooooo`0Rooooo`05o`00ooooooooooooooooool00?l08?ooool0
1Ol00?oooooooooooooooooo003o023ooooo00Go003oooooooooooooooooo`00o`0Tooooo`03o`00
oooooooooooo02?ooooo00?o003oooooooooool00_l00?lPooooo`05o`00ooooooooooooooooool0
0?l0K?ooool00ol0003oooooooooo`0Cooooo`00<Oooool00ol0003oooooooooo`1Jooooo`03o`00
oooooooooooo02;ooooo00Co003ooooooooooooooooo0_l00?lOooooo`05o`00oooooooooooooooo
ool00?l08?ooool01Ol00?oooooooooooooooooo003o02Cooooo00?o003oooooooooool08oooool0
0ol00?ooooooooooo`0Rooooo`05o`00ooooooooooooooooool00?l0K?ooool00ol0003ooooooooo
o`0Cooooo`00<Oooool00ol0003oooooooooo`1Jooooo`03o`00oooooooooooo02;ooooo00Co003o
oooooooooooooooo0_l00?lOooooo`05o`00ooooooooooooooooool00?l08?ooool2o`00o`;ooooo
00?o003oooooooooool08_ooool00ol00?ooooooooooo`0Sooooo`03o`00oooooooooooo02;ooooo
00Go003oooooooooooooooooo`00o`1/ooooo`03o`000?oooooooooo01?ooooo000aooooo`?o0000
F_ooool00ol00?ooooooooooo`0Rooooo`03o`00oooooooooooo02;ooooo00Go003ooooooooooooo
ooooo`00o`0Pooooo`;o003o0_ooool00ol00?ooooooooooo`0Rooooo`03o`00oooooooooooo02?o
oooo00?o003oooooooooool08_ooool01Ol00?oooooooooooooooooo003o06[ooooo0ol0000Eoooo
o`00<Oooool00ol0003oooooooooo`1Jooooo`03o`00oooooooooooo02;ooooo00?o003ooooooooo
ool08_ooool01Ol00?oooooooooooooooooo003o02Cooooo00?o003oooooooooool08_ooool00ol0
0?ooooooooooo`0Sooooo`03o`00oooooooooooo02;ooooo00?o003oooooooooool00_l00?m/oooo
o`03o`000?oooooooooo01?ooooo000aooooo`03o`000?oooooooooo05[ooooo00?o003ooooooooo
ool08_ooool00ol00?ooooooooooo`0Rooooo`04o`00ooooooooooooooooo`;o003o8oooool00ol0
0?ooooooooooo`0Rooooo`03o`00oooooooooooo02?ooooo00?o003oooooooooool08_ooool00ol0
0?ooooooooooo`02o`00ofcooooo00?o0000ooooooooool04oooool0037ooooo00?o0000oooooooo
ool0F_ooool00ol00?ooooooooooo`0Rooooo`03o`00oooooooooooo02;ooooo0_l00?l2ooooo`;o
003o8oooool00ol00?ooooooooooo`0Rooooo`03o`00oooooooooooo02?ooooo00?o003ooooooooo
ool08_ooool00ol00?ooooooooooo`1^ooooo`03o`000?oooooooooo01?ooooo000aooooo`03o`00
0?oooooooooo05[ooooo00?o003oooooooooool08_ooool00ol00?ooooooooooo`0Rooooo`;o003o
9oooool00ol00?ooooooooooo`0Rooooo`03o`00oooooooooooo02?ooooo00?o003oooooooooool0
8Oooool2o`00og3ooooo00?o0000ooooooooool04oooool002Oooooo0ol00007ooooo`03o`000?oo
oooooooo05[ooooo00?o003oooooooooool08_ooool00ol00?ooooooooooo`1;ooooo`;o003o8ooo
ool00ol00?ooooooooooo`0Sooooo`03o`00oooooooooooo027ooooo0_l00?m`ooooo`03o`000?oo
oooooooo01?ooooo000Xooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0F_ooool0
0ol00?ooooooooooo`0Rooooo`;o003oC?ooool2o`00ob?ooooo00?o003oooooooooool08_ooool2
o`00oiGooooo00?o0000ooooooooool04oooool002Sooooo00?o0000ooooooooool01_ooool4o`00
05Sooooo0_l00?lTooooo`;o003oLOooool2o`00ob?ooooo0_l00?nBooooo`Co00005Oooool002So
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo04ko
oooo0_l00?mAooooo`03o`000?oooooooooo04?ooooo0_l00?l;ooooo`03o`000?oooooooooo04oo
oooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01?o
oooo000Xooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0Cooooo`009oooool2o`0000Sooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0Cooooo`00:?ooool00ol0003oooooooooo`06oooooooo0000/ol0000Eooooo`00oooooooioooo
o`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooioooo
o`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooioooo
o`00oooooooiooooo`00oooooooiooooo`00\
\>"],
  ImageRangeCache->{{{0, 503}, {536.562, 0}} -> {-0.0250052, -0.0267009, \
0.0020875, 0.0020875}, {{11.9375, 491}, {523.75, 364.062}} -> {-35.5672, \
-1.40529, 0.246429, 0.0143173}, {{11.9375, 491}, {348.062, 188.438}} -> \
{-33.8842, -1.503, 0.242805, 0.00728415}, {{11.9375, 491}, {172.438, 12.75}} -> \
{-34.5852, -6.56224, 0.242701, 0.0145621}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Magnitude plot of unwindowed DTFT as a function of frequency", \
"Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(X\[Theta]\  = DTFT[xda, \[Theta]]\  // \ Simplify; 
    g1 = Plot[
        Abs[X\[Theta]\  /. \ \[Theta] \[Rule] \ 2  \[Pi]\ f/fs], {f, \(-fs\)/
            2, fs/2}, \ PlotStyle \[Rule] {Blue, \ Dashing[{ .01}]}, \ 
        PlotRange \[Rule] All, PlotPoints \[Rule] 200];\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.047619 0.0146992 0.0196085 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .0147 -6 -4.5 ]
[-0.0125 .0147 0 4.5 ]
[-0.0125 .11274 -6 -4.5 ]
[-0.0125 .11274 0 4.5 ]
[-0.0125 .21078 -12 -4.5 ]
[-0.0125 .21078 0 4.5 ]
[-0.0125 .30883 -12 -4.5 ]
[-0.0125 .30883 0 4.5 ]
[-0.0125 .40687 -12 -4.5 ]
[-0.0125 .40687 0 4.5 ]
[-0.0125 .50491 -12 -4.5 ]
[-0.0125 .50491 0 4.5 ]
[-0.0125 .60295 -12 -4.5 ]
[-0.0125 .60295 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .0147 m
.00625 .0147 L
s
[(0)] -0.0125 .0147 1 0 Mshowa
0 .11274 m
.00625 .11274 L
s
[(5)] -0.0125 .11274 1 0 Mshowa
0 .21078 m
.00625 .21078 L
s
[(10)] -0.0125 .21078 1 0 Mshowa
0 .30883 m
.00625 .30883 L
s
[(15)] -0.0125 .30883 1 0 Mshowa
0 .40687 m
.00625 .40687 L
s
[(20)] -0.0125 .40687 1 0 Mshowa
0 .50491 m
.00625 .50491 L
s
[(25)] -0.0125 .50491 1 0 Mshowa
0 .60295 m
.00625 .60295 L
s
[(30)] -0.0125 .60295 1 0 Mshowa
.125 Mabswid
0 .03431 m
.00375 .03431 L
s
0 .05392 m
.00375 .05392 L
s
0 .07352 m
.00375 .07352 L
s
0 .09313 m
.00375 .09313 L
s
0 .13235 m
.00375 .13235 L
s
0 .15196 m
.00375 .15196 L
s
0 .17157 m
.00375 .17157 L
s
0 .19118 m
.00375 .19118 L
s
0 .23039 m
.00375 .23039 L
s
0 .25 m
.00375 .25 L
s
0 .26961 m
.00375 .26961 L
s
0 .28922 m
.00375 .28922 L
s
0 .32844 m
.00375 .32844 L
s
0 .34804 m
.00375 .34804 L
s
0 .36765 m
.00375 .36765 L
s
0 .38726 m
.00375 .38726 L
s
0 .42648 m
.00375 .42648 L
s
0 .44609 m
.00375 .44609 L
s
0 .46569 m
.00375 .46569 L
s
0 .4853 m
.00375 .4853 L
s
0 .52452 m
.00375 .52452 L
s
0 .54413 m
.00375 .54413 L
s
0 .56374 m
.00375 .56374 L
s
0 .58335 m
.00375 .58335 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .0147 m
1 .0147 L
s
.99375 .11274 m
1 .11274 L
s
.99375 .21078 m
1 .21078 L
s
.99375 .30883 m
1 .30883 L
s
.99375 .40687 m
1 .40687 L
s
.99375 .50491 m
1 .50491 L
s
.99375 .60295 m
1 .60295 L
s
.125 Mabswid
.99625 .03431 m
1 .03431 L
s
.99625 .05392 m
1 .05392 L
s
.99625 .07352 m
1 .07352 L
s
.99625 .09313 m
1 .09313 L
s
.99625 .13235 m
1 .13235 L
s
.99625 .15196 m
1 .15196 L
s
.99625 .17157 m
1 .17157 L
s
.99625 .19118 m
1 .19118 L
s
.99625 .23039 m
1 .23039 L
s
.99625 .25 m
1 .25 L
s
.99625 .26961 m
1 .26961 L
s
.99625 .28922 m
1 .28922 L
s
.99625 .32844 m
1 .32844 L
s
.99625 .34804 m
1 .34804 L
s
.99625 .36765 m
1 .36765 L
s
.99625 .38726 m
1 .38726 L
s
.99625 .42648 m
1 .42648 L
s
.99625 .44609 m
1 .44609 L
s
.99625 .46569 m
1 .46569 L
s
.99625 .4853 m
1 .4853 L
s
.99625 .52452 m
1 .52452 L
s
.99625 .54413 m
1 .54413 L
s
.99625 .56374 m
1 .56374 L
s
.99625 .58335 m
1 .58335 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
0 0 1 r
.5 Mabswid
[ .01 ] 0 setdash
.02381 .03431 m
.02395 .0343 L
.02408 .03428 L
.02423 .03424 L
.02437 .03419 L
.02462 .03406 L
.02489 .03386 L
.02519 .03358 L
.02551 .03321 L
.02608 .03237 L
.02722 .03002 L
.02847 .02655 L
.02973 .02231 L
.03043 .01975 L
.03109 .01723 L
.03139 .01608 L
.03155 .01545 L
.03171 .01485 L
.03179 .01489 L
.03189 .01525 L
.03205 .01589 L
.03238 .01714 L
.03355 .02156 L
.03596 .02922 L
.03717 .03195 L
.03785 .03306 L
.03819 .03348 L
.0385 .0338 L
.03879 .03403 L
.03894 .03413 L
.0391 .03421 L
.03918 .03424 L
.03926 .03427 L
.03941 .03431 L
.03949 .03433 L
.03958 .03434 L
.03967 .03434 L
.03976 .03434 L
.03991 .03432 L
.04006 .03429 L
.04019 .03424 L
.04033 .03418 L
.04065 .03398 L
.04095 .03373 L
.04147 .03314 L
.04204 .03226 L
.04319 .02981 L
.04573 .02188 L
.04631 .01972 L
.04694 .01735 L
Mistroke
.04724 .01618 L
.04739 .01561 L
.04752 .01508 L
.04765 .01481 L
.04778 .01532 L
.04805 .01639 L
.0492 .02077 L
.05046 .02519 L
.05165 .02881 L
.05274 .03143 L
.05332 .03253 L
.05388 .03336 L
.05417 .03369 L
.05447 .03398 L
.05463 .03411 L
.0548 .03422 L
.05495 .0343 L
.05511 .03436 L
.05525 .03441 L
.0554 .03443 L
.05553 .03444 L
.05566 .03444 L
.05581 .03442 L
.05595 .03439 L
.0561 .03433 L
.05625 .03426 L
.05652 .0341 L
.05676 .03389 L
.05732 .03327 L
.05789 .0324 L
.05849 .03122 L
.05959 .02851 L
.06208 .02016 L
.06267 .01789 L
.063 .01663 L
.0633 .01543 L
.06346 .01481 L
.06355 .01493 L
.06363 .01526 L
.064 .01668 L
.06464 .01916 L
.06589 .02379 L
.06706 .0276 L
.06826 .03079 L
.06878 .03191 L
.06934 .03292 L
.06967 .0334 L
.06996 .03377 L
.07027 .03408 L
.07055 .03431 L
Mistroke
.07071 .03441 L
.07085 .03448 L
.07101 .03454 L
.07109 .03457 L
.07118 .03459 L
.07126 .0346 L
.07134 .03461 L
.07149 .03462 L
.07159 .03461 L
.07167 .0346 L
.07175 .03458 L
.07184 .03456 L
.07199 .0345 L
.07213 .03444 L
.07243 .03424 L
.07272 .03399 L
.07299 .0337 L
.07359 .03285 L
.07425 .03163 L
.07557 .02834 L
.07679 .02447 L
.07787 .02053 L
.07844 .01834 L
.07904 .01599 L
.07919 .01538 L
.07928 .01504 L
.07936 .01472 L
.07945 .01505 L
.07954 .01539 L
.07971 .01606 L
.08032 .01847 L
.08152 .02302 L
.0827 .02701 L
.08394 .03052 L
.085 .03277 L
.0856 .03371 L
.08588 .03405 L
.08617 .03434 L
.08633 .03448 L
.08648 .03459 L
.08663 .03468 L
.08677 .03474 L
.08693 .03481 L
.08702 .03483 L
.08711 .03485 L
.08726 .03487 L
.08734 .03487 L
.08742 .03486 L
.08758 .03484 L
.08772 .0348 L
Mistroke
.08786 .03476 L
.088 .03469 L
.08832 .03448 L
.08861 .03421 L
.08913 .03359 L
.0897 .03268 L
.09085 .03014 L
.09339 .02196 L
.09397 .01974 L
.09459 .01729 L
.09489 .01609 L
.09504 .01549 L
.09518 .01495 L
.0953 .01495 L
.09543 .01548 L
.09571 .01659 L
.09685 .0211 L
.0981 .02565 L
.0993 .02938 L
.10038 .03209 L
.10097 .03323 L
.10153 .03408 L
.10181 .03442 L
.10211 .03472 L
.10227 .03485 L
.10244 .03496 L
.10259 .03505 L
.10275 .03511 L
.10289 .03516 L
.10304 .03518 L
.10317 .0352 L
.1033 .03519 L
.10345 .03517 L
.10358 .03514 L
.10374 .03508 L
.10389 .03501 L
.10416 .03483 L
.1044 .03462 L
.10496 .03397 L
.10552 .03307 L
.10613 .03185 L
.10722 .02903 L
.10971 .02035 L
.1103 .01799 L
.11063 .01668 L
.11093 .01543 L
.11102 .01508 L
.11111 .01472 L
.1112 .01508 L
.1113 .01545 L
Mistroke
.11162 .01679 L
.11226 .01939 L
.11343 .02391 L
.11469 .02822 L
.11593 .03168 L
.11652 .03298 L
.11706 .03396 L
.1176 .03472 L
.11789 .03503 L
.1182 .03529 L
.11832 .03538 L
.11846 .03545 L
.11858 .03551 L
.11871 .03555 L
.11885 .03559 L
.119 .03561 L
.11914 .03561 L
.11927 .0356 L
.11943 .03556 L
.1195 .03554 L
.11959 .03551 L
.11988 .03535 L
.12005 .03523 L
.12022 .03508 L
.12054 .03474 L
.12117 .03385 L
.12174 .03277 L
.12289 .02992 L
.12399 .02647 L
.12515 .0222 L
.12578 .01967 L
.12638 .01721 L
.12663 .01618 L
.12676 .01562 L
.12689 .01509 L
.12703 .01488 L
.12718 .0155 L
.12744 .0166 L
.1286 .02138 L
.13086 .02947 L
.13148 .03124 L
.13213 .03286 L
.1327 .03401 L
.13331 .03499 L
.13364 .03539 L
.13394 .03569 L
.13408 .0358 L
.13424 .03591 L
.13439 .03599 L
.13453 .03605 L
Mistroke
.13462 .03607 L
.13471 .0361 L
.13479 .03611 L
.13487 .03612 L
.13495 .03612 L
.13504 .03612 L
.13514 .03611 L
.13523 .03609 L
.13531 .03607 L
.13539 .03605 L
.13554 .03598 L
.1357 .03589 L
.13588 .03577 L
.13617 .03552 L
.13649 .03515 L
.13714 .03416 L
.13774 .03296 L
.13831 .03159 L
.14074 .0235 L
.14182 .01912 L
.14211 .01792 L
.14241 .0166 L
.14255 .016 L
.1427 .01535 L
.14283 .0148 L
.14297 .0152 L
.14313 .01586 L
.14329 .01657 L
.14359 .01786 L
.14416 .02023 L
.14526 .02467 L
.14655 .0293 L
.14775 .03277 L
.14839 .03422 L
.14898 .03526 L
.14929 .03571 L
.14962 .0361 L
.1498 .03628 L
.14997 .03642 L
.15014 .03653 L
.15031 .03662 L
.15046 .03668 L
.1506 .03672 L
.15074 .03674 L
.15087 .03675 L
.15102 .03673 L
.15117 .0367 L
.15132 .03665 L
.15149 .03657 L
.15179 .03636 L
Mistroke
.15208 .03609 L
.15273 .03522 L
.15333 .03412 L
.15398 .03261 L
.15517 .0291 L
.1574 .02049 L
.15804 .01772 L
.15836 .01634 L
.1585 .01573 L
.15865 .01506 L
.15878 .01494 L
.15891 .0155 L
.15919 .01673 L
.15978 .01931 L
.16107 .02477 L
.1623 .02937 L
.16348 .03297 L
.1641 .0345 L
.16476 .03579 L
.16531 .03661 L
.16562 .03696 L
.16592 .03721 L
.16605 .03729 L
.16619 .03737 L
.16631 .03742 L
.16644 .03746 L
.16657 .03748 L
.16672 .03749 L
.16687 .03749 L
.16699 .03746 L
.16714 .03742 L
.16727 .03736 L
.16742 .03728 L
.16758 .03717 L
.1679 .03688 L
.1682 .03653 L
.16876 .03566 L
.1693 .03458 L
.1705 .03138 L
.17181 .0268 L
.17304 .02176 L
.17364 .01911 L
.17419 .01661 L
.17435 .01587 L
.1745 .01518 L
.17465 .01493 L
.17474 .01531 L
.17483 .01572 L
.17551 .01888 L
.17672 .02419 L
Mistroke
.17795 .02909 L
.17928 .03348 L
.17989 .03508 L
.18054 .03645 L
.1811 .03735 L
.18141 .03774 L
.18171 .03802 L
.18185 .03813 L
.182 .03822 L
.18215 .03829 L
.18228 .03834 L
.18243 .03838 L
.18252 .03839 L
.1826 .03839 L
.18274 .03838 L
.1829 .03835 L
.18304 .0383 L
.1832 .03823 L
.18335 .03813 L
.18349 .03803 L
.18383 .0377 L
.18415 .0373 L
.1847 .03638 L
.18521 .03529 L
.18638 .03205 L
.18865 .0232 L
.18928 .02038 L
.18993 .0173 L
.1902 .01601 L
.19035 .01529 L
.19049 .01478 L
.19057 .01516 L
.19066 .01558 L
.19081 .0163 L
.19111 .01772 L
.19245 .02398 L
.1937 .02924 L
.19495 .03369 L
.19557 .03547 L
.19613 .03684 L
.19665 .03786 L
.19722 .03869 L
.19753 .03903 L
.19768 .03915 L
.19782 .03925 L
.19795 .03933 L
.1981 .03939 L
.19825 .03944 L
.19839 .03946 L
.19854 .03947 L
Mistroke
.19869 .03945 L
.19885 .03941 L
.19894 .03937 L
.19902 .03933 L
.19918 .03924 L
.19936 .0391 L
.19969 .03878 L
.19999 .03839 L
.2003 .03788 L
.20088 .03674 L
.20201 .03367 L
.20322 .02927 L
.20437 .02434 L
.20543 .01928 L
.20599 .01651 L
.20615 .01571 L
.2063 .01495 L
.20644 .01513 L
.20658 .01588 L
.20785 .02214 L
.20906 .02778 L
.21039 .03315 L
.21099 .03517 L
.21163 .03704 L
.21218 .03837 L
.21279 .0395 L
.21314 .04 L
.21347 .04035 L
.21363 .04048 L
.21378 .04059 L
.21386 .04063 L
.21395 .04068 L
.21411 .04073 L
.21426 .04076 L
.21434 .04077 L
.21442 .04077 L
.21458 .04075 L
.21466 .04072 L
.21474 .0407 L
.21489 .04063 L
.21504 .04054 L
.21532 .0403 L
.21561 .03999 L
.21591 .03956 L
.21646 .03856 L
.21711 .037 L
.21771 .03523 L
.22025 .02483 L
.22135 .01926 L
.22167 .0176 L
Mistroke
.22197 .01602 L
.2221 .01532 L
.22224 .01481 L
.2224 .01562 L
.22254 .01636 L
.22383 .02314 L
.22503 .02901 L
.22617 .03388 L
.2268 .03617 L
.2274 .03806 L
.22795 .03952 L
.22855 .04079 L
.22882 .04123 L
.2291 .04162 L
.22934 .04189 L
.22961 .04211 L
.22975 .0422 L
.22989 .04226 L
.23004 .04231 L
.23012 .04233 L
.2302 .04234 L
.23035 .04233 L
.23044 .04232 L
.23052 .0423 L
.23067 .04225 L
.23082 .04217 L
.23096 .04208 L
.2311 .04196 L
.23135 .04169 L
.23166 .04128 L
.23194 .04082 L
.23255 .03952 L
.23323 .03767 L
.23445 .03326 L
.23683 .02175 L
.23751 .01799 L
.23767 .01708 L
.23785 .01611 L
.23799 .01528 L
.23808 .01481 L
.23815 .01503 L
.2383 .01585 L
.23843 .01661 L
.23873 .01829 L
.23936 .02179 L
.24057 .02826 L
.24185 .03435 L
.24295 .0386 L
.24358 .04057 L
.24416 .04203 L
Mistroke
.24472 .0431 L
.245 .04351 L
.24531 .04386 L
.24547 .044 L
.24562 .04411 L
.2457 .04415 L
.24579 .04419 L
.24588 .04422 L
.24595 .04424 L
.24609 .04426 L
.24624 .04426 L
.2464 .04423 L
.24655 .04417 L
.24669 .0441 L
.24684 .04399 L
.24711 .04373 L
.24738 .04339 L
.24763 .043 L
.24819 .04187 L
.24879 .04029 L
.25003 .03585 L
.25138 .02957 L
.25254 .02321 L
.25315 .01961 L
.25349 .01758 L
.25366 .01658 L
.25381 .01565 L
.25396 .01473 L
.25404 .01513 L
.25412 .01565 L
.25446 .01772 L
.25506 .02131 L
.25622 .02809 L
.25755 .03503 L
.25876 .04026 L
.25934 .04225 L
.25996 .04402 L
.26025 .04469 L
.26055 .0453 L
.26084 .04577 L
.2611 .04612 L
.26126 .04629 L
.26143 .04643 L
.2616 .04655 L
.2617 .04659 L
.26178 .04662 L
.26187 .04665 L
.26194 .04666 L
.26209 .04666 L
.26225 .04664 L
Mistroke
.26234 .04661 L
.26242 .04657 L
.26257 .04649 L
.2627 .04639 L
.263 .04608 L
.2633 .04567 L
.26362 .04511 L
.26422 .04372 L
.26477 .04205 L
.26604 .03704 L
.26735 .03031 L
.26858 .02288 L
.26916 .0192 L
.26947 .01715 L
.26962 .01614 L
.26976 .01521 L
.26992 .0152 L
.27 .01576 L
.27008 .01629 L
.27043 .0186 L
.27105 .02264 L
.27329 .03617 L
.27445 .0418 L
.27508 .04434 L
.27568 .04631 L
.27624 .04777 L
.27653 .04838 L
.27684 .04891 L
.27711 .04925 L
.27724 .04939 L
.27739 .04952 L
.27753 .0496 L
.27765 .04966 L
.27778 .0497 L
.2779 .04972 L
.27804 .04971 L
.27818 .04968 L
.27832 .04961 L
.27845 .04953 L
.2786 .04942 L
.27875 .04926 L
.27906 .04885 L
.27937 .0483 L
.27971 .04758 L
.2803 .04591 L
.28147 .04139 L
.28253 .03599 L
.28365 .02913 L
.28484 .02099 L
.28514 .01885 L
Mistroke
.28546 .01652 L
.28556 .01583 L
.28565 .01518 L
.28573 .01481 L
.28582 .01545 L
.28615 .01787 L
.28735 .02656 L
.28968 .0415 L
.29032 .0448 L
.29101 .04785 L
.29161 .05002 L
.29193 .05097 L
.29226 .05184 L
.29259 .05253 L
.29289 .05302 L
.29303 .05321 L
.29318 .05338 L
.29333 .05351 L
.29346 .0536 L
.29362 .05367 L
.2937 .0537 L
.29378 .05371 L
.29387 .05371 L
.29396 .0537 L
.29404 .05368 L
.29412 .05365 L
.29427 .05357 L
.29436 .05351 L
.29444 .05344 L
.29473 .05311 L
.29502 .05265 L
.29529 .05211 L
.2959 .0505 L
.29643 .04864 L
.29699 .04625 L
.29936 .03206 L
.30042 .0241 L
.30098 .01965 L
.30129 .01717 L
.30144 .01594 L
.30157 .01481 L
.30172 .01581 L
.30188 .01714 L
.30223 .01997 L
.30283 .02493 L
.30403 .03436 L
.30511 .04212 L
.30627 .04918 L
.30689 .05229 L
.30745 .05466 L
Mistroke
.30801 .05656 L
.30855 .05789 L
.30885 .05844 L
.30902 .05868 L
.30917 .05885 L
.3093 .05897 L
.30945 .05906 L
.3096 .05913 L
.30975 .05915 L
.30983 .05914 L
.30991 .05913 L
.31007 .05906 L
.31016 .05901 L
.31025 .05894 L
.31041 .05877 L
.31072 .05834 L
.31105 .0577 L
.31164 .05606 L
.31219 .054 L
.31345 .04751 L
.31468 .03905 L
.316 .02818 L
.31659 .0228 L
.31692 .01978 L
.31723 .0169 L
.31739 .0154 L
.31748 .01485 L
.31756 .01562 L
.31792 .01909 L
.31856 .0252 L
.32099 .04668 L
.3221 .05466 L
.32328 .06124 L
.32363 .06275 L
.32396 .06397 L
.32428 .06497 L
.32457 .06571 L
.32485 .06626 L
.325 .06649 L
.32515 .06668 L
.32531 .06682 L
.32545 .06691 L
.32554 .06695 L
.32562 .06697 L
.32578 .06696 L
.32591 .06692 L
.32606 .06683 L
.3262 .0667 L
.32633 .06655 L
.32663 .06607 L
Mistroke
.32694 .06537 L
.32753 .0635 L
.32818 .06066 L
.32933 .05365 L
.3304 .04511 L
.33166 .03296 L
.33229 .02637 L
.33286 .02004 L
.33299 .01858 L
.33313 .017 L
.33326 .01551 L
.33338 .01526 L
.33352 .0168 L
.33365 .01827 L
.33394 .0216 L
.3351 .03489 L
.33635 .04835 L
.33752 .05957 L
.33866 .06852 L
.33916 .07169 L
.33971 .07458 L
.34027 .07682 L
.34057 .07774 L
.34085 .07841 L
.34101 .0787 L
.34116 .07891 L
.3413 .07906 L
.34145 .07917 L
.34152 .0792 L
.34161 .07922 L
.3417 .07922 L
.34178 .07921 L
.34193 .07914 L
.34209 .079 L
.34224 .07879 L
.34239 .07855 L
.34273 .07778 L
.34306 .07675 L
.34341 .07536 L
.34404 .07204 L
.34462 .06819 L
.34582 .05767 L
.34693 .04538 L
.34756 .03756 L
.34823 .02858 L
.34855 .02405 L
.34886 .01967 L
.349 .01775 L
.34914 .01568 L
.3493 .01599 L
Mistroke
.34944 .01811 L
.35171 .0512 L
.353 .06855 L
.3542 .08213 L
.35544 .09296 L
.35609 .09698 L
.35642 .09853 L
.35661 .09926 L
.35678 .09985 L
.35694 .10028 L
.3571 .10066 L
.35725 .10093 L
.35739 .10111 L
.35754 .10124 L
.35763 .10127 L
.35771 .10129 L
.35779 .10128 L
.35787 .10125 L
.35796 .10119 L
.35804 .1011 L
.35819 .10091 L
.35834 .10063 L
.35861 .09993 L
.35893 .09877 L
.35922 .09741 L
.35981 .09376 L
.36043 .08862 L
.36154 .07624 L
.36274 .05874 L
.36405 .03533 L
.36435 .02944 L
.36468 .02286 L
.36483 .01979 L
.36492 .01809 L
.36499 .0165 L
.36513 .01574 L
.36528 .0189 L
.3664 .04292 L
.36892 .09602 L
.37011 .11763 L
.37076 .12781 L
.37136 .13601 L
.37192 .1424 L
.37242 .14706 L
.37269 .14907 L
.37299 .15087 L
.37315 .15168 L
.3733 .15231 L
.37344 .1528 L
.37359 .15322 L
Mistroke
.37374 .15352 L
.37388 .15369 L
.37402 .15375 L
.37415 .15371 L
.37431 .15355 L
.37445 .15329 L
.37452 .1531 L
.37461 .15286 L
.37476 .15232 L
.37503 .15098 L
.37533 .1491 L
.37585 .14446 L
.37647 .13694 L
.37704 .12787 L
.37834 .09992 L
.3796 .06331 L
.38022 .04208 L
.3805 .03212 L
.38064 .02668 L
.3808 .0207 L
.38094 .01524 L
.38107 .01925 L
.38132 .02945 L
.38187 .05278 L
.38304 .10587 L
.38782 .34906 L
.39023 .46122 L
.39242 .54046 L
.39301 .55679 L
.39364 .57188 L
.39419 .58263 L
.39479 .59192 L
.39512 .59587 L
.39543 .59881 L
.39576 .60112 L
.39594 .60206 L
.39602 .60239 L
.39611 .60269 L
.39626 .60308 L
.39641 .60328 L
.39656 .60332 L
.39665 .60326 L
.39673 .60315 L
.39688 .60282 L
.39701 .60237 L
.39716 .60171 L
.39732 .60083 L
.39763 .59856 L
.39792 .59574 L
.39847 .58876 L
Mistroke
.39906 .5788 L
.3997 .56524 L
.40085 .53401 L
.40191 .4982 L
.40666 .28443 L
.40904 .16757 L
.41122 .07056 L
.4118 .04774 L
.4121 .03623 L
.41242 .02441 L
.4125 .02167 L
.41258 .01874 L
.41273 .0159 L
.41288 .02089 L
.41301 .02539 L
.41356 .04282 L
.41487 .07799 L
.4155 .09189 L
.41608 .10265 L
.41661 .11083 L
.41718 .11803 L
.41749 .12125 L
.41778 .12377 L
.41806 .12576 L
.41835 .12747 L
.41851 .12819 L
.41865 .12874 L
.41879 .12921 L
.41893 .12955 L
.41908 .12982 L
.41915 .12993 L
.41924 .13001 L
.41932 .13005 L
.41941 .13007 L
.41956 .13001 L
.41972 .12984 L
.4198 .12972 L
.41988 .12955 L
.42018 .12873 L
.42034 .1281 L
.42052 .1273 L
.42085 .12554 L
.42148 .12093 L
.42207 .11542 L
.4234 .09921 L
.42583 .06101 L
.4271 .0391 L
.42773 .02848 L
.428 .02391 L
.42831 .01898 L
Mistroke
.42844 .01685 L
.42858 .0148 L
.42871 .01691 L
.42883 .0188 L
.42939 .02725 L
.43055 .04337 L
.43167 .05627 L
.43286 .06674 L
.43348 .07079 L
.43381 .07254 L
.43416 .0741 L
.43449 .07525 L
.43478 .07606 L
.43493 .07637 L
.43508 .07665 L
.43523 .07685 L
.43536 .07699 L
.43552 .0771 L
.4356 .07713 L
.43568 .07714 L
.43583 .07712 L
.43598 .07705 L
.43606 .07699 L
.43614 .07691 L
.4363 .07672 L
.43646 .07646 L
.43664 .0761 L
.43694 .07533 L
.43726 .07429 L
.43784 .07187 L
.4389 .06572 L
.44008 .05681 L
.44131 .04577 L
.44261 .03302 L
.44372 .02189 L
.44402 .01887 L
.44419 .01723 L
.44434 .01568 L
.44449 .01514 L
.44465 .01667 L
.44493 .01932 L
.44715 .03795 L
.44841 .0459 L
.44903 .04893 L
.44959 .05117 L
.44987 .05211 L
.45018 .05298 L
.45048 .05366 L
.45074 .05416 L
.45106 .05459 L
Mistroke
.45123 .05476 L
.45131 .05482 L
.45139 .05488 L
.45154 .05495 L
.45168 .05498 L
.45182 .05498 L
.45191 .05497 L
.45199 .05494 L
.45214 .05487 L
.45223 .05481 L
.45231 .05474 L
.45263 .05439 L
.45291 .05395 L
.45321 .05336 L
.45383 .05172 L
.45452 .04932 L
.45574 .04374 L
.45686 .03744 L
.45816 .02914 L
.45938 .021 L
.45965 .01916 L
.45994 .01718 L
.46008 .01627 L
.46022 .01532 L
.46035 .01488 L
.46048 .01577 L
.4611 .01974 L
.46166 .02319 L
.46297 .03043 L
.46416 .03581 L
.46473 .03793 L
.46536 .03983 L
.46596 .04123 L
.46651 .04218 L
.46666 .04239 L
.46684 .04258 L
.46699 .04272 L
.46715 .04284 L
.46729 .04293 L
.46745 .043 L
.46759 .04304 L
.46773 .04305 L
.46781 .04305 L
.4679 .04304 L
.46798 .04302 L
.46806 .043 L
.4682 .04294 L
.46835 .04285 L
.46852 .04273 L
.46867 .04258 L
Mistroke
.46903 .04217 L
.46962 .04117 L
.47028 .03968 L
.47147 .03605 L
.4737 .02675 L
.47492 .02089 L
.47552 .01795 L
.47579 .01667 L
.47593 .01599 L
.47607 .01526 L
.47616 .01485 L
.47623 .01491 L
.47638 .01563 L
.47671 .01719 L
.4774 .02038 L
.4786 .0255 L
.47972 .02956 L
.48091 .03295 L
.48152 .03429 L
.48185 .03488 L
.48221 .03541 L
.48253 .03581 L
.48283 .03609 L
.48311 .03629 L
.48325 .03637 L
.48341 .03643 L
.48357 .03648 L
.48371 .0365 L
.48379 .0365 L
.48388 .0365 L
.48396 .03649 L
.48405 .03648 L
.4842 .03644 L
.48434 .03638 L
.4845 .0363 L
.48465 .0362 L
.48493 .03598 L
.48519 .03571 L
.48577 .03491 L
.48642 .03375 L
.487 .03244 L
.4883 .02878 L
.48953 .02458 L
.49082 .01964 L
.49136 .01753 L
.49165 .01635 L
.49193 .01524 L
.49208 .01478 L
.49217 .01514 L
.49226 .01546 L
Mistroke
.49255 .01665 L
.49314 .01893 L
.4943 .0232 L
.49554 .02726 L
.49664 .0302 L
.49779 .03251 L
.49836 .0333 L
.49868 .03365 L
.49897 .03391 L
.49925 .03409 L
.49937 .03416 L
.49949 .03421 L
.49963 .03426 L
.49978 .03429 L
.49991 .0343 L
.50005 .03431 L
.5002 .03429 L
.50035 .03426 L
.50042 .03424 L
.50051 .03421 L
.50066 .03414 L
.50096 .03396 L
.50123 .03374 L
.50187 .03301 L
.50254 .03194 L
.50366 .02946 L
.50488 .02596 L
.50602 .02207 L
.50708 .01806 L
.50764 .01587 L
.5078 .01524 L
.50795 .01477 L
.50809 .01531 L
.50824 .0159 L
.5095 .0209 L
.51071 .02544 L
.51204 .02984 L
.51264 .03152 L
.51328 .03309 L
.51383 .03423 L
.51444 .03523 L
.51479 .03568 L
.51512 .03602 L
.51543 .03625 L
.5156 .03635 L
.51576 .03642 L
.51592 .03647 L
.51606 .03649 L
.51622 .0365 L
.5163 .0365 L
Mistroke
.51639 .03648 L
.51653 .03645 L
.51669 .0364 L
.51684 .03632 L
.51697 .03624 L
.51725 .03603 L
.51755 .03571 L
.51817 .03484 L
.51874 .03376 L
.51928 .0325 L
.52048 .02888 L
.52178 .02394 L
.52239 .02133 L
.52303 .01839 L
.52335 .01691 L
.5235 .01618 L
.52364 .01549 L
.52377 .01487 L
.52391 .01519 L
.52405 .01586 L
.5242 .01659 L
.52542 .02254 L
.52674 .0288 L
.52795 .03388 L
.52909 .0379 L
.52972 .03968 L
.53041 .04123 L
.53071 .04177 L
.53103 .04225 L
.53134 .04259 L
.53161 .04283 L
.53176 .04292 L
.53189 .04298 L
.53204 .04303 L
.53213 .04304 L
.5322 .04305 L
.53236 .04304 L
.53244 .04303 L
.53252 .04301 L
.53267 .04295 L
.53283 .04286 L
.53296 .04277 L
.5331 .04264 L
.53336 .04236 L
.53366 .04193 L
.53394 .04144 L
.53456 .04005 L
.53523 .03805 L
.53645 .03322 L
.53767 .02704 L
Mistroke
.53882 .02022 L
.53913 .01827 L
.53946 .01615 L
.53954 .01561 L
.53963 .01503 L
.53973 .015 L
.53982 .0156 L
.54015 .0178 L
.54135 .02591 L
.54374 .04094 L
.54509 .04772 L
.54573 .05028 L
.54634 .05223 L
.54687 .05353 L
.54717 .05409 L
.54745 .05449 L
.54758 .05464 L
.54773 .05478 L
.54781 .05484 L
.54789 .05489 L
.54804 .05495 L
.5482 .05498 L
.54828 .05498 L
.54836 .05497 L
.54851 .05493 L
.54867 .05484 L
.54882 .05472 L
.54896 .05457 L
.54928 .05412 L
.54957 .05356 L
.54985 .0529 L
.55047 .05097 L
.55114 .04815 L
.55372 .0313 L
.55431 .02628 L
.55493 .02063 L
.55519 .01821 L
.55533 .01686 L
.55547 .01557 L
.55562 .01536 L
.55577 .01677 L
.55605 .01955 L
.55722 .03129 L
.55848 .04381 L
.56077 .06348 L
.56194 .07076 L
.56253 .07349 L
.56287 .07473 L
.56318 .07566 L
.56345 .07628 L
Mistroke
.56358 .07654 L
.56373 .07676 L
.56388 .07693 L
.56401 .07705 L
.5641 .0771 L
.56418 .07713 L
.56432 .07714 L
.56446 .07711 L
.56459 .07703 L
.56471 .07692 L
.56484 .07676 L
.56498 .07654 L
.56513 .07625 L
.5654 .07559 L
.56571 .07459 L
.56604 .07327 L
.56662 .07018 L
.56726 .06586 L
.56796 .05991 L
.56922 .04619 L
.57038 .03064 L
.57097 .02188 L
.57112 .0196 L
.57126 .01742 L
.57138 .01545 L
.57152 .01612 L
.57166 .01843 L
.57179 .02058 L
.57209 .02544 L
.57271 .03596 L
.57523 .0785 L
.57631 .09519 L
.57749 .11051 L
.57816 .11765 L
.57877 .12292 L
.57906 .12498 L
.57939 .12685 L
.57969 .12824 L
.57997 .12919 L
.58013 .12957 L
.58021 .12973 L
.58029 .12986 L
.58043 .13001 L
.58059 .13007 L
.58067 .13006 L
.58075 .13001 L
.5809 .12985 L
.58099 .12971 L
.58107 .12955 L
.58125 .12908 L
Mistroke
.58152 .12805 L
.58183 .12647 L
.58215 .12431 L
.58245 .12181 L
.58301 .11583 L
.58353 .10886 L
.58469 .08786 L
.58588 .05905 L
.58644 .04267 L
.58698 .02572 L
.58712 .0208 L
.58728 .01548 L
.58736 .01674 L
.58745 .01989 L
.58761 .02551 L
.58818 .04692 L
.58947 .09984 L
.59434 .33356 L
.59658 .43768 L
.59902 .52994 L
.59966 .54891 L
.60035 .56624 L
.60094 .5787 L
.60158 .5894 L
.60192 .59391 L
.60223 .59729 L
.60253 .59982 L
.60268 .60085 L
.60285 .60176 L
.603 .60241 L
.60313 .60285 L
.60327 .60314 L
.6034 .6033 L
.60355 .60331 L
.60369 .60317 L
.60384 .60285 L
.60392 .60262 L
.604 .60231 L
.60428 .60087 L
.60445 .59978 L
.60459 .59859 L
.60522 .59176 L
.60576 .58349 L
.60634 .57231 L
.60766 .53803 L
.60886 .4974 L
.61368 .27194 L
.6159 .15792 L
.61716 .09674 L
.61777 .06858 L
Mistroke
.61833 .0441 L
.61862 .03215 L
.61877 .02599 L
.61893 .01954 L
.61906 .01537 L
.61922 .02135 L
.61949 .03163 L
.62073 .07393 L
.62204 .10918 L
.62263 .12171 L
.62327 .13304 L
.62389 .14151 L
.62446 .14738 L
.62477 .14979 L
.62506 .15149 L
.62522 .15222 L
.62539 .15285 L
.62547 .15308 L
.62555 .15329 L
.6257 .15357 L
.62584 .15371 L
.62597 .15375 L
.62611 .15369 L
.62625 .15353 L
.62638 .15329 L
.6265 .15299 L
.62677 .15205 L
.62706 .15059 L
.62733 .1489 L
.62793 .14388 L
.62852 .13747 L
.62915 .12924 L
.63026 .11129 L
.63277 .06085 L
.63391 .03606 L
.63424 .02898 L
.63456 .02234 L
.63469 .01947 L
.63484 .01645 L
.63499 .01623 L
.63514 .01925 L
.63735 .06017 L
.63848 .07655 L
.63908 .08361 L
.6397 .08982 L
.64025 .09419 L
.64054 .09608 L
.64085 .09778 L
.64114 .09905 L
.6414 .09995 L
Mistroke
.64153 .10031 L
.64166 .10063 L
.64179 .10087 L
.64191 .10105 L
.64206 .1012 L
.64219 .10127 L
.64234 .10128 L
.6425 .10121 L
.64264 .10108 L
.64279 .10087 L
.64293 .1006 L
.64305 .1003 L
.64336 .09936 L
.6437 .09799 L
.64431 .09465 L
.64495 .08997 L
.64563 .08387 L
.64685 .0704 L
.64808 .05418 L
.64925 .03742 L
.64976 .02992 L
.6503 .02196 L
.65058 .01783 L
.65066 .0167 L
.65074 .01549 L
.65089 .01609 L
.65104 .0182 L
.65117 .02019 L
.65144 .02389 L
.6538 .05368 L
.655 .0652 L
.65569 .07031 L
.65632 .07405 L
.65693 .07671 L
.65728 .07779 L
.65744 .0782 L
.65759 .07852 L
.65774 .07877 L
.65787 .07895 L
.65802 .0791 L
.65818 .07919 L
.65833 .07923 L
.65842 .07922 L
.65849 .07919 L
.65864 .07911 L
.65879 .07896 L
.65893 .07878 L
.65906 .07858 L
.65934 .07797 L
.6596 .07726 L
Mistroke
.65986 .07637 L
.66042 .07393 L
.66104 .07048 L
.66228 .06132 L
.6634 .05087 L
.66472 .03691 L
.66529 .03041 L
.66593 .02314 L
.66621 .01993 L
.66636 .01816 L
.66651 .01648 L
.66665 .01493 L
.66679 .01615 L
.66705 .01907 L
.66824 .032 L
.66956 .04472 L
.67075 .0542 L
.67134 .058 L
.67198 .0614 L
.67258 .06389 L
.67313 .06554 L
.67343 .06618 L
.67358 .06642 L
.67372 .06661 L
.67379 .0667 L
.67388 .06678 L
.67403 .06689 L
.67411 .06693 L
.6742 .06696 L
.67428 .06697 L
.67436 .06697 L
.67444 .06695 L
.67453 .06692 L
.67468 .06683 L
.67477 .06676 L
.67485 .06668 L
.67503 .06645 L
.67533 .06591 L
.67566 .06514 L
.6763 .06302 L
.6769 .06041 L
.67824 .0524 L
.68067 .03237 L
.68176 .0221 L
.68208 .0191 L
.68223 .01762 L
.68238 .01626 L
.68251 .01502 L
.68264 .01568 L
.68278 .01699 L
Mistroke
.68294 .01843 L
.68422 .03011 L
.68543 .03987 L
.68656 .0476 L
.68776 .05379 L
.68838 .05613 L
.68871 .0571 L
.68907 .05794 L
.68923 .05826 L
.68939 .05852 L
.68955 .05872 L
.68969 .05888 L
.68983 .05899 L
.68997 .05908 L
.69011 .05913 L
.69027 .05915 L
.69043 .05912 L
.69057 .05905 L
.69073 .05894 L
.6909 .05878 L
.69121 .05834 L
.69149 .05781 L
.69207 .05631 L
.69261 .05443 L
.69382 .04869 L
.69513 .04048 L
.69638 .03125 L
.69754 .02191 L
.69812 .01709 L
.6982 .01643 L
.69829 .01571 L
.69845 .015 L
.6986 .01627 L
.69875 .01744 L
.70008 .02794 L
.70233 .04283 L
.70295 .04597 L
.70361 .0488 L
.70424 .0509 L
.70454 .05171 L
.70481 .05233 L
.70509 .05284 L
.70539 .05325 L
.70555 .05343 L
.7057 .05355 L
.70585 .05364 L
.706 .05369 L
.70613 .05371 L
.70627 .0537 L
.7064 .05367 L
Mistroke
.70652 .05361 L
.70666 .05352 L
.70682 .05338 L
.7071 .05304 L
.70743 .0525 L
.70773 .05187 L
.70839 .05 L
.70901 .04774 L
.7096 .04518 L
.71202 .03091 L
.7131 .02334 L
.71369 .01904 L
.71398 .01691 L
.71411 .01597 L
.71425 .01494 L
.7144 .0155 L
.71455 .01661 L
.71487 .01893 L
.71543 .02291 L
.71653 .03029 L
.71783 .03793 L
.71902 .04349 L
.7196 .04558 L
.72022 .0474 L
.72051 .04806 L
.72081 .04865 L
.7211 .04908 L
.72136 .04938 L
.72152 .04951 L
.72161 .04957 L
.72169 .04962 L
.72183 .04968 L
.72198 .04971 L
.72207 .04972 L
.72215 .04971 L
.72231 .04968 L
.7224 .04964 L
.72248 .0496 L
.72266 .04948 L
.7228 .04934 L
.72294 .0492 L
.72325 .04876 L
.72355 .04822 L
.72388 .0475 L
.72503 .04392 L
.72569 .04123 L
.72629 .03834 L
.7276 .03112 L
.72884 .02339 L
.72941 .01963 L
Mistroke
.72973 .01755 L
.73002 .01561 L
.73017 .0148 L
.73026 .01537 L
.73034 .01589 L
.73069 .01818 L
.7313 .02215 L
.73355 .03504 L
.73473 .0403 L
.7353 .04231 L
.73584 .04387 L
.73614 .04461 L
.73647 .04528 L
.73675 .04575 L
.73705 .04615 L
.73721 .04631 L
.73738 .04645 L
.73747 .04651 L
.73755 .04656 L
.73764 .0466 L
.73772 .04663 L
.73787 .04666 L
.73795 .04667 L
.73804 .04666 L
.73818 .04664 L
.73834 .04658 L
.73849 .04649 L
.73862 .04639 L
.73893 .04608 L
.73923 .04566 L
.73956 .04509 L
.74014 .04375 L
.74067 .04221 L
.74197 .03725 L
.74319 .03129 L
.74437 .02472 L
.74501 .02091 L
.74532 .01902 L
.74561 .01728 L
.74573 .01651 L
.74587 .01568 L
.746 .0149 L
.74612 .01523 L
.74625 .016 L
.74639 .01684 L
.74667 .01854 L
.74783 .02532 L
.74897 .03131 L
.75016 .03665 L
.75079 .03895 L
Mistroke
.75147 .04103 L
.7521 .04249 L
.75238 .04301 L
.75268 .04347 L
.75283 .04366 L
.75299 .04384 L
.75314 .04398 L
.75328 .04408 L
.75345 .04417 L
.75354 .04421 L
.75362 .04424 L
.75378 .04426 L
.75386 .04427 L
.75394 .04426 L
.7541 .04423 L
.75425 .04418 L
.75438 .04411 L
.75452 .04401 L
.75484 .0437 L
.75514 .04332 L
.75566 .04241 L
.75623 .04108 L
.75738 .03742 L
.75993 .02567 L
.76052 .0225 L
.76114 .01903 L
.76139 .01759 L
.76167 .01604 L
.76183 .01514 L
.76197 .01507 L
.76211 .01585 L
.76225 .01667 L
.76341 .02302 L
.76466 .02936 L
.76586 .03451 L
.76695 .03819 L
.76754 .03974 L
.7681 .04089 L
.76839 .04135 L
.76869 .04174 L
.76885 .04191 L
.76902 .04206 L
.76918 .04217 L
.76933 .04225 L
.76947 .0423 L
.76961 .04233 L
.76976 .04234 L
.76989 .04233 L
.77002 .0423 L
.77013 .04225 L
Mistroke
.77027 .04219 L
.7704 .04211 L
.77068 .04186 L
.77095 .04156 L
.77154 .04061 L
.77211 .03937 L
.77272 .03771 L
.77382 .03391 L
.77631 .02241 L
.77691 .0193 L
.77724 .01757 L
.77754 .01595 L
.7777 .0151 L
.77779 .01477 L
.77787 .0152 L
.77824 .01713 L
.77888 .02047 L
.78014 .02667 L
.78131 .03172 L
.78241 .03563 L
.78298 .03725 L
.78359 .03868 L
.78394 .03933 L
.78427 .03983 L
.78458 .0402 L
.78473 .04036 L
.7849 .0405 L
.78506 .0406 L
.7852 .04067 L
.78534 .04072 L
.78547 .04075 L
.78562 .04077 L
.78577 .04076 L
.78592 .04072 L
.786 .04069 L
.78609 .04066 L
.78624 .04058 L
.78637 .04048 L
.78668 .0402 L
.78699 .03983 L
.78731 .03934 L
.78789 .0382 L
.78842 .0369 L
.78972 .03276 L
.79094 .0278 L
.79211 .02237 L
.79275 .01922 L
.79306 .01766 L
.79335 .01622 L
.79347 .01559 L
Mistroke
.79361 .01491 L
.79374 .01514 L
.79386 .01574 L
.79441 .01847 L
.79557 .02406 L
.79685 .02956 L
.79805 .03384 L
.79913 .03675 L
.79974 .03795 L
.80029 .03875 L
.80059 .03906 L
.80086 .03927 L
.80101 .03935 L
.80109 .03938 L
.80117 .03941 L
.80133 .03945 L
.80147 .03947 L
.8016 .03947 L
.80174 .03944 L
.80187 .03941 L
.80199 .03936 L
.80212 .03929 L
.80227 .03919 L
.80257 .03893 L
.80289 .03855 L
.80319 .03812 L
.80386 .03686 L
.80506 .03365 L
.80757 .02388 L
.80867 .01877 L
.80897 .01733 L
.80914 .01654 L
.8093 .01578 L
.80944 .01508 L
.80953 .01472 L
.8096 .01508 L
.80988 .01642 L
.81214 .02659 L
.81329 .03093 L
.81453 .03466 L
.81519 .03617 L
.81548 .03672 L
.8158 .03723 L
.81609 .0376 L
.81639 .03793 L
.81656 .03807 L
.81671 .03818 L
.81685 .03826 L
.81701 .03832 L
.81714 .03836 L
Mistroke
.81729 .03839 L
.81743 .03839 L
.81756 .03838 L
.81771 .03835 L
.81785 .0383 L
.81801 .03822 L
.81816 .03812 L
.81843 .0379 L
.81868 .03763 L
.81925 .03681 L
.81986 .03563 L
.82053 .03401 L
.82173 .03026 L
.82397 .02119 L
.82452 .0187 L
.82483 .01731 L
.82512 .01599 L
.82528 .01524 L
.82537 .01482 L
.82546 .01497 L
.82561 .01567 L
.82577 .0164 L
.82637 .01915 L
.8276 .02444 L
.82891 .02947 L
.83014 .03322 L
.83068 .03453 L
.83126 .0357 L
.83153 .03615 L
.83182 .03655 L
.83207 .03684 L
.83234 .0371 L
.83249 .03722 L
.83264 .03731 L
.83278 .03739 L
.83293 .03744 L
.83306 .03747 L
.83318 .03749 L
.83332 .03749 L
.83347 .03748 L
.83355 .03746 L
.83363 .03744 L
.83377 .03738 L
.83393 .0373 L
.8341 .03719 L
.83441 .03693 L
.83469 .03661 L
.83534 .03563 L
.83602 .03423 L
.83717 .03108 L
Mistroke
.83844 .02666 L
.83965 .02177 L
.84025 .0192 L
.8408 .01678 L
.84111 .01542 L
.84126 .01474 L
.84135 .01505 L
.84143 .01542 L
.84212 .01844 L
.84332 .02352 L
.84451 .02802 L
.84576 .03193 L
.84683 .03444 L
.84743 .03547 L
.84771 .03584 L
.84799 .03616 L
.84815 .03631 L
.84831 .03644 L
.84846 .03654 L
.8486 .03661 L
.84877 .03668 L
.84886 .03671 L
.84895 .03673 L
.8491 .03674 L
.84919 .03675 L
.84927 .03674 L
.84941 .03672 L
.84954 .03668 L
.84969 .03662 L
.84985 .03654 L
.85017 .03631 L
.85046 .03601 L
.85099 .03532 L
.85156 .03431 L
.85271 .03155 L
.85527 .02261 L
.85585 .02019 L
.85648 .01756 L
.85673 .01646 L
.85687 .01585 L
.85701 .01528 L
.85717 .0148 L
.85731 .01542 L
.85759 .01664 L
.85875 .02149 L
.86001 .02632 L
.86121 .03025 L
.8623 .03304 L
.86289 .03422 L
.86345 .03508 L
Mistroke
.86376 .03545 L
.86405 .03571 L
.86436 .03593 L
.86452 .03601 L
.8646 .03604 L
.86469 .03607 L
.86484 .03611 L
.86498 .03612 L
.86511 .03612 L
.86524 .03611 L
.86538 .03607 L
.86553 .03602 L
.86569 .03595 L
.86583 .03586 L
.8661 .03565 L
.86635 .03541 L
.86691 .03468 L
.86748 .03368 L
.86809 .03235 L
.86919 .02932 L
.87169 .02022 L
.87229 .01775 L
.87261 .01638 L
.87277 .01571 L
.87292 .0151 L
.873 .01475 L
.87308 .01497 L
.87316 .01532 L
.87325 .01569 L
.87362 .01721 L
.87426 .01985 L
.87554 .02478 L
.87669 .02869 L
.87728 .03041 L
.87792 .03202 L
.87847 .03319 L
.87907 .03423 L
.87938 .03465 L
.87971 .03502 L
.87989 .03518 L
.88006 .03531 L
.88023 .03542 L
.88039 .0355 L
.88053 .03555 L
.88069 .03559 L
.88084 .03561 L
.88093 .03561 L
.88101 .03561 L
.88116 .03559 L
.88129 .03555 L
Mistroke
.88145 .03549 L
.8816 .03542 L
.88191 .03521 L
.88221 .03494 L
.88275 .03425 L
.88335 .03325 L
.88399 .03188 L
.8862 .02522 L
.88745 .02054 L
.88805 .01811 L
.88861 .01586 L
.88875 .01527 L
.88891 .01477 L
.88905 .01537 L
.88919 .01593 L
.88982 .01847 L
.89115 .02361 L
.89223 .02735 L
.89339 .03071 L
.89406 .03226 L
.89468 .03341 L
.89526 .03426 L
.89556 .03458 L
.89588 .03486 L
.89603 .03496 L
.89618 .03505 L
.89627 .03508 L
.89636 .03512 L
.89652 .03516 L
.89666 .03519 L
.89675 .03519 L
.89683 .0352 L
.89697 .03518 L
.89712 .03515 L
.89725 .03511 L
.8974 .03505 L
.89765 .0349 L
.89796 .03465 L
.89824 .03436 L
.89887 .0335 L
.89954 .03225 L
.90077 .0292 L
.90313 .02117 L
.90377 .01865 L
.90413 .01724 L
.90447 .01589 L
.90462 .01528 L
.9047 .01494 L
.90478 .01477 L
.90486 .01511 L
Mistroke
.90496 .01548 L
.90512 .01614 L
.90572 .01851 L
.90693 .02313 L
.9082 .02745 L
.90938 .03073 L
.90996 .03202 L
.91048 .03299 L
.91104 .03382 L
.91156 .03438 L
.91185 .0346 L
.91211 .03474 L
.91225 .0348 L
.9124 .03484 L
.91256 .03486 L
.91271 .03487 L
.91286 .03485 L
.91295 .03484 L
.91303 .03482 L
.91317 .03477 L
.91333 .0347 L
.91362 .03451 L
.91389 .03429 L
.91454 .03351 L
.91515 .0325 L
.91633 .02982 L
.91758 .02612 L
.91875 .02202 L
.91981 .01796 L
.92009 .01684 L
.92024 .01626 L
.9204 .01563 L
.92054 .01508 L
.92069 .01492 L
.92083 .01547 L
.92096 .01598 L
.92219 .02075 L
.9244 .02824 L
.925 .02988 L
.92565 .03142 L
.92623 .03254 L
.92684 .03348 L
.92715 .03386 L
.92745 .03414 L
.92771 .03434 L
.92785 .03443 L
.928 .0345 L
.92814 .03455 L
.92827 .03459 L
.92841 .03461 L
Mistroke
.92856 .03462 L
.9287 .03461 L
.92883 .03459 L
.92895 .03456 L
.92908 .03451 L
.92922 .03445 L
.92936 .03437 L
.92966 .03414 L
.92993 .03389 L
.93021 .03356 L
.93081 .03268 L
.93146 .03142 L
.93277 .02809 L
.93399 .02418 L
.93526 .01954 L
.93589 .01714 L
.93616 .01607 L
.9363 .0155 L
.93646 .01489 L
.9366 .01506 L
.93673 .01557 L
.93698 .01656 L
.93754 .0187 L
.9387 .02303 L
.93981 .02674 L
.941 .03004 L
.94168 .03158 L
.94229 .0327 L
.94259 .03315 L
.94291 .03356 L
.94322 .03388 L
.9435 .03411 L
.94378 .03428 L
.94394 .03435 L
.94409 .0344 L
.94423 .03443 L
.94436 .03444 L
.9445 .03444 L
.94465 .03443 L
.94479 .03439 L
.94488 .03437 L
.94495 .03434 L
.94524 .03419 L
.9454 .03409 L
.94557 .03395 L
.94591 .03361 L
.94654 .03275 L
.94722 .03151 L
.94845 .02854 L
.95085 .02056 L
Mistroke
.95151 .01807 L
.95187 .01668 L
.95205 .01599 L
.95221 .01537 L
.95236 .01479 L
.9525 .01515 L
.95264 .01572 L
.9528 .01635 L
.95346 .01886 L
.95575 .02687 L
.95706 .03041 L
.9577 .03177 L
.95829 .03278 L
.95884 .03352 L
.95912 .0338 L
.95943 .03404 L
.95959 .03414 L
.95974 .03422 L
.95982 .03425 L
.95991 .03428 L
.96007 .03432 L
.96022 .03434 L
.96038 .03434 L
.96052 .03433 L
.96067 .03429 L
.96075 .03427 L
.96084 .03424 L
.961 .03416 L
.9613 .03397 L
.96165 .03366 L
.96198 .03329 L
.96257 .03242 L
.9632 .03122 L
.96444 .02814 L
.96578 .02392 L
.96694 .01973 L
.96756 .01739 L
.9679 .01609 L
.96806 .01544 L
.96822 .01484 L
.96837 .01514 L
.96844 .01544 L
.96853 .01577 L
.96887 .01708 L
.96946 .01934 L
.97062 .02356 L
.97195 .0278 L
.97316 .03089 L
.97387 .03228 L
.97462 .03337 L
Mistroke
.97501 .03377 L
.97537 .03405 L
.97558 .03416 L
.97577 .03424 L
.97587 .03427 L
.97598 .03429 L
.97609 .0343 L
.97619 .03431 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Magnitude plot of DFT as a function of frequency", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(fft\  = \ DFT[xda];\)\), "\n", 
    \(\(g3 = 
        DiscreteListPlot[\({#[\([1]\)], \ Abs[#[\([2]\)]]} &\)\  /@ \ fft, 
          Red, \ PlotRange \[Rule] All, \ Frame \[Rule] True, \ 
          Axes \[Rule] False];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0161421 0.0147151 0.0298707 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18523 -0.0125 -6 -9 ]
[.18523 -0.0125 6 0 ]
[.34665 -0.0125 -6 -9 ]
[.34665 -0.0125 6 0 ]
[.50807 -0.0125 -6 -9 ]
[.50807 -0.0125 6 0 ]
[.66949 -0.0125 -6 -9 ]
[.66949 -0.0125 6 0 ]
[.83091 -0.0125 -6 -9 ]
[.83091 -0.0125 6 0 ]
[.99233 -0.0125 -6 -9 ]
[.99233 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .16407 -6 -4.5 ]
[-0.0125 .16407 0 4.5 ]
[-0.0125 .31342 -12 -4.5 ]
[-0.0125 .31342 0 4.5 ]
[-0.0125 .46278 -12 -4.5 ]
[-0.0125 .46278 0 4.5 ]
[-0.0125 .61213 -12 -4.5 ]
[-0.0125 .61213 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18523 0 m
.18523 .00625 L
s
[(10)] .18523 -0.0125 0 1 Mshowa
.34665 0 m
.34665 .00625 L
s
[(20)] .34665 -0.0125 0 1 Mshowa
.50807 0 m
.50807 .00625 L
s
[(30)] .50807 -0.0125 0 1 Mshowa
.66949 0 m
.66949 .00625 L
s
[(40)] .66949 -0.0125 0 1 Mshowa
.83091 0 m
.83091 .00625 L
s
[(50)] .83091 -0.0125 0 1 Mshowa
.99233 0 m
.99233 .00625 L
s
[(60)] .99233 -0.0125 0 1 Mshowa
.125 Mabswid
.05609 0 m
.05609 .00375 L
s
.08838 0 m
.08838 .00375 L
s
.12066 0 m
.12066 .00375 L
s
.15295 0 m
.15295 .00375 L
s
.21751 0 m
.21751 .00375 L
s
.2498 0 m
.2498 .00375 L
s
.28208 0 m
.28208 .00375 L
s
.31437 0 m
.31437 .00375 L
s
.37893 0 m
.37893 .00375 L
s
.41122 0 m
.41122 .00375 L
s
.4435 0 m
.4435 .00375 L
s
.47579 0 m
.47579 .00375 L
s
.54036 0 m
.54036 .00375 L
s
.57264 0 m
.57264 .00375 L
s
.60492 0 m
.60492 .00375 L
s
.63721 0 m
.63721 .00375 L
s
.70178 0 m
.70178 .00375 L
s
.73406 0 m
.73406 .00375 L
s
.76634 0 m
.76634 .00375 L
s
.79863 0 m
.79863 .00375 L
s
.8632 0 m
.8632 .00375 L
s
.89548 0 m
.89548 .00375 L
s
.92776 0 m
.92776 .00375 L
s
.96005 0 m
.96005 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .16407 m
.00625 .16407 L
s
[(5)] -0.0125 .16407 1 0 Mshowa
0 .31342 m
.00625 .31342 L
s
[(10)] -0.0125 .31342 1 0 Mshowa
0 .46278 m
.00625 .46278 L
s
[(15)] -0.0125 .46278 1 0 Mshowa
0 .61213 m
.00625 .61213 L
s
[(20)] -0.0125 .61213 1 0 Mshowa
.125 Mabswid
0 .04459 m
.00375 .04459 L
s
0 .07446 m
.00375 .07446 L
s
0 .10433 m
.00375 .10433 L
s
0 .1342 m
.00375 .1342 L
s
0 .19394 m
.00375 .19394 L
s
0 .22381 m
.00375 .22381 L
s
0 .25368 m
.00375 .25368 L
s
0 .28355 m
.00375 .28355 L
s
0 .34329 m
.00375 .34329 L
s
0 .37316 m
.00375 .37316 L
s
0 .40303 m
.00375 .40303 L
s
0 .43291 m
.00375 .43291 L
s
0 .49265 m
.00375 .49265 L
s
0 .52252 m
.00375 .52252 L
s
0 .55239 m
.00375 .55239 L
s
0 .58226 m
.00375 .58226 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.18523 .61178 m
.18523 .61803 L
s
.34665 .61178 m
.34665 .61803 L
s
.50807 .61178 m
.50807 .61803 L
s
.66949 .61178 m
.66949 .61803 L
s
.83091 .61178 m
.83091 .61803 L
s
.99233 .61178 m
.99233 .61803 L
s
.125 Mabswid
.05609 .61428 m
.05609 .61803 L
s
.08838 .61428 m
.08838 .61803 L
s
.12066 .61428 m
.12066 .61803 L
s
.15295 .61428 m
.15295 .61803 L
s
.21751 .61428 m
.21751 .61803 L
s
.2498 .61428 m
.2498 .61803 L
s
.28208 .61428 m
.28208 .61803 L
s
.31437 .61428 m
.31437 .61803 L
s
.37893 .61428 m
.37893 .61803 L
s
.41122 .61428 m
.41122 .61803 L
s
.4435 .61428 m
.4435 .61803 L
s
.47579 .61428 m
.47579 .61803 L
s
.54036 .61428 m
.54036 .61803 L
s
.57264 .61428 m
.57264 .61803 L
s
.60492 .61428 m
.60492 .61803 L
s
.63721 .61428 m
.63721 .61803 L
s
.70178 .61428 m
.70178 .61803 L
s
.73406 .61428 m
.73406 .61803 L
s
.76634 .61428 m
.76634 .61803 L
s
.79863 .61428 m
.79863 .61803 L
s
.8632 .61428 m
.8632 .61803 L
s
.89548 .61428 m
.89548 .61803 L
s
.92776 .61428 m
.92776 .61803 L
s
.96005 .61428 m
.96005 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16407 m
1 .16407 L
s
.99375 .31342 m
1 .31342 L
s
.99375 .46278 m
1 .46278 L
s
.99375 .61213 m
1 .61213 L
s
.125 Mabswid
.99625 .04459 m
1 .04459 L
s
.99625 .07446 m
1 .07446 L
s
.99625 .10433 m
1 .10433 L
s
.99625 .1342 m
1 .1342 L
s
.99625 .19394 m
1 .19394 L
s
.99625 .22381 m
1 .22381 L
s
.99625 .25368 m
1 .25368 L
s
.99625 .28355 m
1 .28355 L
s
.99625 .34329 m
1 .34329 L
s
.99625 .37316 m
1 .37316 L
s
.99625 .40303 m
1 .40303 L
s
.99625 .43291 m
1 .43291 L
s
.99625 .49265 m
1 .49265 L
s
.99625 .52252 m
1 .52252 L
s
.99625 .55239 m
1 .55239 L
s
.99625 .58226 m
1 .58226 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .01472 m
.02381 .04459 L
s
.03995 .01472 m
.03995 .04786 L
s
.05609 .01472 m
.05609 .05769 L
s
.07224 .01472 m
.07224 .07562 L
s
.08838 .01472 m
.08838 .10866 L
s
.10452 .01472 m
.10452 .18539 L
s
.12066 .01472 m
.12066 .56642 L
s
.1368 .01472 m
.1368 .60332 L
s
.15295 .01472 m
.15295 .22238 L
s
.16909 .01472 m
.16909 .14578 L
s
.18523 .01472 m
.18523 .11272 L
s
.20137 .01472 m
.20137 .09421 L
s
.21751 .01472 m
.21751 .08235 L
s
.23366 .01472 m
.23366 .0741 L
s
.2498 .01472 m
.2498 .06803 L
s
.26594 .01472 m
.26594 .06339 L
s
.28208 .01472 m
.28208 .05974 L
s
.29822 .01472 m
.29822 .05681 L
s
.31437 .01472 m
.31437 .05442 L
s
.33051 .01472 m
.33051 .05245 L
s
.34665 .01472 m
.34665 .05081 L
s
.36279 .01472 m
.36279 .04944 L
s
.37893 .01472 m
.37893 .0483 L
s
.39508 .01472 m
.39508 .04735 L
s
.41122 .01472 m
.41122 .04657 L
s
.42736 .01472 m
.42736 .04594 L
s
.4435 .01472 m
.4435 .04544 L
s
.45964 .01472 m
.45964 .04506 L
s
.47579 .01472 m
.47579 .04479 L
s
.49193 .01472 m
.49193 .04464 L
s
.50807 .01472 m
.50807 .04459 L
s
.52421 .01472 m
.52421 .04464 L
s
.54036 .01472 m
.54036 .04479 L
s
.5565 .01472 m
.5565 .04506 L
s
.57264 .01472 m
.57264 .04544 L
s
.58878 .01472 m
.58878 .04594 L
s
.60492 .01472 m
.60492 .04657 L
s
.62107 .01472 m
.62107 .04735 L
s
.63721 .01472 m
.63721 .0483 L
s
.65335 .01472 m
.65335 .04944 L
s
.66949 .01472 m
.66949 .05081 L
s
.68563 .01472 m
.68563 .05245 L
s
.70178 .01472 m
.70178 .05442 L
s
.71792 .01472 m
.71792 .05681 L
s
.73406 .01472 m
.73406 .05974 L
s
.7502 .01472 m
.7502 .06339 L
s
.76634 .01472 m
.76634 .06803 L
s
.78249 .01472 m
.78249 .0741 L
s
.79863 .01472 m
.79863 .08235 L
s
.81477 .01472 m
.81477 .09421 L
s
.83091 .01472 m
.83091 .11272 L
s
.84705 .01472 m
.84705 .14578 L
s
.8632 .01472 m
.8632 .22238 L
s
.87934 .01472 m
.87934 .60332 L
s
.89548 .01472 m
.89548 .56642 L
s
.91162 .01472 m
.91162 .18539 L
s
.92776 .01472 m
.92776 .10866 L
s
.94391 .01472 m
.94391 .07562 L
s
.96005 .01472 m
.96005 .05769 L
s
.97619 .01472 m
.97619 .04786 L
s
.015 w
.02381 .04459 Mdot
.03995 .04786 Mdot
.05609 .05769 Mdot
.07224 .07562 Mdot
.08838 .10866 Mdot
.10452 .18539 Mdot
.12066 .56642 Mdot
.1368 .60332 Mdot
.15295 .22238 Mdot
.16909 .14578 Mdot
.18523 .11272 Mdot
.20137 .09421 Mdot
.21751 .08235 Mdot
.23366 .0741 Mdot
.2498 .06803 Mdot
.26594 .06339 Mdot
.28208 .05974 Mdot
.29822 .05681 Mdot
.31437 .05442 Mdot
.33051 .05245 Mdot
.34665 .05081 Mdot
.36279 .04944 Mdot
.37893 .0483 Mdot
.39508 .04735 Mdot
.41122 .04657 Mdot
.42736 .04594 Mdot
.4435 .04544 Mdot
.45964 .04506 Mdot
.47579 .04479 Mdot
.49193 .04464 Mdot
.50807 .04459 Mdot
.52421 .04464 Mdot
.54036 .04479 Mdot
.5565 .04506 Mdot
.57264 .04544 Mdot
.58878 .04594 Mdot
.60492 .04657 Mdot
.62107 .04735 Mdot
.63721 .0483 Mdot
.65335 .04944 Mdot
.66949 .05081 Mdot
.68563 .05245 Mdot
.70178 .05442 Mdot
.71792 .05681 Mdot
.73406 .05974 Mdot
.7502 .06339 Mdot
.76634 .06803 Mdot
.78249 .0741 Mdot
.79863 .08235 Mdot
.81477 .09421 Mdot
.83091 .11272 Mdot
.84705 .14578 Mdot
.8632 .22238 Mdot
.87934 .60332 Mdot
.89548 .56642 Mdot
.91162 .18539 Mdot
.92776 .10866 Mdot
.94391 .07562 Mdot
.96005 .05769 Mdot
.97619 .04786 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Rearrange and scale DFT result", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(g5 = 
        DiscreteListPlot[FourierRearrange[Abs[Last\  /@ \ fft], fs], Red, 
          PlotRange \[Rule] All, ImageSize \[Rule] 504, \ 
          Frame \[Rule] True, \ Axes \[Rule] False, \ 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(g6\  = \ Show[g1, g5];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.047619 0.0147151 0.019608 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .11275 -6 -4.5 ]
[-0.0125 .11275 0 4.5 ]
[-0.0125 .21079 -12 -4.5 ]
[-0.0125 .21079 0 4.5 ]
[-0.0125 .30883 -12 -4.5 ]
[-0.0125 .30883 0 4.5 ]
[-0.0125 .40687 -12 -4.5 ]
[-0.0125 .40687 0 4.5 ]
[-0.0125 .50491 -12 -4.5 ]
[-0.0125 .50491 0 4.5 ]
[-0.0125 .60295 -12 -4.5 ]
[-0.0125 .60295 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .11275 m
.00625 .11275 L
s
[(5)] -0.0125 .11275 1 0 Mshowa
0 .21079 m
.00625 .21079 L
s
[(10)] -0.0125 .21079 1 0 Mshowa
0 .30883 m
.00625 .30883 L
s
[(15)] -0.0125 .30883 1 0 Mshowa
0 .40687 m
.00625 .40687 L
s
[(20)] -0.0125 .40687 1 0 Mshowa
0 .50491 m
.00625 .50491 L
s
[(25)] -0.0125 .50491 1 0 Mshowa
0 .60295 m
.00625 .60295 L
s
[(30)] -0.0125 .60295 1 0 Mshowa
.125 Mabswid
0 .03432 m
.00375 .03432 L
s
0 .05393 m
.00375 .05393 L
s
0 .07354 m
.00375 .07354 L
s
0 .09315 m
.00375 .09315 L
s
0 .13236 m
.00375 .13236 L
s
0 .15197 m
.00375 .15197 L
s
0 .17158 m
.00375 .17158 L
s
0 .19119 m
.00375 .19119 L
s
0 .2304 m
.00375 .2304 L
s
0 .25001 m
.00375 .25001 L
s
0 .26962 m
.00375 .26962 L
s
0 .28923 m
.00375 .28923 L
s
0 .32844 m
.00375 .32844 L
s
0 .34805 m
.00375 .34805 L
s
0 .36766 m
.00375 .36766 L
s
0 .38727 m
.00375 .38727 L
s
0 .42648 m
.00375 .42648 L
s
0 .44609 m
.00375 .44609 L
s
0 .4657 m
.00375 .4657 L
s
0 .48531 m
.00375 .48531 L
s
0 .52452 m
.00375 .52452 L
s
0 .54413 m
.00375 .54413 L
s
0 .56374 m
.00375 .56374 L
s
0 .58335 m
.00375 .58335 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .11275 m
1 .11275 L
s
.99375 .21079 m
1 .21079 L
s
.99375 .30883 m
1 .30883 L
s
.99375 .40687 m
1 .40687 L
s
.99375 .50491 m
1 .50491 L
s
.99375 .60295 m
1 .60295 L
s
.125 Mabswid
.99625 .03432 m
1 .03432 L
s
.99625 .05393 m
1 .05393 L
s
.99625 .07354 m
1 .07354 L
s
.99625 .09315 m
1 .09315 L
s
.99625 .13236 m
1 .13236 L
s
.99625 .15197 m
1 .15197 L
s
.99625 .17158 m
1 .17158 L
s
.99625 .19119 m
1 .19119 L
s
.99625 .2304 m
1 .2304 L
s
.99625 .25001 m
1 .25001 L
s
.99625 .26962 m
1 .26962 L
s
.99625 .28923 m
1 .28923 L
s
.99625 .32844 m
1 .32844 L
s
.99625 .34805 m
1 .34805 L
s
.99625 .36766 m
1 .36766 L
s
.99625 .38727 m
1 .38727 L
s
.99625 .42648 m
1 .42648 L
s
.99625 .44609 m
1 .44609 L
s
.99625 .4657 m
1 .4657 L
s
.99625 .48531 m
1 .48531 L
s
.99625 .52452 m
1 .52452 L
s
.99625 .54413 m
1 .54413 L
s
.99625 .56374 m
1 .56374 L
s
.99625 .58335 m
1 .58335 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
0 0 1 r
.5 Mabswid
[ .01 ] 0 setdash
.02381 .03432 m
.02395 .03432 L
.02408 .03429 L
.02423 .03426 L
.02437 .0342 L
.02462 .03407 L
.02489 .03387 L
.02519 .03359 L
.02551 .03323 L
.02608 .03238 L
.02722 .03003 L
.02847 .02656 L
.02973 .02232 L
.03043 .01977 L
.03109 .01724 L
.03139 .0161 L
.03155 .01546 L
.03171 .01487 L
.03179 .0149 L
.03189 .01527 L
.03205 .01591 L
.03238 .01716 L
.03355 .02158 L
.03596 .02924 L
.03717 .03196 L
.03785 .03308 L
.03819 .0335 L
.0385 .03381 L
.03879 .03405 L
.03894 .03414 L
.0391 .03422 L
.03918 .03426 L
.03926 .03429 L
.03941 .03433 L
.03949 .03434 L
.03958 .03435 L
.03967 .03436 L
.03976 .03436 L
.03991 .03434 L
.04006 .0343 L
.04019 .03426 L
.04033 .0342 L
.04065 .034 L
.04095 .03375 L
.04147 .03315 L
.04204 .03227 L
.04319 .02983 L
.04573 .0219 L
.04631 .01974 L
.04694 .01737 L
Mistroke
.04724 .0162 L
.04739 .01562 L
.04752 .01509 L
.04765 .01482 L
.04778 .01533 L
.04805 .01641 L
.0492 .02079 L
.05046 .0252 L
.05165 .02882 L
.05274 .03144 L
.05332 .03255 L
.05388 .03337 L
.05417 .03371 L
.05447 .034 L
.05463 .03412 L
.0548 .03423 L
.05495 .03431 L
.05511 .03438 L
.05525 .03442 L
.0554 .03445 L
.05553 .03446 L
.05566 .03446 L
.05581 .03444 L
.05595 .0344 L
.0561 .03435 L
.05625 .03428 L
.05652 .03411 L
.05676 .03391 L
.05732 .03328 L
.05789 .03241 L
.05849 .03124 L
.05959 .02852 L
.06208 .02018 L
.06267 .01791 L
.063 .01665 L
.0633 .01545 L
.06346 .01483 L
.06355 .01495 L
.06363 .01527 L
.064 .01669 L
.06464 .01918 L
.06589 .0238 L
.06706 .02762 L
.06826 .03081 L
.06878 .03193 L
.06934 .03294 L
.06967 .03341 L
.06996 .03378 L
.07027 .03409 L
.07055 .03432 L
Mistroke
.07071 .03442 L
.07085 .03449 L
.07101 .03456 L
.07109 .03459 L
.07118 .03461 L
.07126 .03462 L
.07134 .03463 L
.07149 .03463 L
.07159 .03463 L
.07167 .03461 L
.07175 .0346 L
.07184 .03457 L
.07199 .03452 L
.07213 .03445 L
.07243 .03426 L
.07272 .03401 L
.07299 .03371 L
.07359 .03287 L
.07425 .03165 L
.07557 .02836 L
.07679 .02448 L
.07787 .02055 L
.07844 .01836 L
.07904 .01601 L
.07919 .01539 L
.07928 .01506 L
.07936 .01474 L
.07945 .01507 L
.07954 .01541 L
.07971 .01608 L
.08032 .01849 L
.08152 .02303 L
.0827 .02703 L
.08394 .03054 L
.085 .03279 L
.0856 .03372 L
.08588 .03406 L
.08617 .03436 L
.08633 .03449 L
.08648 .0346 L
.08663 .03469 L
.08677 .03476 L
.08693 .03482 L
.08702 .03484 L
.08711 .03486 L
.08726 .03488 L
.08734 .03488 L
.08742 .03488 L
.08758 .03486 L
.08772 .03482 L
Mistroke
.08786 .03477 L
.088 .0347 L
.08832 .03449 L
.08861 .03423 L
.08913 .03361 L
.0897 .03269 L
.09085 .03016 L
.09339 .02198 L
.09397 .01976 L
.09459 .01731 L
.09489 .0161 L
.09504 .01551 L
.09518 .01496 L
.0953 .01497 L
.09543 .0155 L
.09571 .0166 L
.09685 .02111 L
.0981 .02567 L
.0993 .0294 L
.10038 .03211 L
.10097 .03324 L
.10153 .03409 L
.10181 .03444 L
.10211 .03473 L
.10227 .03486 L
.10244 .03498 L
.10259 .03506 L
.10275 .03513 L
.10289 .03517 L
.10304 .0352 L
.10317 .03521 L
.1033 .03521 L
.10345 .03519 L
.10358 .03515 L
.10374 .03509 L
.10389 .03502 L
.10416 .03485 L
.1044 .03464 L
.10496 .03398 L
.10552 .03308 L
.10613 .03186 L
.10722 .02904 L
.10971 .02036 L
.1103 .01801 L
.11063 .01669 L
.11093 .01545 L
.11102 .0151 L
.11111 .01473 L
.1112 .0151 L
.1113 .01547 L
Mistroke
.11162 .01681 L
.11226 .0194 L
.11343 .02393 L
.11469 .02823 L
.11593 .0317 L
.11652 .03299 L
.11706 .03398 L
.1176 .03474 L
.11789 .03505 L
.1182 .03531 L
.11832 .03539 L
.11846 .03547 L
.11858 .03552 L
.11871 .03557 L
.11885 .0356 L
.119 .03562 L
.11914 .03563 L
.11927 .03561 L
.11943 .03558 L
.1195 .03555 L
.11959 .03552 L
.11988 .03537 L
.12005 .03525 L
.12022 .03509 L
.12054 .03476 L
.12117 .03386 L
.12174 .03279 L
.12289 .02994 L
.12399 .02649 L
.12515 .02221 L
.12578 .01968 L
.12638 .01722 L
.12663 .01619 L
.12676 .01563 L
.12689 .01511 L
.12703 .01489 L
.12718 .01552 L
.12744 .01661 L
.1286 .0214 L
.13086 .02948 L
.13148 .03126 L
.13213 .03287 L
.1327 .03403 L
.13331 .035 L
.13364 .03541 L
.13394 .0357 L
.13408 .03582 L
.13424 .03592 L
.13439 .036 L
.13453 .03606 L
Mistroke
.13462 .03609 L
.13471 .03611 L
.13479 .03613 L
.13487 .03614 L
.13495 .03614 L
.13504 .03614 L
.13514 .03613 L
.13523 .03611 L
.13531 .03609 L
.13539 .03606 L
.13554 .036 L
.1357 .03591 L
.13588 .03579 L
.13617 .03553 L
.13649 .03517 L
.13714 .03418 L
.13774 .03297 L
.13831 .0316 L
.14074 .02351 L
.14182 .01913 L
.14211 .01793 L
.14241 .01662 L
.14255 .01601 L
.1427 .01537 L
.14283 .01482 L
.14297 .01521 L
.14313 .01588 L
.14329 .01659 L
.14359 .01787 L
.14416 .02025 L
.14526 .02469 L
.14655 .02932 L
.14775 .03278 L
.14839 .03423 L
.14898 .03528 L
.14929 .03572 L
.14962 .03612 L
.1498 .0363 L
.14997 .03644 L
.15014 .03655 L
.15031 .03664 L
.15046 .0367 L
.1506 .03674 L
.15074 .03676 L
.15087 .03676 L
.15102 .03675 L
.15117 .03672 L
.15132 .03666 L
.15149 .03658 L
.15179 .03637 L
Mistroke
.15208 .0361 L
.15273 .03524 L
.15333 .03414 L
.15398 .03263 L
.15517 .02911 L
.1574 .02051 L
.15804 .01774 L
.15836 .01636 L
.1585 .01575 L
.15865 .01508 L
.15878 .01495 L
.15891 .01552 L
.15919 .01675 L
.15978 .01933 L
.16107 .02479 L
.1623 .02938 L
.16348 .03299 L
.1641 .03451 L
.16476 .03581 L
.16531 .03662 L
.16562 .03697 L
.16592 .03722 L
.16605 .03731 L
.16619 .03738 L
.16631 .03743 L
.16644 .03747 L
.16657 .0375 L
.16672 .03751 L
.16687 .0375 L
.16699 .03748 L
.16714 .03743 L
.16727 .03738 L
.16742 .0373 L
.16758 .03719 L
.1679 .03689 L
.1682 .03655 L
.16876 .03567 L
.1693 .03459 L
.1705 .03139 L
.17181 .02682 L
.17304 .02178 L
.17364 .01912 L
.17419 .01662 L
.17435 .01589 L
.1745 .0152 L
.17465 .01495 L
.17474 .01533 L
.17483 .01574 L
.17551 .01889 L
.17672 .0242 L
Mistroke
.17795 .0291 L
.17928 .03349 L
.17989 .03509 L
.18054 .03647 L
.1811 .03736 L
.18141 .03775 L
.18171 .03804 L
.18185 .03814 L
.182 .03824 L
.18215 .03831 L
.18228 .03836 L
.18243 .03839 L
.18252 .0384 L
.1826 .03841 L
.18274 .0384 L
.1829 .03837 L
.18304 .03832 L
.1832 .03824 L
.18335 .03815 L
.18349 .03804 L
.18383 .03772 L
.18415 .03731 L
.1847 .0364 L
.18521 .03531 L
.18638 .03207 L
.18865 .02322 L
.18928 .02039 L
.18993 .01731 L
.1902 .01602 L
.19035 .01531 L
.19049 .0148 L
.19057 .01518 L
.19066 .01559 L
.19081 .01632 L
.19111 .01774 L
.19245 .024 L
.1937 .02925 L
.19495 .03371 L
.19557 .03549 L
.19613 .03685 L
.19665 .03787 L
.19722 .03871 L
.19753 .03904 L
.19768 .03917 L
.19782 .03927 L
.19795 .03935 L
.1981 .03941 L
.19825 .03946 L
.19839 .03948 L
.19854 .03948 L
Mistroke
.19869 .03947 L
.19885 .03942 L
.19894 .03939 L
.19902 .03935 L
.19918 .03925 L
.19936 .03912 L
.19969 .03879 L
.19999 .0384 L
.2003 .0379 L
.20088 .03676 L
.20201 .03368 L
.20322 .02929 L
.20437 .02436 L
.20543 .0193 L
.20599 .01653 L
.20615 .01573 L
.2063 .01496 L
.20644 .01515 L
.20658 .01589 L
.20785 .02216 L
.20906 .02779 L
.21039 .03316 L
.21099 .03519 L
.21163 .03705 L
.21218 .03838 L
.21279 .03951 L
.21314 .04001 L
.21347 .04036 L
.21363 .0405 L
.21378 .0406 L
.21386 .04065 L
.21395 .04069 L
.21411 .04075 L
.21426 .04077 L
.21434 .04078 L
.21442 .04078 L
.21458 .04076 L
.21466 .04074 L
.21474 .04071 L
.21489 .04065 L
.21504 .04055 L
.21532 .04032 L
.21561 .04001 L
.21591 .03958 L
.21646 .03858 L
.21711 .03702 L
.21771 .03525 L
.22025 .02485 L
.22135 .01928 L
.22167 .01762 L
Mistroke
.22197 .01603 L
.2221 .01534 L
.22224 .01483 L
.2224 .01563 L
.22254 .01638 L
.22383 .02315 L
.22503 .02902 L
.22617 .03389 L
.2268 .03619 L
.2274 .03807 L
.22795 .03954 L
.22855 .0408 L
.22882 .04124 L
.2291 .04163 L
.22934 .0419 L
.22961 .04212 L
.22975 .04222 L
.22989 .04228 L
.23004 .04233 L
.23012 .04234 L
.2302 .04235 L
.23035 .04235 L
.23044 .04234 L
.23052 .04232 L
.23067 .04226 L
.23082 .04218 L
.23096 .04209 L
.2311 .04197 L
.23135 .04171 L
.23166 .0413 L
.23194 .04084 L
.23255 .03953 L
.23323 .03769 L
.23445 .03327 L
.23683 .02177 L
.23751 .01801 L
.23767 .01709 L
.23785 .01613 L
.23799 .0153 L
.23808 .01483 L
.23815 .01504 L
.2383 .01587 L
.23843 .01662 L
.23873 .01831 L
.23936 .0218 L
.24057 .02827 L
.24185 .03436 L
.24295 .03862 L
.24358 .04059 L
.24416 .04204 L
Mistroke
.24472 .04312 L
.245 .04353 L
.24531 .04388 L
.24547 .04402 L
.24562 .04412 L
.2457 .04417 L
.24579 .04421 L
.24588 .04424 L
.24595 .04426 L
.24609 .04428 L
.24624 .04428 L
.2464 .04424 L
.24655 .04419 L
.24669 .04411 L
.24684 .044 L
.24711 .04374 L
.24738 .0434 L
.24763 .04302 L
.24819 .04188 L
.24879 .04031 L
.25003 .03587 L
.25138 .02959 L
.25254 .02322 L
.25315 .01962 L
.25349 .0176 L
.25366 .0166 L
.25381 .01567 L
.25396 .01475 L
.25404 .01515 L
.25412 .01566 L
.25446 .01773 L
.25506 .02132 L
.25622 .0281 L
.25755 .03505 L
.25876 .04027 L
.25934 .04226 L
.25996 .04404 L
.26025 .04471 L
.26055 .04532 L
.26084 .04579 L
.2611 .04614 L
.26126 .0463 L
.26143 .04645 L
.2616 .04656 L
.2617 .04661 L
.26178 .04664 L
.26187 .04666 L
.26194 .04667 L
.26209 .04668 L
.26225 .04665 L
Mistroke
.26234 .04662 L
.26242 .04659 L
.26257 .04651 L
.2627 .04641 L
.263 .0461 L
.2633 .04569 L
.26362 .04512 L
.26422 .04373 L
.26477 .04207 L
.26604 .03706 L
.26735 .03032 L
.26858 .0229 L
.26916 .01922 L
.26947 .01716 L
.26962 .01615 L
.26976 .01523 L
.26992 .01521 L
.27 .01577 L
.27008 .0163 L
.27043 .01861 L
.27105 .02266 L
.27329 .03619 L
.27445 .04182 L
.27508 .04435 L
.27568 .04633 L
.27624 .04779 L
.27653 .0484 L
.27684 .04892 L
.27711 .04926 L
.27724 .04941 L
.27739 .04953 L
.27753 .04962 L
.27765 .04968 L
.27778 .04972 L
.2779 .04973 L
.27804 .04973 L
.27818 .04969 L
.27832 .04963 L
.27845 .04955 L
.2786 .04943 L
.27875 .04928 L
.27906 .04886 L
.27937 .04832 L
.27971 .04759 L
.2803 .04593 L
.28147 .04141 L
.28253 .036 L
.28365 .02915 L
.28484 .02101 L
.28514 .01886 L
Mistroke
.28546 .01654 L
.28556 .01585 L
.28565 .01519 L
.28573 .01483 L
.28582 .01547 L
.28615 .01788 L
.28735 .02658 L
.28968 .04151 L
.29032 .04481 L
.29101 .04786 L
.29161 .05003 L
.29193 .05099 L
.29226 .05186 L
.29259 .05254 L
.29289 .05303 L
.29303 .05323 L
.29318 .0534 L
.29333 .05353 L
.29346 .05362 L
.29362 .05369 L
.2937 .05371 L
.29378 .05372 L
.29387 .05373 L
.29396 .05372 L
.29404 .0537 L
.29412 .05367 L
.29427 .05358 L
.29436 .05352 L
.29444 .05345 L
.29473 .05312 L
.29502 .05266 L
.29529 .05212 L
.2959 .05051 L
.29643 .04866 L
.29699 .04626 L
.29936 .03208 L
.30042 .02411 L
.30098 .01966 L
.30129 .01718 L
.30144 .01596 L
.30157 .01483 L
.30172 .01583 L
.30188 .01716 L
.30223 .01999 L
.30283 .02495 L
.30403 .03437 L
.30511 .04214 L
.30627 .04919 L
.30689 .05231 L
.30745 .05467 L
Mistroke
.30801 .05658 L
.30855 .05791 L
.30885 .05846 L
.30902 .05869 L
.30917 .05887 L
.3093 .05898 L
.30945 .05908 L
.3096 .05914 L
.30975 .05916 L
.30983 .05916 L
.30991 .05914 L
.31007 .05908 L
.31016 .05902 L
.31025 .05895 L
.31041 .05879 L
.31072 .05836 L
.31105 .05771 L
.31164 .05607 L
.31219 .05401 L
.31345 .04752 L
.31468 .03907 L
.316 .0282 L
.31659 .02282 L
.31692 .01979 L
.31723 .01692 L
.31739 .01542 L
.31748 .01486 L
.31756 .01564 L
.31792 .01911 L
.31856 .02521 L
.32099 .04669 L
.3221 .05467 L
.32328 .06126 L
.32363 .06277 L
.32396 .06399 L
.32428 .06498 L
.32457 .06573 L
.32485 .06628 L
.325 .0665 L
.32515 .06669 L
.32531 .06684 L
.32545 .06693 L
.32554 .06696 L
.32562 .06698 L
.32578 .06698 L
.32591 .06693 L
.32606 .06684 L
.3262 .06672 L
.32633 .06657 L
.32663 .06609 L
Mistroke
.32694 .06538 L
.32753 .06351 L
.32818 .06067 L
.32933 .05367 L
.3304 .04513 L
.33166 .03298 L
.33229 .02639 L
.33286 .02005 L
.33299 .01859 L
.33313 .01702 L
.33326 .01552 L
.33338 .01528 L
.33352 .01682 L
.33365 .01829 L
.33394 .02161 L
.3351 .03491 L
.33635 .04836 L
.33752 .05959 L
.33866 .06854 L
.33916 .07171 L
.33971 .07459 L
.34027 .07683 L
.34057 .07776 L
.34085 .07842 L
.34101 .07871 L
.34116 .07893 L
.3413 .07908 L
.34145 .07918 L
.34152 .07922 L
.34161 .07924 L
.3417 .07924 L
.34178 .07922 L
.34193 .07915 L
.34209 .07901 L
.34224 .07881 L
.34239 .07856 L
.34273 .07779 L
.34306 .07677 L
.34341 .07537 L
.34404 .07206 L
.34462 .0682 L
.34582 .05768 L
.34693 .0454 L
.34756 .03758 L
.34823 .02859 L
.34855 .02407 L
.34886 .01969 L
.349 .01776 L
.34914 .0157 L
.3493 .01601 L
Mistroke
.34944 .01813 L
.35171 .05122 L
.353 .06857 L
.3542 .08215 L
.35544 .09297 L
.35609 .097 L
.35642 .09855 L
.35661 .09927 L
.35678 .09986 L
.35694 .10029 L
.3571 .10067 L
.35725 .10094 L
.35739 .10113 L
.35754 .10125 L
.35763 .10129 L
.35771 .1013 L
.35779 .10129 L
.35787 .10126 L
.35796 .1012 L
.35804 .10112 L
.35819 .10093 L
.35834 .10065 L
.35861 .09995 L
.35893 .09878 L
.35922 .09742 L
.35981 .09377 L
.36043 .08864 L
.36154 .07626 L
.36274 .05875 L
.36405 .03534 L
.36435 .02945 L
.36468 .02287 L
.36483 .0198 L
.36492 .01811 L
.36499 .01651 L
.36513 .01576 L
.36528 .01891 L
.3664 .04294 L
.36892 .09604 L
.37011 .11764 L
.37076 .12782 L
.37136 .13603 L
.37192 .14241 L
.37242 .14707 L
.37269 .14909 L
.37299 .15088 L
.37315 .15169 L
.3733 .15232 L
.37344 .15281 L
.37359 .15323 L
Mistroke
.37374 .15353 L
.37388 .1537 L
.37402 .15376 L
.37415 .15373 L
.37431 .15356 L
.37445 .1533 L
.37452 .15311 L
.37461 .15287 L
.37476 .15233 L
.37503 .151 L
.37533 .14911 L
.37585 .14447 L
.37647 .13695 L
.37704 .12789 L
.37834 .09994 L
.3796 .06333 L
.38022 .0421 L
.3805 .03213 L
.38064 .02669 L
.3808 .02072 L
.38094 .01525 L
.38107 .01926 L
.38132 .02946 L
.38187 .05279 L
.38304 .10588 L
.38782 .34907 L
.39023 .46122 L
.39242 .54046 L
.39301 .5568 L
.39364 .57188 L
.39419 .58263 L
.39479 .59192 L
.39512 .59587 L
.39543 .59881 L
.39576 .60112 L
.39594 .60206 L
.39602 .60239 L
.39611 .60269 L
.39626 .60308 L
.39641 .60328 L
.39656 .60332 L
.39665 .60326 L
.39673 .60315 L
.39688 .60282 L
.39701 .60237 L
.39716 .60171 L
.39732 .60083 L
.39763 .59856 L
.39792 .59574 L
.39847 .58876 L
Mistroke
.39906 .5788 L
.3997 .56524 L
.40085 .53402 L
.40191 .4982 L
.40666 .28444 L
.40904 .16758 L
.41122 .07058 L
.4118 .04775 L
.4121 .03624 L
.41242 .02442 L
.4125 .02168 L
.41258 .01875 L
.41273 .01591 L
.41288 .0209 L
.41301 .02541 L
.41356 .04283 L
.41487 .078 L
.4155 .0919 L
.41608 .10266 L
.41661 .11084 L
.41718 .11805 L
.41749 .12127 L
.41778 .12378 L
.41806 .12577 L
.41835 .12748 L
.41851 .1282 L
.41865 .12876 L
.41879 .12922 L
.41893 .12956 L
.41908 .12984 L
.41915 .12994 L
.41924 .13002 L
.41932 .13007 L
.41941 .13008 L
.41956 .13002 L
.41972 .12986 L
.4198 .12973 L
.41988 .12956 L
.42018 .12874 L
.42034 .12811 L
.42052 .12732 L
.42085 .12555 L
.42148 .12094 L
.42207 .11543 L
.4234 .09922 L
.42583 .06103 L
.4271 .03912 L
.42773 .0285 L
.428 .02393 L
.42831 .01899 L
Mistroke
.42844 .01687 L
.42858 .01482 L
.42871 .01692 L
.42883 .01882 L
.42939 .02727 L
.43055 .04338 L
.43167 .05628 L
.43286 .06675 L
.43348 .0708 L
.43381 .07255 L
.43416 .07412 L
.43449 .07526 L
.43478 .07607 L
.43493 .07638 L
.43508 .07666 L
.43523 .07686 L
.43536 .07701 L
.43552 .07711 L
.4356 .07714 L
.43568 .07715 L
.43583 .07714 L
.43598 .07707 L
.43606 .077 L
.43614 .07693 L
.4363 .07674 L
.43646 .07648 L
.43664 .07612 L
.43694 .07535 L
.43726 .0743 L
.43784 .07189 L
.4389 .06574 L
.44008 .05683 L
.44131 .04578 L
.44261 .03304 L
.44372 .0219 L
.44402 .01889 L
.44419 .01724 L
.44434 .0157 L
.44449 .01516 L
.44465 .01669 L
.44493 .01933 L
.44715 .03797 L
.44841 .04591 L
.44903 .04894 L
.44959 .05119 L
.44987 .05212 L
.45018 .05299 L
.45048 .05368 L
.45074 .05417 L
.45106 .0546 L
Mistroke
.45123 .05477 L
.45131 .05484 L
.45139 .05489 L
.45154 .05496 L
.45168 .05499 L
.45182 .055 L
.45191 .05498 L
.45199 .05496 L
.45214 .05488 L
.45223 .05482 L
.45231 .05476 L
.45263 .05441 L
.45291 .05397 L
.45321 .05337 L
.45383 .05173 L
.45452 .04933 L
.45574 .04375 L
.45686 .03746 L
.45816 .02916 L
.45938 .02102 L
.45965 .01918 L
.45994 .01719 L
.46008 .01629 L
.46022 .01534 L
.46035 .0149 L
.46048 .01578 L
.4611 .01975 L
.46166 .0232 L
.46297 .03044 L
.46416 .03583 L
.46473 .03794 L
.46536 .03985 L
.46596 .04125 L
.46651 .04219 L
.46666 .0424 L
.46684 .04259 L
.46699 .04274 L
.46715 .04286 L
.46729 .04295 L
.46745 .04301 L
.46759 .04305 L
.46773 .04306 L
.46781 .04306 L
.4679 .04305 L
.46798 .04304 L
.46806 .04301 L
.4682 .04295 L
.46835 .04286 L
.46852 .04274 L
.46867 .0426 L
Mistroke
.46903 .04218 L
.46962 .04118 L
.47028 .0397 L
.47147 .03606 L
.4737 .02677 L
.47492 .02091 L
.47552 .01797 L
.47579 .01668 L
.47593 .016 L
.47607 .01528 L
.47616 .01487 L
.47623 .01493 L
.47638 .01565 L
.47671 .01721 L
.4774 .0204 L
.4786 .02552 L
.47972 .02958 L
.48091 .03296 L
.48152 .03431 L
.48185 .03489 L
.48221 .03543 L
.48253 .03582 L
.48283 .03611 L
.48311 .03631 L
.48325 .03639 L
.48341 .03645 L
.48357 .03649 L
.48371 .03651 L
.48379 .03652 L
.48388 .03651 L
.48396 .03651 L
.48405 .03649 L
.4842 .03645 L
.48434 .0364 L
.4845 .03632 L
.48465 .03622 L
.48493 .03599 L
.48519 .03573 L
.48577 .03493 L
.48642 .03376 L
.487 .03246 L
.4883 .0288 L
.48953 .0246 L
.49082 .01966 L
.49136 .01754 L
.49165 .01637 L
.49193 .01526 L
.49208 .0148 L
.49217 .01515 L
.49226 .01548 L
Mistroke
.49255 .01666 L
.49314 .01894 L
.4943 .02322 L
.49554 .02728 L
.49664 .03022 L
.49779 .03252 L
.49836 .03332 L
.49868 .03367 L
.49897 .03393 L
.49925 .03411 L
.49937 .03418 L
.49949 .03423 L
.49963 .03427 L
.49978 .0343 L
.49991 .03432 L
.50005 .03432 L
.5002 .03431 L
.50035 .03428 L
.50042 .03426 L
.50051 .03423 L
.50066 .03416 L
.50096 .03398 L
.50123 .03375 L
.50187 .03303 L
.50254 .03195 L
.50366 .02948 L
.50488 .02598 L
.50602 .02208 L
.50708 .01808 L
.50764 .01589 L
.5078 .01525 L
.50795 .01478 L
.50809 .01533 L
.50824 .01592 L
.5095 .02092 L
.51071 .02546 L
.51204 .02985 L
.51264 .03153 L
.51328 .03311 L
.51383 .03425 L
.51444 .03524 L
.51479 .0357 L
.51512 .03603 L
.51543 .03627 L
.5156 .03637 L
.51576 .03644 L
.51592 .03648 L
.51606 .03651 L
.51622 .03652 L
.5163 .03651 L
Mistroke
.51639 .0365 L
.51653 .03647 L
.51669 .03641 L
.51684 .03634 L
.51697 .03626 L
.51725 .03604 L
.51755 .03573 L
.51817 .03486 L
.51874 .03377 L
.51928 .03251 L
.52048 .0289 L
.52178 .02396 L
.52239 .02135 L
.52303 .0184 L
.52335 .01693 L
.5235 .01619 L
.52364 .01551 L
.52377 .01489 L
.52391 .01521 L
.52405 .01587 L
.5242 .01661 L
.52542 .02256 L
.52674 .02881 L
.52795 .0339 L
.52909 .03791 L
.52972 .0397 L
.53041 .04125 L
.53071 .04179 L
.53103 .04226 L
.53134 .04261 L
.53161 .04284 L
.53176 .04293 L
.53189 .043 L
.53204 .04304 L
.53213 .04306 L
.5322 .04306 L
.53236 .04306 L
.53244 .04304 L
.53252 .04302 L
.53267 .04297 L
.53283 .04288 L
.53296 .04278 L
.5331 .04266 L
.53336 .04238 L
.53366 .04194 L
.53394 .04145 L
.53456 .04006 L
.53523 .03807 L
.53645 .03324 L
.53767 .02705 L
Mistroke
.53882 .02024 L
.53913 .01828 L
.53946 .01617 L
.53954 .01563 L
.53963 .01505 L
.53973 .01502 L
.53982 .01562 L
.54015 .01782 L
.54135 .02592 L
.54374 .04095 L
.54509 .04773 L
.54573 .0503 L
.54634 .05224 L
.54687 .05355 L
.54717 .05411 L
.54745 .0545 L
.54758 .05466 L
.54773 .05479 L
.54781 .05486 L
.54789 .0549 L
.54804 .05497 L
.5482 .055 L
.54828 .055 L
.54836 .05499 L
.54851 .05494 L
.54867 .05485 L
.54882 .05473 L
.54896 .05458 L
.54928 .05414 L
.54957 .05358 L
.54985 .05292 L
.55047 .05098 L
.55114 .04817 L
.55372 .03132 L
.55431 .02629 L
.55493 .02064 L
.55519 .01822 L
.55533 .01688 L
.55547 .01559 L
.55562 .01538 L
.55577 .01678 L
.55605 .01956 L
.55722 .0313 L
.55848 .04382 L
.56077 .06349 L
.56194 .07077 L
.56253 .0735 L
.56287 .07475 L
.56318 .07567 L
.56345 .0763 L
Mistroke
.56358 .07655 L
.56373 .07677 L
.56388 .07695 L
.56401 .07706 L
.5641 .07711 L
.56418 .07714 L
.56432 .07715 L
.56446 .07712 L
.56459 .07704 L
.56471 .07693 L
.56484 .07677 L
.56498 .07656 L
.56513 .07627 L
.5654 .0756 L
.56571 .07461 L
.56604 .07328 L
.56662 .0702 L
.56726 .06587 L
.56796 .05992 L
.56922 .0462 L
.57038 .03065 L
.57097 .02189 L
.57112 .01962 L
.57126 .01744 L
.57138 .01546 L
.57152 .01613 L
.57166 .01845 L
.57179 .0206 L
.57209 .02546 L
.57271 .03598 L
.57523 .07851 L
.57631 .0952 L
.57749 .11052 L
.57816 .11766 L
.57877 .12293 L
.57906 .12499 L
.57939 .12686 L
.57969 .12825 L
.57997 .1292 L
.58013 .12958 L
.58021 .12975 L
.58029 .12987 L
.58043 .13002 L
.58059 .13008 L
.58067 .13007 L
.58075 .13003 L
.5809 .12986 L
.58099 .12973 L
.58107 .12957 L
.58125 .1291 L
Mistroke
.58152 .12806 L
.58183 .12648 L
.58215 .12432 L
.58245 .12182 L
.58301 .11584 L
.58353 .10887 L
.58469 .08787 L
.58588 .05906 L
.58644 .04268 L
.58698 .02574 L
.58712 .02082 L
.58728 .0155 L
.58736 .01676 L
.58745 .0199 L
.58761 .02553 L
.58818 .04694 L
.58947 .09985 L
.59434 .33357 L
.59658 .43768 L
.59902 .52994 L
.59966 .54891 L
.60035 .56624 L
.60094 .5787 L
.60158 .5894 L
.60192 .59391 L
.60223 .59729 L
.60253 .59982 L
.60268 .60085 L
.60285 .60176 L
.603 .60241 L
.60313 .60285 L
.60327 .60314 L
.6034 .6033 L
.60355 .60331 L
.60369 .60317 L
.60384 .60285 L
.60392 .60262 L
.604 .60231 L
.60428 .60087 L
.60445 .59978 L
.60459 .59859 L
.60522 .59176 L
.60576 .58349 L
.60634 .57231 L
.60766 .53803 L
.60886 .4974 L
.61368 .27195 L
.6159 .15793 L
.61716 .09676 L
.61777 .06859 L
Mistroke
.61833 .04411 L
.61862 .03216 L
.61877 .026 L
.61893 .01956 L
.61906 .01538 L
.61922 .02137 L
.61949 .03164 L
.62073 .07394 L
.62204 .10919 L
.62263 .12172 L
.62327 .13305 L
.62389 .14153 L
.62446 .14739 L
.62477 .14981 L
.62506 .1515 L
.62522 .15223 L
.62539 .15286 L
.62547 .15309 L
.62555 .1533 L
.6257 .15358 L
.62584 .15372 L
.62597 .15376 L
.62611 .1537 L
.62625 .15354 L
.62638 .1533 L
.6265 .15301 L
.62677 .15207 L
.62706 .15061 L
.62733 .14891 L
.62793 .1439 L
.62852 .13749 L
.62915 .12925 L
.63026 .1113 L
.63277 .06087 L
.63391 .03608 L
.63424 .02899 L
.63456 .02235 L
.63469 .01949 L
.63484 .01647 L
.63499 .01625 L
.63514 .01926 L
.63735 .06019 L
.63848 .07657 L
.63908 .08363 L
.6397 .08983 L
.64025 .0942 L
.64054 .09609 L
.64085 .09779 L
.64114 .09906 L
.6414 .09997 L
Mistroke
.64153 .10032 L
.64166 .10064 L
.64179 .10088 L
.64191 .10106 L
.64206 .10121 L
.64219 .10129 L
.64234 .1013 L
.6425 .10122 L
.64264 .10109 L
.64279 .10088 L
.64293 .10061 L
.64305 .10032 L
.64336 .09937 L
.6437 .09801 L
.64431 .09467 L
.64495 .08998 L
.64563 .08388 L
.64685 .07042 L
.64808 .0542 L
.64925 .03744 L
.64976 .02994 L
.6503 .02197 L
.65058 .01784 L
.65066 .01671 L
.65074 .0155 L
.65089 .0161 L
.65104 .01821 L
.65117 .02021 L
.65144 .02391 L
.6538 .0537 L
.655 .06522 L
.65569 .07032 L
.65632 .07406 L
.65693 .07672 L
.65728 .07781 L
.65744 .07822 L
.65759 .07854 L
.65774 .07879 L
.65787 .07896 L
.65802 .07911 L
.65818 .07921 L
.65833 .07924 L
.65842 .07923 L
.65849 .07921 L
.65864 .07913 L
.65879 .07898 L
.65893 .0788 L
.65906 .07859 L
.65934 .07798 L
.6596 .07728 L
Mistroke
.65986 .07638 L
.66042 .07394 L
.66104 .0705 L
.66228 .06133 L
.6634 .05089 L
.66472 .03692 L
.66529 .03042 L
.66593 .02315 L
.66621 .01994 L
.66636 .01817 L
.66651 .0165 L
.66665 .01495 L
.66679 .01616 L
.66705 .01909 L
.66824 .03201 L
.66956 .04474 L
.67075 .05421 L
.67134 .05802 L
.67198 .06141 L
.67258 .0639 L
.67313 .06555 L
.67343 .06619 L
.67358 .06644 L
.67372 .06662 L
.67379 .06671 L
.67388 .06679 L
.67403 .0669 L
.67411 .06695 L
.6742 .06697 L
.67428 .06698 L
.67436 .06698 L
.67444 .06697 L
.67453 .06694 L
.67468 .06685 L
.67477 .06677 L
.67485 .06669 L
.67503 .06646 L
.67533 .06593 L
.67566 .06516 L
.6763 .06304 L
.6769 .06042 L
.67824 .05242 L
.68067 .03239 L
.68176 .02212 L
.68208 .01912 L
.68223 .01764 L
.68238 .01627 L
.68251 .01504 L
.68264 .0157 L
.68278 .01701 L
Mistroke
.68294 .01845 L
.68422 .03012 L
.68543 .03989 L
.68656 .04761 L
.68776 .0538 L
.68838 .05615 L
.68871 .05712 L
.68907 .05795 L
.68923 .05827 L
.68939 .05853 L
.68955 .05874 L
.68969 .05889 L
.68983 .05901 L
.68997 .0591 L
.69011 .05915 L
.69027 .05916 L
.69043 .05913 L
.69057 .05907 L
.69073 .05896 L
.6909 .05879 L
.69121 .05836 L
.69149 .05782 L
.69207 .05633 L
.69261 .05444 L
.69382 .04871 L
.69513 .04049 L
.69638 .03127 L
.69754 .02192 L
.69812 .01711 L
.6982 .01645 L
.69829 .01572 L
.69845 .01501 L
.6986 .01629 L
.69875 .01746 L
.70008 .02795 L
.70233 .04285 L
.70295 .04598 L
.70361 .04881 L
.70424 .05092 L
.70454 .05173 L
.70481 .05234 L
.70509 .05285 L
.70539 .05327 L
.70555 .05344 L
.7057 .05357 L
.70585 .05365 L
.706 .05371 L
.70613 .05373 L
.70627 .05372 L
.7064 .05368 L
Mistroke
.70652 .05363 L
.70666 .05353 L
.70682 .0534 L
.7071 .05306 L
.70743 .05251 L
.70773 .05188 L
.70839 .05002 L
.70901 .04776 L
.7096 .0452 L
.71202 .03092 L
.7131 .02336 L
.71369 .01905 L
.71398 .01692 L
.71411 .01599 L
.71425 .01496 L
.7144 .01552 L
.71455 .01662 L
.71487 .01894 L
.71543 .02293 L
.71653 .0303 L
.71783 .03795 L
.71902 .04351 L
.7196 .0456 L
.72022 .04742 L
.72051 .04808 L
.72081 .04866 L
.7211 .0491 L
.72136 .04939 L
.72152 .04953 L
.72161 .04959 L
.72169 .04963 L
.72183 .04969 L
.72198 .04973 L
.72207 .04973 L
.72215 .04973 L
.72231 .04969 L
.7224 .04966 L
.72248 .04962 L
.72266 .04949 L
.7228 .04936 L
.72294 .04921 L
.72325 .04878 L
.72355 .04823 L
.72388 .04751 L
.72503 .04393 L
.72569 .04124 L
.72629 .03836 L
.7276 .03113 L
.72884 .0234 L
.72941 .01965 L
Mistroke
.72973 .01757 L
.73002 .01562 L
.73017 .01482 L
.73026 .01539 L
.73034 .0159 L
.73069 .0182 L
.7313 .02217 L
.73355 .03506 L
.73473 .04032 L
.7353 .04232 L
.73584 .04388 L
.73614 .04462 L
.73647 .0453 L
.73675 .04576 L
.73705 .04616 L
.73721 .04632 L
.73738 .04647 L
.73747 .04653 L
.73755 .04658 L
.73764 .04662 L
.73772 .04664 L
.73787 .04668 L
.73795 .04668 L
.73804 .04668 L
.73818 .04665 L
.73834 .04659 L
.73849 .04651 L
.73862 .04641 L
.73893 .04609 L
.73923 .04567 L
.73956 .04511 L
.74014 .04377 L
.74067 .04222 L
.74197 .03727 L
.74319 .03131 L
.74437 .02474 L
.74501 .02093 L
.74532 .01903 L
.74561 .01729 L
.74573 .01653 L
.74587 .0157 L
.746 .01491 L
.74612 .01525 L
.74625 .01601 L
.74639 .01686 L
.74667 .01856 L
.74783 .02534 L
.74897 .03132 L
.75016 .03666 L
.75079 .03896 L
Mistroke
.75147 .04104 L
.7521 .04251 L
.75238 .04303 L
.75268 .04348 L
.75283 .04367 L
.75299 .04385 L
.75314 .04399 L
.75328 .04409 L
.75345 .04419 L
.75354 .04422 L
.75362 .04425 L
.75378 .04428 L
.75386 .04428 L
.75394 .04428 L
.7541 .04425 L
.75425 .04419 L
.75438 .04412 L
.75452 .04402 L
.75484 .04372 L
.75514 .04333 L
.75566 .04242 L
.75623 .04109 L
.75738 .03744 L
.75993 .02568 L
.76052 .02251 L
.76114 .01905 L
.76139 .01761 L
.76167 .01605 L
.76183 .01516 L
.76197 .01509 L
.76211 .01587 L
.76225 .01669 L
.76341 .02304 L
.76466 .02937 L
.76586 .03452 L
.76695 .03821 L
.76754 .03976 L
.7681 .0409 L
.76839 .04136 L
.76869 .04176 L
.76885 .04192 L
.76902 .04207 L
.76918 .04218 L
.76933 .04226 L
.76947 .04231 L
.76961 .04234 L
.76976 .04235 L
.76989 .04234 L
.77002 .04231 L
.77013 .04227 L
Mistroke
.77027 .0422 L
.7704 .04212 L
.77068 .04187 L
.77095 .04157 L
.77154 .04062 L
.77211 .03938 L
.77272 .03772 L
.77382 .03392 L
.77631 .02242 L
.77691 .01932 L
.77724 .01759 L
.77754 .01596 L
.7777 .01512 L
.77779 .01478 L
.77787 .01522 L
.77824 .01714 L
.77888 .02049 L
.78014 .02668 L
.78131 .03174 L
.78241 .03565 L
.78298 .03727 L
.78359 .03869 L
.78394 .03935 L
.78427 .03984 L
.78458 .04022 L
.78473 .04038 L
.7849 .04051 L
.78506 .04062 L
.7852 .04069 L
.78534 .04074 L
.78547 .04077 L
.78562 .04078 L
.78577 .04077 L
.78592 .04074 L
.786 .04071 L
.78609 .04067 L
.78624 .04059 L
.78637 .0405 L
.78668 .04021 L
.78699 .03985 L
.78731 .03936 L
.78789 .03822 L
.78842 .03692 L
.78972 .03278 L
.79094 .02782 L
.79211 .02239 L
.79275 .01924 L
.79306 .01768 L
.79335 .01624 L
.79347 .01561 L
Mistroke
.79361 .01492 L
.79374 .01515 L
.79386 .01576 L
.79441 .01849 L
.79557 .02408 L
.79685 .02958 L
.79805 .03386 L
.79913 .03677 L
.79974 .03797 L
.80029 .03877 L
.80059 .03907 L
.80086 .03928 L
.80101 .03936 L
.80109 .0394 L
.80117 .03943 L
.80133 .03947 L
.80147 .03948 L
.8016 .03948 L
.80174 .03946 L
.80187 .03942 L
.80199 .03937 L
.80212 .0393 L
.80227 .03921 L
.80257 .03895 L
.80289 .03857 L
.80319 .03813 L
.80386 .03687 L
.80506 .03367 L
.80757 .0239 L
.80867 .01879 L
.80897 .01735 L
.80914 .01655 L
.8093 .0158 L
.80944 .0151 L
.80953 .01473 L
.8096 .0151 L
.80988 .01643 L
.81214 .0266 L
.81329 .03095 L
.81453 .03467 L
.81519 .03619 L
.81548 .03673 L
.8158 .03724 L
.81609 .03762 L
.81639 .03794 L
.81656 .03808 L
.81671 .03819 L
.81685 .03827 L
.81701 .03834 L
.81714 .03838 L
Mistroke
.81729 .0384 L
.81743 .03841 L
.81756 .0384 L
.81771 .03836 L
.81785 .03831 L
.81801 .03823 L
.81816 .03814 L
.81843 .03791 L
.81868 .03764 L
.81925 .03683 L
.81986 .03564 L
.82053 .03402 L
.82173 .03028 L
.82397 .0212 L
.82452 .01872 L
.82483 .01733 L
.82512 .016 L
.82528 .01525 L
.82537 .01483 L
.82546 .01499 L
.82561 .01568 L
.82577 .01641 L
.82637 .01917 L
.8276 .02446 L
.82891 .02948 L
.83014 .03324 L
.83068 .03455 L
.83126 .03572 L
.83153 .03616 L
.83182 .03657 L
.83207 .03686 L
.83234 .03712 L
.83249 .03724 L
.83264 .03733 L
.83278 .0374 L
.83293 .03746 L
.83306 .03749 L
.83318 .03751 L
.83332 .03751 L
.83347 .03749 L
.83355 .03748 L
.83363 .03745 L
.83377 .0374 L
.83393 .03732 L
.8341 .03721 L
.83441 .03694 L
.83469 .03663 L
.83534 .03565 L
.83602 .03425 L
.83717 .03109 L
Mistroke
.83844 .02668 L
.83965 .02178 L
.84025 .01922 L
.8408 .0168 L
.84111 .01544 L
.84126 .01475 L
.84135 .01507 L
.84143 .01544 L
.84212 .01846 L
.84332 .02353 L
.84451 .02803 L
.84576 .03195 L
.84683 .03445 L
.84743 .03549 L
.84771 .03586 L
.84799 .03618 L
.84815 .03632 L
.84831 .03645 L
.84846 .03655 L
.8486 .03663 L
.84877 .0367 L
.84886 .03672 L
.84895 .03674 L
.8491 .03676 L
.84919 .03676 L
.84927 .03676 L
.84941 .03673 L
.84954 .0367 L
.84969 .03664 L
.84985 .03656 L
.85017 .03632 L
.85046 .03603 L
.85099 .03534 L
.85156 .03433 L
.85271 .03156 L
.85527 .02262 L
.85585 .02021 L
.85648 .01757 L
.85673 .01648 L
.85687 .01587 L
.85701 .01529 L
.85717 .01482 L
.85731 .01544 L
.85759 .01665 L
.85875 .0215 L
.86001 .02634 L
.86121 .03026 L
.8623 .03306 L
.86289 .03424 L
.86345 .0351 L
Mistroke
.86376 .03546 L
.86405 .03573 L
.86436 .03595 L
.86452 .03602 L
.8646 .03606 L
.86469 .03609 L
.86484 .03612 L
.86498 .03614 L
.86511 .03614 L
.86524 .03612 L
.86538 .03609 L
.86553 .03604 L
.86569 .03596 L
.86583 .03587 L
.8661 .03566 L
.86635 .03542 L
.86691 .03469 L
.86748 .0337 L
.86809 .03236 L
.86919 .02934 L
.87169 .02023 L
.87229 .01777 L
.87261 .0164 L
.87277 .01573 L
.87292 .01511 L
.873 .01477 L
.87308 .01499 L
.87316 .01533 L
.87325 .01571 L
.87362 .01723 L
.87426 .01986 L
.87554 .0248 L
.87669 .0287 L
.87728 .03042 L
.87792 .03204 L
.87847 .03321 L
.87907 .03424 L
.87938 .03466 L
.87971 .03503 L
.87989 .0352 L
.88006 .03533 L
.88023 .03543 L
.88039 .03551 L
.88053 .03557 L
.88069 .0356 L
.88084 .03562 L
.88093 .03563 L
.88101 .03562 L
.88116 .0356 L
.88129 .03557 L
Mistroke
.88145 .03551 L
.8816 .03544 L
.88191 .03522 L
.88221 .03495 L
.88275 .03426 L
.88335 .03326 L
.88399 .0319 L
.8862 .02524 L
.88745 .02056 L
.88805 .01813 L
.88861 .01587 L
.88875 .01529 L
.88891 .01478 L
.88905 .01539 L
.88919 .01595 L
.88982 .01849 L
.89115 .02363 L
.89223 .02736 L
.89339 .03073 L
.89406 .03228 L
.89468 .03343 L
.89526 .03427 L
.89556 .0346 L
.89588 .03487 L
.89603 .03497 L
.89618 .03506 L
.89627 .0351 L
.89636 .03513 L
.89652 .03518 L
.89666 .0352 L
.89675 .03521 L
.89683 .03521 L
.89697 .0352 L
.89712 .03517 L
.89725 .03513 L
.8974 .03507 L
.89765 .03492 L
.89796 .03467 L
.89824 .03438 L
.89887 .03352 L
.89954 .03226 L
.90077 .02922 L
.90313 .02119 L
.90377 .01867 L
.90413 .01725 L
.90447 .0159 L
.90462 .01529 L
.9047 .01496 L
.90478 .01479 L
.90486 .01513 L
Mistroke
.90496 .0155 L
.90512 .01616 L
.90572 .01853 L
.90693 .02314 L
.9082 .02747 L
.90938 .03075 L
.90996 .03203 L
.91048 .03301 L
.91104 .03383 L
.91156 .03439 L
.91185 .03461 L
.91211 .03476 L
.91225 .03481 L
.9124 .03485 L
.91256 .03488 L
.91271 .03488 L
.91286 .03487 L
.91295 .03485 L
.91303 .03483 L
.91317 .03479 L
.91333 .03472 L
.91362 .03453 L
.91389 .0343 L
.91454 .03353 L
.91515 .03251 L
.91633 .02984 L
.91758 .02613 L
.91875 .02204 L
.91981 .01797 L
.92009 .01686 L
.92024 .01627 L
.9204 .01565 L
.92054 .0151 L
.92069 .01493 L
.92083 .01548 L
.92096 .016 L
.92219 .02076 L
.9244 .02826 L
.925 .02989 L
.92565 .03143 L
.92623 .03256 L
.92684 .0335 L
.92715 .03387 L
.92745 .03416 L
.92771 .03436 L
.92785 .03444 L
.928 .03451 L
.92814 .03457 L
.92827 .0346 L
.92841 .03463 L
Mistroke
.92856 .03463 L
.9287 .03463 L
.92883 .0346 L
.92895 .03457 L
.92908 .03453 L
.92922 .03446 L
.92936 .03438 L
.92966 .03416 L
.92993 .0339 L
.93021 .03358 L
.93081 .03269 L
.93146 .03144 L
.93277 .0281 L
.93399 .02419 L
.93526 .01956 L
.93589 .01715 L
.93616 .01608 L
.9363 .01552 L
.93646 .0149 L
.9366 .01508 L
.93673 .01559 L
.93698 .01657 L
.93754 .01872 L
.9387 .02304 L
.93981 .02675 L
.941 .03006 L
.94168 .03159 L
.94229 .03271 L
.94259 .03316 L
.94291 .03357 L
.94322 .03389 L
.9435 .03412 L
.94378 .0343 L
.94394 .03437 L
.94409 .03441 L
.94423 .03444 L
.94436 .03446 L
.9445 .03446 L
.94465 .03444 L
.94479 .03441 L
.94488 .03438 L
.94495 .03436 L
.94524 .03421 L
.9454 .0341 L
.94557 .03397 L
.94591 .03363 L
.94654 .03277 L
.94722 .03153 L
.94845 .02856 L
.95085 .02058 L
Mistroke
.95151 .01808 L
.95187 .01669 L
.95205 .01601 L
.95221 .01538 L
.95236 .01481 L
.9525 .01516 L
.95264 .01574 L
.9528 .01636 L
.95346 .01888 L
.95575 .02688 L
.95706 .03042 L
.9577 .03179 L
.95829 .0328 L
.95884 .03353 L
.95912 .03382 L
.95943 .03406 L
.95959 .03416 L
.95974 .03423 L
.95982 .03427 L
.95991 .0343 L
.96007 .03433 L
.96022 .03435 L
.96038 .03436 L
.96052 .03434 L
.96067 .03431 L
.96075 .03428 L
.96084 .03425 L
.961 .03418 L
.9613 .03398 L
.96165 .03367 L
.96198 .0333 L
.96257 .03243 L
.9632 .03124 L
.96444 .02816 L
.96578 .02393 L
.96694 .01975 L
.96756 .01741 L
.9679 .0161 L
.96806 .01546 L
.96822 .01486 L
.96837 .01516 L
.96844 .01545 L
.96853 .01578 L
.96887 .01709 L
.96946 .01936 L
.97062 .02358 L
.97195 .02781 L
.97316 .03091 L
.97387 .0323 L
.97462 .03338 L
Mistroke
.97501 .03379 L
.97537 .03407 L
.97558 .03418 L
.97577 .03425 L
.97587 .03428 L
.97598 .03431 L
.97609 .03432 L
.97619 .03432 L
Mfstroke
1 0 0 r
[ ] 0 setdash
.03968 .01472 m
.03968 .03436 L
s
.05556 .01472 m
.05556 .03446 L
s
.07143 .01472 m
.07143 .03463 L
s
.0873 .01472 m
.0873 .03488 L
s
.10317 .01472 m
.10317 .03521 L
s
.11905 .01472 m
.11905 .03563 L
s
.13492 .01472 m
.13492 .03614 L
s
.15079 .01472 m
.15079 .03676 L
s
.16667 .01472 m
.16667 .03751 L
s
.18254 .01472 m
.18254 .03841 L
s
.19841 .01472 m
.19841 .03948 L
s
.21429 .01472 m
.21429 .04078 L
s
.23016 .01472 m
.23016 .04235 L
s
.24603 .01472 m
.24603 .04427 L
s
.2619 .01472 m
.2619 .04667 L
s
.27778 .01472 m
.27778 .04972 L
s
.29365 .01472 m
.29365 .0537 L
s
.30952 .01472 m
.30952 .05912 L
s
.3254 .01472 m
.3254 .0669 L
s
.34127 .01472 m
.34127 .07905 L
s
.35714 .01472 m
.35714 .10075 L
s
.37302 .01472 m
.37302 .15104 L
s
.38889 .01472 m
.38889 .40109 L
s
.40476 .01472 m
.40476 .37687 L
s
.42063 .01472 m
.42063 .12675 L
s
.43651 .01472 m
.43651 .07639 L
s
.45238 .01472 m
.45238 .05469 L
s
.46825 .01472 m
.46825 .04293 L
s
.48413 .01472 m
.48413 .03647 L
s
.5 .01472 m
.5 .03432 L
s
.51587 .01472 m
.51587 .03647 L
s
.53175 .01472 m
.53175 .04293 L
s
.54762 .01472 m
.54762 .05469 L
s
.56349 .01472 m
.56349 .07639 L
s
.57937 .01472 m
.57937 .12675 L
s
.59524 .01472 m
.59524 .37687 L
s
.61111 .01472 m
.61111 .40109 L
s
.62698 .01472 m
.62698 .15104 L
s
.64286 .01472 m
.64286 .10075 L
s
.65873 .01472 m
.65873 .07905 L
s
.6746 .01472 m
.6746 .0669 L
s
.69048 .01472 m
.69048 .05912 L
s
.70635 .01472 m
.70635 .0537 L
s
.72222 .01472 m
.72222 .04972 L
s
.7381 .01472 m
.7381 .04667 L
s
.75397 .01472 m
.75397 .04427 L
s
.76984 .01472 m
.76984 .04235 L
s
.78571 .01472 m
.78571 .04078 L
s
.80159 .01472 m
.80159 .03948 L
s
.81746 .01472 m
.81746 .03841 L
s
.83333 .01472 m
.83333 .03751 L
s
.84921 .01472 m
.84921 .03676 L
s
.86508 .01472 m
.86508 .03614 L
s
.88095 .01472 m
.88095 .03563 L
s
.89683 .01472 m
.89683 .03521 L
s
.9127 .01472 m
.9127 .03488 L
s
.92857 .01472 m
.92857 .03463 L
s
.94444 .01472 m
.94444 .03446 L
s
.96032 .01472 m
.96032 .03436 L
s
.97619 .01472 m
.97619 .03432 L
s
.015 w
.03968 .03436 Mdot
.05556 .03446 Mdot
.07143 .03463 Mdot
.0873 .03488 Mdot
.10317 .03521 Mdot
.11905 .03563 Mdot
.13492 .03614 Mdot
.15079 .03676 Mdot
.16667 .03751 Mdot
.18254 .03841 Mdot
.19841 .03948 Mdot
.21429 .04078 Mdot
.23016 .04235 Mdot
.24603 .04427 Mdot
.2619 .04667 Mdot
.27778 .04972 Mdot
.29365 .0537 Mdot
.30952 .05912 Mdot
.3254 .0669 Mdot
.34127 .07905 Mdot
.35714 .10075 Mdot
.37302 .15104 Mdot
.38889 .40109 Mdot
.40476 .37687 Mdot
.42063 .12675 Mdot
.43651 .07639 Mdot
.45238 .05469 Mdot
.46825 .04293 Mdot
.48413 .03647 Mdot
.5 .03432 Mdot
.51587 .03647 Mdot
.53175 .04293 Mdot
.54762 .05469 Mdot
.56349 .07639 Mdot
.57937 .12675 Mdot
.59524 .37687 Mdot
.61111 .40109 Mdot
.62698 .15104 Mdot
.64286 .10075 Mdot
.65873 .07905 Mdot
.6746 .0669 Mdot
.69048 .05912 Mdot
.70635 .0537 Mdot
.72222 .04972 Mdot
.7381 .04667 Mdot
.75397 .04427 Mdot
.76984 .04235 Mdot
.78571 .04078 Mdot
.80159 .03948 Mdot
.81746 .03841 Mdot
.83333 .03751 Mdot
.84921 .03676 Mdot
.86508 .03614 Mdot
.88095 .03563 Mdot
.89683 .03521 Mdot
.9127 .03488 Mdot
.92857 .03463 Mdot
.94444 .03446 Mdot
.96032 .03436 Mdot
.97619 .03432 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Show both", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(gw1 = 
        Show[GraphicsArray[{{g1, g5, \ g6}}], \ 
          ImageSize \[Rule] 504*1.5];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .19314 
%%ImageSize: 756 146.011 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.00459847 0.31746 [
[ 0 0 0 0 ]
[ 1 .19314 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .19314 L
0 .19314 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00459847 0.321429 0.188537 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.047619 0.0146992 0.0196085 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .0147 -6 -4.5 ]
[-0.0125 .0147 0 4.5 ]
[-0.0125 .11274 -6 -4.5 ]
[-0.0125 .11274 0 4.5 ]
[-0.0125 .21078 -12 -4.5 ]
[-0.0125 .21078 0 4.5 ]
[-0.0125 .30883 -12 -4.5 ]
[-0.0125 .30883 0 4.5 ]
[-0.0125 .40687 -12 -4.5 ]
[-0.0125 .40687 0 4.5 ]
[-0.0125 .50491 -12 -4.5 ]
[-0.0125 .50491 0 4.5 ]
[-0.0125 .60295 -12 -4.5 ]
[-0.0125 .60295 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .0147 m
.00625 .0147 L
s
[(0)] -0.0125 .0147 1 0 Mshowa
0 .11274 m
.00625 .11274 L
s
[(5)] -0.0125 .11274 1 0 Mshowa
0 .21078 m
.00625 .21078 L
s
[(10)] -0.0125 .21078 1 0 Mshowa
0 .30883 m
.00625 .30883 L
s
[(15)] -0.0125 .30883 1 0 Mshowa
0 .40687 m
.00625 .40687 L
s
[(20)] -0.0125 .40687 1 0 Mshowa
0 .50491 m
.00625 .50491 L
s
[(25)] -0.0125 .50491 1 0 Mshowa
0 .60295 m
.00625 .60295 L
s
[(30)] -0.0125 .60295 1 0 Mshowa
.125 Mabswid
0 .03431 m
.00375 .03431 L
s
0 .05392 m
.00375 .05392 L
s
0 .07352 m
.00375 .07352 L
s
0 .09313 m
.00375 .09313 L
s
0 .13235 m
.00375 .13235 L
s
0 .15196 m
.00375 .15196 L
s
0 .17157 m
.00375 .17157 L
s
0 .19118 m
.00375 .19118 L
s
0 .23039 m
.00375 .23039 L
s
0 .25 m
.00375 .25 L
s
0 .26961 m
.00375 .26961 L
s
0 .28922 m
.00375 .28922 L
s
0 .32844 m
.00375 .32844 L
s
0 .34804 m
.00375 .34804 L
s
0 .36765 m
.00375 .36765 L
s
0 .38726 m
.00375 .38726 L
s
0 .42648 m
.00375 .42648 L
s
0 .44609 m
.00375 .44609 L
s
0 .46569 m
.00375 .46569 L
s
0 .4853 m
.00375 .4853 L
s
0 .52452 m
.00375 .52452 L
s
0 .54413 m
.00375 .54413 L
s
0 .56374 m
.00375 .56374 L
s
0 .58335 m
.00375 .58335 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .0147 m
1 .0147 L
s
.99375 .11274 m
1 .11274 L
s
.99375 .21078 m
1 .21078 L
s
.99375 .30883 m
1 .30883 L
s
.99375 .40687 m
1 .40687 L
s
.99375 .50491 m
1 .50491 L
s
.99375 .60295 m
1 .60295 L
s
.125 Mabswid
.99625 .03431 m
1 .03431 L
s
.99625 .05392 m
1 .05392 L
s
.99625 .07352 m
1 .07352 L
s
.99625 .09313 m
1 .09313 L
s
.99625 .13235 m
1 .13235 L
s
.99625 .15196 m
1 .15196 L
s
.99625 .17157 m
1 .17157 L
s
.99625 .19118 m
1 .19118 L
s
.99625 .23039 m
1 .23039 L
s
.99625 .25 m
1 .25 L
s
.99625 .26961 m
1 .26961 L
s
.99625 .28922 m
1 .28922 L
s
.99625 .32844 m
1 .32844 L
s
.99625 .34804 m
1 .34804 L
s
.99625 .36765 m
1 .36765 L
s
.99625 .38726 m
1 .38726 L
s
.99625 .42648 m
1 .42648 L
s
.99625 .44609 m
1 .44609 L
s
.99625 .46569 m
1 .46569 L
s
.99625 .4853 m
1 .4853 L
s
.99625 .52452 m
1 .52452 L
s
.99625 .54413 m
1 .54413 L
s
.99625 .56374 m
1 .56374 L
s
.99625 .58335 m
1 .58335 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
0 0 1 r
.5 Mabswid
[ .01 ] 0 setdash
.02381 .03431 m
.02395 .0343 L
.02408 .03428 L
.02423 .03424 L
.02437 .03419 L
.02462 .03406 L
.02489 .03386 L
.02519 .03358 L
.02551 .03321 L
.02608 .03237 L
.02722 .03002 L
.02847 .02655 L
.02973 .02231 L
.03043 .01975 L
.03109 .01723 L
.03139 .01608 L
.03155 .01545 L
.03171 .01485 L
.03179 .01489 L
.03189 .01525 L
.03205 .01589 L
.03238 .01714 L
.03355 .02156 L
.03596 .02922 L
.03717 .03195 L
.03785 .03306 L
.03819 .03348 L
.0385 .0338 L
.03879 .03403 L
.03894 .03413 L
.0391 .03421 L
.03918 .03424 L
.03926 .03427 L
.03941 .03431 L
.03949 .03433 L
.03958 .03434 L
.03967 .03434 L
.03976 .03434 L
.03991 .03432 L
.04006 .03429 L
.04019 .03424 L
.04033 .03418 L
.04065 .03398 L
.04095 .03373 L
.04147 .03314 L
.04204 .03226 L
.04319 .02981 L
.04573 .02188 L
.04631 .01972 L
.04694 .01735 L
Mistroke
.04724 .01618 L
.04739 .01561 L
.04752 .01508 L
.04765 .01481 L
.04778 .01532 L
.04805 .01639 L
.0492 .02077 L
.05046 .02519 L
.05165 .02881 L
.05274 .03143 L
.05332 .03253 L
.05388 .03336 L
.05417 .03369 L
.05447 .03398 L
.05463 .03411 L
.0548 .03422 L
.05495 .0343 L
.05511 .03436 L
.05525 .03441 L
.0554 .03443 L
.05553 .03444 L
.05566 .03444 L
.05581 .03442 L
.05595 .03439 L
.0561 .03433 L
.05625 .03426 L
.05652 .0341 L
.05676 .03389 L
.05732 .03327 L
.05789 .0324 L
.05849 .03122 L
.05959 .02851 L
.06208 .02016 L
.06267 .01789 L
.063 .01663 L
.0633 .01543 L
.06346 .01481 L
.06355 .01493 L
.06363 .01526 L
.064 .01668 L
.06464 .01916 L
.06589 .02379 L
.06706 .0276 L
.06826 .03079 L
.06878 .03191 L
.06934 .03292 L
.06967 .0334 L
.06996 .03377 L
.07027 .03408 L
.07055 .03431 L
Mistroke
.07071 .03441 L
.07085 .03448 L
.07101 .03454 L
.07109 .03457 L
.07118 .03459 L
.07126 .0346 L
.07134 .03461 L
.07149 .03462 L
.07159 .03461 L
.07167 .0346 L
.07175 .03458 L
.07184 .03456 L
.07199 .0345 L
.07213 .03444 L
.07243 .03424 L
.07272 .03399 L
.07299 .0337 L
.07359 .03285 L
.07425 .03163 L
.07557 .02834 L
.07679 .02447 L
.07787 .02053 L
.07844 .01834 L
.07904 .01599 L
.07919 .01538 L
.07928 .01504 L
.07936 .01472 L
.07945 .01505 L
.07954 .01539 L
.07971 .01606 L
.08032 .01847 L
.08152 .02302 L
.0827 .02701 L
.08394 .03052 L
.085 .03277 L
.0856 .03371 L
.08588 .03405 L
.08617 .03434 L
.08633 .03448 L
.08648 .03459 L
.08663 .03468 L
.08677 .03474 L
.08693 .03481 L
.08702 .03483 L
.08711 .03485 L
.08726 .03487 L
.08734 .03487 L
.08742 .03486 L
.08758 .03484 L
.08772 .0348 L
Mistroke
.08786 .03476 L
.088 .03469 L
.08832 .03448 L
.08861 .03421 L
.08913 .03359 L
.0897 .03268 L
.09085 .03014 L
.09339 .02196 L
.09397 .01974 L
.09459 .01729 L
.09489 .01609 L
.09504 .01549 L
.09518 .01495 L
.0953 .01495 L
.09543 .01548 L
.09571 .01659 L
.09685 .0211 L
.0981 .02565 L
.0993 .02938 L
.10038 .03209 L
.10097 .03323 L
.10153 .03408 L
.10181 .03442 L
.10211 .03472 L
.10227 .03485 L
.10244 .03496 L
.10259 .03505 L
.10275 .03511 L
.10289 .03516 L
.10304 .03518 L
.10317 .0352 L
.1033 .03519 L
.10345 .03517 L
.10358 .03514 L
.10374 .03508 L
.10389 .03501 L
.10416 .03483 L
.1044 .03462 L
.10496 .03397 L
.10552 .03307 L
.10613 .03185 L
.10722 .02903 L
.10971 .02035 L
.1103 .01799 L
.11063 .01668 L
.11093 .01543 L
.11102 .01508 L
.11111 .01472 L
.1112 .01508 L
.1113 .01545 L
Mistroke
.11162 .01679 L
.11226 .01939 L
.11343 .02391 L
.11469 .02822 L
.11593 .03168 L
.11652 .03298 L
.11706 .03396 L
.1176 .03472 L
.11789 .03503 L
.1182 .03529 L
.11832 .03538 L
.11846 .03545 L
.11858 .03551 L
.11871 .03555 L
.11885 .03559 L
.119 .03561 L
.11914 .03561 L
.11927 .0356 L
.11943 .03556 L
.1195 .03554 L
.11959 .03551 L
.11988 .03535 L
.12005 .03523 L
.12022 .03508 L
.12054 .03474 L
.12117 .03385 L
.12174 .03277 L
.12289 .02992 L
.12399 .02647 L
.12515 .0222 L
.12578 .01967 L
.12638 .01721 L
.12663 .01618 L
.12676 .01562 L
.12689 .01509 L
.12703 .01488 L
.12718 .0155 L
.12744 .0166 L
.1286 .02138 L
.13086 .02947 L
.13148 .03124 L
.13213 .03286 L
.1327 .03401 L
.13331 .03499 L
.13364 .03539 L
.13394 .03569 L
.13408 .0358 L
.13424 .03591 L
.13439 .03599 L
.13453 .03605 L
Mistroke
.13462 .03607 L
.13471 .0361 L
.13479 .03611 L
.13487 .03612 L
.13495 .03612 L
.13504 .03612 L
.13514 .03611 L
.13523 .03609 L
.13531 .03607 L
.13539 .03605 L
.13554 .03598 L
.1357 .03589 L
.13588 .03577 L
.13617 .03552 L
.13649 .03515 L
.13714 .03416 L
.13774 .03296 L
.13831 .03159 L
.14074 .0235 L
.14182 .01912 L
.14211 .01792 L
.14241 .0166 L
.14255 .016 L
.1427 .01535 L
.14283 .0148 L
.14297 .0152 L
.14313 .01586 L
.14329 .01657 L
.14359 .01786 L
.14416 .02023 L
.14526 .02467 L
.14655 .0293 L
.14775 .03277 L
.14839 .03422 L
.14898 .03526 L
.14929 .03571 L
.14962 .0361 L
.1498 .03628 L
.14997 .03642 L
.15014 .03653 L
.15031 .03662 L
.15046 .03668 L
.1506 .03672 L
.15074 .03674 L
.15087 .03675 L
.15102 .03673 L
.15117 .0367 L
.15132 .03665 L
.15149 .03657 L
.15179 .03636 L
Mistroke
.15208 .03609 L
.15273 .03522 L
.15333 .03412 L
.15398 .03261 L
.15517 .0291 L
.1574 .02049 L
.15804 .01772 L
.15836 .01634 L
.1585 .01573 L
.15865 .01506 L
.15878 .01494 L
.15891 .0155 L
.15919 .01673 L
.15978 .01931 L
.16107 .02477 L
.1623 .02937 L
.16348 .03297 L
.1641 .0345 L
.16476 .03579 L
.16531 .03661 L
.16562 .03696 L
.16592 .03721 L
.16605 .03729 L
.16619 .03737 L
.16631 .03742 L
.16644 .03746 L
.16657 .03748 L
.16672 .03749 L
.16687 .03749 L
.16699 .03746 L
.16714 .03742 L
.16727 .03736 L
.16742 .03728 L
.16758 .03717 L
.1679 .03688 L
.1682 .03653 L
.16876 .03566 L
.1693 .03458 L
.1705 .03138 L
.17181 .0268 L
.17304 .02176 L
.17364 .01911 L
.17419 .01661 L
.17435 .01587 L
.1745 .01518 L
.17465 .01493 L
.17474 .01531 L
.17483 .01572 L
.17551 .01888 L
.17672 .02419 L
Mistroke
.17795 .02909 L
.17928 .03348 L
.17989 .03508 L
.18054 .03645 L
.1811 .03735 L
.18141 .03774 L
.18171 .03802 L
.18185 .03813 L
.182 .03822 L
.18215 .03829 L
.18228 .03834 L
.18243 .03838 L
.18252 .03839 L
.1826 .03839 L
.18274 .03838 L
.1829 .03835 L
.18304 .0383 L
.1832 .03823 L
.18335 .03813 L
.18349 .03803 L
.18383 .0377 L
.18415 .0373 L
.1847 .03638 L
.18521 .03529 L
.18638 .03205 L
.18865 .0232 L
.18928 .02038 L
.18993 .0173 L
.1902 .01601 L
.19035 .01529 L
.19049 .01478 L
.19057 .01516 L
.19066 .01558 L
.19081 .0163 L
.19111 .01772 L
.19245 .02398 L
.1937 .02924 L
.19495 .03369 L
.19557 .03547 L
.19613 .03684 L
.19665 .03786 L
.19722 .03869 L
.19753 .03903 L
.19768 .03915 L
.19782 .03925 L
.19795 .03933 L
.1981 .03939 L
.19825 .03944 L
.19839 .03946 L
.19854 .03947 L
Mistroke
.19869 .03945 L
.19885 .03941 L
.19894 .03937 L
.19902 .03933 L
.19918 .03924 L
.19936 .0391 L
.19969 .03878 L
.19999 .03839 L
.2003 .03788 L
.20088 .03674 L
.20201 .03367 L
.20322 .02927 L
.20437 .02434 L
.20543 .01928 L
.20599 .01651 L
.20615 .01571 L
.2063 .01495 L
.20644 .01513 L
.20658 .01588 L
.20785 .02214 L
.20906 .02778 L
.21039 .03315 L
.21099 .03517 L
.21163 .03704 L
.21218 .03837 L
.21279 .0395 L
.21314 .04 L
.21347 .04035 L
.21363 .04048 L
.21378 .04059 L
.21386 .04063 L
.21395 .04068 L
.21411 .04073 L
.21426 .04076 L
.21434 .04077 L
.21442 .04077 L
.21458 .04075 L
.21466 .04072 L
.21474 .0407 L
.21489 .04063 L
.21504 .04054 L
.21532 .0403 L
.21561 .03999 L
.21591 .03956 L
.21646 .03856 L
.21711 .037 L
.21771 .03523 L
.22025 .02483 L
.22135 .01926 L
.22167 .0176 L
Mistroke
.22197 .01602 L
.2221 .01532 L
.22224 .01481 L
.2224 .01562 L
.22254 .01636 L
.22383 .02314 L
.22503 .02901 L
.22617 .03388 L
.2268 .03617 L
.2274 .03806 L
.22795 .03952 L
.22855 .04079 L
.22882 .04123 L
.2291 .04162 L
.22934 .04189 L
.22961 .04211 L
.22975 .0422 L
.22989 .04226 L
.23004 .04231 L
.23012 .04233 L
.2302 .04234 L
.23035 .04233 L
.23044 .04232 L
.23052 .0423 L
.23067 .04225 L
.23082 .04217 L
.23096 .04208 L
.2311 .04196 L
.23135 .04169 L
.23166 .04128 L
.23194 .04082 L
.23255 .03952 L
.23323 .03767 L
.23445 .03326 L
.23683 .02175 L
.23751 .01799 L
.23767 .01708 L
.23785 .01611 L
.23799 .01528 L
.23808 .01481 L
.23815 .01503 L
.2383 .01585 L
.23843 .01661 L
.23873 .01829 L
.23936 .02179 L
.24057 .02826 L
.24185 .03435 L
.24295 .0386 L
.24358 .04057 L
.24416 .04203 L
Mistroke
.24472 .0431 L
.245 .04351 L
.24531 .04386 L
.24547 .044 L
.24562 .04411 L
.2457 .04415 L
.24579 .04419 L
.24588 .04422 L
.24595 .04424 L
.24609 .04426 L
.24624 .04426 L
.2464 .04423 L
.24655 .04417 L
.24669 .0441 L
.24684 .04399 L
.24711 .04373 L
.24738 .04339 L
.24763 .043 L
.24819 .04187 L
.24879 .04029 L
.25003 .03585 L
.25138 .02957 L
.25254 .02321 L
.25315 .01961 L
.25349 .01758 L
.25366 .01658 L
.25381 .01565 L
.25396 .01473 L
.25404 .01513 L
.25412 .01565 L
.25446 .01772 L
.25506 .02131 L
.25622 .02809 L
.25755 .03503 L
.25876 .04026 L
.25934 .04225 L
.25996 .04402 L
.26025 .04469 L
.26055 .0453 L
.26084 .04577 L
.2611 .04612 L
.26126 .04629 L
.26143 .04643 L
.2616 .04655 L
.2617 .04659 L
.26178 .04662 L
.26187 .04665 L
.26194 .04666 L
.26209 .04666 L
.26225 .04664 L
Mistroke
.26234 .04661 L
.26242 .04657 L
.26257 .04649 L
.2627 .04639 L
.263 .04608 L
.2633 .04567 L
.26362 .04511 L
.26422 .04372 L
.26477 .04205 L
.26604 .03704 L
.26735 .03031 L
.26858 .02288 L
.26916 .0192 L
.26947 .01715 L
.26962 .01614 L
.26976 .01521 L
.26992 .0152 L
.27 .01576 L
.27008 .01629 L
.27043 .0186 L
.27105 .02264 L
.27329 .03617 L
.27445 .0418 L
.27508 .04434 L
.27568 .04631 L
.27624 .04777 L
.27653 .04838 L
.27684 .04891 L
.27711 .04925 L
.27724 .04939 L
.27739 .04952 L
.27753 .0496 L
.27765 .04966 L
.27778 .0497 L
.2779 .04972 L
.27804 .04971 L
.27818 .04968 L
.27832 .04961 L
.27845 .04953 L
.2786 .04942 L
.27875 .04926 L
.27906 .04885 L
.27937 .0483 L
.27971 .04758 L
.2803 .04591 L
.28147 .04139 L
.28253 .03599 L
.28365 .02913 L
.28484 .02099 L
.28514 .01885 L
Mistroke
.28546 .01652 L
.28556 .01583 L
.28565 .01518 L
.28573 .01481 L
.28582 .01545 L
.28615 .01787 L
.28735 .02656 L
.28968 .0415 L
.29032 .0448 L
.29101 .04785 L
.29161 .05002 L
.29193 .05097 L
.29226 .05184 L
.29259 .05253 L
.29289 .05302 L
.29303 .05321 L
.29318 .05338 L
.29333 .05351 L
.29346 .0536 L
.29362 .05367 L
.2937 .0537 L
.29378 .05371 L
.29387 .05371 L
.29396 .0537 L
.29404 .05368 L
.29412 .05365 L
.29427 .05357 L
.29436 .05351 L
.29444 .05344 L
.29473 .05311 L
.29502 .05265 L
.29529 .05211 L
.2959 .0505 L
.29643 .04864 L
.29699 .04625 L
.29936 .03206 L
.30042 .0241 L
.30098 .01965 L
.30129 .01717 L
.30144 .01594 L
.30157 .01481 L
.30172 .01581 L
.30188 .01714 L
.30223 .01997 L
.30283 .02493 L
.30403 .03436 L
.30511 .04212 L
.30627 .04918 L
.30689 .05229 L
.30745 .05466 L
Mistroke
.30801 .05656 L
.30855 .05789 L
.30885 .05844 L
.30902 .05868 L
.30917 .05885 L
.3093 .05897 L
.30945 .05906 L
.3096 .05913 L
.30975 .05915 L
.30983 .05914 L
.30991 .05913 L
.31007 .05906 L
.31016 .05901 L
.31025 .05894 L
.31041 .05877 L
.31072 .05834 L
.31105 .0577 L
.31164 .05606 L
.31219 .054 L
.31345 .04751 L
.31468 .03905 L
.316 .02818 L
.31659 .0228 L
.31692 .01978 L
.31723 .0169 L
.31739 .0154 L
.31748 .01485 L
.31756 .01562 L
.31792 .01909 L
.31856 .0252 L
.32099 .04668 L
.3221 .05466 L
.32328 .06124 L
.32363 .06275 L
.32396 .06397 L
.32428 .06497 L
.32457 .06571 L
.32485 .06626 L
.325 .06649 L
.32515 .06668 L
.32531 .06682 L
.32545 .06691 L
.32554 .06695 L
.32562 .06697 L
.32578 .06696 L
.32591 .06692 L
.32606 .06683 L
.3262 .0667 L
.32633 .06655 L
.32663 .06607 L
Mistroke
.32694 .06537 L
.32753 .0635 L
.32818 .06066 L
.32933 .05365 L
.3304 .04511 L
.33166 .03296 L
.33229 .02637 L
.33286 .02004 L
.33299 .01858 L
.33313 .017 L
.33326 .01551 L
.33338 .01526 L
.33352 .0168 L
.33365 .01827 L
.33394 .0216 L
.3351 .03489 L
.33635 .04835 L
.33752 .05957 L
.33866 .06852 L
.33916 .07169 L
.33971 .07458 L
.34027 .07682 L
.34057 .07774 L
.34085 .07841 L
.34101 .0787 L
.34116 .07891 L
.3413 .07906 L
.34145 .07917 L
.34152 .0792 L
.34161 .07922 L
.3417 .07922 L
.34178 .07921 L
.34193 .07914 L
.34209 .079 L
.34224 .07879 L
.34239 .07855 L
.34273 .07778 L
.34306 .07675 L
.34341 .07536 L
.34404 .07204 L
.34462 .06819 L
.34582 .05767 L
.34693 .04538 L
.34756 .03756 L
.34823 .02858 L
.34855 .02405 L
.34886 .01967 L
.349 .01775 L
.34914 .01568 L
.3493 .01599 L
Mistroke
.34944 .01811 L
.35171 .0512 L
.353 .06855 L
.3542 .08213 L
.35544 .09296 L
.35609 .09698 L
.35642 .09853 L
.35661 .09926 L
.35678 .09985 L
.35694 .10028 L
.3571 .10066 L
.35725 .10093 L
.35739 .10111 L
.35754 .10124 L
.35763 .10127 L
.35771 .10129 L
.35779 .10128 L
.35787 .10125 L
.35796 .10119 L
.35804 .1011 L
.35819 .10091 L
.35834 .10063 L
.35861 .09993 L
.35893 .09877 L
.35922 .09741 L
.35981 .09376 L
.36043 .08862 L
.36154 .07624 L
.36274 .05874 L
.36405 .03533 L
.36435 .02944 L
.36468 .02286 L
.36483 .01979 L
.36492 .01809 L
.36499 .0165 L
.36513 .01574 L
.36528 .0189 L
.3664 .04292 L
.36892 .09602 L
.37011 .11763 L
.37076 .12781 L
.37136 .13601 L
.37192 .1424 L
.37242 .14706 L
.37269 .14907 L
.37299 .15087 L
.37315 .15168 L
.3733 .15231 L
.37344 .1528 L
.37359 .15322 L
Mistroke
.37374 .15352 L
.37388 .15369 L
.37402 .15375 L
.37415 .15371 L
.37431 .15355 L
.37445 .15329 L
.37452 .1531 L
.37461 .15286 L
.37476 .15232 L
.37503 .15098 L
.37533 .1491 L
.37585 .14446 L
.37647 .13694 L
.37704 .12787 L
.37834 .09992 L
.3796 .06331 L
.38022 .04208 L
.3805 .03212 L
.38064 .02668 L
.3808 .0207 L
.38094 .01524 L
.38107 .01925 L
.38132 .02945 L
.38187 .05278 L
.38304 .10587 L
.38782 .34906 L
.39023 .46122 L
.39242 .54046 L
.39301 .55679 L
.39364 .57188 L
.39419 .58263 L
.39479 .59192 L
.39512 .59587 L
.39543 .59881 L
.39576 .60112 L
.39594 .60206 L
.39602 .60239 L
.39611 .60269 L
.39626 .60308 L
.39641 .60328 L
.39656 .60332 L
.39665 .60326 L
.39673 .60315 L
.39688 .60282 L
.39701 .60237 L
.39716 .60171 L
.39732 .60083 L
.39763 .59856 L
.39792 .59574 L
.39847 .58876 L
Mistroke
.39906 .5788 L
.3997 .56524 L
.40085 .53401 L
.40191 .4982 L
.40666 .28443 L
.40904 .16757 L
.41122 .07056 L
.4118 .04774 L
.4121 .03623 L
.41242 .02441 L
.4125 .02167 L
.41258 .01874 L
.41273 .0159 L
.41288 .02089 L
.41301 .02539 L
.41356 .04282 L
.41487 .07799 L
.4155 .09189 L
.41608 .10265 L
.41661 .11083 L
.41718 .11803 L
.41749 .12125 L
.41778 .12377 L
.41806 .12576 L
.41835 .12747 L
.41851 .12819 L
.41865 .12874 L
.41879 .12921 L
.41893 .12955 L
.41908 .12982 L
.41915 .12993 L
.41924 .13001 L
.41932 .13005 L
.41941 .13007 L
.41956 .13001 L
.41972 .12984 L
.4198 .12972 L
.41988 .12955 L
.42018 .12873 L
.42034 .1281 L
.42052 .1273 L
.42085 .12554 L
.42148 .12093 L
.42207 .11542 L
.4234 .09921 L
.42583 .06101 L
.4271 .0391 L
.42773 .02848 L
.428 .02391 L
.42831 .01898 L
Mistroke
.42844 .01685 L
.42858 .0148 L
.42871 .01691 L
.42883 .0188 L
.42939 .02725 L
.43055 .04337 L
.43167 .05627 L
.43286 .06674 L
.43348 .07079 L
.43381 .07254 L
.43416 .0741 L
.43449 .07525 L
.43478 .07606 L
.43493 .07637 L
.43508 .07665 L
.43523 .07685 L
.43536 .07699 L
.43552 .0771 L
.4356 .07713 L
.43568 .07714 L
.43583 .07712 L
.43598 .07705 L
.43606 .07699 L
.43614 .07691 L
.4363 .07672 L
.43646 .07646 L
.43664 .0761 L
.43694 .07533 L
.43726 .07429 L
.43784 .07187 L
.4389 .06572 L
.44008 .05681 L
.44131 .04577 L
.44261 .03302 L
.44372 .02189 L
.44402 .01887 L
.44419 .01723 L
.44434 .01568 L
.44449 .01514 L
.44465 .01667 L
.44493 .01932 L
.44715 .03795 L
.44841 .0459 L
.44903 .04893 L
.44959 .05117 L
.44987 .05211 L
.45018 .05298 L
.45048 .05366 L
.45074 .05416 L
.45106 .05459 L
Mistroke
.45123 .05476 L
.45131 .05482 L
.45139 .05488 L
.45154 .05495 L
.45168 .05498 L
.45182 .05498 L
.45191 .05497 L
.45199 .05494 L
.45214 .05487 L
.45223 .05481 L
.45231 .05474 L
.45263 .05439 L
.45291 .05395 L
.45321 .05336 L
.45383 .05172 L
.45452 .04932 L
.45574 .04374 L
.45686 .03744 L
.45816 .02914 L
.45938 .021 L
.45965 .01916 L
.45994 .01718 L
.46008 .01627 L
.46022 .01532 L
.46035 .01488 L
.46048 .01577 L
.4611 .01974 L
.46166 .02319 L
.46297 .03043 L
.46416 .03581 L
.46473 .03793 L
.46536 .03983 L
.46596 .04123 L
.46651 .04218 L
.46666 .04239 L
.46684 .04258 L
.46699 .04272 L
.46715 .04284 L
.46729 .04293 L
.46745 .043 L
.46759 .04304 L
.46773 .04305 L
.46781 .04305 L
.4679 .04304 L
.46798 .04302 L
.46806 .043 L
.4682 .04294 L
.46835 .04285 L
.46852 .04273 L
.46867 .04258 L
Mistroke
.46903 .04217 L
.46962 .04117 L
.47028 .03968 L
.47147 .03605 L
.4737 .02675 L
.47492 .02089 L
.47552 .01795 L
.47579 .01667 L
.47593 .01599 L
.47607 .01526 L
.47616 .01485 L
.47623 .01491 L
.47638 .01563 L
.47671 .01719 L
.4774 .02038 L
.4786 .0255 L
.47972 .02956 L
.48091 .03295 L
.48152 .03429 L
.48185 .03488 L
.48221 .03541 L
.48253 .03581 L
.48283 .03609 L
.48311 .03629 L
.48325 .03637 L
.48341 .03643 L
.48357 .03648 L
.48371 .0365 L
.48379 .0365 L
.48388 .0365 L
.48396 .03649 L
.48405 .03648 L
.4842 .03644 L
.48434 .03638 L
.4845 .0363 L
.48465 .0362 L
.48493 .03598 L
.48519 .03571 L
.48577 .03491 L
.48642 .03375 L
.487 .03244 L
.4883 .02878 L
.48953 .02458 L
.49082 .01964 L
.49136 .01753 L
.49165 .01635 L
.49193 .01524 L
.49208 .01478 L
.49217 .01514 L
.49226 .01546 L
Mistroke
.49255 .01665 L
.49314 .01893 L
.4943 .0232 L
.49554 .02726 L
.49664 .0302 L
.49779 .03251 L
.49836 .0333 L
.49868 .03365 L
.49897 .03391 L
.49925 .03409 L
.49937 .03416 L
.49949 .03421 L
.49963 .03426 L
.49978 .03429 L
.49991 .0343 L
.50005 .03431 L
.5002 .03429 L
.50035 .03426 L
.50042 .03424 L
.50051 .03421 L
.50066 .03414 L
.50096 .03396 L
.50123 .03374 L
.50187 .03301 L
.50254 .03194 L
.50366 .02946 L
.50488 .02596 L
.50602 .02207 L
.50708 .01806 L
.50764 .01587 L
.5078 .01524 L
.50795 .01477 L
.50809 .01531 L
.50824 .0159 L
.5095 .0209 L
.51071 .02544 L
.51204 .02984 L
.51264 .03152 L
.51328 .03309 L
.51383 .03423 L
.51444 .03523 L
.51479 .03568 L
.51512 .03602 L
.51543 .03625 L
.5156 .03635 L
.51576 .03642 L
.51592 .03647 L
.51606 .03649 L
.51622 .0365 L
.5163 .0365 L
Mistroke
.51639 .03648 L
.51653 .03645 L
.51669 .0364 L
.51684 .03632 L
.51697 .03624 L
.51725 .03603 L
.51755 .03571 L
.51817 .03484 L
.51874 .03376 L
.51928 .0325 L
.52048 .02888 L
.52178 .02394 L
.52239 .02133 L
.52303 .01839 L
.52335 .01691 L
.5235 .01618 L
.52364 .01549 L
.52377 .01487 L
.52391 .01519 L
.52405 .01586 L
.5242 .01659 L
.52542 .02254 L
.52674 .0288 L
.52795 .03388 L
.52909 .0379 L
.52972 .03968 L
.53041 .04123 L
.53071 .04177 L
.53103 .04225 L
.53134 .04259 L
.53161 .04283 L
.53176 .04292 L
.53189 .04298 L
.53204 .04303 L
.53213 .04304 L
.5322 .04305 L
.53236 .04304 L
.53244 .04303 L
.53252 .04301 L
.53267 .04295 L
.53283 .04286 L
.53296 .04277 L
.5331 .04264 L
.53336 .04236 L
.53366 .04193 L
.53394 .04144 L
.53456 .04005 L
.53523 .03805 L
.53645 .03322 L
.53767 .02704 L
Mistroke
.53882 .02022 L
.53913 .01827 L
.53946 .01615 L
.53954 .01561 L
.53963 .01503 L
.53973 .015 L
.53982 .0156 L
.54015 .0178 L
.54135 .02591 L
.54374 .04094 L
.54509 .04772 L
.54573 .05028 L
.54634 .05223 L
.54687 .05353 L
.54717 .05409 L
.54745 .05449 L
.54758 .05464 L
.54773 .05478 L
.54781 .05484 L
.54789 .05489 L
.54804 .05495 L
.5482 .05498 L
.54828 .05498 L
.54836 .05497 L
.54851 .05493 L
.54867 .05484 L
.54882 .05472 L
.54896 .05457 L
.54928 .05412 L
.54957 .05356 L
.54985 .0529 L
.55047 .05097 L
.55114 .04815 L
.55372 .0313 L
.55431 .02628 L
.55493 .02063 L
.55519 .01821 L
.55533 .01686 L
.55547 .01557 L
.55562 .01536 L
.55577 .01677 L
.55605 .01955 L
.55722 .03129 L
.55848 .04381 L
.56077 .06348 L
.56194 .07076 L
.56253 .07349 L
.56287 .07473 L
.56318 .07566 L
.56345 .07628 L
Mistroke
.56358 .07654 L
.56373 .07676 L
.56388 .07693 L
.56401 .07705 L
.5641 .0771 L
.56418 .07713 L
.56432 .07714 L
.56446 .07711 L
.56459 .07703 L
.56471 .07692 L
.56484 .07676 L
.56498 .07654 L
.56513 .07625 L
.5654 .07559 L
.56571 .07459 L
.56604 .07327 L
.56662 .07018 L
.56726 .06586 L
.56796 .05991 L
.56922 .04619 L
.57038 .03064 L
.57097 .02188 L
.57112 .0196 L
.57126 .01742 L
.57138 .01545 L
.57152 .01612 L
.57166 .01843 L
.57179 .02058 L
.57209 .02544 L
.57271 .03596 L
.57523 .0785 L
.57631 .09519 L
.57749 .11051 L
.57816 .11765 L
.57877 .12292 L
.57906 .12498 L
.57939 .12685 L
.57969 .12824 L
.57997 .12919 L
.58013 .12957 L
.58021 .12973 L
.58029 .12986 L
.58043 .13001 L
.58059 .13007 L
.58067 .13006 L
.58075 .13001 L
.5809 .12985 L
.58099 .12971 L
.58107 .12955 L
.58125 .12908 L
Mistroke
.58152 .12805 L
.58183 .12647 L
.58215 .12431 L
.58245 .12181 L
.58301 .11583 L
.58353 .10886 L
.58469 .08786 L
.58588 .05905 L
.58644 .04267 L
.58698 .02572 L
.58712 .0208 L
.58728 .01548 L
.58736 .01674 L
.58745 .01989 L
.58761 .02551 L
.58818 .04692 L
.58947 .09984 L
.59434 .33356 L
.59658 .43768 L
.59902 .52994 L
.59966 .54891 L
.60035 .56624 L
.60094 .5787 L
.60158 .5894 L
.60192 .59391 L
.60223 .59729 L
.60253 .59982 L
.60268 .60085 L
.60285 .60176 L
.603 .60241 L
.60313 .60285 L
.60327 .60314 L
.6034 .6033 L
.60355 .60331 L
.60369 .60317 L
.60384 .60285 L
.60392 .60262 L
.604 .60231 L
.60428 .60087 L
.60445 .59978 L
.60459 .59859 L
.60522 .59176 L
.60576 .58349 L
.60634 .57231 L
.60766 .53803 L
.60886 .4974 L
.61368 .27194 L
.6159 .15792 L
.61716 .09674 L
.61777 .06858 L
Mistroke
.61833 .0441 L
.61862 .03215 L
.61877 .02599 L
.61893 .01954 L
.61906 .01537 L
.61922 .02135 L
.61949 .03163 L
.62073 .07393 L
.62204 .10918 L
.62263 .12171 L
.62327 .13304 L
.62389 .14151 L
.62446 .14738 L
.62477 .14979 L
.62506 .15149 L
.62522 .15222 L
.62539 .15285 L
.62547 .15308 L
.62555 .15329 L
.6257 .15357 L
.62584 .15371 L
.62597 .15375 L
.62611 .15369 L
.62625 .15353 L
.62638 .15329 L
.6265 .15299 L
.62677 .15205 L
.62706 .15059 L
.62733 .1489 L
.62793 .14388 L
.62852 .13747 L
.62915 .12924 L
.63026 .11129 L
.63277 .06085 L
.63391 .03606 L
.63424 .02898 L
.63456 .02234 L
.63469 .01947 L
.63484 .01645 L
.63499 .01623 L
.63514 .01925 L
.63735 .06017 L
.63848 .07655 L
.63908 .08361 L
.6397 .08982 L
.64025 .09419 L
.64054 .09608 L
.64085 .09778 L
.64114 .09905 L
.6414 .09995 L
Mistroke
.64153 .10031 L
.64166 .10063 L
.64179 .10087 L
.64191 .10105 L
.64206 .1012 L
.64219 .10127 L
.64234 .10128 L
.6425 .10121 L
.64264 .10108 L
.64279 .10087 L
.64293 .1006 L
.64305 .1003 L
.64336 .09936 L
.6437 .09799 L
.64431 .09465 L
.64495 .08997 L
.64563 .08387 L
.64685 .0704 L
.64808 .05418 L
.64925 .03742 L
.64976 .02992 L
.6503 .02196 L
.65058 .01783 L
.65066 .0167 L
.65074 .01549 L
.65089 .01609 L
.65104 .0182 L
.65117 .02019 L
.65144 .02389 L
.6538 .05368 L
.655 .0652 L
.65569 .07031 L
.65632 .07405 L
.65693 .07671 L
.65728 .07779 L
.65744 .0782 L
.65759 .07852 L
.65774 .07877 L
.65787 .07895 L
.65802 .0791 L
.65818 .07919 L
.65833 .07923 L
.65842 .07922 L
.65849 .07919 L
.65864 .07911 L
.65879 .07896 L
.65893 .07878 L
.65906 .07858 L
.65934 .07797 L
.6596 .07726 L
Mistroke
.65986 .07637 L
.66042 .07393 L
.66104 .07048 L
.66228 .06132 L
.6634 .05087 L
.66472 .03691 L
.66529 .03041 L
.66593 .02314 L
.66621 .01993 L
.66636 .01816 L
.66651 .01648 L
.66665 .01493 L
.66679 .01615 L
.66705 .01907 L
.66824 .032 L
.66956 .04472 L
.67075 .0542 L
.67134 .058 L
.67198 .0614 L
.67258 .06389 L
.67313 .06554 L
.67343 .06618 L
.67358 .06642 L
.67372 .06661 L
.67379 .0667 L
.67388 .06678 L
.67403 .06689 L
.67411 .06693 L
.6742 .06696 L
.67428 .06697 L
.67436 .06697 L
.67444 .06695 L
.67453 .06692 L
.67468 .06683 L
.67477 .06676 L
.67485 .06668 L
.67503 .06645 L
.67533 .06591 L
.67566 .06514 L
.6763 .06302 L
.6769 .06041 L
.67824 .0524 L
.68067 .03237 L
.68176 .0221 L
.68208 .0191 L
.68223 .01762 L
.68238 .01626 L
.68251 .01502 L
.68264 .01568 L
.68278 .01699 L
Mistroke
.68294 .01843 L
.68422 .03011 L
.68543 .03987 L
.68656 .0476 L
.68776 .05379 L
.68838 .05613 L
.68871 .0571 L
.68907 .05794 L
.68923 .05826 L
.68939 .05852 L
.68955 .05872 L
.68969 .05888 L
.68983 .05899 L
.68997 .05908 L
.69011 .05913 L
.69027 .05915 L
.69043 .05912 L
.69057 .05905 L
.69073 .05894 L
.6909 .05878 L
.69121 .05834 L
.69149 .05781 L
.69207 .05631 L
.69261 .05443 L
.69382 .04869 L
.69513 .04048 L
.69638 .03125 L
.69754 .02191 L
.69812 .01709 L
.6982 .01643 L
.69829 .01571 L
.69845 .015 L
.6986 .01627 L
.69875 .01744 L
.70008 .02794 L
.70233 .04283 L
.70295 .04597 L
.70361 .0488 L
.70424 .0509 L
.70454 .05171 L
.70481 .05233 L
.70509 .05284 L
.70539 .05325 L
.70555 .05343 L
.7057 .05355 L
.70585 .05364 L
.706 .05369 L
.70613 .05371 L
.70627 .0537 L
.7064 .05367 L
Mistroke
.70652 .05361 L
.70666 .05352 L
.70682 .05338 L
.7071 .05304 L
.70743 .0525 L
.70773 .05187 L
.70839 .05 L
.70901 .04774 L
.7096 .04518 L
.71202 .03091 L
.7131 .02334 L
.71369 .01904 L
.71398 .01691 L
.71411 .01597 L
.71425 .01494 L
.7144 .0155 L
.71455 .01661 L
.71487 .01893 L
.71543 .02291 L
.71653 .03029 L
.71783 .03793 L
.71902 .04349 L
.7196 .04558 L
.72022 .0474 L
.72051 .04806 L
.72081 .04865 L
.7211 .04908 L
.72136 .04938 L
.72152 .04951 L
.72161 .04957 L
.72169 .04962 L
.72183 .04968 L
.72198 .04971 L
.72207 .04972 L
.72215 .04971 L
.72231 .04968 L
.7224 .04964 L
.72248 .0496 L
.72266 .04948 L
.7228 .04934 L
.72294 .0492 L
.72325 .04876 L
.72355 .04822 L
.72388 .0475 L
.72503 .04392 L
.72569 .04123 L
.72629 .03834 L
.7276 .03112 L
.72884 .02339 L
.72941 .01963 L
Mistroke
.72973 .01755 L
.73002 .01561 L
.73017 .0148 L
.73026 .01537 L
.73034 .01589 L
.73069 .01818 L
.7313 .02215 L
.73355 .03504 L
.73473 .0403 L
.7353 .04231 L
.73584 .04387 L
.73614 .04461 L
.73647 .04528 L
.73675 .04575 L
.73705 .04615 L
.73721 .04631 L
.73738 .04645 L
.73747 .04651 L
.73755 .04656 L
.73764 .0466 L
.73772 .04663 L
.73787 .04666 L
.73795 .04667 L
.73804 .04666 L
.73818 .04664 L
.73834 .04658 L
.73849 .04649 L
.73862 .04639 L
.73893 .04608 L
.73923 .04566 L
.73956 .04509 L
.74014 .04375 L
.74067 .04221 L
.74197 .03725 L
.74319 .03129 L
.74437 .02472 L
.74501 .02091 L
.74532 .01902 L
.74561 .01728 L
.74573 .01651 L
.74587 .01568 L
.746 .0149 L
.74612 .01523 L
.74625 .016 L
.74639 .01684 L
.74667 .01854 L
.74783 .02532 L
.74897 .03131 L
.75016 .03665 L
.75079 .03895 L
Mistroke
.75147 .04103 L
.7521 .04249 L
.75238 .04301 L
.75268 .04347 L
.75283 .04366 L
.75299 .04384 L
.75314 .04398 L
.75328 .04408 L
.75345 .04417 L
.75354 .04421 L
.75362 .04424 L
.75378 .04426 L
.75386 .04427 L
.75394 .04426 L
.7541 .04423 L
.75425 .04418 L
.75438 .04411 L
.75452 .04401 L
.75484 .0437 L
.75514 .04332 L
.75566 .04241 L
.75623 .04108 L
.75738 .03742 L
.75993 .02567 L
.76052 .0225 L
.76114 .01903 L
.76139 .01759 L
.76167 .01604 L
.76183 .01514 L
.76197 .01507 L
.76211 .01585 L
.76225 .01667 L
.76341 .02302 L
.76466 .02936 L
.76586 .03451 L
.76695 .03819 L
.76754 .03974 L
.7681 .04089 L
.76839 .04135 L
.76869 .04174 L
.76885 .04191 L
.76902 .04206 L
.76918 .04217 L
.76933 .04225 L
.76947 .0423 L
.76961 .04233 L
.76976 .04234 L
.76989 .04233 L
.77002 .0423 L
.77013 .04225 L
Mistroke
.77027 .04219 L
.7704 .04211 L
.77068 .04186 L
.77095 .04156 L
.77154 .04061 L
.77211 .03937 L
.77272 .03771 L
.77382 .03391 L
.77631 .02241 L
.77691 .0193 L
.77724 .01757 L
.77754 .01595 L
.7777 .0151 L
.77779 .01477 L
.77787 .0152 L
.77824 .01713 L
.77888 .02047 L
.78014 .02667 L
.78131 .03172 L
.78241 .03563 L
.78298 .03725 L
.78359 .03868 L
.78394 .03933 L
.78427 .03983 L
.78458 .0402 L
.78473 .04036 L
.7849 .0405 L
.78506 .0406 L
.7852 .04067 L
.78534 .04072 L
.78547 .04075 L
.78562 .04077 L
.78577 .04076 L
.78592 .04072 L
.786 .04069 L
.78609 .04066 L
.78624 .04058 L
.78637 .04048 L
.78668 .0402 L
.78699 .03983 L
.78731 .03934 L
.78789 .0382 L
.78842 .0369 L
.78972 .03276 L
.79094 .0278 L
.79211 .02237 L
.79275 .01922 L
.79306 .01766 L
.79335 .01622 L
.79347 .01559 L
Mistroke
.79361 .01491 L
.79374 .01514 L
.79386 .01574 L
.79441 .01847 L
.79557 .02406 L
.79685 .02956 L
.79805 .03384 L
.79913 .03675 L
.79974 .03795 L
.80029 .03875 L
.80059 .03906 L
.80086 .03927 L
.80101 .03935 L
.80109 .03938 L
.80117 .03941 L
.80133 .03945 L
.80147 .03947 L
.8016 .03947 L
.80174 .03944 L
.80187 .03941 L
.80199 .03936 L
.80212 .03929 L
.80227 .03919 L
.80257 .03893 L
.80289 .03855 L
.80319 .03812 L
.80386 .03686 L
.80506 .03365 L
.80757 .02388 L
.80867 .01877 L
.80897 .01733 L
.80914 .01654 L
.8093 .01578 L
.80944 .01508 L
.80953 .01472 L
.8096 .01508 L
.80988 .01642 L
.81214 .02659 L
.81329 .03093 L
.81453 .03466 L
.81519 .03617 L
.81548 .03672 L
.8158 .03723 L
.81609 .0376 L
.81639 .03793 L
.81656 .03807 L
.81671 .03818 L
.81685 .03826 L
.81701 .03832 L
.81714 .03836 L
Mistroke
.81729 .03839 L
.81743 .03839 L
.81756 .03838 L
.81771 .03835 L
.81785 .0383 L
.81801 .03822 L
.81816 .03812 L
.81843 .0379 L
.81868 .03763 L
.81925 .03681 L
.81986 .03563 L
.82053 .03401 L
.82173 .03026 L
.82397 .02119 L
.82452 .0187 L
.82483 .01731 L
.82512 .01599 L
.82528 .01524 L
.82537 .01482 L
.82546 .01497 L
.82561 .01567 L
.82577 .0164 L
.82637 .01915 L
.8276 .02444 L
.82891 .02947 L
.83014 .03322 L
.83068 .03453 L
.83126 .0357 L
.83153 .03615 L
.83182 .03655 L
.83207 .03684 L
.83234 .0371 L
.83249 .03722 L
.83264 .03731 L
.83278 .03739 L
.83293 .03744 L
.83306 .03747 L
.83318 .03749 L
.83332 .03749 L
.83347 .03748 L
.83355 .03746 L
.83363 .03744 L
.83377 .03738 L
.83393 .0373 L
.8341 .03719 L
.83441 .03693 L
.83469 .03661 L
.83534 .03563 L
.83602 .03423 L
.83717 .03108 L
Mistroke
.83844 .02666 L
.83965 .02177 L
.84025 .0192 L
.8408 .01678 L
.84111 .01542 L
.84126 .01474 L
.84135 .01505 L
.84143 .01542 L
.84212 .01844 L
.84332 .02352 L
.84451 .02802 L
.84576 .03193 L
.84683 .03444 L
.84743 .03547 L
.84771 .03584 L
.84799 .03616 L
.84815 .03631 L
.84831 .03644 L
.84846 .03654 L
.8486 .03661 L
.84877 .03668 L
.84886 .03671 L
.84895 .03673 L
.8491 .03674 L
.84919 .03675 L
.84927 .03674 L
.84941 .03672 L
.84954 .03668 L
.84969 .03662 L
.84985 .03654 L
.85017 .03631 L
.85046 .03601 L
.85099 .03532 L
.85156 .03431 L
.85271 .03155 L
.85527 .02261 L
.85585 .02019 L
.85648 .01756 L
.85673 .01646 L
.85687 .01585 L
.85701 .01528 L
.85717 .0148 L
.85731 .01542 L
.85759 .01664 L
.85875 .02149 L
.86001 .02632 L
.86121 .03025 L
.8623 .03304 L
.86289 .03422 L
.86345 .03508 L
Mistroke
.86376 .03545 L
.86405 .03571 L
.86436 .03593 L
.86452 .03601 L
.8646 .03604 L
.86469 .03607 L
.86484 .03611 L
.86498 .03612 L
.86511 .03612 L
.86524 .03611 L
.86538 .03607 L
.86553 .03602 L
.86569 .03595 L
.86583 .03586 L
.8661 .03565 L
.86635 .03541 L
.86691 .03468 L
.86748 .03368 L
.86809 .03235 L
.86919 .02932 L
.87169 .02022 L
.87229 .01775 L
.87261 .01638 L
.87277 .01571 L
.87292 .0151 L
.873 .01475 L
.87308 .01497 L
.87316 .01532 L
.87325 .01569 L
.87362 .01721 L
.87426 .01985 L
.87554 .02478 L
.87669 .02869 L
.87728 .03041 L
.87792 .03202 L
.87847 .03319 L
.87907 .03423 L
.87938 .03465 L
.87971 .03502 L
.87989 .03518 L
.88006 .03531 L
.88023 .03542 L
.88039 .0355 L
.88053 .03555 L
.88069 .03559 L
.88084 .03561 L
.88093 .03561 L
.88101 .03561 L
.88116 .03559 L
.88129 .03555 L
Mistroke
.88145 .03549 L
.8816 .03542 L
.88191 .03521 L
.88221 .03494 L
.88275 .03425 L
.88335 .03325 L
.88399 .03188 L
.8862 .02522 L
.88745 .02054 L
.88805 .01811 L
.88861 .01586 L
.88875 .01527 L
.88891 .01477 L
.88905 .01537 L
.88919 .01593 L
.88982 .01847 L
.89115 .02361 L
.89223 .02735 L
.89339 .03071 L
.89406 .03226 L
.89468 .03341 L
.89526 .03426 L
.89556 .03458 L
.89588 .03486 L
.89603 .03496 L
.89618 .03505 L
.89627 .03508 L
.89636 .03512 L
.89652 .03516 L
.89666 .03519 L
.89675 .03519 L
.89683 .0352 L
.89697 .03518 L
.89712 .03515 L
.89725 .03511 L
.8974 .03505 L
.89765 .0349 L
.89796 .03465 L
.89824 .03436 L
.89887 .0335 L
.89954 .03225 L
.90077 .0292 L
.90313 .02117 L
.90377 .01865 L
.90413 .01724 L
.90447 .01589 L
.90462 .01528 L
.9047 .01494 L
.90478 .01477 L
.90486 .01511 L
Mistroke
.90496 .01548 L
.90512 .01614 L
.90572 .01851 L
.90693 .02313 L
.9082 .02745 L
.90938 .03073 L
.90996 .03202 L
.91048 .03299 L
.91104 .03382 L
.91156 .03438 L
.91185 .0346 L
.91211 .03474 L
.91225 .0348 L
.9124 .03484 L
.91256 .03486 L
.91271 .03487 L
.91286 .03485 L
.91295 .03484 L
.91303 .03482 L
.91317 .03477 L
.91333 .0347 L
.91362 .03451 L
.91389 .03429 L
.91454 .03351 L
.91515 .0325 L
.91633 .02982 L
.91758 .02612 L
.91875 .02202 L
.91981 .01796 L
.92009 .01684 L
.92024 .01626 L
.9204 .01563 L
.92054 .01508 L
.92069 .01492 L
.92083 .01547 L
.92096 .01598 L
.92219 .02075 L
.9244 .02824 L
.925 .02988 L
.92565 .03142 L
.92623 .03254 L
.92684 .03348 L
.92715 .03386 L
.92745 .03414 L
.92771 .03434 L
.92785 .03443 L
.928 .0345 L
.92814 .03455 L
.92827 .03459 L
.92841 .03461 L
Mistroke
.92856 .03462 L
.9287 .03461 L
.92883 .03459 L
.92895 .03456 L
.92908 .03451 L
.92922 .03445 L
.92936 .03437 L
.92966 .03414 L
.92993 .03389 L
.93021 .03356 L
.93081 .03268 L
.93146 .03142 L
.93277 .02809 L
.93399 .02418 L
.93526 .01954 L
.93589 .01714 L
.93616 .01607 L
.9363 .0155 L
.93646 .01489 L
.9366 .01506 L
.93673 .01557 L
.93698 .01656 L
.93754 .0187 L
.9387 .02303 L
.93981 .02674 L
.941 .03004 L
.94168 .03158 L
.94229 .0327 L
.94259 .03315 L
.94291 .03356 L
.94322 .03388 L
.9435 .03411 L
.94378 .03428 L
.94394 .03435 L
.94409 .0344 L
.94423 .03443 L
.94436 .03444 L
.9445 .03444 L
.94465 .03443 L
.94479 .03439 L
.94488 .03437 L
.94495 .03434 L
.94524 .03419 L
.9454 .03409 L
.94557 .03395 L
.94591 .03361 L
.94654 .03275 L
.94722 .03151 L
.94845 .02854 L
.95085 .02056 L
Mistroke
.95151 .01807 L
.95187 .01668 L
.95205 .01599 L
.95221 .01537 L
.95236 .01479 L
.9525 .01515 L
.95264 .01572 L
.9528 .01635 L
.95346 .01886 L
.95575 .02687 L
.95706 .03041 L
.9577 .03177 L
.95829 .03278 L
.95884 .03352 L
.95912 .0338 L
.95943 .03404 L
.95959 .03414 L
.95974 .03422 L
.95982 .03425 L
.95991 .03428 L
.96007 .03432 L
.96022 .03434 L
.96038 .03434 L
.96052 .03433 L
.96067 .03429 L
.96075 .03427 L
.96084 .03424 L
.961 .03416 L
.9613 .03397 L
.96165 .03366 L
.96198 .03329 L
.96257 .03242 L
.9632 .03122 L
.96444 .02814 L
.96578 .02392 L
.96694 .01973 L
.96756 .01739 L
.9679 .01609 L
.96806 .01544 L
.96822 .01484 L
.96837 .01514 L
.96844 .01544 L
.96853 .01577 L
.96887 .01708 L
.96946 .01934 L
.97062 .02356 L
.97195 .0278 L
.97316 .03089 L
.97387 .03228 L
.97462 .03337 L
Mistroke
.97501 .03377 L
.97537 .03405 L
.97558 .03416 L
.97577 .03424 L
.97587 .03427 L
.97598 .03429 L
.97609 .0343 L
.97619 .03431 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.00459847 0.64881 0.188537 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.491929 0.0484262 0.0147151 0.0298707 [
[.00767 -0.0125 -9 -9 ]
[.00767 -0.0125 9 0 ]
[.2498 -0.0125 -6 -9 ]
[.2498 -0.0125 6 0 ]
[.49193 -0.0125 -3 -9 ]
[.49193 -0.0125 3 0 ]
[.73406 -0.0125 -3 -9 ]
[.73406 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .16407 -6 -4.5 ]
[-0.0125 .16407 0 4.5 ]
[-0.0125 .31342 -12 -4.5 ]
[-0.0125 .31342 0 4.5 ]
[-0.0125 .46278 -12 -4.5 ]
[-0.0125 .46278 0 4.5 ]
[-0.0125 .61213 -12 -4.5 ]
[-0.0125 .61213 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.00767 0 m
.00767 .00625 L
s
[(-10)] .00767 -0.0125 0 1 Mshowa
.2498 0 m
.2498 .00625 L
s
[(-5)] .2498 -0.0125 0 1 Mshowa
.49193 0 m
.49193 .00625 L
s
[(0)] .49193 -0.0125 0 1 Mshowa
.73406 0 m
.73406 .00625 L
s
[(5)] .73406 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05609 0 m
.05609 .00375 L
s
.10452 0 m
.10452 .00375 L
s
.15295 0 m
.15295 .00375 L
s
.20137 0 m
.20137 .00375 L
s
.29822 0 m
.29822 .00375 L
s
.34665 0 m
.34665 .00375 L
s
.39508 0 m
.39508 .00375 L
s
.4435 0 m
.4435 .00375 L
s
.54036 0 m
.54036 .00375 L
s
.58878 0 m
.58878 .00375 L
s
.63721 0 m
.63721 .00375 L
s
.68563 0 m
.68563 .00375 L
s
.78249 0 m
.78249 .00375 L
s
.83091 0 m
.83091 .00375 L
s
.87934 0 m
.87934 .00375 L
s
.92776 0 m
.92776 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .16407 m
.00625 .16407 L
s
[(5)] -0.0125 .16407 1 0 Mshowa
0 .31342 m
.00625 .31342 L
s
[(10)] -0.0125 .31342 1 0 Mshowa
0 .46278 m
.00625 .46278 L
s
[(15)] -0.0125 .46278 1 0 Mshowa
0 .61213 m
.00625 .61213 L
s
[(20)] -0.0125 .61213 1 0 Mshowa
.125 Mabswid
0 .04459 m
.00375 .04459 L
s
0 .07446 m
.00375 .07446 L
s
0 .10433 m
.00375 .10433 L
s
0 .1342 m
.00375 .1342 L
s
0 .19394 m
.00375 .19394 L
s
0 .22381 m
.00375 .22381 L
s
0 .25368 m
.00375 .25368 L
s
0 .28355 m
.00375 .28355 L
s
0 .34329 m
.00375 .34329 L
s
0 .37316 m
.00375 .37316 L
s
0 .40303 m
.00375 .40303 L
s
0 .43291 m
.00375 .43291 L
s
0 .49265 m
.00375 .49265 L
s
0 .52252 m
.00375 .52252 L
s
0 .55239 m
.00375 .55239 L
s
0 .58226 m
.00375 .58226 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.00767 .61178 m
.00767 .61803 L
s
.2498 .61178 m
.2498 .61803 L
s
.49193 .61178 m
.49193 .61803 L
s
.73406 .61178 m
.73406 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.05609 .61428 m
.05609 .61803 L
s
.10452 .61428 m
.10452 .61803 L
s
.15295 .61428 m
.15295 .61803 L
s
.20137 .61428 m
.20137 .61803 L
s
.29822 .61428 m
.29822 .61803 L
s
.34665 .61428 m
.34665 .61803 L
s
.39508 .61428 m
.39508 .61803 L
s
.4435 .61428 m
.4435 .61803 L
s
.54036 .61428 m
.54036 .61803 L
s
.58878 .61428 m
.58878 .61803 L
s
.63721 .61428 m
.63721 .61803 L
s
.68563 .61428 m
.68563 .61803 L
s
.78249 .61428 m
.78249 .61803 L
s
.83091 .61428 m
.83091 .61803 L
s
.87934 .61428 m
.87934 .61803 L
s
.92776 .61428 m
.92776 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16407 m
1 .16407 L
s
.99375 .31342 m
1 .31342 L
s
.99375 .46278 m
1 .46278 L
s
.99375 .61213 m
1 .61213 L
s
.125 Mabswid
.99625 .04459 m
1 .04459 L
s
.99625 .07446 m
1 .07446 L
s
.99625 .10433 m
1 .10433 L
s
.99625 .1342 m
1 .1342 L
s
.99625 .19394 m
1 .19394 L
s
.99625 .22381 m
1 .22381 L
s
.99625 .25368 m
1 .25368 L
s
.99625 .28355 m
1 .28355 L
s
.99625 .34329 m
1 .34329 L
s
.99625 .37316 m
1 .37316 L
s
.99625 .40303 m
1 .40303 L
s
.99625 .43291 m
1 .43291 L
s
.99625 .49265 m
1 .49265 L
s
.99625 .52252 m
1 .52252 L
s
.99625 .55239 m
1 .55239 L
s
.99625 .58226 m
1 .58226 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .01472 m
.02381 .04464 L
s
.03995 .01472 m
.03995 .04479 L
s
.05609 .01472 m
.05609 .04506 L
s
.07224 .01472 m
.07224 .04544 L
s
.08838 .01472 m
.08838 .04594 L
s
.10452 .01472 m
.10452 .04657 L
s
.12066 .01472 m
.12066 .04735 L
s
.1368 .01472 m
.1368 .0483 L
s
.15295 .01472 m
.15295 .04944 L
s
.16909 .01472 m
.16909 .05081 L
s
.18523 .01472 m
.18523 .05245 L
s
.20137 .01472 m
.20137 .05442 L
s
.21751 .01472 m
.21751 .05681 L
s
.23366 .01472 m
.23366 .05974 L
s
.2498 .01472 m
.2498 .06339 L
s
.26594 .01472 m
.26594 .06803 L
s
.28208 .01472 m
.28208 .0741 L
s
.29822 .01472 m
.29822 .08235 L
s
.31437 .01472 m
.31437 .09421 L
s
.33051 .01472 m
.33051 .11272 L
s
.34665 .01472 m
.34665 .14578 L
s
.36279 .01472 m
.36279 .22238 L
s
.37893 .01472 m
.37893 .60332 L
s
.39508 .01472 m
.39508 .56642 L
s
.41122 .01472 m
.41122 .18539 L
s
.42736 .01472 m
.42736 .10866 L
s
.4435 .01472 m
.4435 .07562 L
s
.45964 .01472 m
.45964 .05769 L
s
.47579 .01472 m
.47579 .04786 L
s
.49193 .01472 m
.49193 .04459 L
s
.50807 .01472 m
.50807 .04786 L
s
.52421 .01472 m
.52421 .05769 L
s
.54036 .01472 m
.54036 .07562 L
s
.5565 .01472 m
.5565 .10866 L
s
.57264 .01472 m
.57264 .18539 L
s
.58878 .01472 m
.58878 .56642 L
s
.60492 .01472 m
.60492 .60332 L
s
.62107 .01472 m
.62107 .22238 L
s
.63721 .01472 m
.63721 .14578 L
s
.65335 .01472 m
.65335 .11272 L
s
.66949 .01472 m
.66949 .09421 L
s
.68563 .01472 m
.68563 .08235 L
s
.70178 .01472 m
.70178 .0741 L
s
.71792 .01472 m
.71792 .06803 L
s
.73406 .01472 m
.73406 .06339 L
s
.7502 .01472 m
.7502 .05974 L
s
.76634 .01472 m
.76634 .05681 L
s
.78249 .01472 m
.78249 .05442 L
s
.79863 .01472 m
.79863 .05245 L
s
.81477 .01472 m
.81477 .05081 L
s
.83091 .01472 m
.83091 .04944 L
s
.84705 .01472 m
.84705 .0483 L
s
.8632 .01472 m
.8632 .04735 L
s
.87934 .01472 m
.87934 .04657 L
s
.89548 .01472 m
.89548 .04594 L
s
.91162 .01472 m
.91162 .04544 L
s
.92776 .01472 m
.92776 .04506 L
s
.94391 .01472 m
.94391 .04479 L
s
.96005 .01472 m
.96005 .04464 L
s
.97619 .01472 m
.97619 .04459 L
s
.015 w
.02381 .04464 Mdot
.03995 .04479 Mdot
.05609 .04506 Mdot
.07224 .04544 Mdot
.08838 .04594 Mdot
.10452 .04657 Mdot
.12066 .04735 Mdot
.1368 .0483 Mdot
.15295 .04944 Mdot
.16909 .05081 Mdot
.18523 .05245 Mdot
.20137 .05442 Mdot
.21751 .05681 Mdot
.23366 .05974 Mdot
.2498 .06339 Mdot
.26594 .06803 Mdot
.28208 .0741 Mdot
.29822 .08235 Mdot
.31437 .09421 Mdot
.33051 .11272 Mdot
.34665 .14578 Mdot
.36279 .22238 Mdot
.37893 .60332 Mdot
.39508 .56642 Mdot
.41122 .18539 Mdot
.42736 .10866 Mdot
.4435 .07562 Mdot
.45964 .05769 Mdot
.47579 .04786 Mdot
.49193 .04459 Mdot
.50807 .04786 Mdot
.52421 .05769 Mdot
.54036 .07562 Mdot
.5565 .10866 Mdot
.57264 .18539 Mdot
.58878 .56642 Mdot
.60492 .60332 Mdot
.62107 .22238 Mdot
.63721 .14578 Mdot
.65335 .11272 Mdot
.66949 .09421 Mdot
.68563 .08235 Mdot
.70178 .0741 Mdot
.71792 .06803 Mdot
.73406 .06339 Mdot
.7502 .05974 Mdot
.76634 .05681 Mdot
.78249 .05442 Mdot
.79863 .05245 Mdot
.81477 .05081 Mdot
.83091 .04944 Mdot
.84705 .0483 Mdot
.8632 .04735 Mdot
.87934 .04657 Mdot
.89548 .04594 Mdot
.91162 .04544 Mdot
.92776 .04506 Mdot
.94391 .04479 Mdot
.96005 .04464 Mdot
.97619 .04459 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.00459847 0.97619 0.188537 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.047619 0.0147151 0.019608 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .11275 -6 -4.5 ]
[-0.0125 .11275 0 4.5 ]
[-0.0125 .21079 -12 -4.5 ]
[-0.0125 .21079 0 4.5 ]
[-0.0125 .30883 -12 -4.5 ]
[-0.0125 .30883 0 4.5 ]
[-0.0125 .40687 -12 -4.5 ]
[-0.0125 .40687 0 4.5 ]
[-0.0125 .50491 -12 -4.5 ]
[-0.0125 .50491 0 4.5 ]
[-0.0125 .60295 -12 -4.5 ]
[-0.0125 .60295 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .11275 m
.00625 .11275 L
s
[(5)] -0.0125 .11275 1 0 Mshowa
0 .21079 m
.00625 .21079 L
s
[(10)] -0.0125 .21079 1 0 Mshowa
0 .30883 m
.00625 .30883 L
s
[(15)] -0.0125 .30883 1 0 Mshowa
0 .40687 m
.00625 .40687 L
s
[(20)] -0.0125 .40687 1 0 Mshowa
0 .50491 m
.00625 .50491 L
s
[(25)] -0.0125 .50491 1 0 Mshowa
0 .60295 m
.00625 .60295 L
s
[(30)] -0.0125 .60295 1 0 Mshowa
.125 Mabswid
0 .03432 m
.00375 .03432 L
s
0 .05393 m
.00375 .05393 L
s
0 .07354 m
.00375 .07354 L
s
0 .09315 m
.00375 .09315 L
s
0 .13236 m
.00375 .13236 L
s
0 .15197 m
.00375 .15197 L
s
0 .17158 m
.00375 .17158 L
s
0 .19119 m
.00375 .19119 L
s
0 .2304 m
.00375 .2304 L
s
0 .25001 m
.00375 .25001 L
s
0 .26962 m
.00375 .26962 L
s
0 .28923 m
.00375 .28923 L
s
0 .32844 m
.00375 .32844 L
s
0 .34805 m
.00375 .34805 L
s
0 .36766 m
.00375 .36766 L
s
0 .38727 m
.00375 .38727 L
s
0 .42648 m
.00375 .42648 L
s
0 .44609 m
.00375 .44609 L
s
0 .4657 m
.00375 .4657 L
s
0 .48531 m
.00375 .48531 L
s
0 .52452 m
.00375 .52452 L
s
0 .54413 m
.00375 .54413 L
s
0 .56374 m
.00375 .56374 L
s
0 .58335 m
.00375 .58335 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .11275 m
1 .11275 L
s
.99375 .21079 m
1 .21079 L
s
.99375 .30883 m
1 .30883 L
s
.99375 .40687 m
1 .40687 L
s
.99375 .50491 m
1 .50491 L
s
.99375 .60295 m
1 .60295 L
s
.125 Mabswid
.99625 .03432 m
1 .03432 L
s
.99625 .05393 m
1 .05393 L
s
.99625 .07354 m
1 .07354 L
s
.99625 .09315 m
1 .09315 L
s
.99625 .13236 m
1 .13236 L
s
.99625 .15197 m
1 .15197 L
s
.99625 .17158 m
1 .17158 L
s
.99625 .19119 m
1 .19119 L
s
.99625 .2304 m
1 .2304 L
s
.99625 .25001 m
1 .25001 L
s
.99625 .26962 m
1 .26962 L
s
.99625 .28923 m
1 .28923 L
s
.99625 .32844 m
1 .32844 L
s
.99625 .34805 m
1 .34805 L
s
.99625 .36766 m
1 .36766 L
s
.99625 .38727 m
1 .38727 L
s
.99625 .42648 m
1 .42648 L
s
.99625 .44609 m
1 .44609 L
s
.99625 .4657 m
1 .4657 L
s
.99625 .48531 m
1 .48531 L
s
.99625 .52452 m
1 .52452 L
s
.99625 .54413 m
1 .54413 L
s
.99625 .56374 m
1 .56374 L
s
.99625 .58335 m
1 .58335 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
0 0 1 r
.5 Mabswid
[ .01 ] 0 setdash
.02381 .03432 m
.02395 .03432 L
.02408 .03429 L
.02423 .03426 L
.02437 .0342 L
.02462 .03407 L
.02489 .03387 L
.02519 .03359 L
.02551 .03323 L
.02608 .03238 L
.02722 .03003 L
.02847 .02656 L
.02973 .02232 L
.03043 .01977 L
.03109 .01724 L
.03139 .0161 L
.03155 .01546 L
.03171 .01487 L
.03179 .0149 L
.03189 .01527 L
.03205 .01591 L
.03238 .01716 L
.03355 .02158 L
.03596 .02924 L
.03717 .03196 L
.03785 .03308 L
.03819 .0335 L
.0385 .03381 L
.03879 .03405 L
.03894 .03414 L
.0391 .03422 L
.03918 .03426 L
.03926 .03429 L
.03941 .03433 L
.03949 .03434 L
.03958 .03435 L
.03967 .03436 L
.03976 .03436 L
.03991 .03434 L
.04006 .0343 L
.04019 .03426 L
.04033 .0342 L
.04065 .034 L
.04095 .03375 L
.04147 .03315 L
.04204 .03227 L
.04319 .02983 L
.04573 .0219 L
.04631 .01974 L
.04694 .01737 L
Mistroke
.04724 .0162 L
.04739 .01562 L
.04752 .01509 L
.04765 .01482 L
.04778 .01533 L
.04805 .01641 L
.0492 .02079 L
.05046 .0252 L
.05165 .02882 L
.05274 .03144 L
.05332 .03255 L
.05388 .03337 L
.05417 .03371 L
.05447 .034 L
.05463 .03412 L
.0548 .03423 L
.05495 .03431 L
.05511 .03438 L
.05525 .03442 L
.0554 .03445 L
.05553 .03446 L
.05566 .03446 L
.05581 .03444 L
.05595 .0344 L
.0561 .03435 L
.05625 .03428 L
.05652 .03411 L
.05676 .03391 L
.05732 .03328 L
.05789 .03241 L
.05849 .03124 L
.05959 .02852 L
.06208 .02018 L
.06267 .01791 L
.063 .01665 L
.0633 .01545 L
.06346 .01483 L
.06355 .01495 L
.06363 .01527 L
.064 .01669 L
.06464 .01918 L
.06589 .0238 L
.06706 .02762 L
.06826 .03081 L
.06878 .03193 L
.06934 .03294 L
.06967 .03341 L
.06996 .03378 L
.07027 .03409 L
.07055 .03432 L
Mistroke
.07071 .03442 L
.07085 .03449 L
.07101 .03456 L
.07109 .03459 L
.07118 .03461 L
.07126 .03462 L
.07134 .03463 L
.07149 .03463 L
.07159 .03463 L
.07167 .03461 L
.07175 .0346 L
.07184 .03457 L
.07199 .03452 L
.07213 .03445 L
.07243 .03426 L
.07272 .03401 L
.07299 .03371 L
.07359 .03287 L
.07425 .03165 L
.07557 .02836 L
.07679 .02448 L
.07787 .02055 L
.07844 .01836 L
.07904 .01601 L
.07919 .01539 L
.07928 .01506 L
.07936 .01474 L
.07945 .01507 L
.07954 .01541 L
.07971 .01608 L
.08032 .01849 L
.08152 .02303 L
.0827 .02703 L
.08394 .03054 L
.085 .03279 L
.0856 .03372 L
.08588 .03406 L
.08617 .03436 L
.08633 .03449 L
.08648 .0346 L
.08663 .03469 L
.08677 .03476 L
.08693 .03482 L
.08702 .03484 L
.08711 .03486 L
.08726 .03488 L
.08734 .03488 L
.08742 .03488 L
.08758 .03486 L
.08772 .03482 L
Mistroke
.08786 .03477 L
.088 .0347 L
.08832 .03449 L
.08861 .03423 L
.08913 .03361 L
.0897 .03269 L
.09085 .03016 L
.09339 .02198 L
.09397 .01976 L
.09459 .01731 L
.09489 .0161 L
.09504 .01551 L
.09518 .01496 L
.0953 .01497 L
.09543 .0155 L
.09571 .0166 L
.09685 .02111 L
.0981 .02567 L
.0993 .0294 L
.10038 .03211 L
.10097 .03324 L
.10153 .03409 L
.10181 .03444 L
.10211 .03473 L
.10227 .03486 L
.10244 .03498 L
.10259 .03506 L
.10275 .03513 L
.10289 .03517 L
.10304 .0352 L
.10317 .03521 L
.1033 .03521 L
.10345 .03519 L
.10358 .03515 L
.10374 .03509 L
.10389 .03502 L
.10416 .03485 L
.1044 .03464 L
.10496 .03398 L
.10552 .03308 L
.10613 .03186 L
.10722 .02904 L
.10971 .02036 L
.1103 .01801 L
.11063 .01669 L
.11093 .01545 L
.11102 .0151 L
.11111 .01473 L
.1112 .0151 L
.1113 .01547 L
Mistroke
.11162 .01681 L
.11226 .0194 L
.11343 .02393 L
.11469 .02823 L
.11593 .0317 L
.11652 .03299 L
.11706 .03398 L
.1176 .03474 L
.11789 .03505 L
.1182 .03531 L
.11832 .03539 L
.11846 .03547 L
.11858 .03552 L
.11871 .03557 L
.11885 .0356 L
.119 .03562 L
.11914 .03563 L
.11927 .03561 L
.11943 .03558 L
.1195 .03555 L
.11959 .03552 L
.11988 .03537 L
.12005 .03525 L
.12022 .03509 L
.12054 .03476 L
.12117 .03386 L
.12174 .03279 L
.12289 .02994 L
.12399 .02649 L
.12515 .02221 L
.12578 .01968 L
.12638 .01722 L
.12663 .01619 L
.12676 .01563 L
.12689 .01511 L
.12703 .01489 L
.12718 .01552 L
.12744 .01661 L
.1286 .0214 L
.13086 .02948 L
.13148 .03126 L
.13213 .03287 L
.1327 .03403 L
.13331 .035 L
.13364 .03541 L
.13394 .0357 L
.13408 .03582 L
.13424 .03592 L
.13439 .036 L
.13453 .03606 L
Mistroke
.13462 .03609 L
.13471 .03611 L
.13479 .03613 L
.13487 .03614 L
.13495 .03614 L
.13504 .03614 L
.13514 .03613 L
.13523 .03611 L
.13531 .03609 L
.13539 .03606 L
.13554 .036 L
.1357 .03591 L
.13588 .03579 L
.13617 .03553 L
.13649 .03517 L
.13714 .03418 L
.13774 .03297 L
.13831 .0316 L
.14074 .02351 L
.14182 .01913 L
.14211 .01793 L
.14241 .01662 L
.14255 .01601 L
.1427 .01537 L
.14283 .01482 L
.14297 .01521 L
.14313 .01588 L
.14329 .01659 L
.14359 .01787 L
.14416 .02025 L
.14526 .02469 L
.14655 .02932 L
.14775 .03278 L
.14839 .03423 L
.14898 .03528 L
.14929 .03572 L
.14962 .03612 L
.1498 .0363 L
.14997 .03644 L
.15014 .03655 L
.15031 .03664 L
.15046 .0367 L
.1506 .03674 L
.15074 .03676 L
.15087 .03676 L
.15102 .03675 L
.15117 .03672 L
.15132 .03666 L
.15149 .03658 L
.15179 .03637 L
Mistroke
.15208 .0361 L
.15273 .03524 L
.15333 .03414 L
.15398 .03263 L
.15517 .02911 L
.1574 .02051 L
.15804 .01774 L
.15836 .01636 L
.1585 .01575 L
.15865 .01508 L
.15878 .01495 L
.15891 .01552 L
.15919 .01675 L
.15978 .01933 L
.16107 .02479 L
.1623 .02938 L
.16348 .03299 L
.1641 .03451 L
.16476 .03581 L
.16531 .03662 L
.16562 .03697 L
.16592 .03722 L
.16605 .03731 L
.16619 .03738 L
.16631 .03743 L
.16644 .03747 L
.16657 .0375 L
.16672 .03751 L
.16687 .0375 L
.16699 .03748 L
.16714 .03743 L
.16727 .03738 L
.16742 .0373 L
.16758 .03719 L
.1679 .03689 L
.1682 .03655 L
.16876 .03567 L
.1693 .03459 L
.1705 .03139 L
.17181 .02682 L
.17304 .02178 L
.17364 .01912 L
.17419 .01662 L
.17435 .01589 L
.1745 .0152 L
.17465 .01495 L
.17474 .01533 L
.17483 .01574 L
.17551 .01889 L
.17672 .0242 L
Mistroke
.17795 .0291 L
.17928 .03349 L
.17989 .03509 L
.18054 .03647 L
.1811 .03736 L
.18141 .03775 L
.18171 .03804 L
.18185 .03814 L
.182 .03824 L
.18215 .03831 L
.18228 .03836 L
.18243 .03839 L
.18252 .0384 L
.1826 .03841 L
.18274 .0384 L
.1829 .03837 L
.18304 .03832 L
.1832 .03824 L
.18335 .03815 L
.18349 .03804 L
.18383 .03772 L
.18415 .03731 L
.1847 .0364 L
.18521 .03531 L
.18638 .03207 L
.18865 .02322 L
.18928 .02039 L
.18993 .01731 L
.1902 .01602 L
.19035 .01531 L
.19049 .0148 L
.19057 .01518 L
.19066 .01559 L
.19081 .01632 L
.19111 .01774 L
.19245 .024 L
.1937 .02925 L
.19495 .03371 L
.19557 .03549 L
.19613 .03685 L
.19665 .03787 L
.19722 .03871 L
.19753 .03904 L
.19768 .03917 L
.19782 .03927 L
.19795 .03935 L
.1981 .03941 L
.19825 .03946 L
.19839 .03948 L
.19854 .03948 L
Mistroke
.19869 .03947 L
.19885 .03942 L
.19894 .03939 L
.19902 .03935 L
.19918 .03925 L
.19936 .03912 L
.19969 .03879 L
.19999 .0384 L
.2003 .0379 L
.20088 .03676 L
.20201 .03368 L
.20322 .02929 L
.20437 .02436 L
.20543 .0193 L
.20599 .01653 L
.20615 .01573 L
.2063 .01496 L
.20644 .01515 L
.20658 .01589 L
.20785 .02216 L
.20906 .02779 L
.21039 .03316 L
.21099 .03519 L
.21163 .03705 L
.21218 .03838 L
.21279 .03951 L
.21314 .04001 L
.21347 .04036 L
.21363 .0405 L
.21378 .0406 L
.21386 .04065 L
.21395 .04069 L
.21411 .04075 L
.21426 .04077 L
.21434 .04078 L
.21442 .04078 L
.21458 .04076 L
.21466 .04074 L
.21474 .04071 L
.21489 .04065 L
.21504 .04055 L
.21532 .04032 L
.21561 .04001 L
.21591 .03958 L
.21646 .03858 L
.21711 .03702 L
.21771 .03525 L
.22025 .02485 L
.22135 .01928 L
.22167 .01762 L
Mistroke
.22197 .01603 L
.2221 .01534 L
.22224 .01483 L
.2224 .01563 L
.22254 .01638 L
.22383 .02315 L
.22503 .02902 L
.22617 .03389 L
.2268 .03619 L
.2274 .03807 L
.22795 .03954 L
.22855 .0408 L
.22882 .04124 L
.2291 .04163 L
.22934 .0419 L
.22961 .04212 L
.22975 .04222 L
.22989 .04228 L
.23004 .04233 L
.23012 .04234 L
.2302 .04235 L
.23035 .04235 L
.23044 .04234 L
.23052 .04232 L
.23067 .04226 L
.23082 .04218 L
.23096 .04209 L
.2311 .04197 L
.23135 .04171 L
.23166 .0413 L
.23194 .04084 L
.23255 .03953 L
.23323 .03769 L
.23445 .03327 L
.23683 .02177 L
.23751 .01801 L
.23767 .01709 L
.23785 .01613 L
.23799 .0153 L
.23808 .01483 L
.23815 .01504 L
.2383 .01587 L
.23843 .01662 L
.23873 .01831 L
.23936 .0218 L
.24057 .02827 L
.24185 .03436 L
.24295 .03862 L
.24358 .04059 L
.24416 .04204 L
Mistroke
.24472 .04312 L
.245 .04353 L
.24531 .04388 L
.24547 .04402 L
.24562 .04412 L
.2457 .04417 L
.24579 .04421 L
.24588 .04424 L
.24595 .04426 L
.24609 .04428 L
.24624 .04428 L
.2464 .04424 L
.24655 .04419 L
.24669 .04411 L
.24684 .044 L
.24711 .04374 L
.24738 .0434 L
.24763 .04302 L
.24819 .04188 L
.24879 .04031 L
.25003 .03587 L
.25138 .02959 L
.25254 .02322 L
.25315 .01962 L
.25349 .0176 L
.25366 .0166 L
.25381 .01567 L
.25396 .01475 L
.25404 .01515 L
.25412 .01566 L
.25446 .01773 L
.25506 .02132 L
.25622 .0281 L
.25755 .03505 L
.25876 .04027 L
.25934 .04226 L
.25996 .04404 L
.26025 .04471 L
.26055 .04532 L
.26084 .04579 L
.2611 .04614 L
.26126 .0463 L
.26143 .04645 L
.2616 .04656 L
.2617 .04661 L
.26178 .04664 L
.26187 .04666 L
.26194 .04667 L
.26209 .04668 L
.26225 .04665 L
Mistroke
.26234 .04662 L
.26242 .04659 L
.26257 .04651 L
.2627 .04641 L
.263 .0461 L
.2633 .04569 L
.26362 .04512 L
.26422 .04373 L
.26477 .04207 L
.26604 .03706 L
.26735 .03032 L
.26858 .0229 L
.26916 .01922 L
.26947 .01716 L
.26962 .01615 L
.26976 .01523 L
.26992 .01521 L
.27 .01577 L
.27008 .0163 L
.27043 .01861 L
.27105 .02266 L
.27329 .03619 L
.27445 .04182 L
.27508 .04435 L
.27568 .04633 L
.27624 .04779 L
.27653 .0484 L
.27684 .04892 L
.27711 .04926 L
.27724 .04941 L
.27739 .04953 L
.27753 .04962 L
.27765 .04968 L
.27778 .04972 L
.2779 .04973 L
.27804 .04973 L
.27818 .04969 L
.27832 .04963 L
.27845 .04955 L
.2786 .04943 L
.27875 .04928 L
.27906 .04886 L
.27937 .04832 L
.27971 .04759 L
.2803 .04593 L
.28147 .04141 L
.28253 .036 L
.28365 .02915 L
.28484 .02101 L
.28514 .01886 L
Mistroke
.28546 .01654 L
.28556 .01585 L
.28565 .01519 L
.28573 .01483 L
.28582 .01547 L
.28615 .01788 L
.28735 .02658 L
.28968 .04151 L
.29032 .04481 L
.29101 .04786 L
.29161 .05003 L
.29193 .05099 L
.29226 .05186 L
.29259 .05254 L
.29289 .05303 L
.29303 .05323 L
.29318 .0534 L
.29333 .05353 L
.29346 .05362 L
.29362 .05369 L
.2937 .05371 L
.29378 .05372 L
.29387 .05373 L
.29396 .05372 L
.29404 .0537 L
.29412 .05367 L
.29427 .05358 L
.29436 .05352 L
.29444 .05345 L
.29473 .05312 L
.29502 .05266 L
.29529 .05212 L
.2959 .05051 L
.29643 .04866 L
.29699 .04626 L
.29936 .03208 L
.30042 .02411 L
.30098 .01966 L
.30129 .01718 L
.30144 .01596 L
.30157 .01483 L
.30172 .01583 L
.30188 .01716 L
.30223 .01999 L
.30283 .02495 L
.30403 .03437 L
.30511 .04214 L
.30627 .04919 L
.30689 .05231 L
.30745 .05467 L
Mistroke
.30801 .05658 L
.30855 .05791 L
.30885 .05846 L
.30902 .05869 L
.30917 .05887 L
.3093 .05898 L
.30945 .05908 L
.3096 .05914 L
.30975 .05916 L
.30983 .05916 L
.30991 .05914 L
.31007 .05908 L
.31016 .05902 L
.31025 .05895 L
.31041 .05879 L
.31072 .05836 L
.31105 .05771 L
.31164 .05607 L
.31219 .05401 L
.31345 .04752 L
.31468 .03907 L
.316 .0282 L
.31659 .02282 L
.31692 .01979 L
.31723 .01692 L
.31739 .01542 L
.31748 .01486 L
.31756 .01564 L
.31792 .01911 L
.31856 .02521 L
.32099 .04669 L
.3221 .05467 L
.32328 .06126 L
.32363 .06277 L
.32396 .06399 L
.32428 .06498 L
.32457 .06573 L
.32485 .06628 L
.325 .0665 L
.32515 .06669 L
.32531 .06684 L
.32545 .06693 L
.32554 .06696 L
.32562 .06698 L
.32578 .06698 L
.32591 .06693 L
.32606 .06684 L
.3262 .06672 L
.32633 .06657 L
.32663 .06609 L
Mistroke
.32694 .06538 L
.32753 .06351 L
.32818 .06067 L
.32933 .05367 L
.3304 .04513 L
.33166 .03298 L
.33229 .02639 L
.33286 .02005 L
.33299 .01859 L
.33313 .01702 L
.33326 .01552 L
.33338 .01528 L
.33352 .01682 L
.33365 .01829 L
.33394 .02161 L
.3351 .03491 L
.33635 .04836 L
.33752 .05959 L
.33866 .06854 L
.33916 .07171 L
.33971 .07459 L
.34027 .07683 L
.34057 .07776 L
.34085 .07842 L
.34101 .07871 L
.34116 .07893 L
.3413 .07908 L
.34145 .07918 L
.34152 .07922 L
.34161 .07924 L
.3417 .07924 L
.34178 .07922 L
.34193 .07915 L
.34209 .07901 L
.34224 .07881 L
.34239 .07856 L
.34273 .07779 L
.34306 .07677 L
.34341 .07537 L
.34404 .07206 L
.34462 .0682 L
.34582 .05768 L
.34693 .0454 L
.34756 .03758 L
.34823 .02859 L
.34855 .02407 L
.34886 .01969 L
.349 .01776 L
.34914 .0157 L
.3493 .01601 L
Mistroke
.34944 .01813 L
.35171 .05122 L
.353 .06857 L
.3542 .08215 L
.35544 .09297 L
.35609 .097 L
.35642 .09855 L
.35661 .09927 L
.35678 .09986 L
.35694 .10029 L
.3571 .10067 L
.35725 .10094 L
.35739 .10113 L
.35754 .10125 L
.35763 .10129 L
.35771 .1013 L
.35779 .10129 L
.35787 .10126 L
.35796 .1012 L
.35804 .10112 L
.35819 .10093 L
.35834 .10065 L
.35861 .09995 L
.35893 .09878 L
.35922 .09742 L
.35981 .09377 L
.36043 .08864 L
.36154 .07626 L
.36274 .05875 L
.36405 .03534 L
.36435 .02945 L
.36468 .02287 L
.36483 .0198 L
.36492 .01811 L
.36499 .01651 L
.36513 .01576 L
.36528 .01891 L
.3664 .04294 L
.36892 .09604 L
.37011 .11764 L
.37076 .12782 L
.37136 .13603 L
.37192 .14241 L
.37242 .14707 L
.37269 .14909 L
.37299 .15088 L
.37315 .15169 L
.3733 .15232 L
.37344 .15281 L
.37359 .15323 L
Mistroke
.37374 .15353 L
.37388 .1537 L
.37402 .15376 L
.37415 .15373 L
.37431 .15356 L
.37445 .1533 L
.37452 .15311 L
.37461 .15287 L
.37476 .15233 L
.37503 .151 L
.37533 .14911 L
.37585 .14447 L
.37647 .13695 L
.37704 .12789 L
.37834 .09994 L
.3796 .06333 L
.38022 .0421 L
.3805 .03213 L
.38064 .02669 L
.3808 .02072 L
.38094 .01525 L
.38107 .01926 L
.38132 .02946 L
.38187 .05279 L
.38304 .10588 L
.38782 .34907 L
.39023 .46122 L
.39242 .54046 L
.39301 .5568 L
.39364 .57188 L
.39419 .58263 L
.39479 .59192 L
.39512 .59587 L
.39543 .59881 L
.39576 .60112 L
.39594 .60206 L
.39602 .60239 L
.39611 .60269 L
.39626 .60308 L
.39641 .60328 L
.39656 .60332 L
.39665 .60326 L
.39673 .60315 L
.39688 .60282 L
.39701 .60237 L
.39716 .60171 L
.39732 .60083 L
.39763 .59856 L
.39792 .59574 L
.39847 .58876 L
Mistroke
.39906 .5788 L
.3997 .56524 L
.40085 .53402 L
.40191 .4982 L
.40666 .28444 L
.40904 .16758 L
.41122 .07058 L
.4118 .04775 L
.4121 .03624 L
.41242 .02442 L
.4125 .02168 L
.41258 .01875 L
.41273 .01591 L
.41288 .0209 L
.41301 .02541 L
.41356 .04283 L
.41487 .078 L
.4155 .0919 L
.41608 .10266 L
.41661 .11084 L
.41718 .11805 L
.41749 .12127 L
.41778 .12378 L
.41806 .12577 L
.41835 .12748 L
.41851 .1282 L
.41865 .12876 L
.41879 .12922 L
.41893 .12956 L
.41908 .12984 L
.41915 .12994 L
.41924 .13002 L
.41932 .13007 L
.41941 .13008 L
.41956 .13002 L
.41972 .12986 L
.4198 .12973 L
.41988 .12956 L
.42018 .12874 L
.42034 .12811 L
.42052 .12732 L
.42085 .12555 L
.42148 .12094 L
.42207 .11543 L
.4234 .09922 L
.42583 .06103 L
.4271 .03912 L
.42773 .0285 L
.428 .02393 L
.42831 .01899 L
Mistroke
.42844 .01687 L
.42858 .01482 L
.42871 .01692 L
.42883 .01882 L
.42939 .02727 L
.43055 .04338 L
.43167 .05628 L
.43286 .06675 L
.43348 .0708 L
.43381 .07255 L
.43416 .07412 L
.43449 .07526 L
.43478 .07607 L
.43493 .07638 L
.43508 .07666 L
.43523 .07686 L
.43536 .07701 L
.43552 .07711 L
.4356 .07714 L
.43568 .07715 L
.43583 .07714 L
.43598 .07707 L
.43606 .077 L
.43614 .07693 L
.4363 .07674 L
.43646 .07648 L
.43664 .07612 L
.43694 .07535 L
.43726 .0743 L
.43784 .07189 L
.4389 .06574 L
.44008 .05683 L
.44131 .04578 L
.44261 .03304 L
.44372 .0219 L
.44402 .01889 L
.44419 .01724 L
.44434 .0157 L
.44449 .01516 L
.44465 .01669 L
.44493 .01933 L
.44715 .03797 L
.44841 .04591 L
.44903 .04894 L
.44959 .05119 L
.44987 .05212 L
.45018 .05299 L
.45048 .05368 L
.45074 .05417 L
.45106 .0546 L
Mistroke
.45123 .05477 L
.45131 .05484 L
.45139 .05489 L
.45154 .05496 L
.45168 .05499 L
.45182 .055 L
.45191 .05498 L
.45199 .05496 L
.45214 .05488 L
.45223 .05482 L
.45231 .05476 L
.45263 .05441 L
.45291 .05397 L
.45321 .05337 L
.45383 .05173 L
.45452 .04933 L
.45574 .04375 L
.45686 .03746 L
.45816 .02916 L
.45938 .02102 L
.45965 .01918 L
.45994 .01719 L
.46008 .01629 L
.46022 .01534 L
.46035 .0149 L
.46048 .01578 L
.4611 .01975 L
.46166 .0232 L
.46297 .03044 L
.46416 .03583 L
.46473 .03794 L
.46536 .03985 L
.46596 .04125 L
.46651 .04219 L
.46666 .0424 L
.46684 .04259 L
.46699 .04274 L
.46715 .04286 L
.46729 .04295 L
.46745 .04301 L
.46759 .04305 L
.46773 .04306 L
.46781 .04306 L
.4679 .04305 L
.46798 .04304 L
.46806 .04301 L
.4682 .04295 L
.46835 .04286 L
.46852 .04274 L
.46867 .0426 L
Mistroke
.46903 .04218 L
.46962 .04118 L
.47028 .0397 L
.47147 .03606 L
.4737 .02677 L
.47492 .02091 L
.47552 .01797 L
.47579 .01668 L
.47593 .016 L
.47607 .01528 L
.47616 .01487 L
.47623 .01493 L
.47638 .01565 L
.47671 .01721 L
.4774 .0204 L
.4786 .02552 L
.47972 .02958 L
.48091 .03296 L
.48152 .03431 L
.48185 .03489 L
.48221 .03543 L
.48253 .03582 L
.48283 .03611 L
.48311 .03631 L
.48325 .03639 L
.48341 .03645 L
.48357 .03649 L
.48371 .03651 L
.48379 .03652 L
.48388 .03651 L
.48396 .03651 L
.48405 .03649 L
.4842 .03645 L
.48434 .0364 L
.4845 .03632 L
.48465 .03622 L
.48493 .03599 L
.48519 .03573 L
.48577 .03493 L
.48642 .03376 L
.487 .03246 L
.4883 .0288 L
.48953 .0246 L
.49082 .01966 L
.49136 .01754 L
.49165 .01637 L
.49193 .01526 L
.49208 .0148 L
.49217 .01515 L
.49226 .01548 L
Mistroke
.49255 .01666 L
.49314 .01894 L
.4943 .02322 L
.49554 .02728 L
.49664 .03022 L
.49779 .03252 L
.49836 .03332 L
.49868 .03367 L
.49897 .03393 L
.49925 .03411 L
.49937 .03418 L
.49949 .03423 L
.49963 .03427 L
.49978 .0343 L
.49991 .03432 L
.50005 .03432 L
.5002 .03431 L
.50035 .03428 L
.50042 .03426 L
.50051 .03423 L
.50066 .03416 L
.50096 .03398 L
.50123 .03375 L
.50187 .03303 L
.50254 .03195 L
.50366 .02948 L
.50488 .02598 L
.50602 .02208 L
.50708 .01808 L
.50764 .01589 L
.5078 .01525 L
.50795 .01478 L
.50809 .01533 L
.50824 .01592 L
.5095 .02092 L
.51071 .02546 L
.51204 .02985 L
.51264 .03153 L
.51328 .03311 L
.51383 .03425 L
.51444 .03524 L
.51479 .0357 L
.51512 .03603 L
.51543 .03627 L
.5156 .03637 L
.51576 .03644 L
.51592 .03648 L
.51606 .03651 L
.51622 .03652 L
.5163 .03651 L
Mistroke
.51639 .0365 L
.51653 .03647 L
.51669 .03641 L
.51684 .03634 L
.51697 .03626 L
.51725 .03604 L
.51755 .03573 L
.51817 .03486 L
.51874 .03377 L
.51928 .03251 L
.52048 .0289 L
.52178 .02396 L
.52239 .02135 L
.52303 .0184 L
.52335 .01693 L
.5235 .01619 L
.52364 .01551 L
.52377 .01489 L
.52391 .01521 L
.52405 .01587 L
.5242 .01661 L
.52542 .02256 L
.52674 .02881 L
.52795 .0339 L
.52909 .03791 L
.52972 .0397 L
.53041 .04125 L
.53071 .04179 L
.53103 .04226 L
.53134 .04261 L
.53161 .04284 L
.53176 .04293 L
.53189 .043 L
.53204 .04304 L
.53213 .04306 L
.5322 .04306 L
.53236 .04306 L
.53244 .04304 L
.53252 .04302 L
.53267 .04297 L
.53283 .04288 L
.53296 .04278 L
.5331 .04266 L
.53336 .04238 L
.53366 .04194 L
.53394 .04145 L
.53456 .04006 L
.53523 .03807 L
.53645 .03324 L
.53767 .02705 L
Mistroke
.53882 .02024 L
.53913 .01828 L
.53946 .01617 L
.53954 .01563 L
.53963 .01505 L
.53973 .01502 L
.53982 .01562 L
.54015 .01782 L
.54135 .02592 L
.54374 .04095 L
.54509 .04773 L
.54573 .0503 L
.54634 .05224 L
.54687 .05355 L
.54717 .05411 L
.54745 .0545 L
.54758 .05466 L
.54773 .05479 L
.54781 .05486 L
.54789 .0549 L
.54804 .05497 L
.5482 .055 L
.54828 .055 L
.54836 .05499 L
.54851 .05494 L
.54867 .05485 L
.54882 .05473 L
.54896 .05458 L
.54928 .05414 L
.54957 .05358 L
.54985 .05292 L
.55047 .05098 L
.55114 .04817 L
.55372 .03132 L
.55431 .02629 L
.55493 .02064 L
.55519 .01822 L
.55533 .01688 L
.55547 .01559 L
.55562 .01538 L
.55577 .01678 L
.55605 .01956 L
.55722 .0313 L
.55848 .04382 L
.56077 .06349 L
.56194 .07077 L
.56253 .0735 L
.56287 .07475 L
.56318 .07567 L
.56345 .0763 L
Mistroke
.56358 .07655 L
.56373 .07677 L
.56388 .07695 L
.56401 .07706 L
.5641 .07711 L
.56418 .07714 L
.56432 .07715 L
.56446 .07712 L
.56459 .07704 L
.56471 .07693 L
.56484 .07677 L
.56498 .07656 L
.56513 .07627 L
.5654 .0756 L
.56571 .07461 L
.56604 .07328 L
.56662 .0702 L
.56726 .06587 L
.56796 .05992 L
.56922 .0462 L
.57038 .03065 L
.57097 .02189 L
.57112 .01962 L
.57126 .01744 L
.57138 .01546 L
.57152 .01613 L
.57166 .01845 L
.57179 .0206 L
.57209 .02546 L
.57271 .03598 L
.57523 .07851 L
.57631 .0952 L
.57749 .11052 L
.57816 .11766 L
.57877 .12293 L
.57906 .12499 L
.57939 .12686 L
.57969 .12825 L
.57997 .1292 L
.58013 .12958 L
.58021 .12975 L
.58029 .12987 L
.58043 .13002 L
.58059 .13008 L
.58067 .13007 L
.58075 .13003 L
.5809 .12986 L
.58099 .12973 L
.58107 .12957 L
.58125 .1291 L
Mistroke
.58152 .12806 L
.58183 .12648 L
.58215 .12432 L
.58245 .12182 L
.58301 .11584 L
.58353 .10887 L
.58469 .08787 L
.58588 .05906 L
.58644 .04268 L
.58698 .02574 L
.58712 .02082 L
.58728 .0155 L
.58736 .01676 L
.58745 .0199 L
.58761 .02553 L
.58818 .04694 L
.58947 .09985 L
.59434 .33357 L
.59658 .43768 L
.59902 .52994 L
.59966 .54891 L
.60035 .56624 L
.60094 .5787 L
.60158 .5894 L
.60192 .59391 L
.60223 .59729 L
.60253 .59982 L
.60268 .60085 L
.60285 .60176 L
.603 .60241 L
.60313 .60285 L
.60327 .60314 L
.6034 .6033 L
.60355 .60331 L
.60369 .60317 L
.60384 .60285 L
.60392 .60262 L
.604 .60231 L
.60428 .60087 L
.60445 .59978 L
.60459 .59859 L
.60522 .59176 L
.60576 .58349 L
.60634 .57231 L
.60766 .53803 L
.60886 .4974 L
.61368 .27195 L
.6159 .15793 L
.61716 .09676 L
.61777 .06859 L
Mistroke
.61833 .04411 L
.61862 .03216 L
.61877 .026 L
.61893 .01956 L
.61906 .01538 L
.61922 .02137 L
.61949 .03164 L
.62073 .07394 L
.62204 .10919 L
.62263 .12172 L
.62327 .13305 L
.62389 .14153 L
.62446 .14739 L
.62477 .14981 L
.62506 .1515 L
.62522 .15223 L
.62539 .15286 L
.62547 .15309 L
.62555 .1533 L
.6257 .15358 L
.62584 .15372 L
.62597 .15376 L
.62611 .1537 L
.62625 .15354 L
.62638 .1533 L
.6265 .15301 L
.62677 .15207 L
.62706 .15061 L
.62733 .14891 L
.62793 .1439 L
.62852 .13749 L
.62915 .12925 L
.63026 .1113 L
.63277 .06087 L
.63391 .03608 L
.63424 .02899 L
.63456 .02235 L
.63469 .01949 L
.63484 .01647 L
.63499 .01625 L
.63514 .01926 L
.63735 .06019 L
.63848 .07657 L
.63908 .08363 L
.6397 .08983 L
.64025 .0942 L
.64054 .09609 L
.64085 .09779 L
.64114 .09906 L
.6414 .09997 L
Mistroke
.64153 .10032 L
.64166 .10064 L
.64179 .10088 L
.64191 .10106 L
.64206 .10121 L
.64219 .10129 L
.64234 .1013 L
.6425 .10122 L
.64264 .10109 L
.64279 .10088 L
.64293 .10061 L
.64305 .10032 L
.64336 .09937 L
.6437 .09801 L
.64431 .09467 L
.64495 .08998 L
.64563 .08388 L
.64685 .07042 L
.64808 .0542 L
.64925 .03744 L
.64976 .02994 L
.6503 .02197 L
.65058 .01784 L
.65066 .01671 L
.65074 .0155 L
.65089 .0161 L
.65104 .01821 L
.65117 .02021 L
.65144 .02391 L
.6538 .0537 L
.655 .06522 L
.65569 .07032 L
.65632 .07406 L
.65693 .07672 L
.65728 .07781 L
.65744 .07822 L
.65759 .07854 L
.65774 .07879 L
.65787 .07896 L
.65802 .07911 L
.65818 .07921 L
.65833 .07924 L
.65842 .07923 L
.65849 .07921 L
.65864 .07913 L
.65879 .07898 L
.65893 .0788 L
.65906 .07859 L
.65934 .07798 L
.6596 .07728 L
Mistroke
.65986 .07638 L
.66042 .07394 L
.66104 .0705 L
.66228 .06133 L
.6634 .05089 L
.66472 .03692 L
.66529 .03042 L
.66593 .02315 L
.66621 .01994 L
.66636 .01817 L
.66651 .0165 L
.66665 .01495 L
.66679 .01616 L
.66705 .01909 L
.66824 .03201 L
.66956 .04474 L
.67075 .05421 L
.67134 .05802 L
.67198 .06141 L
.67258 .0639 L
.67313 .06555 L
.67343 .06619 L
.67358 .06644 L
.67372 .06662 L
.67379 .06671 L
.67388 .06679 L
.67403 .0669 L
.67411 .06695 L
.6742 .06697 L
.67428 .06698 L
.67436 .06698 L
.67444 .06697 L
.67453 .06694 L
.67468 .06685 L
.67477 .06677 L
.67485 .06669 L
.67503 .06646 L
.67533 .06593 L
.67566 .06516 L
.6763 .06304 L
.6769 .06042 L
.67824 .05242 L
.68067 .03239 L
.68176 .02212 L
.68208 .01912 L
.68223 .01764 L
.68238 .01627 L
.68251 .01504 L
.68264 .0157 L
.68278 .01701 L
Mistroke
.68294 .01845 L
.68422 .03012 L
.68543 .03989 L
.68656 .04761 L
.68776 .0538 L
.68838 .05615 L
.68871 .05712 L
.68907 .05795 L
.68923 .05827 L
.68939 .05853 L
.68955 .05874 L
.68969 .05889 L
.68983 .05901 L
.68997 .0591 L
.69011 .05915 L
.69027 .05916 L
.69043 .05913 L
.69057 .05907 L
.69073 .05896 L
.6909 .05879 L
.69121 .05836 L
.69149 .05782 L
.69207 .05633 L
.69261 .05444 L
.69382 .04871 L
.69513 .04049 L
.69638 .03127 L
.69754 .02192 L
.69812 .01711 L
.6982 .01645 L
.69829 .01572 L
.69845 .01501 L
.6986 .01629 L
.69875 .01746 L
.70008 .02795 L
.70233 .04285 L
.70295 .04598 L
.70361 .04881 L
.70424 .05092 L
.70454 .05173 L
.70481 .05234 L
.70509 .05285 L
.70539 .05327 L
.70555 .05344 L
.7057 .05357 L
.70585 .05365 L
.706 .05371 L
.70613 .05373 L
.70627 .05372 L
.7064 .05368 L
Mistroke
.70652 .05363 L
.70666 .05353 L
.70682 .0534 L
.7071 .05306 L
.70743 .05251 L
.70773 .05188 L
.70839 .05002 L
.70901 .04776 L
.7096 .0452 L
.71202 .03092 L
.7131 .02336 L
.71369 .01905 L
.71398 .01692 L
.71411 .01599 L
.71425 .01496 L
.7144 .01552 L
.71455 .01662 L
.71487 .01894 L
.71543 .02293 L
.71653 .0303 L
.71783 .03795 L
.71902 .04351 L
.7196 .0456 L
.72022 .04742 L
.72051 .04808 L
.72081 .04866 L
.7211 .0491 L
.72136 .04939 L
.72152 .04953 L
.72161 .04959 L
.72169 .04963 L
.72183 .04969 L
.72198 .04973 L
.72207 .04973 L
.72215 .04973 L
.72231 .04969 L
.7224 .04966 L
.72248 .04962 L
.72266 .04949 L
.7228 .04936 L
.72294 .04921 L
.72325 .04878 L
.72355 .04823 L
.72388 .04751 L
.72503 .04393 L
.72569 .04124 L
.72629 .03836 L
.7276 .03113 L
.72884 .0234 L
.72941 .01965 L
Mistroke
.72973 .01757 L
.73002 .01562 L
.73017 .01482 L
.73026 .01539 L
.73034 .0159 L
.73069 .0182 L
.7313 .02217 L
.73355 .03506 L
.73473 .04032 L
.7353 .04232 L
.73584 .04388 L
.73614 .04462 L
.73647 .0453 L
.73675 .04576 L
.73705 .04616 L
.73721 .04632 L
.73738 .04647 L
.73747 .04653 L
.73755 .04658 L
.73764 .04662 L
.73772 .04664 L
.73787 .04668 L
.73795 .04668 L
.73804 .04668 L
.73818 .04665 L
.73834 .04659 L
.73849 .04651 L
.73862 .04641 L
.73893 .04609 L
.73923 .04567 L
.73956 .04511 L
.74014 .04377 L
.74067 .04222 L
.74197 .03727 L
.74319 .03131 L
.74437 .02474 L
.74501 .02093 L
.74532 .01903 L
.74561 .01729 L
.74573 .01653 L
.74587 .0157 L
.746 .01491 L
.74612 .01525 L
.74625 .01601 L
.74639 .01686 L
.74667 .01856 L
.74783 .02534 L
.74897 .03132 L
.75016 .03666 L
.75079 .03896 L
Mistroke
.75147 .04104 L
.7521 .04251 L
.75238 .04303 L
.75268 .04348 L
.75283 .04367 L
.75299 .04385 L
.75314 .04399 L
.75328 .04409 L
.75345 .04419 L
.75354 .04422 L
.75362 .04425 L
.75378 .04428 L
.75386 .04428 L
.75394 .04428 L
.7541 .04425 L
.75425 .04419 L
.75438 .04412 L
.75452 .04402 L
.75484 .04372 L
.75514 .04333 L
.75566 .04242 L
.75623 .04109 L
.75738 .03744 L
.75993 .02568 L
.76052 .02251 L
.76114 .01905 L
.76139 .01761 L
.76167 .01605 L
.76183 .01516 L
.76197 .01509 L
.76211 .01587 L
.76225 .01669 L
.76341 .02304 L
.76466 .02937 L
.76586 .03452 L
.76695 .03821 L
.76754 .03976 L
.7681 .0409 L
.76839 .04136 L
.76869 .04176 L
.76885 .04192 L
.76902 .04207 L
.76918 .04218 L
.76933 .04226 L
.76947 .04231 L
.76961 .04234 L
.76976 .04235 L
.76989 .04234 L
.77002 .04231 L
.77013 .04227 L
Mistroke
.77027 .0422 L
.7704 .04212 L
.77068 .04187 L
.77095 .04157 L
.77154 .04062 L
.77211 .03938 L
.77272 .03772 L
.77382 .03392 L
.77631 .02242 L
.77691 .01932 L
.77724 .01759 L
.77754 .01596 L
.7777 .01512 L
.77779 .01478 L
.77787 .01522 L
.77824 .01714 L
.77888 .02049 L
.78014 .02668 L
.78131 .03174 L
.78241 .03565 L
.78298 .03727 L
.78359 .03869 L
.78394 .03935 L
.78427 .03984 L
.78458 .04022 L
.78473 .04038 L
.7849 .04051 L
.78506 .04062 L
.7852 .04069 L
.78534 .04074 L
.78547 .04077 L
.78562 .04078 L
.78577 .04077 L
.78592 .04074 L
.786 .04071 L
.78609 .04067 L
.78624 .04059 L
.78637 .0405 L
.78668 .04021 L
.78699 .03985 L
.78731 .03936 L
.78789 .03822 L
.78842 .03692 L
.78972 .03278 L
.79094 .02782 L
.79211 .02239 L
.79275 .01924 L
.79306 .01768 L
.79335 .01624 L
.79347 .01561 L
Mistroke
.79361 .01492 L
.79374 .01515 L
.79386 .01576 L
.79441 .01849 L
.79557 .02408 L
.79685 .02958 L
.79805 .03386 L
.79913 .03677 L
.79974 .03797 L
.80029 .03877 L
.80059 .03907 L
.80086 .03928 L
.80101 .03936 L
.80109 .0394 L
.80117 .03943 L
.80133 .03947 L
.80147 .03948 L
.8016 .03948 L
.80174 .03946 L
.80187 .03942 L
.80199 .03937 L
.80212 .0393 L
.80227 .03921 L
.80257 .03895 L
.80289 .03857 L
.80319 .03813 L
.80386 .03687 L
.80506 .03367 L
.80757 .0239 L
.80867 .01879 L
.80897 .01735 L
.80914 .01655 L
.8093 .0158 L
.80944 .0151 L
.80953 .01473 L
.8096 .0151 L
.80988 .01643 L
.81214 .0266 L
.81329 .03095 L
.81453 .03467 L
.81519 .03619 L
.81548 .03673 L
.8158 .03724 L
.81609 .03762 L
.81639 .03794 L
.81656 .03808 L
.81671 .03819 L
.81685 .03827 L
.81701 .03834 L
.81714 .03838 L
Mistroke
.81729 .0384 L
.81743 .03841 L
.81756 .0384 L
.81771 .03836 L
.81785 .03831 L
.81801 .03823 L
.81816 .03814 L
.81843 .03791 L
.81868 .03764 L
.81925 .03683 L
.81986 .03564 L
.82053 .03402 L
.82173 .03028 L
.82397 .0212 L
.82452 .01872 L
.82483 .01733 L
.82512 .016 L
.82528 .01525 L
.82537 .01483 L
.82546 .01499 L
.82561 .01568 L
.82577 .01641 L
.82637 .01917 L
.8276 .02446 L
.82891 .02948 L
.83014 .03324 L
.83068 .03455 L
.83126 .03572 L
.83153 .03616 L
.83182 .03657 L
.83207 .03686 L
.83234 .03712 L
.83249 .03724 L
.83264 .03733 L
.83278 .0374 L
.83293 .03746 L
.83306 .03749 L
.83318 .03751 L
.83332 .03751 L
.83347 .03749 L
.83355 .03748 L
.83363 .03745 L
.83377 .0374 L
.83393 .03732 L
.8341 .03721 L
.83441 .03694 L
.83469 .03663 L
.83534 .03565 L
.83602 .03425 L
.83717 .03109 L
Mistroke
.83844 .02668 L
.83965 .02178 L
.84025 .01922 L
.8408 .0168 L
.84111 .01544 L
.84126 .01475 L
.84135 .01507 L
.84143 .01544 L
.84212 .01846 L
.84332 .02353 L
.84451 .02803 L
.84576 .03195 L
.84683 .03445 L
.84743 .03549 L
.84771 .03586 L
.84799 .03618 L
.84815 .03632 L
.84831 .03645 L
.84846 .03655 L
.8486 .03663 L
.84877 .0367 L
.84886 .03672 L
.84895 .03674 L
.8491 .03676 L
.84919 .03676 L
.84927 .03676 L
.84941 .03673 L
.84954 .0367 L
.84969 .03664 L
.84985 .03656 L
.85017 .03632 L
.85046 .03603 L
.85099 .03534 L
.85156 .03433 L
.85271 .03156 L
.85527 .02262 L
.85585 .02021 L
.85648 .01757 L
.85673 .01648 L
.85687 .01587 L
.85701 .01529 L
.85717 .01482 L
.85731 .01544 L
.85759 .01665 L
.85875 .0215 L
.86001 .02634 L
.86121 .03026 L
.8623 .03306 L
.86289 .03424 L
.86345 .0351 L
Mistroke
.86376 .03546 L
.86405 .03573 L
.86436 .03595 L
.86452 .03602 L
.8646 .03606 L
.86469 .03609 L
.86484 .03612 L
.86498 .03614 L
.86511 .03614 L
.86524 .03612 L
.86538 .03609 L
.86553 .03604 L
.86569 .03596 L
.86583 .03587 L
.8661 .03566 L
.86635 .03542 L
.86691 .03469 L
.86748 .0337 L
.86809 .03236 L
.86919 .02934 L
.87169 .02023 L
.87229 .01777 L
.87261 .0164 L
.87277 .01573 L
.87292 .01511 L
.873 .01477 L
.87308 .01499 L
.87316 .01533 L
.87325 .01571 L
.87362 .01723 L
.87426 .01986 L
.87554 .0248 L
.87669 .0287 L
.87728 .03042 L
.87792 .03204 L
.87847 .03321 L
.87907 .03424 L
.87938 .03466 L
.87971 .03503 L
.87989 .0352 L
.88006 .03533 L
.88023 .03543 L
.88039 .03551 L
.88053 .03557 L
.88069 .0356 L
.88084 .03562 L
.88093 .03563 L
.88101 .03562 L
.88116 .0356 L
.88129 .03557 L
Mistroke
.88145 .03551 L
.8816 .03544 L
.88191 .03522 L
.88221 .03495 L
.88275 .03426 L
.88335 .03326 L
.88399 .0319 L
.8862 .02524 L
.88745 .02056 L
.88805 .01813 L
.88861 .01587 L
.88875 .01529 L
.88891 .01478 L
.88905 .01539 L
.88919 .01595 L
.88982 .01849 L
.89115 .02363 L
.89223 .02736 L
.89339 .03073 L
.89406 .03228 L
.89468 .03343 L
.89526 .03427 L
.89556 .0346 L
.89588 .03487 L
.89603 .03497 L
.89618 .03506 L
.89627 .0351 L
.89636 .03513 L
.89652 .03518 L
.89666 .0352 L
.89675 .03521 L
.89683 .03521 L
.89697 .0352 L
.89712 .03517 L
.89725 .03513 L
.8974 .03507 L
.89765 .03492 L
.89796 .03467 L
.89824 .03438 L
.89887 .03352 L
.89954 .03226 L
.90077 .02922 L
.90313 .02119 L
.90377 .01867 L
.90413 .01725 L
.90447 .0159 L
.90462 .01529 L
.9047 .01496 L
.90478 .01479 L
.90486 .01513 L
Mistroke
.90496 .0155 L
.90512 .01616 L
.90572 .01853 L
.90693 .02314 L
.9082 .02747 L
.90938 .03075 L
.90996 .03203 L
.91048 .03301 L
.91104 .03383 L
.91156 .03439 L
.91185 .03461 L
.91211 .03476 L
.91225 .03481 L
.9124 .03485 L
.91256 .03488 L
.91271 .03488 L
.91286 .03487 L
.91295 .03485 L
.91303 .03483 L
.91317 .03479 L
.91333 .03472 L
.91362 .03453 L
.91389 .0343 L
.91454 .03353 L
.91515 .03251 L
.91633 .02984 L
.91758 .02613 L
.91875 .02204 L
.91981 .01797 L
.92009 .01686 L
.92024 .01627 L
.9204 .01565 L
.92054 .0151 L
.92069 .01493 L
.92083 .01548 L
.92096 .016 L
.92219 .02076 L
.9244 .02826 L
.925 .02989 L
.92565 .03143 L
.92623 .03256 L
.92684 .0335 L
.92715 .03387 L
.92745 .03416 L
.92771 .03436 L
.92785 .03444 L
.928 .03451 L
.92814 .03457 L
.92827 .0346 L
.92841 .03463 L
Mistroke
.92856 .03463 L
.9287 .03463 L
.92883 .0346 L
.92895 .03457 L
.92908 .03453 L
.92922 .03446 L
.92936 .03438 L
.92966 .03416 L
.92993 .0339 L
.93021 .03358 L
.93081 .03269 L
.93146 .03144 L
.93277 .0281 L
.93399 .02419 L
.93526 .01956 L
.93589 .01715 L
.93616 .01608 L
.9363 .01552 L
.93646 .0149 L
.9366 .01508 L
.93673 .01559 L
.93698 .01657 L
.93754 .01872 L
.9387 .02304 L
.93981 .02675 L
.941 .03006 L
.94168 .03159 L
.94229 .03271 L
.94259 .03316 L
.94291 .03357 L
.94322 .03389 L
.9435 .03412 L
.94378 .0343 L
.94394 .03437 L
.94409 .03441 L
.94423 .03444 L
.94436 .03446 L
.9445 .03446 L
.94465 .03444 L
.94479 .03441 L
.94488 .03438 L
.94495 .03436 L
.94524 .03421 L
.9454 .0341 L
.94557 .03397 L
.94591 .03363 L
.94654 .03277 L
.94722 .03153 L
.94845 .02856 L
.95085 .02058 L
Mistroke
.95151 .01808 L
.95187 .01669 L
.95205 .01601 L
.95221 .01538 L
.95236 .01481 L
.9525 .01516 L
.95264 .01574 L
.9528 .01636 L
.95346 .01888 L
.95575 .02688 L
.95706 .03042 L
.9577 .03179 L
.95829 .0328 L
.95884 .03353 L
.95912 .03382 L
.95943 .03406 L
.95959 .03416 L
.95974 .03423 L
.95982 .03427 L
.95991 .0343 L
.96007 .03433 L
.96022 .03435 L
.96038 .03436 L
.96052 .03434 L
.96067 .03431 L
.96075 .03428 L
.96084 .03425 L
.961 .03418 L
.9613 .03398 L
.96165 .03367 L
.96198 .0333 L
.96257 .03243 L
.9632 .03124 L
.96444 .02816 L
.96578 .02393 L
.96694 .01975 L
.96756 .01741 L
.9679 .0161 L
.96806 .01546 L
.96822 .01486 L
.96837 .01516 L
.96844 .01545 L
.96853 .01578 L
.96887 .01709 L
.96946 .01936 L
.97062 .02358 L
.97195 .02781 L
.97316 .03091 L
.97387 .0323 L
.97462 .03338 L
Mistroke
.97501 .03379 L
.97537 .03407 L
.97558 .03418 L
.97577 .03425 L
.97587 .03428 L
.97598 .03431 L
.97609 .03432 L
.97619 .03432 L
Mfstroke
1 0 0 r
[ ] 0 setdash
.03968 .01472 m
.03968 .03436 L
s
.05556 .01472 m
.05556 .03446 L
s
.07143 .01472 m
.07143 .03463 L
s
.0873 .01472 m
.0873 .03488 L
s
.10317 .01472 m
.10317 .03521 L
s
.11905 .01472 m
.11905 .03563 L
s
.13492 .01472 m
.13492 .03614 L
s
.15079 .01472 m
.15079 .03676 L
s
.16667 .01472 m
.16667 .03751 L
s
.18254 .01472 m
.18254 .03841 L
s
.19841 .01472 m
.19841 .03948 L
s
.21429 .01472 m
.21429 .04078 L
s
.23016 .01472 m
.23016 .04235 L
s
.24603 .01472 m
.24603 .04427 L
s
.2619 .01472 m
.2619 .04667 L
s
.27778 .01472 m
.27778 .04972 L
s
.29365 .01472 m
.29365 .0537 L
s
.30952 .01472 m
.30952 .05912 L
s
.3254 .01472 m
.3254 .0669 L
s
.34127 .01472 m
.34127 .07905 L
s
.35714 .01472 m
.35714 .10075 L
s
.37302 .01472 m
.37302 .15104 L
s
.38889 .01472 m
.38889 .40109 L
s
.40476 .01472 m
.40476 .37687 L
s
.42063 .01472 m
.42063 .12675 L
s
.43651 .01472 m
.43651 .07639 L
s
.45238 .01472 m
.45238 .05469 L
s
.46825 .01472 m
.46825 .04293 L
s
.48413 .01472 m
.48413 .03647 L
s
.5 .01472 m
.5 .03432 L
s
.51587 .01472 m
.51587 .03647 L
s
.53175 .01472 m
.53175 .04293 L
s
.54762 .01472 m
.54762 .05469 L
s
.56349 .01472 m
.56349 .07639 L
s
.57937 .01472 m
.57937 .12675 L
s
.59524 .01472 m
.59524 .37687 L
s
.61111 .01472 m
.61111 .40109 L
s
.62698 .01472 m
.62698 .15104 L
s
.64286 .01472 m
.64286 .10075 L
s
.65873 .01472 m
.65873 .07905 L
s
.6746 .01472 m
.6746 .0669 L
s
.69048 .01472 m
.69048 .05912 L
s
.70635 .01472 m
.70635 .0537 L
s
.72222 .01472 m
.72222 .04972 L
s
.7381 .01472 m
.7381 .04667 L
s
.75397 .01472 m
.75397 .04427 L
s
.76984 .01472 m
.76984 .04235 L
s
.78571 .01472 m
.78571 .04078 L
s
.80159 .01472 m
.80159 .03948 L
s
.81746 .01472 m
.81746 .03841 L
s
.83333 .01472 m
.83333 .03751 L
s
.84921 .01472 m
.84921 .03676 L
s
.86508 .01472 m
.86508 .03614 L
s
.88095 .01472 m
.88095 .03563 L
s
.89683 .01472 m
.89683 .03521 L
s
.9127 .01472 m
.9127 .03488 L
s
.92857 .01472 m
.92857 .03463 L
s
.94444 .01472 m
.94444 .03446 L
s
.96032 .01472 m
.96032 .03436 L
s
.97619 .01472 m
.97619 .03432 L
s
.015 w
.03968 .03436 Mdot
.05556 .03446 Mdot
.07143 .03463 Mdot
.0873 .03488 Mdot
.10317 .03521 Mdot
.11905 .03563 Mdot
.13492 .03614 Mdot
.15079 .03676 Mdot
.16667 .03751 Mdot
.18254 .03841 Mdot
.19841 .03948 Mdot
.21429 .04078 Mdot
.23016 .04235 Mdot
.24603 .04427 Mdot
.2619 .04667 Mdot
.27778 .04972 Mdot
.29365 .0537 Mdot
.30952 .05912 Mdot
.3254 .0669 Mdot
.34127 .07905 Mdot
.35714 .10075 Mdot
.37302 .15104 Mdot
.38889 .40109 Mdot
.40476 .37687 Mdot
.42063 .12675 Mdot
.43651 .07639 Mdot
.45238 .05469 Mdot
.46825 .04293 Mdot
.48413 .03647 Mdot
.5 .03432 Mdot
.51587 .03647 Mdot
.53175 .04293 Mdot
.54762 .05469 Mdot
.56349 .07639 Mdot
.57937 .12675 Mdot
.59524 .37687 Mdot
.61111 .40109 Mdot
.62698 .15104 Mdot
.64286 .10075 Mdot
.65873 .07905 Mdot
.6746 .0669 Mdot
.69048 .05912 Mdot
.70635 .0537 Mdot
.72222 .04972 Mdot
.7381 .04667 Mdot
.75397 .04427 Mdot
.76984 .04235 Mdot
.78571 .04078 Mdot
.80159 .03948 Mdot
.81746 .03841 Mdot
.83333 .03751 Mdot
.84921 .03676 Mdot
.86508 .03614 Mdot
.88095 .03563 Mdot
.89683 .03521 Mdot
.9127 .03488 Mdot
.92857 .03463 Mdot
.94444 .03446 Mdot
.96032 .03436 Mdot
.97619 .03432 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{756, 146},
  ImageCacheValid->False]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Magnitude plot of windowed DTFT as a function of frequency", \
"Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(X\[Theta]\  = DTFT[xdc, \[Theta]]\  // \ Simplify; 
    g1 = Plot[
        Abs[X\[Theta]\  /. \ \[Theta] \[Rule] \ 2  \[Pi]\ f/fs], {f, \(-fs\)/
            2, fs/2}, \ PlotStyle \[Rule] {Blue, \ Dashing[{ .01}]}, \ 
        PlotRange \[Rule] All, PlotPoints \[Rule] 200];\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.047619 0.0147142 0.0363327 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01471 -6 -4.5 ]
[-0.0125 .01471 0 4.5 ]
[-0.0125 .10555 -18 -4.5 ]
[-0.0125 .10555 0 4.5 ]
[-0.0125 .19638 -6 -4.5 ]
[-0.0125 .19638 0 4.5 ]
[-0.0125 .28721 -18 -4.5 ]
[-0.0125 .28721 0 4.5 ]
[-0.0125 .37804 -12 -4.5 ]
[-0.0125 .37804 0 4.5 ]
[-0.0125 .46887 -24 -4.5 ]
[-0.0125 .46887 0 4.5 ]
[-0.0125 .5597 -12 -4.5 ]
[-0.0125 .5597 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01471 m
.00625 .01471 L
s
[(0)] -0.0125 .01471 1 0 Mshowa
0 .10555 m
.00625 .10555 L
s
[(2.5)] -0.0125 .10555 1 0 Mshowa
0 .19638 m
.00625 .19638 L
s
[(5)] -0.0125 .19638 1 0 Mshowa
0 .28721 m
.00625 .28721 L
s
[(7.5)] -0.0125 .28721 1 0 Mshowa
0 .37804 m
.00625 .37804 L
s
[(10)] -0.0125 .37804 1 0 Mshowa
0 .46887 m
.00625 .46887 L
s
[(12.5)] -0.0125 .46887 1 0 Mshowa
0 .5597 m
.00625 .5597 L
s
[(15)] -0.0125 .5597 1 0 Mshowa
.125 Mabswid
0 .03288 m
.00375 .03288 L
s
0 .05105 m
.00375 .05105 L
s
0 .06921 m
.00375 .06921 L
s
0 .08738 m
.00375 .08738 L
s
0 .12371 m
.00375 .12371 L
s
0 .14188 m
.00375 .14188 L
s
0 .16005 m
.00375 .16005 L
s
0 .17821 m
.00375 .17821 L
s
0 .21454 m
.00375 .21454 L
s
0 .23271 m
.00375 .23271 L
s
0 .25088 m
.00375 .25088 L
s
0 .26904 m
.00375 .26904 L
s
0 .30538 m
.00375 .30538 L
s
0 .32354 m
.00375 .32354 L
s
0 .34171 m
.00375 .34171 L
s
0 .35987 m
.00375 .35987 L
s
0 .39621 m
.00375 .39621 L
s
0 .41437 m
.00375 .41437 L
s
0 .43254 m
.00375 .43254 L
s
0 .45071 m
.00375 .45071 L
s
0 .48704 m
.00375 .48704 L
s
0 .50521 m
.00375 .50521 L
s
0 .52337 m
.00375 .52337 L
s
0 .54154 m
.00375 .54154 L
s
0 .57787 m
.00375 .57787 L
s
0 .59604 m
.00375 .59604 L
s
0 .6142 m
.00375 .6142 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01471 m
1 .01471 L
s
.99375 .10555 m
1 .10555 L
s
.99375 .19638 m
1 .19638 L
s
.99375 .28721 m
1 .28721 L
s
.99375 .37804 m
1 .37804 L
s
.99375 .46887 m
1 .46887 L
s
.99375 .5597 m
1 .5597 L
s
.125 Mabswid
.99625 .03288 m
1 .03288 L
s
.99625 .05105 m
1 .05105 L
s
.99625 .06921 m
1 .06921 L
s
.99625 .08738 m
1 .08738 L
s
.99625 .12371 m
1 .12371 L
s
.99625 .14188 m
1 .14188 L
s
.99625 .16005 m
1 .16005 L
s
.99625 .17821 m
1 .17821 L
s
.99625 .21454 m
1 .21454 L
s
.99625 .23271 m
1 .23271 L
s
.99625 .25088 m
1 .25088 L
s
.99625 .26904 m
1 .26904 L
s
.99625 .30538 m
1 .30538 L
s
.99625 .32354 m
1 .32354 L
s
.99625 .34171 m
1 .34171 L
s
.99625 .35987 m
1 .35987 L
s
.99625 .39621 m
1 .39621 L
s
.99625 .41437 m
1 .41437 L
s
.99625 .43254 m
1 .43254 L
s
.99625 .45071 m
1 .45071 L
s
.99625 .48704 m
1 .48704 L
s
.99625 .50521 m
1 .50521 L
s
.99625 .52337 m
1 .52337 L
s
.99625 .54154 m
1 .54154 L
s
.99625 .57787 m
1 .57787 L
s
.99625 .59604 m
1 .59604 L
s
.99625 .6142 m
1 .6142 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
0 0 1 r
.5 Mabswid
[ .01 ] 0 setdash
.02381 .01762 m
.02395 .01762 L
.02408 .01762 L
.02423 .01761 L
.02437 .0176 L
.02462 .01758 L
.02489 .01755 L
.02519 .01751 L
.02551 .01746 L
.02608 .01733 L
.02722 .01699 L
.02847 .01647 L
.02973 .01584 L
.03043 .01546 L
.03109 .01509 L
.03139 .01492 L
.03155 .01483 L
.03171 .01474 L
.03179 .01474 L
.03189 .0148 L
.03205 .01489 L
.03238 .01508 L
.03355 .01573 L
.03596 .01687 L
.03717 .01727 L
.03785 .01744 L
.03819 .0175 L
.0385 .01755 L
.03879 .01758 L
.03894 .01759 L
.0391 .01761 L
.03918 .01761 L
.03926 .01762 L
.03941 .01762 L
.03949 .01762 L
.03958 .01762 L
.03967 .01763 L
.03976 .01763 L
.03991 .01762 L
.04006 .01762 L
.04019 .01761 L
.04033 .0176 L
.04065 .01757 L
.04095 .01754 L
.04147 .01745 L
.04204 .01732 L
.04319 .01695 L
.04573 .01578 L
.04631 .01546 L
.04694 .01511 L
Mistroke
.04724 .01493 L
.04739 .01485 L
.04752 .01477 L
.04765 .01473 L
.04778 .01481 L
.04805 .01496 L
.0492 .01561 L
.05046 .01627 L
.05165 .01681 L
.05274 .01719 L
.05332 .01736 L
.05388 .01748 L
.05417 .01753 L
.05447 .01757 L
.05463 .01759 L
.0548 .01761 L
.05495 .01762 L
.05511 .01763 L
.05525 .01763 L
.0554 .01764 L
.05553 .01764 L
.05566 .01764 L
.05581 .01764 L
.05595 .01763 L
.0561 .01762 L
.05625 .01761 L
.05652 .01759 L
.05676 .01756 L
.05732 .01747 L
.05789 .01734 L
.05849 .01716 L
.05959 .01676 L
.06208 .01552 L
.06267 .01519 L
.063 .015 L
.0633 .01482 L
.06346 .01473 L
.06355 .01475 L
.06363 .0148 L
.064 .01501 L
.06464 .01538 L
.06589 .01606 L
.06706 .01663 L
.06826 .0171 L
.06878 .01726 L
.06934 .01741 L
.06967 .01748 L
.06996 .01754 L
.07027 .01759 L
.07055 .01762 L
Mistroke
.07071 .01763 L
.07085 .01764 L
.07101 .01765 L
.07109 .01766 L
.07118 .01766 L
.07126 .01766 L
.07134 .01766 L
.07149 .01766 L
.07159 .01766 L
.07167 .01766 L
.07175 .01766 L
.07184 .01766 L
.07199 .01765 L
.07213 .01764 L
.07243 .01761 L
.07272 .01757 L
.07299 .01753 L
.07359 .0174 L
.07425 .01722 L
.07557 .01674 L
.07679 .01616 L
.07787 .01558 L
.07844 .01525 L
.07904 .01491 L
.07919 .01481 L
.07928 .01476 L
.07936 .01472 L
.07945 .01477 L
.07954 .01482 L
.07971 .01492 L
.08032 .01527 L
.08152 .01595 L
.0827 .01654 L
.08394 .01706 L
.085 .01739 L
.0856 .01753 L
.08588 .01758 L
.08617 .01762 L
.08633 .01764 L
.08648 .01766 L
.08663 .01767 L
.08677 .01768 L
.08693 .01769 L
.08702 .01769 L
.08711 .0177 L
.08726 .0177 L
.08734 .0177 L
.08742 .0177 L
.08758 .0177 L
.08772 .01769 L
Mistroke
.08786 .01768 L
.088 .01767 L
.08832 .01764 L
.08861 .0176 L
.08913 .01751 L
.0897 .01738 L
.09085 .017 L
.09339 .01579 L
.09397 .01546 L
.09459 .0151 L
.09489 .01492 L
.09504 .01483 L
.09518 .01475 L
.0953 .01475 L
.09543 .01483 L
.09571 .01499 L
.09685 .01566 L
.0981 .01633 L
.0993 .01689 L
.10038 .01729 L
.10097 .01746 L
.10153 .01758 L
.10181 .01763 L
.10211 .01768 L
.10227 .01769 L
.10244 .01771 L
.10259 .01772 L
.10275 .01773 L
.10289 .01774 L
.10304 .01774 L
.10317 .01775 L
.1033 .01775 L
.10345 .01774 L
.10358 .01774 L
.10374 .01773 L
.10389 .01772 L
.10416 .01769 L
.1044 .01766 L
.10496 .01756 L
.10552 .01743 L
.10613 .01725 L
.10722 .01683 L
.10971 .01555 L
.1103 .0152 L
.11063 .01501 L
.11093 .01482 L
.11102 .01477 L
.11111 .01472 L
.1112 .01477 L
.1113 .01483 L
Mistroke
.11162 .01502 L
.11226 .01541 L
.11343 .01608 L
.11469 .01671 L
.11593 .01722 L
.11652 .01742 L
.11706 .01756 L
.1176 .01767 L
.11789 .01772 L
.1182 .01776 L
.11832 .01777 L
.11846 .01778 L
.11858 .01779 L
.11871 .0178 L
.11885 .0178 L
.119 .0178 L
.11914 .0178 L
.11927 .0178 L
.11943 .0178 L
.1195 .01779 L
.11959 .01779 L
.11988 .01777 L
.12005 .01775 L
.12022 .01773 L
.12054 .01768 L
.12117 .01754 L
.12174 .01738 L
.12289 .01696 L
.12399 .01645 L
.12515 .01582 L
.12578 .01545 L
.12638 .01508 L
.12663 .01493 L
.12676 .01485 L
.12689 .01477 L
.12703 .01474 L
.12718 .01483 L
.12744 .01499 L
.1286 .0157 L
.13086 .01689 L
.13148 .01716 L
.13213 .0174 L
.1327 .01757 L
.13331 .01771 L
.13364 .01777 L
.13394 .01781 L
.13408 .01783 L
.13424 .01784 L
.13439 .01786 L
.13453 .01786 L
Mistroke
.13462 .01787 L
.13471 .01787 L
.13479 .01787 L
.13487 .01788 L
.13495 .01788 L
.13504 .01788 L
.13514 .01787 L
.13523 .01787 L
.13531 .01787 L
.13539 .01786 L
.13554 .01786 L
.1357 .01784 L
.13588 .01782 L
.13617 .01779 L
.13649 .01773 L
.13714 .01759 L
.13774 .01741 L
.13831 .01721 L
.14074 .01601 L
.14182 .01537 L
.14211 .01519 L
.14241 .01499 L
.14255 .01491 L
.1427 .01481 L
.14283 .01473 L
.14297 .01479 L
.14313 .01489 L
.14329 .01499 L
.14359 .01518 L
.14416 .01553 L
.14526 .01618 L
.14655 .01687 L
.14775 .01738 L
.14839 .01759 L
.14898 .01774 L
.14929 .01781 L
.14962 .01787 L
.1498 .01789 L
.14997 .01792 L
.15014 .01793 L
.15031 .01794 L
.15046 .01795 L
.1506 .01796 L
.15074 .01796 L
.15087 .01796 L
.15102 .01796 L
.15117 .01796 L
.15132 .01795 L
.15149 .01794 L
.15179 .01791 L
Mistroke
.15208 .01787 L
.15273 .01774 L
.15333 .01758 L
.15398 .01735 L
.15517 .01683 L
.1574 .01557 L
.15804 .01516 L
.15836 .01496 L
.1585 .01487 L
.15865 .01477 L
.15878 .01475 L
.15891 .01483 L
.15919 .01501 L
.15978 .01539 L
.16107 .0162 L
.1623 .01687 L
.16348 .0174 L
.1641 .01763 L
.16476 .01782 L
.16531 .01794 L
.16562 .01799 L
.16592 .01802 L
.16605 .01804 L
.16619 .01805 L
.16631 .01805 L
.16644 .01806 L
.16657 .01806 L
.16672 .01807 L
.16687 .01806 L
.16699 .01806 L
.16714 .01805 L
.16727 .01805 L
.16742 .01803 L
.16758 .01802 L
.1679 .01797 L
.1682 .01792 L
.16876 .01779 L
.1693 .01764 L
.1705 .01716 L
.17181 .01649 L
.17304 .01575 L
.17364 .01536 L
.17419 .01499 L
.17435 .01489 L
.1745 .01479 L
.17465 .01475 L
.17474 .0148 L
.17483 .01486 L
.17551 .01533 L
.17672 .01611 L
Mistroke
.17795 .01683 L
.17928 .01747 L
.17989 .0177 L
.18054 .01791 L
.1811 .01804 L
.18141 .01809 L
.18171 .01813 L
.18185 .01815 L
.182 .01816 L
.18215 .01817 L
.18228 .01818 L
.18243 .01819 L
.18252 .01819 L
.1826 .01819 L
.18274 .01819 L
.1829 .01818 L
.18304 .01818 L
.1832 .01816 L
.18335 .01815 L
.18349 .01813 L
.18383 .01809 L
.18415 .01803 L
.1847 .01789 L
.18521 .01773 L
.18638 .01726 L
.18865 .01596 L
.18928 .01555 L
.18993 .01509 L
.1902 .01491 L
.19035 .0148 L
.19049 .01473 L
.19057 .01478 L
.19066 .01484 L
.19081 .01495 L
.19111 .01516 L
.19245 .01607 L
.1937 .01684 L
.19495 .01749 L
.19557 .01775 L
.19613 .01795 L
.19669 .01811 L
.19722 .01822 L
.19751 .01827 L
.19778 .0183 L
.19793 .01831 L
.19807 .01832 L
.19815 .01833 L
.19824 .01833 L
.19839 .01833 L
.19854 .01833 L
Mistroke
.19869 .01833 L
.19885 .01832 L
.19894 .01832 L
.19902 .01831 L
.19918 .0183 L
.19936 .01828 L
.19969 .01823 L
.19999 .01817 L
.2003 .0181 L
.20088 .01793 L
.20201 .01748 L
.20322 .01684 L
.20437 .01612 L
.20543 .01538 L
.20599 .01498 L
.20615 .01486 L
.2063 .01475 L
.20644 .01478 L
.20658 .01489 L
.20785 .0158 L
.20906 .01662 L
.21039 .0174 L
.21099 .01769 L
.21163 .01797 L
.21218 .01816 L
.21279 .01832 L
.21314 .01839 L
.21331 .01842 L
.21347 .01845 L
.21362 .01846 L
.21378 .01848 L
.21387 .01849 L
.21395 .01849 L
.21403 .0185 L
.21411 .0185 L
.21426 .0185 L
.21439 .01851 L
.21448 .0185 L
.21456 .0185 L
.2147 .0185 L
.21486 .01849 L
.215 .01848 L
.21532 .01844 L
.21562 .01839 L
.21589 .01833 L
.21649 .01817 L
.21702 .01799 L
.21758 .01776 L
.22007 .01631 L
.22122 .01548 L
Mistroke
.22155 .01523 L
.22187 .01499 L
.222 .01488 L
.22215 .01477 L
.22231 .01478 L
.22245 .01489 L
.22467 .01654 L
.22581 .01728 L
.22703 .01793 L
.22763 .01819 L
.22819 .01838 L
.22869 .01852 L
.22898 .01858 L
.22924 .01863 L
.22952 .01867 L
.22967 .01868 L
.22983 .01869 L
.22996 .0187 L
.23009 .01871 L
.23023 .01871 L
.23037 .01871 L
.23046 .01871 L
.23054 .0187 L
.23062 .0187 L
.23071 .01869 L
.23086 .01868 L
.23103 .01866 L
.23134 .01862 L
.23162 .01856 L
.23226 .01839 L
.23284 .01819 L
.23416 .01756 L
.23536 .01681 L
.23664 .01587 L
.23726 .01538 L
.23757 .01514 L
.23785 .01491 L
.23798 .0148 L
.23811 .01472 L
.23824 .01483 L
.23838 .01494 L
.23895 .01541 L
.24131 .01719 L
.24248 .0179 L
.24356 .01842 L
.24413 .01862 L
.24473 .01879 L
.24505 .01885 L
.24534 .0189 L
.24551 .01892 L
Mistroke
.24566 .01893 L
.24574 .01894 L
.24583 .01894 L
.24593 .01895 L
.24601 .01895 L
.24615 .01895 L
.2463 .01895 L
.24645 .01894 L
.24658 .01893 L
.2467 .01892 L
.24683 .01891 L
.24709 .01887 L
.24738 .01882 L
.24769 .01875 L
.24825 .01858 L
.24888 .01833 L
.24947 .01805 L
.25081 .01724 L
.25197 .01638 L
.25323 .01535 L
.25355 .01507 L
.25373 .01492 L
.25382 .01484 L
.2539 .01478 L
.25404 .01477 L
.25419 .0149 L
.25451 .01518 L
.25571 .0162 L
.25796 .01787 L
.25854 .01822 L
.25916 .01854 L
.25969 .01877 L
.26026 .01897 L
.26059 .01906 L
.26088 .01912 L
.26118 .01917 L
.26132 .01919 L
.26146 .01921 L
.26161 .01922 L
.2617 .01923 L
.26178 .01923 L
.26193 .01924 L
.26208 .01924 L
.26217 .01924 L
.26226 .01923 L
.26235 .01923 L
.26244 .01922 L
.2626 .01921 L
.26277 .01919 L
.26308 .01914 L
Mistroke
.26341 .01907 L
.264 .01889 L
.26463 .01864 L
.26533 .01829 L
.26776 .01657 L
.26889 .01558 L
.26946 .01506 L
.26962 .01492 L
.26971 .01484 L
.26979 .01476 L
.26995 .01481 L
.27009 .01494 L
.2714 .01615 L
.2726 .01718 L
.27377 .01806 L
.27502 .01881 L
.27553 .01905 L
.27607 .01927 L
.27639 .01936 L
.27668 .01944 L
.27697 .01949 L
.27724 .01954 L
.27739 .01955 L
.27747 .01956 L
.27755 .01957 L
.27771 .01957 L
.27785 .01958 L
.27798 .01958 L
.27811 .01957 L
.27825 .01957 L
.2784 .01955 L
.27856 .01954 L
.27873 .01951 L
.27904 .01945 L
.27935 .01938 L
.27963 .01929 L
.28071 .01884 L
.28125 .01853 L
.28185 .01815 L
.28309 .01719 L
.28438 .01602 L
.28492 .0155 L
.28521 .01521 L
.28549 .01494 L
.28565 .01478 L
.28574 .01474 L
.28582 .01482 L
.28612 .01512 L
.2867 .0157 L
.28912 .01792 L
Mistroke
.2903 .01879 L
.29137 .01939 L
.29193 .01963 L
.29247 .0198 L
.29276 .01987 L
.29303 .01992 L
.29317 .01993 L
.29332 .01995 L
.2934 .01996 L
.29349 .01996 L
.29364 .01997 L
.2938 .01997 L
.29394 .01997 L
.29403 .01997 L
.2941 .01996 L
.29419 .01996 L
.29427 .01995 L
.29444 .01993 L
.29459 .01991 L
.29494 .01983 L
.29521 .01976 L
.29552 .01966 L
.29613 .01941 L
.29735 .0187 L
.29847 .01783 L
.29978 .01662 L
.30041 .01597 L
.30099 .01536 L
.30126 .01506 L
.30141 .01491 L
.30156 .01474 L
.30169 .01483 L
.30184 .01499 L
.3021 .01527 L
.30328 .01653 L
.30459 .01782 L
.30578 .01884 L
.30636 .01925 L
.30699 .01964 L
.30753 .01992 L
.30813 .02015 L
.30846 .02025 L
.30877 .02032 L
.30894 .02035 L
.30909 .02037 L
.30926 .02039 L
.30935 .02039 L
.30944 .0204 L
.3096 .0204 L
.30975 .0204 L
Mistroke
.30983 .0204 L
.30991 .0204 L
.31007 .02038 L
.31022 .02037 L
.31037 .02035 L
.31065 .02029 L
.31096 .02021 L
.31125 .02012 L
.31179 .01989 L
.31238 .01958 L
.31302 .01917 L
.31522 .01721 L
.31645 .01588 L
.31674 .01555 L
.31705 .01519 L
.31731 .01489 L
.31746 .01472 L
.3176 .01488 L
.31824 .01562 L
.31893 .01641 L
.32013 .01772 L
.3214 .01891 L
.32259 .01981 L
.32311 .02012 L
.32367 .02038 L
.32395 .02049 L
.32427 .02059 L
.32456 .02066 L
.32483 .02071 L
.32497 .02073 L
.32513 .02075 L
.32527 .02075 L
.3254 .02076 L
.32555 .02076 L
.32564 .02075 L
.32572 .02075 L
.32587 .02074 L
.32602 .02072 L
.32617 .0207 L
.32633 .02067 L
.32662 .0206 L
.32696 .02049 L
.32727 .02037 L
.32842 .01973 L
.3295 .01889 L
.3317 .01665 L
.3323 .01595 L
.33262 .01557 L
.33295 .01518 L
.33309 .01501 L
Mistroke
.33324 .01482 L
.33333 .01472 L
.33341 .0148 L
.33356 .01499 L
.33412 .01566 L
.33651 .01824 L
.33781 .01933 L
.33839 .01972 L
.33904 .02006 L
.33933 .02018 L
.33964 .02029 L
.33991 .02037 L
.34021 .02043 L
.34038 .02046 L
.34047 .02047 L
.34054 .02048 L
.34069 .02049 L
.34078 .0205 L
.34086 .0205 L
.34101 .0205 L
.34114 .0205 L
.34129 .02049 L
.34145 .02048 L
.34159 .02046 L
.34171 .02044 L
.342 .02038 L
.34226 .02031 L
.34251 .02023 L
.34307 .02 L
.34367 .01967 L
.34481 .01889 L
.34606 .01781 L
.34738 .01652 L
.34796 .01594 L
.3486 .01531 L
.34888 .01503 L
.34904 .01488 L
.34918 .01473 L
.34932 .01482 L
.34947 .01496 L
.34973 .0152 L
.35093 .01619 L
.35157 .01663 L
.35224 .01702 L
.35281 .01728 L
.35312 .0174 L
.35345 .0175 L
.35377 .01759 L
.35408 .01765 L
.35437 .01769 L
Mistroke
.35453 .01771 L
.35467 .01772 L
.35482 .01773 L
.35495 .01773 L
.3551 .01774 L
.35525 .01774 L
.35539 .01774 L
.35551 .01773 L
.35565 .01773 L
.35579 .01772 L
.35831 .01763 L
.35948 .0178 L
.36011 .01794 L
.36071 .01805 L
.36087 .01807 L
.36102 .01809 L
.3611 .0181 L
.36119 .01811 L
.36135 .01812 L
.36145 .01812 L
.36153 .01812 L
.36163 .01812 L
.36172 .01811 L
.36181 .0181 L
.36189 .01809 L
.36206 .01806 L
.36221 .01803 L
.36235 .01799 L
.36267 .01786 L
.36298 .01768 L
.36331 .01743 L
.36363 .01712 L
.36393 .01677 L
.3646 .01571 L
.36475 .01542 L
.36491 .01509 L
.36506 .01476 L
.3652 .015 L
.36534 .01537 L
.3655 .01578 L
.36583 .01675 L
.36693 .02093 L
.36813 .02739 L
.36936 .03646 L
.37049 .04706 L
.37302 .07997 L
.37533 .12181 L
.37784 .17943 L
.38277 .32022 L
.38752 .46162 L
Mistroke
.38991 .52167 L
.39209 .56432 L
.39329 .58165 L
.39385 .58799 L
.39444 .59357 L
.39476 .59614 L
.39506 .59814 L
.39536 .59984 L
.39564 .6011 L
.39597 .60223 L
.39614 .60266 L
.39622 .60284 L
.39632 .603 L
.39647 .6032 L
.39662 .6033 L
.39671 .60332 L
.3968 .60331 L
.39695 .60323 L
.39709 .60308 L
.39724 .60284 L
.39738 .60254 L
.39751 .6022 L
.39781 .60118 L
.39812 .59976 L
.39871 .5961 L
.39936 .59066 L
.40051 .5774 L
.40158 .56117 L
.40405 .51111 L
.4063 .45369 L
.41112 .31169 L
.41577 .18256 L
.41812 .12899 L
.42071 .0823 L
.42189 .0653 L
.42317 .05005 L
.42436 .03842 L
.42547 .02978 L
.42669 .02235 L
.42732 .01931 L
.42766 .0179 L
.42802 .01652 L
.42818 .01598 L
.42834 .01544 L
.42848 .015 L
.42863 .01489 L
.42877 .01529 L
.42892 .01571 L
.4292 .0164 L
.42985 .01778 L
Mistroke
.43045 .01874 L
.43105 .01945 L
.43135 .01972 L
.43168 .01995 L
.43201 .02013 L
.4322 .02021 L
.43237 .02026 L
.43253 .0203 L
.43261 .02032 L
.4327 .02034 L
.43279 .02035 L
.43287 .02036 L
.43302 .02037 L
.43317 .02037 L
.43325 .02037 L
.43333 .02037 L
.43348 .02035 L
.43362 .02034 L
.43378 .02031 L
.43393 .02028 L
.43427 .02019 L
.43488 .01997 L
.43545 .01971 L
.44007 .01713 L
.44241 .01586 L
.44305 .01551 L
.44374 .01512 L
.44406 .01494 L
.44423 .01484 L
.44432 .01479 L
.44439 .01474 L
.44453 .01476 L
.44468 .01485 L
.44499 .01503 L
.44746 .0164 L
.44854 .01692 L
.44973 .01739 L
.45027 .01756 L
.45085 .01771 L
.45117 .01777 L
.45147 .01782 L
.45176 .01786 L
.45191 .01787 L
.45204 .01788 L
.4522 .01789 L
.45235 .0179 L
.4525 .0179 L
.45259 .0179 L
.45267 .0179 L
.4528 .0179 L
Mistroke
.45295 .01789 L
.4531 .01789 L
.45324 .01787 L
.45357 .01784 L
.45388 .0178 L
.45422 .01773 L
.45455 .01766 L
.45572 .01729 L
.45696 .01673 L
.45918 .01545 L
.45976 .01507 L
.46005 .01489 L
.46019 .0148 L
.46032 .01472 L
.46046 .01481 L
.46062 .01491 L
.46095 .01513 L
.46154 .0155 L
.46374 .01677 L
.46495 .01731 L
.46553 .01752 L
.46606 .01767 L
.46664 .01781 L
.46695 .01786 L
.46728 .0179 L
.46745 .01792 L
.46763 .01794 L
.46771 .01794 L
.4678 .01794 L
.46796 .01795 L
.46811 .01795 L
.46825 .01795 L
.4684 .01795 L
.46849 .01795 L
.46857 .01794 L
.46873 .01793 L
.46887 .01792 L
.46914 .01789 L
.46944 .01785 L
.46975 .01779 L
.47033 .01766 L
.47085 .0175 L
.47206 .01704 L
.47335 .0164 L
.47449 .01576 L
.47511 .01538 L
.47571 .01501 L
.47597 .01485 L
.47612 .01476 L
.47626 .01476 L
Mistroke
.47634 .0148 L
.47642 .01486 L
.47657 .01495 L
.47686 .01513 L
.47792 .01575 L
.47916 .01642 L
.48032 .01695 L
.48153 .01737 L
.48218 .01753 L
.48254 .0176 L
.48286 .01765 L
.48314 .01768 L
.4833 .0177 L
.48344 .01771 L
.4836 .01772 L
.48368 .01772 L
.48376 .01772 L
.48391 .01773 L
.48406 .01773 L
.48421 .01773 L
.48434 .01772 L
.48449 .01771 L
.48463 .0177 L
.48489 .01768 L
.48517 .01765 L
.48547 .0176 L
.4858 .01754 L
.48647 .01738 L
.48767 .01698 L
.48898 .01641 L
.49022 .01577 L
.49133 .01514 L
.49164 .01496 L
.4918 .01487 L
.49196 .01477 L
.49211 .01474 L
.49227 .01483 L
.49254 .01499 L
.49478 .01621 L
.49605 .01678 L
.49666 .01701 L
.49723 .0172 L
.49779 .01735 L
.49839 .01748 L
.49873 .01753 L
.49903 .01757 L
.49933 .0176 L
.49948 .01761 L
.49964 .01761 L
.49972 .01762 L
Mistroke
.49981 .01762 L
.49989 .01762 L
.49997 .01762 L
.50012 .01762 L
.50027 .01762 L
.50036 .01761 L
.50046 .01761 L
.50063 .0176 L
.5008 .01758 L
.50095 .01757 L
.50155 .01749 L
.50185 .01743 L
.50218 .01736 L
.50341 .01699 L
.50454 .01653 L
.50585 .01589 L
.50642 .01558 L
.50706 .01522 L
.50733 .01506 L
.50763 .01489 L
.50777 .01481 L
.50792 .01473 L
.50804 .01477 L
.50817 .01485 L
.50936 .01553 L
.51067 .01624 L
.51186 .0168 L
.51245 .01703 L
.51308 .01725 L
.51363 .01741 L
.51423 .01755 L
.51454 .01761 L
.51487 .01765 L
.51505 .01768 L
.51522 .01769 L
.51539 .01771 L
.51554 .01772 L
.51569 .01772 L
.51584 .01773 L
.51593 .01773 L
.51601 .01773 L
.51616 .01773 L
.51631 .01772 L
.51645 .01771 L
.5166 .0177 L
.51675 .01769 L
.51706 .01766 L
.51735 .01762 L
.5179 .01751 L
.51849 .01736 L
Mistroke
.51913 .01716 L
.52134 .01616 L
.52257 .01547 L
.52318 .0151 L
.52344 .01494 L
.52359 .01485 L
.52373 .01476 L
.52387 .01475 L
.52401 .01484 L
.52431 .01502 L
.52494 .01541 L
.52626 .01619 L
.5275 .01684 L
.52815 .01713 L
.52884 .0174 L
.52945 .0176 L
.53011 .01776 L
.5304 .01782 L
.53071 .01787 L
.53101 .01791 L
.53128 .01793 L
.53142 .01794 L
.53155 .01795 L
.5317 .01795 L
.53185 .01795 L
.53201 .01795 L
.53209 .01795 L
.53217 .01795 L
.53233 .01794 L
.53247 .01793 L
.53275 .0179 L
.533 .01787 L
.53357 .01776 L
.53419 .0176 L
.53486 .01738 L
.53608 .01686 L
.53847 .0155 L
.53905 .01512 L
.53937 .01492 L
.53953 .01481 L
.53968 .01472 L
.53976 .01477 L
.53985 .01482 L
.54004 .01495 L
.54037 .01516 L
.54101 .01557 L
.54225 .01631 L
.54359 .017 L
.54421 .01726 L
.54486 .01749 L
Mistroke
.54542 .01765 L
.54603 .01778 L
.54633 .01783 L
.54649 .01785 L
.54666 .01787 L
.54681 .01788 L
.54688 .01788 L
.54697 .01789 L
.54712 .0179 L
.54726 .0179 L
.54739 .0179 L
.54754 .0179 L
.5477 .0179 L
.54784 .01789 L
.54798 .01788 L
.5481 .01787 L
.54838 .01784 L
.5487 .01779 L
.549 .01774 L
.54968 .01758 L
.5509 .01716 L
.55317 .01607 L
.55447 .01534 L
.55477 .01517 L
.55509 .01499 L
.55524 .0149 L
.55539 .01481 L
.55552 .01474 L
.55566 .01477 L
.5558 .01486 L
.55596 .01495 L
.55623 .0151 L
.55686 .01546 L
.558 .01609 L
.56052 .01746 L
.56293 .01883 L
.56397 .01942 L
.56511 .01996 L
.56542 .02008 L
.56574 .02019 L
.56602 .02027 L
.56618 .0203 L
.56632 .02033 L
.56647 .02035 L
.56661 .02036 L
.56676 .02037 L
.56684 .02037 L
.56692 .02037 L
.56706 .02036 L
.56718 .02035 L
Mistroke
.56733 .02033 L
.56747 .0203 L
.56762 .02027 L
.56778 .02022 L
.5681 .02007 L
.5684 .0199 L
.56868 .01969 L
.56932 .01905 L
.56967 .01857 L
.57 .01805 L
.57058 .01692 L
.57089 .01618 L
.57119 .0154 L
.57131 .01505 L
.57144 .01476 L
.57159 .0152 L
.57172 .01562 L
.5723 .01772 L
.57349 .02332 L
.5748 .03167 L
.57604 .04203 L
.57716 .05372 L
.57969 .08862 L
.582 .13156 L
.58451 .18951 L
.58944 .32867 L
.59419 .46699 L
.59658 .52545 L
.59876 .56677 L
.59996 .58341 L
.60052 .58945 L
.60111 .59472 L
.60143 .59712 L
.60173 .59896 L
.60203 .6005 L
.60231 .60163 L
.60247 .60213 L
.60264 .60258 L
.60281 .60293 L
.6029 .60307 L
.60299 .60318 L
.60307 .60325 L
.60315 .60329 L
.6033 .60332 L
.60345 .60326 L
.60354 .60318 L
.60362 .60308 L
.60377 .60285 L
.60392 .60253 L
.60418 .60176 L
Mistroke
.60447 .60062 L
.60479 .59903 L
.60535 .59527 L
.60588 .59075 L
.60708 .57676 L
.60836 .55655 L
.61094 .50161 L
.61337 .43642 L
.61802 .29619 L
.62037 .22729 L
.62296 .15987 L
.62544 .10655 L
.62771 .06909 L
.63006 .04155 L
.63136 .03086 L
.63258 .02331 L
.63375 .01819 L
.63433 .01626 L
.63449 .0158 L
.63467 .01534 L
.63475 .01513 L
.63483 .01493 L
.63498 .01485 L
.63512 .01516 L
.63525 .01542 L
.63553 .01595 L
.63604 .01673 L
.63633 .01708 L
.63664 .01739 L
.63693 .01762 L
.6372 .01779 L
.63748 .01793 L
.63764 .01798 L
.63779 .01803 L
.63792 .01806 L
.63805 .01808 L
.6382 .0181 L
.63834 .01811 L
.63842 .01812 L
.6385 .01812 L
.63859 .01812 L
.63868 .01812 L
.63883 .01811 L
.63892 .0181 L
.639 .01809 L
.63929 .01805 L
.63959 .018 L
.64023 .01786 L
.64058 .01779 L
.64091 .01773 L
Mistroke
.64121 .01768 L
.64149 .01765 L
.64164 .01764 L
.6418 .01762 L
.64196 .01762 L
.64205 .01761 L
.64213 .01761 L
.64221 .01761 L
.64229 .01761 L
.64244 .01761 L
.64259 .01762 L
.64272 .01762 L
.64303 .01764 L
.64336 .01766 L
.64369 .01769 L
.64405 .01771 L
.64422 .01772 L
.64438 .01773 L
.64453 .01774 L
.64462 .01774 L
.64469 .01774 L
.64484 .01774 L
.64499 .01774 L
.64511 .01773 L
.64525 .01772 L
.6454 .01771 L
.64556 .0177 L
.64585 .01766 L
.64616 .0176 L
.64645 .01753 L
.64712 .01731 L
.64821 .01677 L
.64937 .01596 L
.64998 .01546 L
.6503 .01517 L
.65047 .01502 L
.65064 .01486 L
.6508 .01472 L
.65088 .0148 L
.65096 .01487 L
.65125 .01515 L
.65182 .01572 L
.65439 .01821 L
.65555 .01916 L
.65617 .01958 L
.65681 .01994 L
.65713 .02009 L
.65748 .02022 L
.6578 .02033 L
.65809 .0204 L
Mistroke
.65839 .02046 L
.65855 .02048 L
.65871 .02049 L
.65885 .0205 L
.65898 .0205 L
.65913 .0205 L
.65929 .0205 L
.65942 .02048 L
.65955 .02047 L
.65969 .02045 L
.65984 .02042 L
.66008 .02037 L
.66035 .02029 L
.66096 .02006 L
.66153 .01976 L
.6628 .01886 L
.66399 .01775 L
.66506 .0166 L
.66567 .0159 L
.66596 .01555 L
.66624 .01523 L
.66637 .01506 L
.66653 .01488 L
.66667 .01472 L
.6668 .01487 L
.66741 .0156 L
.66865 .01704 L
.66972 .01817 L
.67087 .01921 L
.67154 .0197 L
.67215 .02008 L
.67273 .02037 L
.67303 .02048 L
.67335 .02059 L
.67364 .02066 L
.6739 .02071 L
.67403 .02073 L
.67417 .02074 L
.6743 .02075 L
.67442 .02076 L
.67456 .02076 L
.67469 .02076 L
.67483 .02075 L
.67499 .02073 L
.67514 .02072 L
.6753 .02069 L
.67559 .02063 L
.6759 .02054 L
.6762 .02044 L
.67675 .02019 L
Mistroke
.67798 .01942 L
.67904 .01852 L
.68019 .01738 L
.68143 .016 L
.68204 .0153 L
.6823 .01499 L
.68245 .01481 L
.68259 .01478 L
.68274 .01494 L
.68289 .01512 L
.68318 .01545 L
.6838 .01616 L
.68513 .01757 L
.68638 .01871 L
.68703 .0192 L
.68772 .01964 L
.68833 .01995 L
.68865 .02008 L
.68899 .0202 L
.68931 .02028 L
.68959 .02034 L
.68973 .02036 L
.68988 .02038 L
.69002 .02039 L
.69016 .0204 L
.69031 .0204 L
.69045 .0204 L
.69058 .0204 L
.69072 .02039 L
.69087 .02038 L
.69103 .02035 L
.69132 .0203 L
.69162 .02023 L
.69189 .02014 L
.69241 .01994 L
.69304 .01963 L
.69361 .01928 L
.6949 .01828 L
.69717 .01605 L
.69779 .01539 L
.69813 .01502 L
.69822 .01493 L
.6983 .01483 L
.69846 .01476 L
.6986 .01492 L
.69876 .01509 L
.69909 .01544 L
.69966 .01604 L
.70089 .01726 L
.70219 .01836 L
Mistroke
.7033 .01911 L
.70393 .01944 L
.70451 .01967 L
.7048 .01977 L
.70512 .01985 L
.70526 .01988 L
.70542 .01991 L
.70555 .01993 L
.70569 .01994 L
.70583 .01996 L
.70596 .01997 L
.70608 .01997 L
.7062 .01997 L
.70634 .01997 L
.70647 .01997 L
.70661 .01996 L
.70677 .01994 L
.70693 .01992 L
.70708 .0199 L
.70742 .01983 L
.70771 .01975 L
.70803 .01964 L
.70917 .01911 L
.71032 .01836 L
.71155 .01736 L
.7127 .01629 L
.71376 .01524 L
.71391 .01509 L
.71407 .01493 L
.71422 .01478 L
.71436 .01478 L
.7145 .01493 L
.71466 .01509 L
.71499 .01541 L
.71633 .01668 L
.7175 .01767 L
.71875 .01854 L
.7194 .01889 L
.72 .01916 L
.72055 .01935 L
.72086 .01943 L
.72114 .01949 L
.72127 .01951 L
.7214 .01953 L
.72152 .01955 L
.72165 .01956 L
.7218 .01957 L
.72195 .01957 L
.72209 .01958 L
.72222 .01958 L
Mistroke
.72235 .01957 L
.72248 .01956 L
.72262 .01955 L
.72277 .01953 L
.72307 .01949 L
.72336 .01943 L
.72393 .01927 L
.72454 .01903 L
.72563 .01845 L
.72694 .01754 L
.72813 .01656 L
.72925 .01555 L
.72982 .01503 L
.72997 .01489 L
.73006 .01481 L
.73014 .01473 L
.7303 .01484 L
.73044 .01497 L
.73174 .01615 L
.73295 .01714 L
.7341 .01795 L
.73474 .01833 L
.73534 .01863 L
.7359 .01885 L
.73619 .01895 L
.7365 .01904 L
.73676 .0191 L
.73705 .01916 L
.73718 .01918 L
.73731 .0192 L
.73744 .01921 L
.73755 .01922 L
.7377 .01923 L
.73778 .01923 L
.73786 .01924 L
.73795 .01924 L
.73804 .01924 L
.73819 .01923 L
.73834 .01923 L
.73847 .01922 L
.73862 .0192 L
.73878 .01918 L
.73914 .01912 L
.73948 .01904 L
.74012 .01884 L
.74072 .01859 L
.74128 .01832 L
.74254 .01754 L
.74481 .01577 L
.74543 .01524 L
Mistroke
.74559 .01509 L
.74577 .01494 L
.74585 .01487 L
.74594 .01479 L
.74609 .01477 L
.74618 .01484 L
.74626 .01492 L
.74642 .01505 L
.74672 .01531 L
.7473 .01579 L
.74966 .01755 L
.75031 .01793 L
.751 .01828 L
.75165 .01855 L
.75225 .01873 L
.75255 .01881 L
.75287 .01887 L
.75318 .01891 L
.75336 .01893 L
.75345 .01894 L
.75353 .01894 L
.75369 .01895 L
.75384 .01895 L
.75398 .01895 L
.75412 .01894 L
.7542 .01894 L
.75428 .01894 L
.75442 .01892 L
.75458 .01891 L
.75475 .01889 L
.75502 .01884 L
.75532 .01878 L
.75593 .0186 L
.7565 .01839 L
.75702 .01816 L
.75947 .01663 L
.76056 .0158 L
.76115 .01532 L
.76144 .01509 L
.76171 .01487 L
.76184 .01476 L
.76198 .01478 L
.76213 .01489 L
.76228 .01502 L
.76291 .01552 L
.76401 .01637 L
.76532 .01725 L
.76651 .01791 L
.7671 .01817 L
.76773 .01839 L
Mistroke
.76802 .01848 L
.76833 .01855 L
.76861 .01861 L
.76888 .01865 L
.76902 .01867 L
.76918 .01868 L
.76926 .01869 L
.76934 .0187 L
.7695 .0187 L
.76965 .01871 L
.76978 .01871 L
.76994 .01871 L
.77008 .0187 L
.77016 .0187 L
.77024 .01869 L
.77041 .01867 L
.77072 .01864 L
.77107 .01857 L
.7714 .0185 L
.77201 .01832 L
.77267 .01807 L
.77386 .01747 L
.7761 .01599 L
.77665 .01558 L
.77724 .01513 L
.7774 .015 L
.77757 .01487 L
.77772 .01476 L
.7778 .01473 L
.77788 .01479 L
.77849 .01526 L
.77979 .01621 L
.78102 .01702 L
.78221 .01766 L
.78283 .01793 L
.78349 .01817 L
.78405 .01832 L
.78437 .01839 L
.78466 .01843 L
.7848 .01845 L
.78493 .01847 L
.78505 .01848 L
.78518 .01849 L
.78532 .0185 L
.78545 .0185 L
.78558 .0185 L
.78574 .0185 L
.78588 .0185 L
.78602 .01849 L
.78617 .01848 L
Mistroke
.78633 .01847 L
.78665 .01843 L
.78695 .01838 L
.78752 .01824 L
.78806 .01808 L
.78927 .01757 L
.79058 .01685 L
.79181 .01604 L
.79297 .01521 L
.79327 .01499 L
.79342 .01489 L
.79355 .01479 L
.79371 .01476 L
.79379 .01482 L
.79388 .01488 L
.79418 .0151 L
.79551 .01604 L
.79675 .01682 L
.79809 .01753 L
.79871 .01778 L
.79936 .01801 L
.79991 .01815 L
.80023 .01822 L
.80052 .01826 L
.80067 .01828 L
.80084 .0183 L
.80098 .01831 L
.80113 .01832 L
.80121 .01833 L
.80129 .01833 L
.80144 .01833 L
.80152 .01833 L
.80161 .01833 L
.8017 .01833 L
.80178 .01833 L
.80194 .01832 L
.80209 .01831 L
.80222 .0183 L
.80236 .01828 L
.80268 .01824 L
.80298 .01818 L
.80349 .01806 L
.80406 .01789 L
.80522 .01741 L
.80652 .01671 L
.80776 .01593 L
.80887 .01517 L
.80917 .01496 L
.80934 .01484 L
.8095 .01473 L
Mistroke
.80964 .0148 L
.8098 .01491 L
.81008 .0151 L
.81231 .01656 L
.81358 .01724 L
.8142 .01751 L
.81476 .01772 L
.81532 .0179 L
.81593 .01804 L
.81626 .0181 L
.81641 .01812 L
.81657 .01814 L
.81671 .01816 L
.81686 .01817 L
.81694 .01817 L
.81702 .01818 L
.81717 .01818 L
.81732 .01819 L
.81748 .01819 L
.81763 .01818 L
.81776 .01818 L
.81785 .01817 L
.81792 .01817 L
.8181 .01816 L
.81841 .01812 L
.81871 .01807 L
.81904 .01801 L
.81971 .01783 L
.82035 .01762 L
.82094 .01737 L
.82206 .01682 L
.82329 .0161 L
.82396 .01568 L
.82459 .01526 L
.82513 .01489 L
.82528 .01479 L
.82544 .01474 L
.82558 .01484 L
.82573 .01494 L
.82698 .01576 L
.8292 .01703 L
.82984 .01732 L
.83044 .01755 L
.83099 .01773 L
.83157 .01787 L
.83187 .01794 L
.8322 .01799 L
.83234 .01801 L
.8325 .01803 L
.83264 .01804 L
Mistroke
.83278 .01805 L
.83287 .01805 L
.83295 .01806 L
.83304 .01806 L
.83313 .01806 L
.83321 .01807 L
.8333 .01807 L
.83339 .01807 L
.83346 .01806 L
.83361 .01806 L
.83369 .01805 L
.83377 .01805 L
.83393 .01804 L
.83409 .01802 L
.8344 .01798 L
.83473 .01793 L
.83532 .0178 L
.83596 .01761 L
.83666 .01735 L
.83908 .0161 L
.84022 .0154 L
.84052 .0152 L
.84084 .01499 L
.841 .01489 L
.84114 .0148 L
.84128 .01472 L
.84142 .01481 L
.84205 .01522 L
.84273 .01565 L
.84393 .01637 L
.84517 .017 L
.84633 .01747 L
.84692 .01765 L
.84754 .0178 L
.8479 .01786 L
.84824 .01791 L
.84838 .01792 L
.84854 .01794 L
.84863 .01794 L
.84871 .01795 L
.84887 .01796 L
.84902 .01796 L
.84915 .01796 L
.8493 .01796 L
.84939 .01796 L
.84946 .01796 L
.84962 .01795 L
.84978 .01794 L
.84994 .01792 L
.85009 .01791 L
Mistroke
.85063 .01783 L
.8509 .01777 L
.8512 .0177 L
.8525 .01728 L
.85371 .01674 L
.85496 .01606 L
.85615 .01534 L
.85667 .01501 L
.85681 .01493 L
.85695 .01483 L
.85709 .01475 L
.85722 .01476 L
.85738 .01486 L
.85754 .01496 L
.85783 .01515 L
.85839 .01549 L
.85962 .01621 L
.86078 .01681 L
.86192 .01729 L
.86297 .01761 L
.86351 .01773 L
.86379 .01778 L
.86409 .01782 L
.86424 .01784 L
.8644 .01785 L
.86457 .01786 L
.86472 .01787 L
.86487 .01787 L
.86501 .01788 L
.86516 .01788 L
.86524 .01787 L
.86532 .01787 L
.86548 .01786 L
.86555 .01786 L
.86564 .01785 L
.86594 .01783 L
.86611 .01781 L
.86629 .01778 L
.86661 .01772 L
.86725 .01758 L
.86784 .0174 L
.86903 .01694 L
.87013 .01641 L
.87142 .01569 L
.87205 .01531 L
.87233 .01514 L
.87263 .01495 L
.87278 .01486 L
.87293 .01476 L
.87308 .01475 L
Mistroke
.87321 .01484 L
.87383 .01521 L
.87511 .01597 L
.8762 .01655 L
.87736 .01707 L
.87793 .01728 L
.87856 .01747 L
.87913 .01761 L
.87966 .01771 L
.87997 .01775 L
.88014 .01777 L
.88029 .01778 L
.88043 .01779 L
.88057 .0178 L
.88073 .0178 L
.88087 .0178 L
.88095 .0178 L
.88104 .0178 L
.88119 .0178 L
.88128 .0178 L
.88136 .01779 L
.88154 .01778 L
.8817 .01777 L
.88184 .01775 L
.88217 .01771 L
.88275 .0176 L
.88336 .01745 L
.88447 .01708 L
.88565 .01655 L
.88697 .01585 L
.8881 .01519 L
.88838 .01502 L
.88867 .01484 L
.88876 .01479 L
.88884 .01474 L
.889 .01478 L
.88914 .01487 L
.8893 .01496 L
.89061 .01573 L
.89181 .01638 L
.89305 .01695 L
.89421 .01736 L
.89479 .01751 L
.89541 .01763 L
.89577 .01768 L
.89594 .0177 L
.89611 .01772 L
.89625 .01773 L
.89641 .01774 L
.8965 .01774 L
Mistroke
.89658 .01774 L
.89674 .01775 L
.89688 .01775 L
.89703 .01774 L
.89717 .01774 L
.8973 .01773 L
.89745 .01772 L
.89762 .01771 L
.89792 .01767 L
.89823 .01762 L
.89857 .01756 L
.89916 .01742 L
.90022 .01708 L
.90139 .01658 L
.90253 .016 L
.90373 .01533 L
.90435 .01496 L
.90452 .01486 L
.90462 .0148 L
.90471 .01475 L
.90479 .01473 L
.90488 .01479 L
.90504 .01488 L
.90624 .01558 L
.90864 .01679 L
.90985 .01724 L
.91054 .01744 L
.91087 .01751 L
.91118 .01757 L
.91149 .01762 L
.91178 .01765 L
.91193 .01767 L
.9121 .01768 L
.91219 .01769 L
.91227 .01769 L
.91235 .01769 L
.91243 .0177 L
.91258 .0177 L
.91271 .0177 L
.91287 .0177 L
.91301 .01769 L
.91316 .01769 L
.91333 .01768 L
.91363 .01765 L
.91389 .01761 L
.91419 .01757 L
.91479 .01744 L
.91534 .01729 L
.91586 .01713 L
.9183 .01604 L
Mistroke
.91938 .01544 L
.91997 .0151 L
.92027 .01493 L
.92039 .01486 L
.92053 .01477 L
.92068 .01474 L
.92083 .01483 L
.92116 .01502 L
.92172 .01535 L
.92282 .01596 L
.92413 .0166 L
.92532 .01708 L
.9259 .01727 L
.92653 .01743 L
.92682 .01749 L
.92712 .01755 L
.92741 .01759 L
.92767 .01762 L
.92781 .01763 L
.92797 .01764 L
.92812 .01765 L
.92821 .01766 L
.92829 .01766 L
.92844 .01766 L
.92857 .01766 L
.92872 .01766 L
.92887 .01766 L
.92895 .01766 L
.92903 .01765 L
.9292 .01764 L
.9295 .01761 L
.92986 .01757 L
.93019 .01751 L
.93079 .01738 L
.93145 .0172 L
.93264 .01675 L
.93487 .01565 L
.93551 .01529 L
.93583 .01511 L
.93612 .01494 L
.93638 .01479 L
.93652 .01472 L
.93666 .0148 L
.93725 .01514 L
.93857 .01588 L
.93978 .01648 L
.94091 .01696 L
.9415 .01716 L
.94213 .01734 L
.94245 .01742 L
Mistroke
.94281 .01749 L
.94313 .01754 L
.94343 .01758 L
.94373 .01761 L
.94389 .01762 L
.94398 .01763 L
.94406 .01763 L
.94421 .01764 L
.94435 .01764 L
.94443 .01764 L
.94451 .01764 L
.94466 .01764 L
.9448 .01763 L
.94495 .01763 L
.94509 .01762 L
.94522 .01761 L
.94553 .01757 L
.94583 .01753 L
.94643 .01742 L
.94707 .01725 L
.94823 .01685 L
.9493 .01639 L
.95058 .01573 L
.95121 .01539 L
.95178 .01506 L
.95205 .0149 L
.95219 .01483 L
.95231 .01476 L
.95244 .01475 L
.95257 .01482 L
.95286 .01499 L
.95403 .01565 L
.95634 .01677 L
.95697 .01701 L
.95764 .01723 L
.95827 .01739 L
.95884 .0175 L
.95912 .01755 L
.95942 .01758 L
.95956 .01759 L
.95971 .01761 L
.95985 .01761 L
.95998 .01762 L
.96014 .01762 L
.96028 .01763 L
.96044 .01762 L
.96052 .01762 L
.96061 .01762 L
.96075 .01761 L
.96091 .01761 L
Mistroke
.96106 .01759 L
.9612 .01758 L
.96174 .01751 L
.96205 .01746 L
.96233 .0174 L
.96341 .0171 L
.96457 .01665 L
.96566 .01614 L
.96687 .0155 L
.96753 .01513 L
.96785 .01495 L
.96799 .01487 L
.96814 .01478 L
.96829 .01474 L
.96843 .01482 L
.9687 .01497 L
.9693 .01531 L
.97057 .016 L
.97173 .01656 L
.97281 .01699 L
.97358 .01724 L
.97442 .01744 L
.97465 .01749 L
.97489 .01753 L
.97511 .01755 L
.97534 .01758 L
.97546 .01759 L
.97557 .0176 L
.97568 .01761 L
.97578 .01761 L
.97588 .01762 L
.97598 .01762 L
.97608 .01762 L
.97619 .01762 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Magnitude plot of DFT as a function of frequency", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(fft\  = \ DFT[xdc];\)\), "\n", 
    \(\(g3 = 
        DiscreteListPlot[\({#[\([1]\)], \ Abs[#[\([2]\)]]} &\)\  /@ \ fft, 
          Red, \ PlotRange \[Rule] All, \ Frame \[Rule] True, \ 
          Axes \[Rule] False];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0161421 0.0147151 0.0443004 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18523 -0.0125 -6 -9 ]
[.18523 -0.0125 6 0 ]
[.34665 -0.0125 -6 -9 ]
[.34665 -0.0125 6 0 ]
[.50807 -0.0125 -6 -9 ]
[.50807 -0.0125 6 0 ]
[.66949 -0.0125 -6 -9 ]
[.66949 -0.0125 6 0 ]
[.83091 -0.0125 -6 -9 ]
[.83091 -0.0125 6 0 ]
[.99233 -0.0125 -6 -9 ]
[.99233 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .10332 -6 -4.5 ]
[-0.0125 .10332 0 4.5 ]
[-0.0125 .19192 -6 -4.5 ]
[-0.0125 .19192 0 4.5 ]
[-0.0125 .28052 -6 -4.5 ]
[-0.0125 .28052 0 4.5 ]
[-0.0125 .36912 -6 -4.5 ]
[-0.0125 .36912 0 4.5 ]
[-0.0125 .45772 -12 -4.5 ]
[-0.0125 .45772 0 4.5 ]
[-0.0125 .54632 -12 -4.5 ]
[-0.0125 .54632 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18523 0 m
.18523 .00625 L
s
[(10)] .18523 -0.0125 0 1 Mshowa
.34665 0 m
.34665 .00625 L
s
[(20)] .34665 -0.0125 0 1 Mshowa
.50807 0 m
.50807 .00625 L
s
[(30)] .50807 -0.0125 0 1 Mshowa
.66949 0 m
.66949 .00625 L
s
[(40)] .66949 -0.0125 0 1 Mshowa
.83091 0 m
.83091 .00625 L
s
[(50)] .83091 -0.0125 0 1 Mshowa
.99233 0 m
.99233 .00625 L
s
[(60)] .99233 -0.0125 0 1 Mshowa
.125 Mabswid
.05609 0 m
.05609 .00375 L
s
.08838 0 m
.08838 .00375 L
s
.12066 0 m
.12066 .00375 L
s
.15295 0 m
.15295 .00375 L
s
.21751 0 m
.21751 .00375 L
s
.2498 0 m
.2498 .00375 L
s
.28208 0 m
.28208 .00375 L
s
.31437 0 m
.31437 .00375 L
s
.37893 0 m
.37893 .00375 L
s
.41122 0 m
.41122 .00375 L
s
.4435 0 m
.4435 .00375 L
s
.47579 0 m
.47579 .00375 L
s
.54036 0 m
.54036 .00375 L
s
.57264 0 m
.57264 .00375 L
s
.60492 0 m
.60492 .00375 L
s
.63721 0 m
.63721 .00375 L
s
.70178 0 m
.70178 .00375 L
s
.73406 0 m
.73406 .00375 L
s
.76634 0 m
.76634 .00375 L
s
.79863 0 m
.79863 .00375 L
s
.8632 0 m
.8632 .00375 L
s
.89548 0 m
.89548 .00375 L
s
.92776 0 m
.92776 .00375 L
s
.96005 0 m
.96005 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .10332 m
.00625 .10332 L
s
[(2)] -0.0125 .10332 1 0 Mshowa
0 .19192 m
.00625 .19192 L
s
[(4)] -0.0125 .19192 1 0 Mshowa
0 .28052 m
.00625 .28052 L
s
[(6)] -0.0125 .28052 1 0 Mshowa
0 .36912 m
.00625 .36912 L
s
[(8)] -0.0125 .36912 1 0 Mshowa
0 .45772 m
.00625 .45772 L
s
[(10)] -0.0125 .45772 1 0 Mshowa
0 .54632 m
.00625 .54632 L
s
[(12)] -0.0125 .54632 1 0 Mshowa
.125 Mabswid
0 .03687 m
.00375 .03687 L
s
0 .05902 m
.00375 .05902 L
s
0 .08117 m
.00375 .08117 L
s
0 .12547 m
.00375 .12547 L
s
0 .14762 m
.00375 .14762 L
s
0 .16977 m
.00375 .16977 L
s
0 .21407 m
.00375 .21407 L
s
0 .23622 m
.00375 .23622 L
s
0 .25837 m
.00375 .25837 L
s
0 .30267 m
.00375 .30267 L
s
0 .32482 m
.00375 .32482 L
s
0 .34697 m
.00375 .34697 L
s
0 .39127 m
.00375 .39127 L
s
0 .41342 m
.00375 .41342 L
s
0 .43557 m
.00375 .43557 L
s
0 .47987 m
.00375 .47987 L
s
0 .50202 m
.00375 .50202 L
s
0 .52417 m
.00375 .52417 L
s
0 .56847 m
.00375 .56847 L
s
0 .59062 m
.00375 .59062 L
s
0 .61277 m
.00375 .61277 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.18523 .61178 m
.18523 .61803 L
s
.34665 .61178 m
.34665 .61803 L
s
.50807 .61178 m
.50807 .61803 L
s
.66949 .61178 m
.66949 .61803 L
s
.83091 .61178 m
.83091 .61803 L
s
.99233 .61178 m
.99233 .61803 L
s
.125 Mabswid
.05609 .61428 m
.05609 .61803 L
s
.08838 .61428 m
.08838 .61803 L
s
.12066 .61428 m
.12066 .61803 L
s
.15295 .61428 m
.15295 .61803 L
s
.21751 .61428 m
.21751 .61803 L
s
.2498 .61428 m
.2498 .61803 L
s
.28208 .61428 m
.28208 .61803 L
s
.31437 .61428 m
.31437 .61803 L
s
.37893 .61428 m
.37893 .61803 L
s
.41122 .61428 m
.41122 .61803 L
s
.4435 .61428 m
.4435 .61803 L
s
.47579 .61428 m
.47579 .61803 L
s
.54036 .61428 m
.54036 .61803 L
s
.57264 .61428 m
.57264 .61803 L
s
.60492 .61428 m
.60492 .61803 L
s
.63721 .61428 m
.63721 .61803 L
s
.70178 .61428 m
.70178 .61803 L
s
.73406 .61428 m
.73406 .61803 L
s
.76634 .61428 m
.76634 .61803 L
s
.79863 .61428 m
.79863 .61803 L
s
.8632 .61428 m
.8632 .61803 L
s
.89548 .61428 m
.89548 .61803 L
s
.92776 .61428 m
.92776 .61803 L
s
.96005 .61428 m
.96005 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .10332 m
1 .10332 L
s
.99375 .19192 m
1 .19192 L
s
.99375 .28052 m
1 .28052 L
s
.99375 .36912 m
1 .36912 L
s
.99375 .45772 m
1 .45772 L
s
.99375 .54632 m
1 .54632 L
s
.125 Mabswid
.99625 .03687 m
1 .03687 L
s
.99625 .05902 m
1 .05902 L
s
.99625 .08117 m
1 .08117 L
s
.99625 .12547 m
1 .12547 L
s
.99625 .14762 m
1 .14762 L
s
.99625 .16977 m
1 .16977 L
s
.99625 .21407 m
1 .21407 L
s
.99625 .23622 m
1 .23622 L
s
.99625 .25837 m
1 .25837 L
s
.99625 .30267 m
1 .30267 L
s
.99625 .32482 m
1 .32482 L
s
.99625 .34697 m
1 .34697 L
s
.99625 .39127 m
1 .39127 L
s
.99625 .41342 m
1 .41342 L
s
.99625 .43557 m
1 .43557 L
s
.99625 .47987 m
1 .47987 L
s
.99625 .50202 m
1 .50202 L
s
.99625 .52417 m
1 .52417 L
s
.99625 .56847 m
1 .56847 L
s
.99625 .59062 m
1 .59062 L
s
.99625 .61277 m
1 .61277 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .01472 m
.02381 .01826 L
s
.03995 .01472 m
.03995 .01839 L
s
.05609 .01472 m
.05609 .01866 L
s
.07224 .01472 m
.07224 .0186 L
s
.08838 .01472 m
.08838 .02013 L
s
.10452 .01472 m
.10452 .09851 L
s
.12066 .01472 m
.12066 .59911 L
s
.1368 .01472 m
.1368 .60332 L
s
.15295 .01472 m
.15295 .09426 L
s
.16909 .01472 m
.16909 .01827 L
s
.18523 .01472 m
.18523 .02176 L
s
.20137 .01472 m
.20137 .02208 L
s
.21751 .01472 m
.21751 .02165 L
s
.23366 .01472 m
.23366 .02113 L
s
.2498 .01472 m
.2498 .02064 L
s
.26594 .01472 m
.26594 .02023 L
s
.28208 .01472 m
.28208 .01988 L
s
.29822 .01472 m
.29822 .01958 L
s
.31437 .01472 m
.31437 .01934 L
s
.33051 .01472 m
.33051 .01913 L
s
.34665 .01472 m
.34665 .01895 L
s
.36279 .01472 m
.36279 .0188 L
s
.37893 .01472 m
.37893 .01868 L
s
.39508 .01472 m
.39508 .01857 L
s
.41122 .01472 m
.41122 .01848 L
s
.42736 .01472 m
.42736 .01841 L
s
.4435 .01472 m
.4435 .01836 L
s
.45964 .01472 m
.45964 .01831 L
s
.47579 .01472 m
.47579 .01828 L
s
.49193 .01472 m
.49193 .01827 L
s
.50807 .01472 m
.50807 .01826 L
s
.52421 .01472 m
.52421 .01827 L
s
.54036 .01472 m
.54036 .01828 L
s
.5565 .01472 m
.5565 .01831 L
s
.57264 .01472 m
.57264 .01836 L
s
.58878 .01472 m
.58878 .01841 L
s
.60492 .01472 m
.60492 .01848 L
s
.62107 .01472 m
.62107 .01857 L
s
.63721 .01472 m
.63721 .01868 L
s
.65335 .01472 m
.65335 .0188 L
s
.66949 .01472 m
.66949 .01895 L
s
.68563 .01472 m
.68563 .01913 L
s
.70178 .01472 m
.70178 .01934 L
s
.71792 .01472 m
.71792 .01958 L
s
.73406 .01472 m
.73406 .01988 L
s
.7502 .01472 m
.7502 .02023 L
s
.76634 .01472 m
.76634 .02064 L
s
.78249 .01472 m
.78249 .02113 L
s
.79863 .01472 m
.79863 .02165 L
s
.81477 .01472 m
.81477 .02208 L
s
.83091 .01472 m
.83091 .02176 L
s
.84705 .01472 m
.84705 .01827 L
s
.8632 .01472 m
.8632 .09426 L
s
.87934 .01472 m
.87934 .60332 L
s
.89548 .01472 m
.89548 .59911 L
s
.91162 .01472 m
.91162 .09851 L
s
.92776 .01472 m
.92776 .02013 L
s
.94391 .01472 m
.94391 .0186 L
s
.96005 .01472 m
.96005 .01866 L
s
.97619 .01472 m
.97619 .01839 L
s
.015 w
.02381 .01826 Mdot
.03995 .01839 Mdot
.05609 .01866 Mdot
.07224 .0186 Mdot
.08838 .02013 Mdot
.10452 .09851 Mdot
.12066 .59911 Mdot
.1368 .60332 Mdot
.15295 .09426 Mdot
.16909 .01827 Mdot
.18523 .02176 Mdot
.20137 .02208 Mdot
.21751 .02165 Mdot
.23366 .02113 Mdot
.2498 .02064 Mdot
.26594 .02023 Mdot
.28208 .01988 Mdot
.29822 .01958 Mdot
.31437 .01934 Mdot
.33051 .01913 Mdot
.34665 .01895 Mdot
.36279 .0188 Mdot
.37893 .01868 Mdot
.39508 .01857 Mdot
.41122 .01848 Mdot
.42736 .01841 Mdot
.4435 .01836 Mdot
.45964 .01831 Mdot
.47579 .01828 Mdot
.49193 .01827 Mdot
.50807 .01826 Mdot
.52421 .01827 Mdot
.54036 .01828 Mdot
.5565 .01831 Mdot
.57264 .01836 Mdot
.58878 .01841 Mdot
.60492 .01848 Mdot
.62107 .01857 Mdot
.63721 .01868 Mdot
.65335 .0188 Mdot
.66949 .01895 Mdot
.68563 .01913 Mdot
.70178 .01934 Mdot
.71792 .01958 Mdot
.73406 .01988 Mdot
.7502 .02023 Mdot
.76634 .02064 Mdot
.78249 .02113 Mdot
.79863 .02165 Mdot
.81477 .02208 Mdot
.83091 .02176 Mdot
.84705 .01827 Mdot
.8632 .09426 Mdot
.87934 .60332 Mdot
.89548 .59911 Mdot
.91162 .09851 Mdot
.92776 .02013 Mdot
.94391 .0186 Mdot
.96005 .01866 Mdot
.97619 .01839 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Rearrange and scale DFT result", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(g5 = 
        DiscreteListPlot[FourierRearrange[Abs[Last\  /@ \ fft], fs], Red, 
          PlotRange \[Rule] All, ImageSize \[Rule] 504, \ 
          Frame \[Rule] True, \ Axes \[Rule] False, \ 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(g6\  = \ Show[g1, g5];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.047619 0.0147151 0.0363327 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .10555 -18 -4.5 ]
[-0.0125 .10555 0 4.5 ]
[-0.0125 .19638 -6 -4.5 ]
[-0.0125 .19638 0 4.5 ]
[-0.0125 .28721 -18 -4.5 ]
[-0.0125 .28721 0 4.5 ]
[-0.0125 .37804 -12 -4.5 ]
[-0.0125 .37804 0 4.5 ]
[-0.0125 .46887 -24 -4.5 ]
[-0.0125 .46887 0 4.5 ]
[-0.0125 .5597 -12 -4.5 ]
[-0.0125 .5597 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .10555 m
.00625 .10555 L
s
[(2.5)] -0.0125 .10555 1 0 Mshowa
0 .19638 m
.00625 .19638 L
s
[(5)] -0.0125 .19638 1 0 Mshowa
0 .28721 m
.00625 .28721 L
s
[(7.5)] -0.0125 .28721 1 0 Mshowa
0 .37804 m
.00625 .37804 L
s
[(10)] -0.0125 .37804 1 0 Mshowa
0 .46887 m
.00625 .46887 L
s
[(12.5)] -0.0125 .46887 1 0 Mshowa
0 .5597 m
.00625 .5597 L
s
[(15)] -0.0125 .5597 1 0 Mshowa
.125 Mabswid
0 .03288 m
.00375 .03288 L
s
0 .05105 m
.00375 .05105 L
s
0 .06921 m
.00375 .06921 L
s
0 .08738 m
.00375 .08738 L
s
0 .12371 m
.00375 .12371 L
s
0 .14188 m
.00375 .14188 L
s
0 .16005 m
.00375 .16005 L
s
0 .17821 m
.00375 .17821 L
s
0 .21454 m
.00375 .21454 L
s
0 .23271 m
.00375 .23271 L
s
0 .25088 m
.00375 .25088 L
s
0 .26904 m
.00375 .26904 L
s
0 .30538 m
.00375 .30538 L
s
0 .32354 m
.00375 .32354 L
s
0 .34171 m
.00375 .34171 L
s
0 .35988 m
.00375 .35988 L
s
0 .39621 m
.00375 .39621 L
s
0 .41437 m
.00375 .41437 L
s
0 .43254 m
.00375 .43254 L
s
0 .45071 m
.00375 .45071 L
s
0 .48704 m
.00375 .48704 L
s
0 .50521 m
.00375 .50521 L
s
0 .52337 m
.00375 .52337 L
s
0 .54154 m
.00375 .54154 L
s
0 .57787 m
.00375 .57787 L
s
0 .59604 m
.00375 .59604 L
s
0 .6142 m
.00375 .6142 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .10555 m
1 .10555 L
s
.99375 .19638 m
1 .19638 L
s
.99375 .28721 m
1 .28721 L
s
.99375 .37804 m
1 .37804 L
s
.99375 .46887 m
1 .46887 L
s
.99375 .5597 m
1 .5597 L
s
.125 Mabswid
.99625 .03288 m
1 .03288 L
s
.99625 .05105 m
1 .05105 L
s
.99625 .06921 m
1 .06921 L
s
.99625 .08738 m
1 .08738 L
s
.99625 .12371 m
1 .12371 L
s
.99625 .14188 m
1 .14188 L
s
.99625 .16005 m
1 .16005 L
s
.99625 .17821 m
1 .17821 L
s
.99625 .21454 m
1 .21454 L
s
.99625 .23271 m
1 .23271 L
s
.99625 .25088 m
1 .25088 L
s
.99625 .26904 m
1 .26904 L
s
.99625 .30538 m
1 .30538 L
s
.99625 .32354 m
1 .32354 L
s
.99625 .34171 m
1 .34171 L
s
.99625 .35988 m
1 .35988 L
s
.99625 .39621 m
1 .39621 L
s
.99625 .41437 m
1 .41437 L
s
.99625 .43254 m
1 .43254 L
s
.99625 .45071 m
1 .45071 L
s
.99625 .48704 m
1 .48704 L
s
.99625 .50521 m
1 .50521 L
s
.99625 .52337 m
1 .52337 L
s
.99625 .54154 m
1 .54154 L
s
.99625 .57787 m
1 .57787 L
s
.99625 .59604 m
1 .59604 L
s
.99625 .6142 m
1 .6142 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
0 0 1 r
.5 Mabswid
[ .01 ] 0 setdash
.02381 .01762 m
.02395 .01762 L
.02408 .01762 L
.02423 .01761 L
.02437 .0176 L
.02462 .01758 L
.02489 .01756 L
.02519 .01751 L
.02551 .01746 L
.02608 .01733 L
.02722 .01699 L
.02847 .01647 L
.02973 .01584 L
.03043 .01546 L
.03109 .01509 L
.03139 .01492 L
.03155 .01483 L
.03171 .01474 L
.03179 .01474 L
.03189 .0148 L
.03205 .01489 L
.03238 .01508 L
.03355 .01573 L
.03596 .01687 L
.03717 .01727 L
.03785 .01744 L
.03819 .0175 L
.0385 .01755 L
.03879 .01758 L
.03894 .01759 L
.0391 .01761 L
.03918 .01761 L
.03926 .01762 L
.03941 .01762 L
.03949 .01762 L
.03958 .01763 L
.03967 .01763 L
.03976 .01763 L
.03991 .01762 L
.04006 .01762 L
.04019 .01761 L
.04033 .0176 L
.04065 .01757 L
.04095 .01754 L
.04147 .01745 L
.04204 .01732 L
.04319 .01696 L
.04573 .01578 L
.04631 .01546 L
.04694 .01511 L
Mistroke
.04724 .01493 L
.04739 .01485 L
.04752 .01477 L
.04765 .01473 L
.04778 .01481 L
.04805 .01497 L
.0492 .01562 L
.05046 .01627 L
.05165 .01681 L
.05274 .01719 L
.05332 .01736 L
.05388 .01748 L
.05417 .01753 L
.05447 .01757 L
.05463 .01759 L
.0548 .01761 L
.05495 .01762 L
.05511 .01763 L
.05525 .01764 L
.0554 .01764 L
.05553 .01764 L
.05566 .01764 L
.05581 .01764 L
.05595 .01763 L
.0561 .01762 L
.05625 .01761 L
.05652 .01759 L
.05676 .01756 L
.05732 .01747 L
.05789 .01734 L
.05849 .01716 L
.05959 .01676 L
.06208 .01552 L
.06267 .01519 L
.063 .015 L
.0633 .01482 L
.06346 .01473 L
.06355 .01475 L
.06363 .0148 L
.064 .01501 L
.06464 .01538 L
.06589 .01606 L
.06706 .01663 L
.06826 .0171 L
.06878 .01727 L
.06934 .01741 L
.06967 .01749 L
.06996 .01754 L
.07027 .01759 L
.07055 .01762 L
Mistroke
.07071 .01763 L
.07085 .01765 L
.07101 .01765 L
.07109 .01766 L
.07118 .01766 L
.07126 .01766 L
.07134 .01767 L
.07149 .01767 L
.07159 .01766 L
.07167 .01766 L
.07175 .01766 L
.07184 .01766 L
.07199 .01765 L
.07213 .01764 L
.07243 .01761 L
.07272 .01757 L
.07299 .01753 L
.07359 .0174 L
.07425 .01722 L
.07557 .01674 L
.07679 .01616 L
.07787 .01558 L
.07844 .01525 L
.07904 .01491 L
.07919 .01482 L
.07928 .01477 L
.07936 .01472 L
.07945 .01477 L
.07954 .01482 L
.07971 .01492 L
.08032 .01527 L
.08152 .01595 L
.0827 .01654 L
.08394 .01706 L
.085 .01739 L
.0856 .01753 L
.08588 .01758 L
.08617 .01762 L
.08633 .01764 L
.08648 .01766 L
.08663 .01767 L
.08677 .01768 L
.08693 .01769 L
.08702 .0177 L
.08711 .0177 L
.08726 .0177 L
.08734 .0177 L
.08742 .0177 L
.08758 .0177 L
.08772 .01769 L
Mistroke
.08786 .01768 L
.088 .01767 L
.08832 .01764 L
.08861 .0176 L
.08913 .01751 L
.0897 .01738 L
.09085 .017 L
.09339 .01579 L
.09397 .01546 L
.09459 .0151 L
.09489 .01492 L
.09504 .01483 L
.09518 .01475 L
.0953 .01475 L
.09543 .01483 L
.09571 .01499 L
.09685 .01566 L
.0981 .01634 L
.0993 .01689 L
.10038 .01729 L
.10097 .01746 L
.10153 .01758 L
.10181 .01763 L
.10211 .01768 L
.10227 .0177 L
.10244 .01771 L
.10259 .01773 L
.10275 .01774 L
.10289 .01774 L
.10304 .01775 L
.10317 .01775 L
.1033 .01775 L
.10345 .01774 L
.10358 .01774 L
.10374 .01773 L
.10389 .01772 L
.10416 .01769 L
.1044 .01766 L
.10496 .01757 L
.10552 .01743 L
.10613 .01725 L
.10722 .01683 L
.10971 .01555 L
.1103 .0152 L
.11063 .01501 L
.11093 .01482 L
.11102 .01477 L
.11111 .01472 L
.1112 .01477 L
.1113 .01483 L
Mistroke
.11162 .01502 L
.11226 .01541 L
.11343 .01608 L
.11469 .01671 L
.11593 .01723 L
.11652 .01742 L
.11706 .01756 L
.1176 .01767 L
.11789 .01772 L
.1182 .01776 L
.11832 .01777 L
.11846 .01778 L
.11858 .01779 L
.11871 .0178 L
.11885 .0178 L
.119 .01781 L
.11914 .01781 L
.11927 .0178 L
.11943 .0178 L
.1195 .01779 L
.11959 .01779 L
.11988 .01777 L
.12005 .01775 L
.12022 .01773 L
.12054 .01768 L
.12117 .01754 L
.12174 .01739 L
.12289 .01696 L
.12399 .01645 L
.12515 .01582 L
.12578 .01545 L
.12638 .01509 L
.12663 .01493 L
.12676 .01485 L
.12689 .01477 L
.12703 .01474 L
.12718 .01483 L
.12744 .015 L
.1286 .0157 L
.13086 .0169 L
.13148 .01716 L
.13213 .0174 L
.1327 .01757 L
.13331 .01771 L
.13364 .01777 L
.13394 .01781 L
.13408 .01783 L
.13424 .01785 L
.13439 .01786 L
.13453 .01787 L
Mistroke
.13462 .01787 L
.13471 .01787 L
.13479 .01788 L
.13487 .01788 L
.13495 .01788 L
.13504 .01788 L
.13514 .01788 L
.13523 .01787 L
.13531 .01787 L
.13539 .01787 L
.13554 .01786 L
.1357 .01784 L
.13588 .01783 L
.13617 .01779 L
.13649 .01773 L
.13714 .01759 L
.13774 .01741 L
.13831 .01721 L
.14074 .01601 L
.14182 .01537 L
.14211 .01519 L
.14241 .015 L
.14255 .01491 L
.1427 .01481 L
.14283 .01473 L
.14297 .01479 L
.14313 .01489 L
.14329 .01499 L
.14359 .01518 L
.14416 .01553 L
.14526 .01619 L
.14655 .01687 L
.14775 .01738 L
.14839 .01759 L
.14898 .01775 L
.14929 .01781 L
.14962 .01787 L
.1498 .0179 L
.14997 .01792 L
.15014 .01793 L
.15031 .01795 L
.15046 .01795 L
.1506 .01796 L
.15074 .01796 L
.15087 .01796 L
.15102 .01796 L
.15117 .01796 L
.15132 .01795 L
.15149 .01794 L
.15179 .01791 L
Mistroke
.15208 .01787 L
.15273 .01774 L
.15333 .01758 L
.15398 .01735 L
.15517 .01684 L
.1574 .01557 L
.15804 .01516 L
.15836 .01496 L
.1585 .01487 L
.15865 .01477 L
.15878 .01475 L
.15891 .01483 L
.15919 .01501 L
.15978 .01539 L
.16107 .0162 L
.1623 .01687 L
.16348 .0174 L
.1641 .01763 L
.16476 .01782 L
.16531 .01794 L
.16562 .01799 L
.16592 .01802 L
.16605 .01804 L
.16619 .01805 L
.16631 .01806 L
.16644 .01806 L
.16657 .01807 L
.16672 .01807 L
.16687 .01807 L
.16699 .01806 L
.16714 .01806 L
.16727 .01805 L
.16742 .01803 L
.16758 .01802 L
.1679 .01798 L
.1682 .01792 L
.16876 .0178 L
.1693 .01764 L
.1705 .01717 L
.17181 .01649 L
.17304 .01575 L
.17364 .01536 L
.17419 .015 L
.17435 .01489 L
.1745 .01479 L
.17465 .01475 L
.17474 .01481 L
.17483 .01487 L
.17551 .01533 L
.17672 .01611 L
Mistroke
.17795 .01683 L
.17928 .01747 L
.17989 .0177 L
.18054 .01791 L
.1811 .01804 L
.18141 .01809 L
.18171 .01814 L
.18185 .01815 L
.182 .01817 L
.18215 .01818 L
.18228 .01818 L
.18243 .01819 L
.18252 .01819 L
.1826 .01819 L
.18274 .01819 L
.1829 .01818 L
.18304 .01818 L
.1832 .01816 L
.18335 .01815 L
.18349 .01814 L
.18383 .01809 L
.18415 .01803 L
.1847 .01789 L
.18521 .01773 L
.18638 .01726 L
.18865 .01596 L
.18928 .01555 L
.18993 .0151 L
.1902 .01491 L
.19035 .0148 L
.19049 .01473 L
.19057 .01478 L
.19066 .01484 L
.19081 .01495 L
.19111 .01516 L
.19245 .01607 L
.1937 .01684 L
.19495 .01749 L
.19557 .01775 L
.19613 .01795 L
.19669 .01811 L
.19722 .01822 L
.19751 .01827 L
.19778 .0183 L
.19793 .01831 L
.19807 .01832 L
.19815 .01833 L
.19824 .01833 L
.19839 .01833 L
.19854 .01833 L
Mistroke
.19869 .01833 L
.19885 .01832 L
.19894 .01832 L
.19902 .01831 L
.19918 .0183 L
.19936 .01828 L
.19969 .01823 L
.19999 .01818 L
.2003 .0181 L
.20088 .01793 L
.20201 .01748 L
.20322 .01684 L
.20437 .01612 L
.20543 .01538 L
.20599 .01498 L
.20615 .01486 L
.2063 .01475 L
.20644 .01478 L
.20658 .01489 L
.20785 .0158 L
.20906 .01662 L
.21039 .0174 L
.21099 .0177 L
.21163 .01797 L
.21218 .01816 L
.21279 .01832 L
.21314 .0184 L
.21331 .01842 L
.21347 .01845 L
.21362 .01846 L
.21378 .01848 L
.21387 .01849 L
.21395 .01849 L
.21403 .0185 L
.21411 .0185 L
.21426 .01851 L
.21439 .01851 L
.21448 .01851 L
.21456 .0185 L
.2147 .0185 L
.21486 .01849 L
.215 .01848 L
.21532 .01844 L
.21562 .01839 L
.21589 .01834 L
.21649 .01817 L
.21702 .01799 L
.21758 .01776 L
.22007 .01631 L
.22122 .01548 L
Mistroke
.22155 .01523 L
.22187 .01499 L
.222 .01488 L
.22215 .01477 L
.22231 .01478 L
.22245 .01489 L
.22467 .01654 L
.22581 .01728 L
.22703 .01793 L
.22763 .01819 L
.22819 .01838 L
.22869 .01852 L
.22898 .01858 L
.22924 .01863 L
.22952 .01867 L
.22967 .01868 L
.22983 .0187 L
.22996 .0187 L
.23009 .01871 L
.23023 .01871 L
.23037 .01871 L
.23046 .01871 L
.23054 .0187 L
.23062 .0187 L
.23071 .01869 L
.23086 .01868 L
.23103 .01866 L
.23134 .01862 L
.23162 .01856 L
.23226 .01839 L
.23284 .01819 L
.23416 .01756 L
.23536 .01681 L
.23664 .01587 L
.23726 .01539 L
.23757 .01514 L
.23785 .01491 L
.23798 .01481 L
.23811 .01473 L
.23824 .01483 L
.23838 .01495 L
.23895 .01541 L
.24131 .01719 L
.24248 .0179 L
.24356 .01842 L
.24413 .01862 L
.24473 .01879 L
.24505 .01885 L
.24534 .0189 L
.24551 .01892 L
Mistroke
.24566 .01893 L
.24574 .01894 L
.24583 .01894 L
.24593 .01895 L
.24601 .01895 L
.24615 .01895 L
.2463 .01895 L
.24645 .01894 L
.24658 .01893 L
.2467 .01892 L
.24683 .01891 L
.24709 .01887 L
.24738 .01882 L
.24769 .01875 L
.24825 .01858 L
.24888 .01833 L
.24947 .01805 L
.25081 .01724 L
.25197 .01639 L
.25323 .01535 L
.25355 .01507 L
.25373 .01492 L
.25382 .01485 L
.2539 .01478 L
.25404 .01478 L
.25419 .01491 L
.25451 .01518 L
.25571 .0162 L
.25796 .01787 L
.25854 .01822 L
.25916 .01854 L
.25969 .01877 L
.26026 .01897 L
.26059 .01906 L
.26088 .01912 L
.26118 .01918 L
.26132 .0192 L
.26146 .01921 L
.26161 .01922 L
.2617 .01923 L
.26178 .01923 L
.26193 .01924 L
.26208 .01924 L
.26217 .01924 L
.26226 .01923 L
.26235 .01923 L
.26244 .01922 L
.2626 .01921 L
.26277 .01919 L
.26308 .01914 L
Mistroke
.26341 .01907 L
.264 .01889 L
.26463 .01864 L
.26533 .01829 L
.26776 .01658 L
.26889 .01559 L
.26946 .01506 L
.26962 .01492 L
.26971 .01484 L
.26979 .01476 L
.26995 .01481 L
.27009 .01494 L
.2714 .01615 L
.2726 .01718 L
.27377 .01807 L
.27502 .01881 L
.27553 .01906 L
.27607 .01927 L
.27639 .01936 L
.27668 .01944 L
.27697 .0195 L
.27724 .01954 L
.27739 .01955 L
.27747 .01956 L
.27755 .01957 L
.27771 .01957 L
.27785 .01958 L
.27798 .01958 L
.27811 .01957 L
.27825 .01957 L
.2784 .01955 L
.27856 .01954 L
.27873 .01951 L
.27904 .01945 L
.27935 .01938 L
.27963 .01929 L
.28071 .01884 L
.28125 .01854 L
.28185 .01815 L
.28309 .01719 L
.28438 .01602 L
.28492 .0155 L
.28521 .01521 L
.28549 .01494 L
.28565 .01478 L
.28574 .01474 L
.28582 .01482 L
.28612 .01512 L
.2867 .0157 L
.28912 .01792 L
Mistroke
.2903 .01879 L
.29137 .01939 L
.29193 .01963 L
.29247 .0198 L
.29276 .01987 L
.29303 .01992 L
.29317 .01994 L
.29332 .01995 L
.2934 .01996 L
.29349 .01997 L
.29364 .01997 L
.2938 .01997 L
.29394 .01997 L
.29403 .01997 L
.2941 .01996 L
.29419 .01996 L
.29427 .01995 L
.29444 .01993 L
.29459 .01991 L
.29494 .01984 L
.29521 .01976 L
.29552 .01966 L
.29613 .01941 L
.29735 .0187 L
.29847 .01783 L
.29978 .01662 L
.30041 .01597 L
.30099 .01536 L
.30126 .01506 L
.30141 .01491 L
.30156 .01474 L
.30169 .01483 L
.30184 .01499 L
.3021 .01527 L
.30328 .01653 L
.30459 .01782 L
.30578 .01884 L
.30636 .01925 L
.30699 .01964 L
.30753 .01992 L
.30813 .02015 L
.30846 .02025 L
.30877 .02032 L
.30894 .02035 L
.30909 .02037 L
.30926 .02039 L
.30935 .0204 L
.30944 .0204 L
.3096 .02041 L
.30975 .0204 L
Mistroke
.30983 .0204 L
.30991 .0204 L
.31007 .02039 L
.31022 .02037 L
.31037 .02035 L
.31065 .02029 L
.31096 .02021 L
.31125 .02012 L
.31179 .01989 L
.31238 .01958 L
.31302 .01917 L
.31522 .01722 L
.31645 .01588 L
.31674 .01555 L
.31705 .01519 L
.31731 .01489 L
.31746 .01472 L
.3176 .01488 L
.31824 .01562 L
.31893 .01641 L
.32013 .01772 L
.3214 .01891 L
.32259 .01981 L
.32311 .02012 L
.32367 .02038 L
.32395 .02049 L
.32427 .02059 L
.32456 .02066 L
.32483 .02071 L
.32497 .02073 L
.32513 .02075 L
.32527 .02075 L
.3254 .02076 L
.32555 .02076 L
.32564 .02075 L
.32572 .02075 L
.32587 .02074 L
.32602 .02072 L
.32617 .0207 L
.32633 .02067 L
.32662 .0206 L
.32696 .02049 L
.32727 .02037 L
.32842 .01974 L
.3295 .01889 L
.3317 .01665 L
.3323 .01595 L
.33262 .01557 L
.33295 .01518 L
.33309 .01501 L
Mistroke
.33324 .01483 L
.33333 .01472 L
.33341 .0148 L
.33356 .01499 L
.33412 .01566 L
.33651 .01824 L
.33781 .01933 L
.33839 .01972 L
.33904 .02006 L
.33933 .02018 L
.33964 .02029 L
.33991 .02037 L
.34021 .02043 L
.34038 .02046 L
.34047 .02047 L
.34054 .02048 L
.34069 .02049 L
.34078 .0205 L
.34086 .0205 L
.34101 .0205 L
.34114 .0205 L
.34129 .02049 L
.34145 .02048 L
.34159 .02046 L
.34171 .02044 L
.342 .02038 L
.34226 .02031 L
.34251 .02023 L
.34307 .02 L
.34367 .01968 L
.34481 .01889 L
.34606 .01781 L
.34738 .01652 L
.34796 .01594 L
.3486 .01531 L
.34888 .01503 L
.34904 .01488 L
.34918 .01474 L
.34932 .01482 L
.34947 .01496 L
.34973 .0152 L
.35093 .01619 L
.35157 .01663 L
.35224 .01702 L
.35281 .01728 L
.35312 .0174 L
.35345 .0175 L
.35377 .01759 L
.35408 .01765 L
.35437 .01769 L
Mistroke
.35453 .01771 L
.35467 .01772 L
.35482 .01773 L
.35495 .01774 L
.3551 .01774 L
.35525 .01774 L
.35539 .01774 L
.35551 .01774 L
.35565 .01773 L
.35579 .01772 L
.35831 .01763 L
.35948 .0178 L
.36011 .01794 L
.36071 .01805 L
.36087 .01808 L
.36102 .01809 L
.3611 .0181 L
.36119 .01811 L
.36135 .01812 L
.36145 .01812 L
.36153 .01812 L
.36163 .01812 L
.36172 .01811 L
.36181 .0181 L
.36189 .01809 L
.36206 .01806 L
.36221 .01803 L
.36235 .01799 L
.36267 .01786 L
.36298 .01768 L
.36331 .01743 L
.36363 .01712 L
.36393 .01677 L
.3646 .01571 L
.36475 .01542 L
.36491 .01509 L
.36506 .01476 L
.3652 .015 L
.36534 .01537 L
.3655 .01578 L
.36583 .01675 L
.36693 .02093 L
.36813 .02739 L
.36936 .03646 L
.37049 .04706 L
.37302 .07997 L
.37533 .12181 L
.37784 .17943 L
.38277 .32022 L
.38752 .46162 L
Mistroke
.38991 .52167 L
.39209 .56432 L
.39329 .58165 L
.39385 .58799 L
.39444 .59357 L
.39476 .59614 L
.39506 .59814 L
.39536 .59984 L
.39564 .6011 L
.39597 .60223 L
.39614 .60266 L
.39622 .60284 L
.39632 .603 L
.39647 .6032 L
.39662 .6033 L
.39671 .60332 L
.3968 .60331 L
.39695 .60323 L
.39709 .60308 L
.39724 .60284 L
.39738 .60254 L
.39751 .6022 L
.39781 .60118 L
.39812 .59976 L
.39871 .5961 L
.39936 .59066 L
.40051 .5774 L
.40158 .56117 L
.40405 .51111 L
.4063 .45369 L
.41112 .31169 L
.41577 .18256 L
.41812 .12899 L
.42071 .0823 L
.42189 .0653 L
.42317 .05005 L
.42436 .03842 L
.42547 .02978 L
.42669 .02235 L
.42732 .01931 L
.42766 .0179 L
.42802 .01652 L
.42818 .01598 L
.42834 .01544 L
.42848 .015 L
.42863 .01489 L
.42877 .0153 L
.42892 .01571 L
.4292 .0164 L
.42985 .01778 L
Mistroke
.43045 .01874 L
.43105 .01945 L
.43135 .01972 L
.43168 .01995 L
.43201 .02013 L
.4322 .02021 L
.43237 .02026 L
.43253 .02031 L
.43261 .02032 L
.4327 .02034 L
.43279 .02035 L
.43287 .02036 L
.43302 .02037 L
.43317 .02037 L
.43325 .02037 L
.43333 .02037 L
.43348 .02035 L
.43362 .02034 L
.43378 .02031 L
.43393 .02028 L
.43427 .02019 L
.43488 .01997 L
.43545 .01971 L
.44007 .01714 L
.44241 .01586 L
.44305 .01551 L
.44374 .01512 L
.44406 .01494 L
.44423 .01484 L
.44432 .01479 L
.44439 .01474 L
.44453 .01477 L
.44468 .01485 L
.44499 .01503 L
.44746 .0164 L
.44854 .01692 L
.44973 .01739 L
.45027 .01756 L
.45085 .01771 L
.45117 .01777 L
.45147 .01782 L
.45176 .01786 L
.45191 .01787 L
.45204 .01788 L
.4522 .01789 L
.45235 .0179 L
.4525 .0179 L
.45259 .0179 L
.45267 .0179 L
.4528 .0179 L
Mistroke
.45295 .01789 L
.4531 .01789 L
.45324 .01788 L
.45357 .01784 L
.45388 .0178 L
.45422 .01773 L
.45455 .01766 L
.45572 .01729 L
.45696 .01673 L
.45918 .01545 L
.45976 .01508 L
.46005 .01489 L
.46019 .0148 L
.46032 .01472 L
.46046 .01481 L
.46062 .01491 L
.46095 .01513 L
.46154 .0155 L
.46374 .01677 L
.46495 .01731 L
.46553 .01752 L
.46606 .01768 L
.46664 .01781 L
.46695 .01786 L
.46728 .0179 L
.46745 .01792 L
.46763 .01794 L
.46771 .01794 L
.4678 .01795 L
.46796 .01795 L
.46811 .01795 L
.46825 .01795 L
.4684 .01795 L
.46849 .01795 L
.46857 .01794 L
.46873 .01793 L
.46887 .01792 L
.46914 .01789 L
.46944 .01785 L
.46975 .01779 L
.47033 .01766 L
.47085 .0175 L
.47206 .01704 L
.47335 .0164 L
.47449 .01576 L
.47511 .01538 L
.47571 .01501 L
.47597 .01485 L
.47612 .01476 L
.47626 .01476 L
Mistroke
.47634 .01481 L
.47642 .01486 L
.47657 .01495 L
.47686 .01513 L
.47792 .01575 L
.47916 .01642 L
.48032 .01695 L
.48153 .01737 L
.48218 .01753 L
.48254 .0176 L
.48286 .01765 L
.48314 .01768 L
.4833 .0177 L
.48344 .01771 L
.4836 .01772 L
.48368 .01772 L
.48376 .01772 L
.48391 .01773 L
.48406 .01773 L
.48421 .01773 L
.48434 .01772 L
.48449 .01772 L
.48463 .01771 L
.48489 .01768 L
.48517 .01765 L
.48547 .01761 L
.4858 .01754 L
.48647 .01738 L
.48767 .01698 L
.48898 .01641 L
.49022 .01577 L
.49133 .01514 L
.49164 .01496 L
.4918 .01487 L
.49196 .01478 L
.49211 .01474 L
.49227 .01483 L
.49254 .01499 L
.49478 .01621 L
.49605 .01678 L
.49666 .01702 L
.49723 .0172 L
.49779 .01735 L
.49839 .01748 L
.49873 .01753 L
.49903 .01757 L
.49933 .0176 L
.49948 .01761 L
.49964 .01761 L
.49972 .01762 L
Mistroke
.49981 .01762 L
.49989 .01762 L
.49997 .01762 L
.50012 .01762 L
.50027 .01762 L
.50036 .01761 L
.50046 .01761 L
.50063 .0176 L
.5008 .01759 L
.50095 .01757 L
.50155 .01749 L
.50185 .01743 L
.50218 .01736 L
.50341 .01699 L
.50454 .01653 L
.50585 .01589 L
.50642 .01558 L
.50706 .01522 L
.50733 .01506 L
.50763 .01489 L
.50777 .01481 L
.50792 .01473 L
.50804 .01477 L
.50817 .01485 L
.50936 .01553 L
.51067 .01624 L
.51186 .0168 L
.51245 .01703 L
.51308 .01725 L
.51363 .01741 L
.51423 .01755 L
.51454 .01761 L
.51487 .01766 L
.51505 .01768 L
.51522 .01769 L
.51539 .01771 L
.51554 .01772 L
.51569 .01772 L
.51584 .01773 L
.51593 .01773 L
.51601 .01773 L
.51616 .01773 L
.51631 .01772 L
.51645 .01772 L
.5166 .01771 L
.51675 .01769 L
.51706 .01766 L
.51735 .01762 L
.5179 .01751 L
.51849 .01736 L
Mistroke
.51913 .01716 L
.52134 .01616 L
.52257 .01547 L
.52318 .0151 L
.52344 .01494 L
.52359 .01485 L
.52373 .01476 L
.52387 .01475 L
.52401 .01484 L
.52431 .01503 L
.52494 .01541 L
.52626 .01619 L
.5275 .01684 L
.52815 .01713 L
.52884 .0174 L
.52945 .0176 L
.53011 .01776 L
.5304 .01782 L
.53071 .01787 L
.53101 .01791 L
.53128 .01793 L
.53142 .01794 L
.53155 .01795 L
.5317 .01795 L
.53185 .01795 L
.53201 .01795 L
.53209 .01795 L
.53217 .01795 L
.53233 .01794 L
.53247 .01793 L
.53275 .0179 L
.533 .01787 L
.53357 .01776 L
.53419 .01761 L
.53486 .01738 L
.53608 .01686 L
.53847 .0155 L
.53905 .01512 L
.53937 .01492 L
.53953 .01481 L
.53968 .01472 L
.53976 .01477 L
.53985 .01482 L
.54004 .01495 L
.54037 .01516 L
.54101 .01557 L
.54225 .01631 L
.54359 .017 L
.54421 .01726 L
.54486 .01749 L
Mistroke
.54542 .01765 L
.54603 .01778 L
.54633 .01783 L
.54649 .01785 L
.54666 .01787 L
.54681 .01788 L
.54688 .01788 L
.54697 .01789 L
.54712 .0179 L
.54726 .0179 L
.54739 .0179 L
.54754 .0179 L
.5477 .0179 L
.54784 .01789 L
.54798 .01788 L
.5481 .01787 L
.54838 .01784 L
.5487 .01779 L
.549 .01774 L
.54968 .01758 L
.5509 .01716 L
.55317 .01607 L
.55447 .01534 L
.55477 .01517 L
.55509 .01499 L
.55524 .0149 L
.55539 .01481 L
.55552 .01474 L
.55566 .01477 L
.5558 .01486 L
.55596 .01495 L
.55623 .0151 L
.55686 .01546 L
.558 .01609 L
.56052 .01746 L
.56293 .01883 L
.56397 .01942 L
.56511 .01996 L
.56542 .02008 L
.56574 .02019 L
.56602 .02027 L
.56618 .0203 L
.56632 .02033 L
.56647 .02035 L
.56661 .02036 L
.56676 .02037 L
.56684 .02037 L
.56692 .02037 L
.56706 .02037 L
.56718 .02035 L
Mistroke
.56733 .02033 L
.56747 .02031 L
.56762 .02027 L
.56778 .02022 L
.5681 .02008 L
.5684 .0199 L
.56868 .01969 L
.56932 .01905 L
.56967 .01857 L
.57 .01805 L
.57058 .01692 L
.57089 .01618 L
.57119 .0154 L
.57131 .01505 L
.57144 .01476 L
.57159 .0152 L
.57172 .01562 L
.5723 .01772 L
.57349 .02332 L
.5748 .03167 L
.57604 .04203 L
.57716 .05372 L
.57969 .08862 L
.582 .13156 L
.58451 .18952 L
.58944 .32867 L
.59419 .46699 L
.59658 .52545 L
.59876 .56677 L
.59996 .58341 L
.60052 .58945 L
.60111 .59472 L
.60143 .59712 L
.60173 .59896 L
.60203 .6005 L
.60231 .60163 L
.60247 .60213 L
.60264 .60258 L
.60281 .60293 L
.6029 .60307 L
.60299 .60318 L
.60307 .60325 L
.60315 .60329 L
.6033 .60332 L
.60345 .60326 L
.60354 .60318 L
.60362 .60308 L
.60377 .60285 L
.60392 .60254 L
.60418 .60176 L
Mistroke
.60447 .60062 L
.60479 .59903 L
.60535 .59527 L
.60588 .59075 L
.60708 .57676 L
.60836 .55655 L
.61094 .50161 L
.61337 .43642 L
.61802 .2962 L
.62037 .22729 L
.62296 .15987 L
.62544 .10655 L
.62771 .0691 L
.63006 .04155 L
.63136 .03086 L
.63258 .02331 L
.63375 .01819 L
.63433 .01626 L
.63449 .0158 L
.63467 .01534 L
.63475 .01514 L
.63483 .01493 L
.63498 .01485 L
.63512 .01516 L
.63525 .01542 L
.63553 .01595 L
.63604 .01673 L
.63633 .01708 L
.63664 .01739 L
.63693 .01762 L
.6372 .01779 L
.63748 .01793 L
.63764 .01798 L
.63779 .01803 L
.63792 .01806 L
.63805 .01808 L
.6382 .0181 L
.63834 .01811 L
.63842 .01812 L
.6385 .01812 L
.63859 .01812 L
.63868 .01812 L
.63883 .01811 L
.63892 .0181 L
.639 .01809 L
.63929 .01805 L
.63959 .018 L
.64023 .01786 L
.64058 .01779 L
.64091 .01773 L
Mistroke
.64121 .01768 L
.64149 .01765 L
.64164 .01764 L
.6418 .01763 L
.64196 .01762 L
.64205 .01761 L
.64213 .01761 L
.64221 .01761 L
.64229 .01761 L
.64244 .01761 L
.64259 .01762 L
.64272 .01762 L
.64303 .01764 L
.64336 .01766 L
.64369 .01769 L
.64405 .01771 L
.64422 .01772 L
.64438 .01773 L
.64453 .01774 L
.64462 .01774 L
.64469 .01774 L
.64484 .01774 L
.64499 .01774 L
.64511 .01773 L
.64525 .01773 L
.6454 .01771 L
.64556 .0177 L
.64585 .01766 L
.64616 .0176 L
.64645 .01753 L
.64712 .01731 L
.64821 .01677 L
.64937 .01596 L
.64998 .01546 L
.6503 .01517 L
.65047 .01502 L
.65064 .01486 L
.6508 .01472 L
.65088 .0148 L
.65096 .01487 L
.65125 .01515 L
.65182 .01572 L
.65439 .01821 L
.65555 .01916 L
.65617 .01958 L
.65681 .01994 L
.65713 .02009 L
.65748 .02023 L
.6578 .02033 L
.65809 .0204 L
Mistroke
.65839 .02046 L
.65855 .02048 L
.65871 .02049 L
.65885 .0205 L
.65898 .0205 L
.65913 .0205 L
.65929 .0205 L
.65942 .02049 L
.65955 .02047 L
.65969 .02045 L
.65984 .02042 L
.66008 .02037 L
.66035 .02029 L
.66096 .02006 L
.66153 .01976 L
.6628 .01886 L
.66399 .01775 L
.66506 .0166 L
.66567 .0159 L
.66596 .01555 L
.66624 .01523 L
.66637 .01507 L
.66653 .01488 L
.66667 .01472 L
.6668 .01488 L
.66741 .0156 L
.66865 .01704 L
.66972 .01817 L
.67087 .01921 L
.67154 .0197 L
.67215 .02008 L
.67273 .02037 L
.67303 .02049 L
.67335 .02059 L
.67364 .02066 L
.6739 .02071 L
.67403 .02073 L
.67417 .02074 L
.6743 .02075 L
.67442 .02076 L
.67456 .02076 L
.67469 .02076 L
.67483 .02075 L
.67499 .02074 L
.67514 .02072 L
.6753 .02069 L
.67559 .02063 L
.6759 .02054 L
.6762 .02044 L
.67675 .02019 L
Mistroke
.67798 .01942 L
.67904 .01853 L
.68019 .01738 L
.68143 .016 L
.68204 .0153 L
.6823 .01499 L
.68245 .01482 L
.68259 .01478 L
.68274 .01495 L
.68289 .01512 L
.68318 .01545 L
.6838 .01616 L
.68513 .01758 L
.68638 .01871 L
.68703 .0192 L
.68772 .01964 L
.68833 .01995 L
.68865 .02008 L
.68899 .0202 L
.68931 .02028 L
.68959 .02034 L
.68973 .02036 L
.68988 .02038 L
.69002 .02039 L
.69016 .0204 L
.69031 .02041 L
.69045 .0204 L
.69058 .0204 L
.69072 .02039 L
.69087 .02038 L
.69103 .02035 L
.69132 .0203 L
.69162 .02023 L
.69189 .02014 L
.69241 .01994 L
.69304 .01963 L
.69361 .01928 L
.6949 .01828 L
.69717 .01606 L
.69779 .01539 L
.69813 .01502 L
.69822 .01493 L
.6983 .01483 L
.69846 .01476 L
.6986 .01492 L
.69876 .01509 L
.69909 .01544 L
.69966 .01605 L
.70089 .01726 L
.70219 .01837 L
Mistroke
.7033 .01911 L
.70393 .01944 L
.70451 .01967 L
.7048 .01977 L
.70512 .01985 L
.70526 .01988 L
.70542 .01991 L
.70555 .01993 L
.70569 .01995 L
.70583 .01996 L
.70596 .01997 L
.70608 .01997 L
.7062 .01997 L
.70634 .01997 L
.70647 .01997 L
.70661 .01996 L
.70677 .01994 L
.70693 .01992 L
.70708 .0199 L
.70742 .01983 L
.70771 .01975 L
.70803 .01964 L
.70917 .01911 L
.71032 .01836 L
.71155 .01736 L
.7127 .01629 L
.71376 .01524 L
.71391 .01509 L
.71407 .01493 L
.71422 .01478 L
.71436 .01479 L
.7145 .01493 L
.71466 .01509 L
.71499 .01541 L
.71633 .01668 L
.7175 .01767 L
.71875 .01854 L
.7194 .01889 L
.72 .01916 L
.72055 .01935 L
.72086 .01943 L
.72114 .01949 L
.72127 .01951 L
.7214 .01953 L
.72152 .01955 L
.72165 .01956 L
.7218 .01957 L
.72195 .01958 L
.72209 .01958 L
.72222 .01958 L
Mistroke
.72235 .01957 L
.72248 .01956 L
.72262 .01955 L
.72277 .01954 L
.72307 .01949 L
.72336 .01943 L
.72393 .01927 L
.72454 .01903 L
.72563 .01845 L
.72694 .01754 L
.72813 .01656 L
.72925 .01556 L
.72982 .01503 L
.72997 .01489 L
.73006 .01481 L
.73014 .01473 L
.7303 .01484 L
.73044 .01498 L
.73174 .01615 L
.73295 .01714 L
.7341 .01795 L
.73474 .01833 L
.73534 .01863 L
.7359 .01885 L
.73619 .01895 L
.7365 .01904 L
.73676 .01911 L
.73705 .01916 L
.73718 .01918 L
.73731 .0192 L
.73744 .01921 L
.73755 .01922 L
.7377 .01923 L
.73778 .01923 L
.73786 .01924 L
.73795 .01924 L
.73804 .01924 L
.73819 .01923 L
.73834 .01923 L
.73847 .01922 L
.73862 .0192 L
.73878 .01918 L
.73914 .01912 L
.73948 .01904 L
.74012 .01884 L
.74072 .01859 L
.74128 .01832 L
.74254 .01754 L
.74481 .01577 L
.74543 .01524 L
Mistroke
.74559 .0151 L
.74577 .01494 L
.74585 .01487 L
.74594 .0148 L
.74609 .01477 L
.74618 .01484 L
.74626 .01492 L
.74642 .01505 L
.74672 .01531 L
.7473 .01579 L
.74966 .01755 L
.75031 .01793 L
.751 .01828 L
.75165 .01855 L
.75225 .01873 L
.75255 .01881 L
.75287 .01887 L
.75318 .01891 L
.75336 .01893 L
.75345 .01894 L
.75353 .01894 L
.75369 .01895 L
.75384 .01895 L
.75398 .01895 L
.75412 .01895 L
.7542 .01894 L
.75428 .01894 L
.75442 .01893 L
.75458 .01891 L
.75475 .01889 L
.75502 .01884 L
.75532 .01878 L
.75593 .0186 L
.7565 .0184 L
.75702 .01816 L
.75947 .01663 L
.76056 .0158 L
.76115 .01533 L
.76144 .01509 L
.76171 .01487 L
.76184 .01476 L
.76198 .01478 L
.76213 .01489 L
.76228 .01502 L
.76291 .01552 L
.76401 .01637 L
.76532 .01726 L
.76651 .01791 L
.7671 .01817 L
.76773 .01839 L
Mistroke
.76802 .01848 L
.76833 .01855 L
.76861 .01861 L
.76888 .01865 L
.76902 .01867 L
.76918 .01868 L
.76926 .01869 L
.76934 .0187 L
.7695 .0187 L
.76965 .01871 L
.76978 .01871 L
.76994 .01871 L
.77008 .0187 L
.77016 .0187 L
.77024 .01869 L
.77041 .01868 L
.77072 .01864 L
.77107 .01857 L
.7714 .0185 L
.77201 .01832 L
.77267 .01807 L
.77386 .01747 L
.7761 .01599 L
.77665 .01558 L
.77724 .01513 L
.7774 .01501 L
.77757 .01487 L
.77772 .01476 L
.7778 .01474 L
.77788 .0148 L
.77849 .01526 L
.77979 .01621 L
.78102 .01702 L
.78221 .01766 L
.78283 .01793 L
.78349 .01817 L
.78405 .01832 L
.78437 .01839 L
.78466 .01844 L
.7848 .01845 L
.78493 .01847 L
.78505 .01848 L
.78518 .01849 L
.78532 .0185 L
.78545 .0185 L
.78558 .01851 L
.78574 .01851 L
.78588 .0185 L
.78602 .0185 L
.78617 .01849 L
Mistroke
.78633 .01847 L
.78665 .01843 L
.78695 .01838 L
.78752 .01825 L
.78806 .01808 L
.78927 .01757 L
.79058 .01685 L
.79181 .01604 L
.79297 .01521 L
.79327 .01499 L
.79342 .01489 L
.79355 .01479 L
.79371 .01476 L
.79379 .01482 L
.79388 .01488 L
.79418 .0151 L
.79551 .01604 L
.79675 .01683 L
.79809 .01753 L
.79871 .01779 L
.79936 .01801 L
.79991 .01815 L
.80023 .01822 L
.80052 .01826 L
.80067 .01828 L
.80084 .0183 L
.80098 .01831 L
.80113 .01832 L
.80121 .01833 L
.80129 .01833 L
.80144 .01833 L
.80152 .01833 L
.80161 .01833 L
.8017 .01833 L
.80178 .01833 L
.80194 .01832 L
.80209 .01831 L
.80222 .0183 L
.80236 .01828 L
.80268 .01824 L
.80298 .01818 L
.80349 .01806 L
.80406 .01789 L
.80522 .01741 L
.80652 .01672 L
.80776 .01593 L
.80887 .01517 L
.80917 .01496 L
.80934 .01484 L
.8095 .01473 L
Mistroke
.80964 .0148 L
.8098 .01491 L
.81008 .0151 L
.81231 .01656 L
.81358 .01724 L
.8142 .01751 L
.81476 .01773 L
.81532 .0179 L
.81593 .01804 L
.81626 .0181 L
.81641 .01812 L
.81657 .01814 L
.81671 .01816 L
.81686 .01817 L
.81694 .01818 L
.81702 .01818 L
.81717 .01819 L
.81732 .01819 L
.81748 .01819 L
.81763 .01819 L
.81776 .01818 L
.81785 .01818 L
.81792 .01817 L
.8181 .01816 L
.81841 .01812 L
.81871 .01807 L
.81904 .01801 L
.81971 .01783 L
.82035 .01762 L
.82094 .01737 L
.82206 .01682 L
.82329 .01611 L
.82396 .01568 L
.82459 .01526 L
.82513 .01489 L
.82528 .01479 L
.82544 .01475 L
.82558 .01484 L
.82573 .01494 L
.82698 .01577 L
.8292 .01703 L
.82984 .01732 L
.83044 .01755 L
.83099 .01773 L
.83157 .01788 L
.83187 .01794 L
.8322 .01799 L
.83234 .01801 L
.8325 .01803 L
.83264 .01804 L
Mistroke
.83278 .01805 L
.83287 .01806 L
.83295 .01806 L
.83304 .01806 L
.83313 .01807 L
.83321 .01807 L
.8333 .01807 L
.83339 .01807 L
.83346 .01806 L
.83361 .01806 L
.83369 .01806 L
.83377 .01805 L
.83393 .01804 L
.83409 .01802 L
.8344 .01798 L
.83473 .01793 L
.83532 .0178 L
.83596 .01761 L
.83666 .01735 L
.83908 .0161 L
.84022 .0154 L
.84052 .0152 L
.84084 .01499 L
.841 .01489 L
.84114 .0148 L
.84128 .01472 L
.84142 .01481 L
.84205 .01522 L
.84273 .01565 L
.84393 .01637 L
.84517 .017 L
.84633 .01747 L
.84692 .01765 L
.84754 .0178 L
.8479 .01786 L
.84824 .01791 L
.84838 .01793 L
.84854 .01794 L
.84863 .01795 L
.84871 .01795 L
.84887 .01796 L
.84902 .01796 L
.84915 .01796 L
.8493 .01796 L
.84939 .01796 L
.84946 .01796 L
.84962 .01795 L
.84978 .01794 L
.84994 .01792 L
.85009 .01791 L
Mistroke
.85063 .01783 L
.8509 .01777 L
.8512 .0177 L
.8525 .01728 L
.85371 .01674 L
.85496 .01606 L
.85615 .01534 L
.85667 .01501 L
.85681 .01493 L
.85695 .01483 L
.85709 .01475 L
.85722 .01477 L
.85738 .01486 L
.85754 .01497 L
.85783 .01515 L
.85839 .01549 L
.85962 .01622 L
.86078 .01682 L
.86192 .01729 L
.86297 .01761 L
.86351 .01773 L
.86379 .01778 L
.86409 .01782 L
.86424 .01784 L
.8644 .01785 L
.86457 .01786 L
.86472 .01787 L
.86487 .01788 L
.86501 .01788 L
.86516 .01788 L
.86524 .01787 L
.86532 .01787 L
.86548 .01787 L
.86555 .01786 L
.86564 .01785 L
.86594 .01783 L
.86611 .01781 L
.86629 .01778 L
.86661 .01772 L
.86725 .01758 L
.86784 .01741 L
.86903 .01695 L
.87013 .01641 L
.87142 .01569 L
.87205 .01531 L
.87233 .01514 L
.87263 .01495 L
.87278 .01486 L
.87293 .01477 L
.87308 .01475 L
Mistroke
.87321 .01484 L
.87383 .01521 L
.87511 .01597 L
.8762 .01655 L
.87736 .01707 L
.87793 .01728 L
.87856 .01747 L
.87913 .01761 L
.87966 .01771 L
.87997 .01775 L
.88014 .01777 L
.88029 .01778 L
.88043 .01779 L
.88057 .0178 L
.88073 .0178 L
.88087 .01781 L
.88095 .01781 L
.88104 .0178 L
.88119 .0178 L
.88128 .0178 L
.88136 .01779 L
.88154 .01778 L
.8817 .01777 L
.88184 .01775 L
.88217 .01771 L
.88275 .01761 L
.88336 .01745 L
.88447 .01708 L
.88565 .01655 L
.88697 .01585 L
.8881 .01519 L
.88838 .01502 L
.88867 .01485 L
.88876 .01479 L
.88884 .01474 L
.889 .01478 L
.88914 .01487 L
.8893 .01496 L
.89061 .01573 L
.89181 .01638 L
.89305 .01695 L
.89421 .01736 L
.89479 .01751 L
.89541 .01763 L
.89577 .01768 L
.89594 .0177 L
.89611 .01772 L
.89625 .01773 L
.89641 .01774 L
.8965 .01774 L
Mistroke
.89658 .01774 L
.89674 .01775 L
.89688 .01775 L
.89703 .01774 L
.89717 .01774 L
.8973 .01773 L
.89745 .01772 L
.89762 .01771 L
.89792 .01767 L
.89823 .01763 L
.89857 .01756 L
.89916 .01742 L
.90022 .01708 L
.90139 .01658 L
.90253 .016 L
.90373 .01533 L
.90435 .01496 L
.90452 .01486 L
.90462 .0148 L
.90471 .01475 L
.90479 .01473 L
.90488 .01479 L
.90504 .01488 L
.90624 .01558 L
.90864 .0168 L
.90985 .01724 L
.91054 .01744 L
.91087 .01751 L
.91118 .01757 L
.91149 .01762 L
.91178 .01765 L
.91193 .01767 L
.9121 .01768 L
.91219 .01769 L
.91227 .01769 L
.91235 .01769 L
.91243 .0177 L
.91258 .0177 L
.91271 .0177 L
.91287 .0177 L
.91301 .01769 L
.91316 .01769 L
.91333 .01768 L
.91363 .01765 L
.91389 .01761 L
.91419 .01757 L
.91479 .01744 L
.91534 .0173 L
.91586 .01713 L
.9183 .01604 L
Mistroke
.91938 .01544 L
.91997 .0151 L
.92027 .01493 L
.92039 .01486 L
.92053 .01477 L
.92068 .01474 L
.92083 .01483 L
.92116 .01502 L
.92172 .01535 L
.92282 .01596 L
.92413 .0166 L
.92532 .01708 L
.9259 .01727 L
.92653 .01743 L
.92682 .01749 L
.92712 .01755 L
.92741 .01759 L
.92767 .01762 L
.92781 .01763 L
.92797 .01765 L
.92812 .01766 L
.92821 .01766 L
.92829 .01766 L
.92844 .01766 L
.92857 .01767 L
.92872 .01766 L
.92887 .01766 L
.92895 .01766 L
.92903 .01765 L
.9292 .01764 L
.9295 .01761 L
.92986 .01757 L
.93019 .01751 L
.93079 .01738 L
.93145 .0172 L
.93264 .01676 L
.93487 .01565 L
.93551 .01529 L
.93583 .01511 L
.93612 .01494 L
.93638 .01479 L
.93652 .01472 L
.93666 .0148 L
.93725 .01514 L
.93857 .01588 L
.93978 .01648 L
.94091 .01696 L
.9415 .01716 L
.94213 .01734 L
.94245 .01742 L
Mistroke
.94281 .01749 L
.94313 .01754 L
.94343 .01758 L
.94373 .01761 L
.94389 .01762 L
.94398 .01763 L
.94406 .01763 L
.94421 .01764 L
.94435 .01764 L
.94443 .01764 L
.94451 .01764 L
.94466 .01764 L
.9448 .01763 L
.94495 .01763 L
.94509 .01762 L
.94522 .01761 L
.94553 .01757 L
.94583 .01753 L
.94643 .01742 L
.94707 .01725 L
.94823 .01686 L
.9493 .01639 L
.95058 .01573 L
.95121 .01539 L
.95178 .01506 L
.95205 .0149 L
.95219 .01483 L
.95231 .01476 L
.95244 .01475 L
.95257 .01483 L
.95286 .01499 L
.95403 .01565 L
.95634 .01677 L
.95697 .01701 L
.95764 .01723 L
.95827 .01739 L
.95884 .0175 L
.95912 .01755 L
.95942 .01758 L
.95956 .01759 L
.95971 .01761 L
.95985 .01761 L
.95998 .01762 L
.96014 .01762 L
.96028 .01763 L
.96044 .01763 L
.96052 .01762 L
.96061 .01762 L
.96075 .01762 L
.96091 .01761 L
Mistroke
.96106 .01759 L
.9612 .01758 L
.96174 .01751 L
.96205 .01746 L
.96233 .0174 L
.96341 .0171 L
.96457 .01665 L
.96566 .01615 L
.96687 .0155 L
.96753 .01513 L
.96785 .01495 L
.96799 .01487 L
.96814 .01478 L
.96829 .01474 L
.96843 .01482 L
.9687 .01497 L
.9693 .01531 L
.97057 .016 L
.97173 .01656 L
.97281 .01699 L
.97358 .01724 L
.97442 .01744 L
.97465 .01749 L
.97489 .01753 L
.97511 .01756 L
.97534 .01758 L
.97546 .01759 L
.97557 .0176 L
.97568 .01761 L
.97578 .01761 L
.97588 .01762 L
.97598 .01762 L
.97608 .01762 L
.97619 .01762 L
Mfstroke
1 0 0 r
[ ] 0 setdash
.03968 .01472 m
.03968 .01763 L
s
.05556 .01472 m
.05556 .01764 L
s
.07143 .01472 m
.07143 .01767 L
s
.0873 .01472 m
.0873 .0177 L
s
.10317 .01472 m
.10317 .01775 L
s
.11905 .01472 m
.11905 .01781 L
s
.13492 .01472 m
.13492 .01788 L
s
.15079 .01472 m
.15079 .01796 L
s
.16667 .01472 m
.16667 .01807 L
s
.18254 .01472 m
.18254 .01819 L
s
.19841 .01472 m
.19841 .01833 L
s
.21429 .01472 m
.21429 .01851 L
s
.23016 .01472 m
.23016 .01871 L
s
.24603 .01472 m
.24603 .01895 L
s
.2619 .01472 m
.2619 .01924 L
s
.27778 .01472 m
.27778 .01958 L
s
.29365 .01472 m
.29365 .01997 L
s
.30952 .01472 m
.30952 .0204 L
s
.3254 .01472 m
.3254 .02076 L
s
.34127 .01472 m
.34127 .02049 L
s
.35714 .01472 m
.35714 .01763 L
s
.37302 .01472 m
.37302 .07995 L
s
.38889 .01472 m
.38889 .49745 L
s
.40476 .01472 m
.40476 .494 L
s
.42063 .01472 m
.42063 .08344 L
s
.43651 .01472 m
.43651 .01915 L
s
.45238 .01472 m
.45238 .0179 L
s
.46825 .01472 m
.46825 .01795 L
s
.48413 .01472 m
.48413 .01773 L
s
.5 .01472 m
.5 .01762 L
s
.51587 .01472 m
.51587 .01773 L
s
.53175 .01472 m
.53175 .01795 L
s
.54762 .01472 m
.54762 .0179 L
s
.56349 .01472 m
.56349 .01915 L
s
.57937 .01472 m
.57937 .08344 L
s
.59524 .01472 m
.59524 .494 L
s
.61111 .01472 m
.61111 .49745 L
s
.62698 .01472 m
.62698 .07995 L
s
.64286 .01472 m
.64286 .01763 L
s
.65873 .01472 m
.65873 .02049 L
s
.6746 .01472 m
.6746 .02076 L
s
.69048 .01472 m
.69048 .0204 L
s
.70635 .01472 m
.70635 .01997 L
s
.72222 .01472 m
.72222 .01958 L
s
.7381 .01472 m
.7381 .01924 L
s
.75397 .01472 m
.75397 .01895 L
s
.76984 .01472 m
.76984 .01871 L
s
.78571 .01472 m
.78571 .01851 L
s
.80159 .01472 m
.80159 .01833 L
s
.81746 .01472 m
.81746 .01819 L
s
.83333 .01472 m
.83333 .01807 L
s
.84921 .01472 m
.84921 .01796 L
s
.86508 .01472 m
.86508 .01788 L
s
.88095 .01472 m
.88095 .01781 L
s
.89683 .01472 m
.89683 .01775 L
s
.9127 .01472 m
.9127 .0177 L
s
.92857 .01472 m
.92857 .01767 L
s
.94444 .01472 m
.94444 .01764 L
s
.96032 .01472 m
.96032 .01763 L
s
.97619 .01472 m
.97619 .01762 L
s
.015 w
.03968 .01763 Mdot
.05556 .01764 Mdot
.07143 .01767 Mdot
.0873 .0177 Mdot
.10317 .01775 Mdot
.11905 .01781 Mdot
.13492 .01788 Mdot
.15079 .01796 Mdot
.16667 .01807 Mdot
.18254 .01819 Mdot
.19841 .01833 Mdot
.21429 .01851 Mdot
.23016 .01871 Mdot
.24603 .01895 Mdot
.2619 .01924 Mdot
.27778 .01958 Mdot
.29365 .01997 Mdot
.30952 .0204 Mdot
.3254 .02076 Mdot
.34127 .02049 Mdot
.35714 .01763 Mdot
.37302 .07995 Mdot
.38889 .49745 Mdot
.40476 .494 Mdot
.42063 .08344 Mdot
.43651 .01915 Mdot
.45238 .0179 Mdot
.46825 .01795 Mdot
.48413 .01773 Mdot
.5 .01762 Mdot
.51587 .01773 Mdot
.53175 .01795 Mdot
.54762 .0179 Mdot
.56349 .01915 Mdot
.57937 .08344 Mdot
.59524 .494 Mdot
.61111 .49745 Mdot
.62698 .07995 Mdot
.64286 .01763 Mdot
.65873 .02049 Mdot
.6746 .02076 Mdot
.69048 .0204 Mdot
.70635 .01997 Mdot
.72222 .01958 Mdot
.7381 .01924 Mdot
.75397 .01895 Mdot
.76984 .01871 Mdot
.78571 .01851 Mdot
.80159 .01833 Mdot
.81746 .01819 Mdot
.83333 .01807 Mdot
.84921 .01796 Mdot
.86508 .01788 Mdot
.88095 .01781 Mdot
.89683 .01775 Mdot
.9127 .0177 Mdot
.92857 .01767 Mdot
.94444 .01764 Mdot
.96032 .01763 Mdot
.97619 .01762 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Show both", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(gw2 = 
        Show[GraphicsArray[{{g1, g5, \ g6}}], \ 
          ImageSize \[Rule] 504*1.5];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .19314 
%%ImageSize: 756 146.011 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.00459847 0.31746 [
[ 0 0 0 0 ]
[ 1 .19314 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .19314 L
0 .19314 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00459847 0.321429 0.188537 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.047619 0.0147142 0.0363327 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01471 -6 -4.5 ]
[-0.0125 .01471 0 4.5 ]
[-0.0125 .10555 -18 -4.5 ]
[-0.0125 .10555 0 4.5 ]
[-0.0125 .19638 -6 -4.5 ]
[-0.0125 .19638 0 4.5 ]
[-0.0125 .28721 -18 -4.5 ]
[-0.0125 .28721 0 4.5 ]
[-0.0125 .37804 -12 -4.5 ]
[-0.0125 .37804 0 4.5 ]
[-0.0125 .46887 -24 -4.5 ]
[-0.0125 .46887 0 4.5 ]
[-0.0125 .5597 -12 -4.5 ]
[-0.0125 .5597 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01471 m
.00625 .01471 L
s
[(0)] -0.0125 .01471 1 0 Mshowa
0 .10555 m
.00625 .10555 L
s
[(2.5)] -0.0125 .10555 1 0 Mshowa
0 .19638 m
.00625 .19638 L
s
[(5)] -0.0125 .19638 1 0 Mshowa
0 .28721 m
.00625 .28721 L
s
[(7.5)] -0.0125 .28721 1 0 Mshowa
0 .37804 m
.00625 .37804 L
s
[(10)] -0.0125 .37804 1 0 Mshowa
0 .46887 m
.00625 .46887 L
s
[(12.5)] -0.0125 .46887 1 0 Mshowa
0 .5597 m
.00625 .5597 L
s
[(15)] -0.0125 .5597 1 0 Mshowa
.125 Mabswid
0 .03288 m
.00375 .03288 L
s
0 .05105 m
.00375 .05105 L
s
0 .06921 m
.00375 .06921 L
s
0 .08738 m
.00375 .08738 L
s
0 .12371 m
.00375 .12371 L
s
0 .14188 m
.00375 .14188 L
s
0 .16005 m
.00375 .16005 L
s
0 .17821 m
.00375 .17821 L
s
0 .21454 m
.00375 .21454 L
s
0 .23271 m
.00375 .23271 L
s
0 .25088 m
.00375 .25088 L
s
0 .26904 m
.00375 .26904 L
s
0 .30538 m
.00375 .30538 L
s
0 .32354 m
.00375 .32354 L
s
0 .34171 m
.00375 .34171 L
s
0 .35987 m
.00375 .35987 L
s
0 .39621 m
.00375 .39621 L
s
0 .41437 m
.00375 .41437 L
s
0 .43254 m
.00375 .43254 L
s
0 .45071 m
.00375 .45071 L
s
0 .48704 m
.00375 .48704 L
s
0 .50521 m
.00375 .50521 L
s
0 .52337 m
.00375 .52337 L
s
0 .54154 m
.00375 .54154 L
s
0 .57787 m
.00375 .57787 L
s
0 .59604 m
.00375 .59604 L
s
0 .6142 m
.00375 .6142 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01471 m
1 .01471 L
s
.99375 .10555 m
1 .10555 L
s
.99375 .19638 m
1 .19638 L
s
.99375 .28721 m
1 .28721 L
s
.99375 .37804 m
1 .37804 L
s
.99375 .46887 m
1 .46887 L
s
.99375 .5597 m
1 .5597 L
s
.125 Mabswid
.99625 .03288 m
1 .03288 L
s
.99625 .05105 m
1 .05105 L
s
.99625 .06921 m
1 .06921 L
s
.99625 .08738 m
1 .08738 L
s
.99625 .12371 m
1 .12371 L
s
.99625 .14188 m
1 .14188 L
s
.99625 .16005 m
1 .16005 L
s
.99625 .17821 m
1 .17821 L
s
.99625 .21454 m
1 .21454 L
s
.99625 .23271 m
1 .23271 L
s
.99625 .25088 m
1 .25088 L
s
.99625 .26904 m
1 .26904 L
s
.99625 .30538 m
1 .30538 L
s
.99625 .32354 m
1 .32354 L
s
.99625 .34171 m
1 .34171 L
s
.99625 .35987 m
1 .35987 L
s
.99625 .39621 m
1 .39621 L
s
.99625 .41437 m
1 .41437 L
s
.99625 .43254 m
1 .43254 L
s
.99625 .45071 m
1 .45071 L
s
.99625 .48704 m
1 .48704 L
s
.99625 .50521 m
1 .50521 L
s
.99625 .52337 m
1 .52337 L
s
.99625 .54154 m
1 .54154 L
s
.99625 .57787 m
1 .57787 L
s
.99625 .59604 m
1 .59604 L
s
.99625 .6142 m
1 .6142 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
0 0 1 r
.5 Mabswid
[ .01 ] 0 setdash
.02381 .01762 m
.02395 .01762 L
.02408 .01762 L
.02423 .01761 L
.02437 .0176 L
.02462 .01758 L
.02489 .01755 L
.02519 .01751 L
.02551 .01746 L
.02608 .01733 L
.02722 .01699 L
.02847 .01647 L
.02973 .01584 L
.03043 .01546 L
.03109 .01509 L
.03139 .01492 L
.03155 .01483 L
.03171 .01474 L
.03179 .01474 L
.03189 .0148 L
.03205 .01489 L
.03238 .01508 L
.03355 .01573 L
.03596 .01687 L
.03717 .01727 L
.03785 .01744 L
.03819 .0175 L
.0385 .01755 L
.03879 .01758 L
.03894 .01759 L
.0391 .01761 L
.03918 .01761 L
.03926 .01762 L
.03941 .01762 L
.03949 .01762 L
.03958 .01762 L
.03967 .01763 L
.03976 .01763 L
.03991 .01762 L
.04006 .01762 L
.04019 .01761 L
.04033 .0176 L
.04065 .01757 L
.04095 .01754 L
.04147 .01745 L
.04204 .01732 L
.04319 .01695 L
.04573 .01578 L
.04631 .01546 L
.04694 .01511 L
Mistroke
.04724 .01493 L
.04739 .01485 L
.04752 .01477 L
.04765 .01473 L
.04778 .01481 L
.04805 .01496 L
.0492 .01561 L
.05046 .01627 L
.05165 .01681 L
.05274 .01719 L
.05332 .01736 L
.05388 .01748 L
.05417 .01753 L
.05447 .01757 L
.05463 .01759 L
.0548 .01761 L
.05495 .01762 L
.05511 .01763 L
.05525 .01763 L
.0554 .01764 L
.05553 .01764 L
.05566 .01764 L
.05581 .01764 L
.05595 .01763 L
.0561 .01762 L
.05625 .01761 L
.05652 .01759 L
.05676 .01756 L
.05732 .01747 L
.05789 .01734 L
.05849 .01716 L
.05959 .01676 L
.06208 .01552 L
.06267 .01519 L
.063 .015 L
.0633 .01482 L
.06346 .01473 L
.06355 .01475 L
.06363 .0148 L
.064 .01501 L
.06464 .01538 L
.06589 .01606 L
.06706 .01663 L
.06826 .0171 L
.06878 .01726 L
.06934 .01741 L
.06967 .01748 L
.06996 .01754 L
.07027 .01759 L
.07055 .01762 L
Mistroke
.07071 .01763 L
.07085 .01764 L
.07101 .01765 L
.07109 .01766 L
.07118 .01766 L
.07126 .01766 L
.07134 .01766 L
.07149 .01766 L
.07159 .01766 L
.07167 .01766 L
.07175 .01766 L
.07184 .01766 L
.07199 .01765 L
.07213 .01764 L
.07243 .01761 L
.07272 .01757 L
.07299 .01753 L
.07359 .0174 L
.07425 .01722 L
.07557 .01674 L
.07679 .01616 L
.07787 .01558 L
.07844 .01525 L
.07904 .01491 L
.07919 .01481 L
.07928 .01476 L
.07936 .01472 L
.07945 .01477 L
.07954 .01482 L
.07971 .01492 L
.08032 .01527 L
.08152 .01595 L
.0827 .01654 L
.08394 .01706 L
.085 .01739 L
.0856 .01753 L
.08588 .01758 L
.08617 .01762 L
.08633 .01764 L
.08648 .01766 L
.08663 .01767 L
.08677 .01768 L
.08693 .01769 L
.08702 .01769 L
.08711 .0177 L
.08726 .0177 L
.08734 .0177 L
.08742 .0177 L
.08758 .0177 L
.08772 .01769 L
Mistroke
.08786 .01768 L
.088 .01767 L
.08832 .01764 L
.08861 .0176 L
.08913 .01751 L
.0897 .01738 L
.09085 .017 L
.09339 .01579 L
.09397 .01546 L
.09459 .0151 L
.09489 .01492 L
.09504 .01483 L
.09518 .01475 L
.0953 .01475 L
.09543 .01483 L
.09571 .01499 L
.09685 .01566 L
.0981 .01633 L
.0993 .01689 L
.10038 .01729 L
.10097 .01746 L
.10153 .01758 L
.10181 .01763 L
.10211 .01768 L
.10227 .01769 L
.10244 .01771 L
.10259 .01772 L
.10275 .01773 L
.10289 .01774 L
.10304 .01774 L
.10317 .01775 L
.1033 .01775 L
.10345 .01774 L
.10358 .01774 L
.10374 .01773 L
.10389 .01772 L
.10416 .01769 L
.1044 .01766 L
.10496 .01756 L
.10552 .01743 L
.10613 .01725 L
.10722 .01683 L
.10971 .01555 L
.1103 .0152 L
.11063 .01501 L
.11093 .01482 L
.11102 .01477 L
.11111 .01472 L
.1112 .01477 L
.1113 .01483 L
Mistroke
.11162 .01502 L
.11226 .01541 L
.11343 .01608 L
.11469 .01671 L
.11593 .01722 L
.11652 .01742 L
.11706 .01756 L
.1176 .01767 L
.11789 .01772 L
.1182 .01776 L
.11832 .01777 L
.11846 .01778 L
.11858 .01779 L
.11871 .0178 L
.11885 .0178 L
.119 .0178 L
.11914 .0178 L
.11927 .0178 L
.11943 .0178 L
.1195 .01779 L
.11959 .01779 L
.11988 .01777 L
.12005 .01775 L
.12022 .01773 L
.12054 .01768 L
.12117 .01754 L
.12174 .01738 L
.12289 .01696 L
.12399 .01645 L
.12515 .01582 L
.12578 .01545 L
.12638 .01508 L
.12663 .01493 L
.12676 .01485 L
.12689 .01477 L
.12703 .01474 L
.12718 .01483 L
.12744 .01499 L
.1286 .0157 L
.13086 .01689 L
.13148 .01716 L
.13213 .0174 L
.1327 .01757 L
.13331 .01771 L
.13364 .01777 L
.13394 .01781 L
.13408 .01783 L
.13424 .01784 L
.13439 .01786 L
.13453 .01786 L
Mistroke
.13462 .01787 L
.13471 .01787 L
.13479 .01787 L
.13487 .01788 L
.13495 .01788 L
.13504 .01788 L
.13514 .01787 L
.13523 .01787 L
.13531 .01787 L
.13539 .01786 L
.13554 .01786 L
.1357 .01784 L
.13588 .01782 L
.13617 .01779 L
.13649 .01773 L
.13714 .01759 L
.13774 .01741 L
.13831 .01721 L
.14074 .01601 L
.14182 .01537 L
.14211 .01519 L
.14241 .01499 L
.14255 .01491 L
.1427 .01481 L
.14283 .01473 L
.14297 .01479 L
.14313 .01489 L
.14329 .01499 L
.14359 .01518 L
.14416 .01553 L
.14526 .01618 L
.14655 .01687 L
.14775 .01738 L
.14839 .01759 L
.14898 .01774 L
.14929 .01781 L
.14962 .01787 L
.1498 .01789 L
.14997 .01792 L
.15014 .01793 L
.15031 .01794 L
.15046 .01795 L
.1506 .01796 L
.15074 .01796 L
.15087 .01796 L
.15102 .01796 L
.15117 .01796 L
.15132 .01795 L
.15149 .01794 L
.15179 .01791 L
Mistroke
.15208 .01787 L
.15273 .01774 L
.15333 .01758 L
.15398 .01735 L
.15517 .01683 L
.1574 .01557 L
.15804 .01516 L
.15836 .01496 L
.1585 .01487 L
.15865 .01477 L
.15878 .01475 L
.15891 .01483 L
.15919 .01501 L
.15978 .01539 L
.16107 .0162 L
.1623 .01687 L
.16348 .0174 L
.1641 .01763 L
.16476 .01782 L
.16531 .01794 L
.16562 .01799 L
.16592 .01802 L
.16605 .01804 L
.16619 .01805 L
.16631 .01805 L
.16644 .01806 L
.16657 .01806 L
.16672 .01807 L
.16687 .01806 L
.16699 .01806 L
.16714 .01805 L
.16727 .01805 L
.16742 .01803 L
.16758 .01802 L
.1679 .01797 L
.1682 .01792 L
.16876 .01779 L
.1693 .01764 L
.1705 .01716 L
.17181 .01649 L
.17304 .01575 L
.17364 .01536 L
.17419 .01499 L
.17435 .01489 L
.1745 .01479 L
.17465 .01475 L
.17474 .0148 L
.17483 .01486 L
.17551 .01533 L
.17672 .01611 L
Mistroke
.17795 .01683 L
.17928 .01747 L
.17989 .0177 L
.18054 .01791 L
.1811 .01804 L
.18141 .01809 L
.18171 .01813 L
.18185 .01815 L
.182 .01816 L
.18215 .01817 L
.18228 .01818 L
.18243 .01819 L
.18252 .01819 L
.1826 .01819 L
.18274 .01819 L
.1829 .01818 L
.18304 .01818 L
.1832 .01816 L
.18335 .01815 L
.18349 .01813 L
.18383 .01809 L
.18415 .01803 L
.1847 .01789 L
.18521 .01773 L
.18638 .01726 L
.18865 .01596 L
.18928 .01555 L
.18993 .01509 L
.1902 .01491 L
.19035 .0148 L
.19049 .01473 L
.19057 .01478 L
.19066 .01484 L
.19081 .01495 L
.19111 .01516 L
.19245 .01607 L
.1937 .01684 L
.19495 .01749 L
.19557 .01775 L
.19613 .01795 L
.19669 .01811 L
.19722 .01822 L
.19751 .01827 L
.19778 .0183 L
.19793 .01831 L
.19807 .01832 L
.19815 .01833 L
.19824 .01833 L
.19839 .01833 L
.19854 .01833 L
Mistroke
.19869 .01833 L
.19885 .01832 L
.19894 .01832 L
.19902 .01831 L
.19918 .0183 L
.19936 .01828 L
.19969 .01823 L
.19999 .01817 L
.2003 .0181 L
.20088 .01793 L
.20201 .01748 L
.20322 .01684 L
.20437 .01612 L
.20543 .01538 L
.20599 .01498 L
.20615 .01486 L
.2063 .01475 L
.20644 .01478 L
.20658 .01489 L
.20785 .0158 L
.20906 .01662 L
.21039 .0174 L
.21099 .01769 L
.21163 .01797 L
.21218 .01816 L
.21279 .01832 L
.21314 .01839 L
.21331 .01842 L
.21347 .01845 L
.21362 .01846 L
.21378 .01848 L
.21387 .01849 L
.21395 .01849 L
.21403 .0185 L
.21411 .0185 L
.21426 .0185 L
.21439 .01851 L
.21448 .0185 L
.21456 .0185 L
.2147 .0185 L
.21486 .01849 L
.215 .01848 L
.21532 .01844 L
.21562 .01839 L
.21589 .01833 L
.21649 .01817 L
.21702 .01799 L
.21758 .01776 L
.22007 .01631 L
.22122 .01548 L
Mistroke
.22155 .01523 L
.22187 .01499 L
.222 .01488 L
.22215 .01477 L
.22231 .01478 L
.22245 .01489 L
.22467 .01654 L
.22581 .01728 L
.22703 .01793 L
.22763 .01819 L
.22819 .01838 L
.22869 .01852 L
.22898 .01858 L
.22924 .01863 L
.22952 .01867 L
.22967 .01868 L
.22983 .01869 L
.22996 .0187 L
.23009 .01871 L
.23023 .01871 L
.23037 .01871 L
.23046 .01871 L
.23054 .0187 L
.23062 .0187 L
.23071 .01869 L
.23086 .01868 L
.23103 .01866 L
.23134 .01862 L
.23162 .01856 L
.23226 .01839 L
.23284 .01819 L
.23416 .01756 L
.23536 .01681 L
.23664 .01587 L
.23726 .01538 L
.23757 .01514 L
.23785 .01491 L
.23798 .0148 L
.23811 .01472 L
.23824 .01483 L
.23838 .01494 L
.23895 .01541 L
.24131 .01719 L
.24248 .0179 L
.24356 .01842 L
.24413 .01862 L
.24473 .01879 L
.24505 .01885 L
.24534 .0189 L
.24551 .01892 L
Mistroke
.24566 .01893 L
.24574 .01894 L
.24583 .01894 L
.24593 .01895 L
.24601 .01895 L
.24615 .01895 L
.2463 .01895 L
.24645 .01894 L
.24658 .01893 L
.2467 .01892 L
.24683 .01891 L
.24709 .01887 L
.24738 .01882 L
.24769 .01875 L
.24825 .01858 L
.24888 .01833 L
.24947 .01805 L
.25081 .01724 L
.25197 .01638 L
.25323 .01535 L
.25355 .01507 L
.25373 .01492 L
.25382 .01484 L
.2539 .01478 L
.25404 .01477 L
.25419 .0149 L
.25451 .01518 L
.25571 .0162 L
.25796 .01787 L
.25854 .01822 L
.25916 .01854 L
.25969 .01877 L
.26026 .01897 L
.26059 .01906 L
.26088 .01912 L
.26118 .01917 L
.26132 .01919 L
.26146 .01921 L
.26161 .01922 L
.2617 .01923 L
.26178 .01923 L
.26193 .01924 L
.26208 .01924 L
.26217 .01924 L
.26226 .01923 L
.26235 .01923 L
.26244 .01922 L
.2626 .01921 L
.26277 .01919 L
.26308 .01914 L
Mistroke
.26341 .01907 L
.264 .01889 L
.26463 .01864 L
.26533 .01829 L
.26776 .01657 L
.26889 .01558 L
.26946 .01506 L
.26962 .01492 L
.26971 .01484 L
.26979 .01476 L
.26995 .01481 L
.27009 .01494 L
.2714 .01615 L
.2726 .01718 L
.27377 .01806 L
.27502 .01881 L
.27553 .01905 L
.27607 .01927 L
.27639 .01936 L
.27668 .01944 L
.27697 .01949 L
.27724 .01954 L
.27739 .01955 L
.27747 .01956 L
.27755 .01957 L
.27771 .01957 L
.27785 .01958 L
.27798 .01958 L
.27811 .01957 L
.27825 .01957 L
.2784 .01955 L
.27856 .01954 L
.27873 .01951 L
.27904 .01945 L
.27935 .01938 L
.27963 .01929 L
.28071 .01884 L
.28125 .01853 L
.28185 .01815 L
.28309 .01719 L
.28438 .01602 L
.28492 .0155 L
.28521 .01521 L
.28549 .01494 L
.28565 .01478 L
.28574 .01474 L
.28582 .01482 L
.28612 .01512 L
.2867 .0157 L
.28912 .01792 L
Mistroke
.2903 .01879 L
.29137 .01939 L
.29193 .01963 L
.29247 .0198 L
.29276 .01987 L
.29303 .01992 L
.29317 .01993 L
.29332 .01995 L
.2934 .01996 L
.29349 .01996 L
.29364 .01997 L
.2938 .01997 L
.29394 .01997 L
.29403 .01997 L
.2941 .01996 L
.29419 .01996 L
.29427 .01995 L
.29444 .01993 L
.29459 .01991 L
.29494 .01983 L
.29521 .01976 L
.29552 .01966 L
.29613 .01941 L
.29735 .0187 L
.29847 .01783 L
.29978 .01662 L
.30041 .01597 L
.30099 .01536 L
.30126 .01506 L
.30141 .01491 L
.30156 .01474 L
.30169 .01483 L
.30184 .01499 L
.3021 .01527 L
.30328 .01653 L
.30459 .01782 L
.30578 .01884 L
.30636 .01925 L
.30699 .01964 L
.30753 .01992 L
.30813 .02015 L
.30846 .02025 L
.30877 .02032 L
.30894 .02035 L
.30909 .02037 L
.30926 .02039 L
.30935 .02039 L
.30944 .0204 L
.3096 .0204 L
.30975 .0204 L
Mistroke
.30983 .0204 L
.30991 .0204 L
.31007 .02038 L
.31022 .02037 L
.31037 .02035 L
.31065 .02029 L
.31096 .02021 L
.31125 .02012 L
.31179 .01989 L
.31238 .01958 L
.31302 .01917 L
.31522 .01721 L
.31645 .01588 L
.31674 .01555 L
.31705 .01519 L
.31731 .01489 L
.31746 .01472 L
.3176 .01488 L
.31824 .01562 L
.31893 .01641 L
.32013 .01772 L
.3214 .01891 L
.32259 .01981 L
.32311 .02012 L
.32367 .02038 L
.32395 .02049 L
.32427 .02059 L
.32456 .02066 L
.32483 .02071 L
.32497 .02073 L
.32513 .02075 L
.32527 .02075 L
.3254 .02076 L
.32555 .02076 L
.32564 .02075 L
.32572 .02075 L
.32587 .02074 L
.32602 .02072 L
.32617 .0207 L
.32633 .02067 L
.32662 .0206 L
.32696 .02049 L
.32727 .02037 L
.32842 .01973 L
.3295 .01889 L
.3317 .01665 L
.3323 .01595 L
.33262 .01557 L
.33295 .01518 L
.33309 .01501 L
Mistroke
.33324 .01482 L
.33333 .01472 L
.33341 .0148 L
.33356 .01499 L
.33412 .01566 L
.33651 .01824 L
.33781 .01933 L
.33839 .01972 L
.33904 .02006 L
.33933 .02018 L
.33964 .02029 L
.33991 .02037 L
.34021 .02043 L
.34038 .02046 L
.34047 .02047 L
.34054 .02048 L
.34069 .02049 L
.34078 .0205 L
.34086 .0205 L
.34101 .0205 L
.34114 .0205 L
.34129 .02049 L
.34145 .02048 L
.34159 .02046 L
.34171 .02044 L
.342 .02038 L
.34226 .02031 L
.34251 .02023 L
.34307 .02 L
.34367 .01967 L
.34481 .01889 L
.34606 .01781 L
.34738 .01652 L
.34796 .01594 L
.3486 .01531 L
.34888 .01503 L
.34904 .01488 L
.34918 .01473 L
.34932 .01482 L
.34947 .01496 L
.34973 .0152 L
.35093 .01619 L
.35157 .01663 L
.35224 .01702 L
.35281 .01728 L
.35312 .0174 L
.35345 .0175 L
.35377 .01759 L
.35408 .01765 L
.35437 .01769 L
Mistroke
.35453 .01771 L
.35467 .01772 L
.35482 .01773 L
.35495 .01773 L
.3551 .01774 L
.35525 .01774 L
.35539 .01774 L
.35551 .01773 L
.35565 .01773 L
.35579 .01772 L
.35831 .01763 L
.35948 .0178 L
.36011 .01794 L
.36071 .01805 L
.36087 .01807 L
.36102 .01809 L
.3611 .0181 L
.36119 .01811 L
.36135 .01812 L
.36145 .01812 L
.36153 .01812 L
.36163 .01812 L
.36172 .01811 L
.36181 .0181 L
.36189 .01809 L
.36206 .01806 L
.36221 .01803 L
.36235 .01799 L
.36267 .01786 L
.36298 .01768 L
.36331 .01743 L
.36363 .01712 L
.36393 .01677 L
.3646 .01571 L
.36475 .01542 L
.36491 .01509 L
.36506 .01476 L
.3652 .015 L
.36534 .01537 L
.3655 .01578 L
.36583 .01675 L
.36693 .02093 L
.36813 .02739 L
.36936 .03646 L
.37049 .04706 L
.37302 .07997 L
.37533 .12181 L
.37784 .17943 L
.38277 .32022 L
.38752 .46162 L
Mistroke
.38991 .52167 L
.39209 .56432 L
.39329 .58165 L
.39385 .58799 L
.39444 .59357 L
.39476 .59614 L
.39506 .59814 L
.39536 .59984 L
.39564 .6011 L
.39597 .60223 L
.39614 .60266 L
.39622 .60284 L
.39632 .603 L
.39647 .6032 L
.39662 .6033 L
.39671 .60332 L
.3968 .60331 L
.39695 .60323 L
.39709 .60308 L
.39724 .60284 L
.39738 .60254 L
.39751 .6022 L
.39781 .60118 L
.39812 .59976 L
.39871 .5961 L
.39936 .59066 L
.40051 .5774 L
.40158 .56117 L
.40405 .51111 L
.4063 .45369 L
.41112 .31169 L
.41577 .18256 L
.41812 .12899 L
.42071 .0823 L
.42189 .0653 L
.42317 .05005 L
.42436 .03842 L
.42547 .02978 L
.42669 .02235 L
.42732 .01931 L
.42766 .0179 L
.42802 .01652 L
.42818 .01598 L
.42834 .01544 L
.42848 .015 L
.42863 .01489 L
.42877 .01529 L
.42892 .01571 L
.4292 .0164 L
.42985 .01778 L
Mistroke
.43045 .01874 L
.43105 .01945 L
.43135 .01972 L
.43168 .01995 L
.43201 .02013 L
.4322 .02021 L
.43237 .02026 L
.43253 .0203 L
.43261 .02032 L
.4327 .02034 L
.43279 .02035 L
.43287 .02036 L
.43302 .02037 L
.43317 .02037 L
.43325 .02037 L
.43333 .02037 L
.43348 .02035 L
.43362 .02034 L
.43378 .02031 L
.43393 .02028 L
.43427 .02019 L
.43488 .01997 L
.43545 .01971 L
.44007 .01713 L
.44241 .01586 L
.44305 .01551 L
.44374 .01512 L
.44406 .01494 L
.44423 .01484 L
.44432 .01479 L
.44439 .01474 L
.44453 .01476 L
.44468 .01485 L
.44499 .01503 L
.44746 .0164 L
.44854 .01692 L
.44973 .01739 L
.45027 .01756 L
.45085 .01771 L
.45117 .01777 L
.45147 .01782 L
.45176 .01786 L
.45191 .01787 L
.45204 .01788 L
.4522 .01789 L
.45235 .0179 L
.4525 .0179 L
.45259 .0179 L
.45267 .0179 L
.4528 .0179 L
Mistroke
.45295 .01789 L
.4531 .01789 L
.45324 .01787 L
.45357 .01784 L
.45388 .0178 L
.45422 .01773 L
.45455 .01766 L
.45572 .01729 L
.45696 .01673 L
.45918 .01545 L
.45976 .01507 L
.46005 .01489 L
.46019 .0148 L
.46032 .01472 L
.46046 .01481 L
.46062 .01491 L
.46095 .01513 L
.46154 .0155 L
.46374 .01677 L
.46495 .01731 L
.46553 .01752 L
.46606 .01767 L
.46664 .01781 L
.46695 .01786 L
.46728 .0179 L
.46745 .01792 L
.46763 .01794 L
.46771 .01794 L
.4678 .01794 L
.46796 .01795 L
.46811 .01795 L
.46825 .01795 L
.4684 .01795 L
.46849 .01795 L
.46857 .01794 L
.46873 .01793 L
.46887 .01792 L
.46914 .01789 L
.46944 .01785 L
.46975 .01779 L
.47033 .01766 L
.47085 .0175 L
.47206 .01704 L
.47335 .0164 L
.47449 .01576 L
.47511 .01538 L
.47571 .01501 L
.47597 .01485 L
.47612 .01476 L
.47626 .01476 L
Mistroke
.47634 .0148 L
.47642 .01486 L
.47657 .01495 L
.47686 .01513 L
.47792 .01575 L
.47916 .01642 L
.48032 .01695 L
.48153 .01737 L
.48218 .01753 L
.48254 .0176 L
.48286 .01765 L
.48314 .01768 L
.4833 .0177 L
.48344 .01771 L
.4836 .01772 L
.48368 .01772 L
.48376 .01772 L
.48391 .01773 L
.48406 .01773 L
.48421 .01773 L
.48434 .01772 L
.48449 .01771 L
.48463 .0177 L
.48489 .01768 L
.48517 .01765 L
.48547 .0176 L
.4858 .01754 L
.48647 .01738 L
.48767 .01698 L
.48898 .01641 L
.49022 .01577 L
.49133 .01514 L
.49164 .01496 L
.4918 .01487 L
.49196 .01477 L
.49211 .01474 L
.49227 .01483 L
.49254 .01499 L
.49478 .01621 L
.49605 .01678 L
.49666 .01701 L
.49723 .0172 L
.49779 .01735 L
.49839 .01748 L
.49873 .01753 L
.49903 .01757 L
.49933 .0176 L
.49948 .01761 L
.49964 .01761 L
.49972 .01762 L
Mistroke
.49981 .01762 L
.49989 .01762 L
.49997 .01762 L
.50012 .01762 L
.50027 .01762 L
.50036 .01761 L
.50046 .01761 L
.50063 .0176 L
.5008 .01758 L
.50095 .01757 L
.50155 .01749 L
.50185 .01743 L
.50218 .01736 L
.50341 .01699 L
.50454 .01653 L
.50585 .01589 L
.50642 .01558 L
.50706 .01522 L
.50733 .01506 L
.50763 .01489 L
.50777 .01481 L
.50792 .01473 L
.50804 .01477 L
.50817 .01485 L
.50936 .01553 L
.51067 .01624 L
.51186 .0168 L
.51245 .01703 L
.51308 .01725 L
.51363 .01741 L
.51423 .01755 L
.51454 .01761 L
.51487 .01765 L
.51505 .01768 L
.51522 .01769 L
.51539 .01771 L
.51554 .01772 L
.51569 .01772 L
.51584 .01773 L
.51593 .01773 L
.51601 .01773 L
.51616 .01773 L
.51631 .01772 L
.51645 .01771 L
.5166 .0177 L
.51675 .01769 L
.51706 .01766 L
.51735 .01762 L
.5179 .01751 L
.51849 .01736 L
Mistroke
.51913 .01716 L
.52134 .01616 L
.52257 .01547 L
.52318 .0151 L
.52344 .01494 L
.52359 .01485 L
.52373 .01476 L
.52387 .01475 L
.52401 .01484 L
.52431 .01502 L
.52494 .01541 L
.52626 .01619 L
.5275 .01684 L
.52815 .01713 L
.52884 .0174 L
.52945 .0176 L
.53011 .01776 L
.5304 .01782 L
.53071 .01787 L
.53101 .01791 L
.53128 .01793 L
.53142 .01794 L
.53155 .01795 L
.5317 .01795 L
.53185 .01795 L
.53201 .01795 L
.53209 .01795 L
.53217 .01795 L
.53233 .01794 L
.53247 .01793 L
.53275 .0179 L
.533 .01787 L
.53357 .01776 L
.53419 .0176 L
.53486 .01738 L
.53608 .01686 L
.53847 .0155 L
.53905 .01512 L
.53937 .01492 L
.53953 .01481 L
.53968 .01472 L
.53976 .01477 L
.53985 .01482 L
.54004 .01495 L
.54037 .01516 L
.54101 .01557 L
.54225 .01631 L
.54359 .017 L
.54421 .01726 L
.54486 .01749 L
Mistroke
.54542 .01765 L
.54603 .01778 L
.54633 .01783 L
.54649 .01785 L
.54666 .01787 L
.54681 .01788 L
.54688 .01788 L
.54697 .01789 L
.54712 .0179 L
.54726 .0179 L
.54739 .0179 L
.54754 .0179 L
.5477 .0179 L
.54784 .01789 L
.54798 .01788 L
.5481 .01787 L
.54838 .01784 L
.5487 .01779 L
.549 .01774 L
.54968 .01758 L
.5509 .01716 L
.55317 .01607 L
.55447 .01534 L
.55477 .01517 L
.55509 .01499 L
.55524 .0149 L
.55539 .01481 L
.55552 .01474 L
.55566 .01477 L
.5558 .01486 L
.55596 .01495 L
.55623 .0151 L
.55686 .01546 L
.558 .01609 L
.56052 .01746 L
.56293 .01883 L
.56397 .01942 L
.56511 .01996 L
.56542 .02008 L
.56574 .02019 L
.56602 .02027 L
.56618 .0203 L
.56632 .02033 L
.56647 .02035 L
.56661 .02036 L
.56676 .02037 L
.56684 .02037 L
.56692 .02037 L
.56706 .02036 L
.56718 .02035 L
Mistroke
.56733 .02033 L
.56747 .0203 L
.56762 .02027 L
.56778 .02022 L
.5681 .02007 L
.5684 .0199 L
.56868 .01969 L
.56932 .01905 L
.56967 .01857 L
.57 .01805 L
.57058 .01692 L
.57089 .01618 L
.57119 .0154 L
.57131 .01505 L
.57144 .01476 L
.57159 .0152 L
.57172 .01562 L
.5723 .01772 L
.57349 .02332 L
.5748 .03167 L
.57604 .04203 L
.57716 .05372 L
.57969 .08862 L
.582 .13156 L
.58451 .18951 L
.58944 .32867 L
.59419 .46699 L
.59658 .52545 L
.59876 .56677 L
.59996 .58341 L
.60052 .58945 L
.60111 .59472 L
.60143 .59712 L
.60173 .59896 L
.60203 .6005 L
.60231 .60163 L
.60247 .60213 L
.60264 .60258 L
.60281 .60293 L
.6029 .60307 L
.60299 .60318 L
.60307 .60325 L
.60315 .60329 L
.6033 .60332 L
.60345 .60326 L
.60354 .60318 L
.60362 .60308 L
.60377 .60285 L
.60392 .60253 L
.60418 .60176 L
Mistroke
.60447 .60062 L
.60479 .59903 L
.60535 .59527 L
.60588 .59075 L
.60708 .57676 L
.60836 .55655 L
.61094 .50161 L
.61337 .43642 L
.61802 .29619 L
.62037 .22729 L
.62296 .15987 L
.62544 .10655 L
.62771 .06909 L
.63006 .04155 L
.63136 .03086 L
.63258 .02331 L
.63375 .01819 L
.63433 .01626 L
.63449 .0158 L
.63467 .01534 L
.63475 .01513 L
.63483 .01493 L
.63498 .01485 L
.63512 .01516 L
.63525 .01542 L
.63553 .01595 L
.63604 .01673 L
.63633 .01708 L
.63664 .01739 L
.63693 .01762 L
.6372 .01779 L
.63748 .01793 L
.63764 .01798 L
.63779 .01803 L
.63792 .01806 L
.63805 .01808 L
.6382 .0181 L
.63834 .01811 L
.63842 .01812 L
.6385 .01812 L
.63859 .01812 L
.63868 .01812 L
.63883 .01811 L
.63892 .0181 L
.639 .01809 L
.63929 .01805 L
.63959 .018 L
.64023 .01786 L
.64058 .01779 L
.64091 .01773 L
Mistroke
.64121 .01768 L
.64149 .01765 L
.64164 .01764 L
.6418 .01762 L
.64196 .01762 L
.64205 .01761 L
.64213 .01761 L
.64221 .01761 L
.64229 .01761 L
.64244 .01761 L
.64259 .01762 L
.64272 .01762 L
.64303 .01764 L
.64336 .01766 L
.64369 .01769 L
.64405 .01771 L
.64422 .01772 L
.64438 .01773 L
.64453 .01774 L
.64462 .01774 L
.64469 .01774 L
.64484 .01774 L
.64499 .01774 L
.64511 .01773 L
.64525 .01772 L
.6454 .01771 L
.64556 .0177 L
.64585 .01766 L
.64616 .0176 L
.64645 .01753 L
.64712 .01731 L
.64821 .01677 L
.64937 .01596 L
.64998 .01546 L
.6503 .01517 L
.65047 .01502 L
.65064 .01486 L
.6508 .01472 L
.65088 .0148 L
.65096 .01487 L
.65125 .01515 L
.65182 .01572 L
.65439 .01821 L
.65555 .01916 L
.65617 .01958 L
.65681 .01994 L
.65713 .02009 L
.65748 .02022 L
.6578 .02033 L
.65809 .0204 L
Mistroke
.65839 .02046 L
.65855 .02048 L
.65871 .02049 L
.65885 .0205 L
.65898 .0205 L
.65913 .0205 L
.65929 .0205 L
.65942 .02048 L
.65955 .02047 L
.65969 .02045 L
.65984 .02042 L
.66008 .02037 L
.66035 .02029 L
.66096 .02006 L
.66153 .01976 L
.6628 .01886 L
.66399 .01775 L
.66506 .0166 L
.66567 .0159 L
.66596 .01555 L
.66624 .01523 L
.66637 .01506 L
.66653 .01488 L
.66667 .01472 L
.6668 .01487 L
.66741 .0156 L
.66865 .01704 L
.66972 .01817 L
.67087 .01921 L
.67154 .0197 L
.67215 .02008 L
.67273 .02037 L
.67303 .02048 L
.67335 .02059 L
.67364 .02066 L
.6739 .02071 L
.67403 .02073 L
.67417 .02074 L
.6743 .02075 L
.67442 .02076 L
.67456 .02076 L
.67469 .02076 L
.67483 .02075 L
.67499 .02073 L
.67514 .02072 L
.6753 .02069 L
.67559 .02063 L
.6759 .02054 L
.6762 .02044 L
.67675 .02019 L
Mistroke
.67798 .01942 L
.67904 .01852 L
.68019 .01738 L
.68143 .016 L
.68204 .0153 L
.6823 .01499 L
.68245 .01481 L
.68259 .01478 L
.68274 .01494 L
.68289 .01512 L
.68318 .01545 L
.6838 .01616 L
.68513 .01757 L
.68638 .01871 L
.68703 .0192 L
.68772 .01964 L
.68833 .01995 L
.68865 .02008 L
.68899 .0202 L
.68931 .02028 L
.68959 .02034 L
.68973 .02036 L
.68988 .02038 L
.69002 .02039 L
.69016 .0204 L
.69031 .0204 L
.69045 .0204 L
.69058 .0204 L
.69072 .02039 L
.69087 .02038 L
.69103 .02035 L
.69132 .0203 L
.69162 .02023 L
.69189 .02014 L
.69241 .01994 L
.69304 .01963 L
.69361 .01928 L
.6949 .01828 L
.69717 .01605 L
.69779 .01539 L
.69813 .01502 L
.69822 .01493 L
.6983 .01483 L
.69846 .01476 L
.6986 .01492 L
.69876 .01509 L
.69909 .01544 L
.69966 .01604 L
.70089 .01726 L
.70219 .01836 L
Mistroke
.7033 .01911 L
.70393 .01944 L
.70451 .01967 L
.7048 .01977 L
.70512 .01985 L
.70526 .01988 L
.70542 .01991 L
.70555 .01993 L
.70569 .01994 L
.70583 .01996 L
.70596 .01997 L
.70608 .01997 L
.7062 .01997 L
.70634 .01997 L
.70647 .01997 L
.70661 .01996 L
.70677 .01994 L
.70693 .01992 L
.70708 .0199 L
.70742 .01983 L
.70771 .01975 L
.70803 .01964 L
.70917 .01911 L
.71032 .01836 L
.71155 .01736 L
.7127 .01629 L
.71376 .01524 L
.71391 .01509 L
.71407 .01493 L
.71422 .01478 L
.71436 .01478 L
.7145 .01493 L
.71466 .01509 L
.71499 .01541 L
.71633 .01668 L
.7175 .01767 L
.71875 .01854 L
.7194 .01889 L
.72 .01916 L
.72055 .01935 L
.72086 .01943 L
.72114 .01949 L
.72127 .01951 L
.7214 .01953 L
.72152 .01955 L
.72165 .01956 L
.7218 .01957 L
.72195 .01957 L
.72209 .01958 L
.72222 .01958 L
Mistroke
.72235 .01957 L
.72248 .01956 L
.72262 .01955 L
.72277 .01953 L
.72307 .01949 L
.72336 .01943 L
.72393 .01927 L
.72454 .01903 L
.72563 .01845 L
.72694 .01754 L
.72813 .01656 L
.72925 .01555 L
.72982 .01503 L
.72997 .01489 L
.73006 .01481 L
.73014 .01473 L
.7303 .01484 L
.73044 .01497 L
.73174 .01615 L
.73295 .01714 L
.7341 .01795 L
.73474 .01833 L
.73534 .01863 L
.7359 .01885 L
.73619 .01895 L
.7365 .01904 L
.73676 .0191 L
.73705 .01916 L
.73718 .01918 L
.73731 .0192 L
.73744 .01921 L
.73755 .01922 L
.7377 .01923 L
.73778 .01923 L
.73786 .01924 L
.73795 .01924 L
.73804 .01924 L
.73819 .01923 L
.73834 .01923 L
.73847 .01922 L
.73862 .0192 L
.73878 .01918 L
.73914 .01912 L
.73948 .01904 L
.74012 .01884 L
.74072 .01859 L
.74128 .01832 L
.74254 .01754 L
.74481 .01577 L
.74543 .01524 L
Mistroke
.74559 .01509 L
.74577 .01494 L
.74585 .01487 L
.74594 .01479 L
.74609 .01477 L
.74618 .01484 L
.74626 .01492 L
.74642 .01505 L
.74672 .01531 L
.7473 .01579 L
.74966 .01755 L
.75031 .01793 L
.751 .01828 L
.75165 .01855 L
.75225 .01873 L
.75255 .01881 L
.75287 .01887 L
.75318 .01891 L
.75336 .01893 L
.75345 .01894 L
.75353 .01894 L
.75369 .01895 L
.75384 .01895 L
.75398 .01895 L
.75412 .01894 L
.7542 .01894 L
.75428 .01894 L
.75442 .01892 L
.75458 .01891 L
.75475 .01889 L
.75502 .01884 L
.75532 .01878 L
.75593 .0186 L
.7565 .01839 L
.75702 .01816 L
.75947 .01663 L
.76056 .0158 L
.76115 .01532 L
.76144 .01509 L
.76171 .01487 L
.76184 .01476 L
.76198 .01478 L
.76213 .01489 L
.76228 .01502 L
.76291 .01552 L
.76401 .01637 L
.76532 .01725 L
.76651 .01791 L
.7671 .01817 L
.76773 .01839 L
Mistroke
.76802 .01848 L
.76833 .01855 L
.76861 .01861 L
.76888 .01865 L
.76902 .01867 L
.76918 .01868 L
.76926 .01869 L
.76934 .0187 L
.7695 .0187 L
.76965 .01871 L
.76978 .01871 L
.76994 .01871 L
.77008 .0187 L
.77016 .0187 L
.77024 .01869 L
.77041 .01867 L
.77072 .01864 L
.77107 .01857 L
.7714 .0185 L
.77201 .01832 L
.77267 .01807 L
.77386 .01747 L
.7761 .01599 L
.77665 .01558 L
.77724 .01513 L
.7774 .015 L
.77757 .01487 L
.77772 .01476 L
.7778 .01473 L
.77788 .01479 L
.77849 .01526 L
.77979 .01621 L
.78102 .01702 L
.78221 .01766 L
.78283 .01793 L
.78349 .01817 L
.78405 .01832 L
.78437 .01839 L
.78466 .01843 L
.7848 .01845 L
.78493 .01847 L
.78505 .01848 L
.78518 .01849 L
.78532 .0185 L
.78545 .0185 L
.78558 .0185 L
.78574 .0185 L
.78588 .0185 L
.78602 .01849 L
.78617 .01848 L
Mistroke
.78633 .01847 L
.78665 .01843 L
.78695 .01838 L
.78752 .01824 L
.78806 .01808 L
.78927 .01757 L
.79058 .01685 L
.79181 .01604 L
.79297 .01521 L
.79327 .01499 L
.79342 .01489 L
.79355 .01479 L
.79371 .01476 L
.79379 .01482 L
.79388 .01488 L
.79418 .0151 L
.79551 .01604 L
.79675 .01682 L
.79809 .01753 L
.79871 .01778 L
.79936 .01801 L
.79991 .01815 L
.80023 .01822 L
.80052 .01826 L
.80067 .01828 L
.80084 .0183 L
.80098 .01831 L
.80113 .01832 L
.80121 .01833 L
.80129 .01833 L
.80144 .01833 L
.80152 .01833 L
.80161 .01833 L
.8017 .01833 L
.80178 .01833 L
.80194 .01832 L
.80209 .01831 L
.80222 .0183 L
.80236 .01828 L
.80268 .01824 L
.80298 .01818 L
.80349 .01806 L
.80406 .01789 L
.80522 .01741 L
.80652 .01671 L
.80776 .01593 L
.80887 .01517 L
.80917 .01496 L
.80934 .01484 L
.8095 .01473 L
Mistroke
.80964 .0148 L
.8098 .01491 L
.81008 .0151 L
.81231 .01656 L
.81358 .01724 L
.8142 .01751 L
.81476 .01772 L
.81532 .0179 L
.81593 .01804 L
.81626 .0181 L
.81641 .01812 L
.81657 .01814 L
.81671 .01816 L
.81686 .01817 L
.81694 .01817 L
.81702 .01818 L
.81717 .01818 L
.81732 .01819 L
.81748 .01819 L
.81763 .01818 L
.81776 .01818 L
.81785 .01817 L
.81792 .01817 L
.8181 .01816 L
.81841 .01812 L
.81871 .01807 L
.81904 .01801 L
.81971 .01783 L
.82035 .01762 L
.82094 .01737 L
.82206 .01682 L
.82329 .0161 L
.82396 .01568 L
.82459 .01526 L
.82513 .01489 L
.82528 .01479 L
.82544 .01474 L
.82558 .01484 L
.82573 .01494 L
.82698 .01576 L
.8292 .01703 L
.82984 .01732 L
.83044 .01755 L
.83099 .01773 L
.83157 .01787 L
.83187 .01794 L
.8322 .01799 L
.83234 .01801 L
.8325 .01803 L
.83264 .01804 L
Mistroke
.83278 .01805 L
.83287 .01805 L
.83295 .01806 L
.83304 .01806 L
.83313 .01806 L
.83321 .01807 L
.8333 .01807 L
.83339 .01807 L
.83346 .01806 L
.83361 .01806 L
.83369 .01805 L
.83377 .01805 L
.83393 .01804 L
.83409 .01802 L
.8344 .01798 L
.83473 .01793 L
.83532 .0178 L
.83596 .01761 L
.83666 .01735 L
.83908 .0161 L
.84022 .0154 L
.84052 .0152 L
.84084 .01499 L
.841 .01489 L
.84114 .0148 L
.84128 .01472 L
.84142 .01481 L
.84205 .01522 L
.84273 .01565 L
.84393 .01637 L
.84517 .017 L
.84633 .01747 L
.84692 .01765 L
.84754 .0178 L
.8479 .01786 L
.84824 .01791 L
.84838 .01792 L
.84854 .01794 L
.84863 .01794 L
.84871 .01795 L
.84887 .01796 L
.84902 .01796 L
.84915 .01796 L
.8493 .01796 L
.84939 .01796 L
.84946 .01796 L
.84962 .01795 L
.84978 .01794 L
.84994 .01792 L
.85009 .01791 L
Mistroke
.85063 .01783 L
.8509 .01777 L
.8512 .0177 L
.8525 .01728 L
.85371 .01674 L
.85496 .01606 L
.85615 .01534 L
.85667 .01501 L
.85681 .01493 L
.85695 .01483 L
.85709 .01475 L
.85722 .01476 L
.85738 .01486 L
.85754 .01496 L
.85783 .01515 L
.85839 .01549 L
.85962 .01621 L
.86078 .01681 L
.86192 .01729 L
.86297 .01761 L
.86351 .01773 L
.86379 .01778 L
.86409 .01782 L
.86424 .01784 L
.8644 .01785 L
.86457 .01786 L
.86472 .01787 L
.86487 .01787 L
.86501 .01788 L
.86516 .01788 L
.86524 .01787 L
.86532 .01787 L
.86548 .01786 L
.86555 .01786 L
.86564 .01785 L
.86594 .01783 L
.86611 .01781 L
.86629 .01778 L
.86661 .01772 L
.86725 .01758 L
.86784 .0174 L
.86903 .01694 L
.87013 .01641 L
.87142 .01569 L
.87205 .01531 L
.87233 .01514 L
.87263 .01495 L
.87278 .01486 L
.87293 .01476 L
.87308 .01475 L
Mistroke
.87321 .01484 L
.87383 .01521 L
.87511 .01597 L
.8762 .01655 L
.87736 .01707 L
.87793 .01728 L
.87856 .01747 L
.87913 .01761 L
.87966 .01771 L
.87997 .01775 L
.88014 .01777 L
.88029 .01778 L
.88043 .01779 L
.88057 .0178 L
.88073 .0178 L
.88087 .0178 L
.88095 .0178 L
.88104 .0178 L
.88119 .0178 L
.88128 .0178 L
.88136 .01779 L
.88154 .01778 L
.8817 .01777 L
.88184 .01775 L
.88217 .01771 L
.88275 .0176 L
.88336 .01745 L
.88447 .01708 L
.88565 .01655 L
.88697 .01585 L
.8881 .01519 L
.88838 .01502 L
.88867 .01484 L
.88876 .01479 L
.88884 .01474 L
.889 .01478 L
.88914 .01487 L
.8893 .01496 L
.89061 .01573 L
.89181 .01638 L
.89305 .01695 L
.89421 .01736 L
.89479 .01751 L
.89541 .01763 L
.89577 .01768 L
.89594 .0177 L
.89611 .01772 L
.89625 .01773 L
.89641 .01774 L
.8965 .01774 L
Mistroke
.89658 .01774 L
.89674 .01775 L
.89688 .01775 L
.89703 .01774 L
.89717 .01774 L
.8973 .01773 L
.89745 .01772 L
.89762 .01771 L
.89792 .01767 L
.89823 .01762 L
.89857 .01756 L
.89916 .01742 L
.90022 .01708 L
.90139 .01658 L
.90253 .016 L
.90373 .01533 L
.90435 .01496 L
.90452 .01486 L
.90462 .0148 L
.90471 .01475 L
.90479 .01473 L
.90488 .01479 L
.90504 .01488 L
.90624 .01558 L
.90864 .01679 L
.90985 .01724 L
.91054 .01744 L
.91087 .01751 L
.91118 .01757 L
.91149 .01762 L
.91178 .01765 L
.91193 .01767 L
.9121 .01768 L
.91219 .01769 L
.91227 .01769 L
.91235 .01769 L
.91243 .0177 L
.91258 .0177 L
.91271 .0177 L
.91287 .0177 L
.91301 .01769 L
.91316 .01769 L
.91333 .01768 L
.91363 .01765 L
.91389 .01761 L
.91419 .01757 L
.91479 .01744 L
.91534 .01729 L
.91586 .01713 L
.9183 .01604 L
Mistroke
.91938 .01544 L
.91997 .0151 L
.92027 .01493 L
.92039 .01486 L
.92053 .01477 L
.92068 .01474 L
.92083 .01483 L
.92116 .01502 L
.92172 .01535 L
.92282 .01596 L
.92413 .0166 L
.92532 .01708 L
.9259 .01727 L
.92653 .01743 L
.92682 .01749 L
.92712 .01755 L
.92741 .01759 L
.92767 .01762 L
.92781 .01763 L
.92797 .01764 L
.92812 .01765 L
.92821 .01766 L
.92829 .01766 L
.92844 .01766 L
.92857 .01766 L
.92872 .01766 L
.92887 .01766 L
.92895 .01766 L
.92903 .01765 L
.9292 .01764 L
.9295 .01761 L
.92986 .01757 L
.93019 .01751 L
.93079 .01738 L
.93145 .0172 L
.93264 .01675 L
.93487 .01565 L
.93551 .01529 L
.93583 .01511 L
.93612 .01494 L
.93638 .01479 L
.93652 .01472 L
.93666 .0148 L
.93725 .01514 L
.93857 .01588 L
.93978 .01648 L
.94091 .01696 L
.9415 .01716 L
.94213 .01734 L
.94245 .01742 L
Mistroke
.94281 .01749 L
.94313 .01754 L
.94343 .01758 L
.94373 .01761 L
.94389 .01762 L
.94398 .01763 L
.94406 .01763 L
.94421 .01764 L
.94435 .01764 L
.94443 .01764 L
.94451 .01764 L
.94466 .01764 L
.9448 .01763 L
.94495 .01763 L
.94509 .01762 L
.94522 .01761 L
.94553 .01757 L
.94583 .01753 L
.94643 .01742 L
.94707 .01725 L
.94823 .01685 L
.9493 .01639 L
.95058 .01573 L
.95121 .01539 L
.95178 .01506 L
.95205 .0149 L
.95219 .01483 L
.95231 .01476 L
.95244 .01475 L
.95257 .01482 L
.95286 .01499 L
.95403 .01565 L
.95634 .01677 L
.95697 .01701 L
.95764 .01723 L
.95827 .01739 L
.95884 .0175 L
.95912 .01755 L
.95942 .01758 L
.95956 .01759 L
.95971 .01761 L
.95985 .01761 L
.95998 .01762 L
.96014 .01762 L
.96028 .01763 L
.96044 .01762 L
.96052 .01762 L
.96061 .01762 L
.96075 .01761 L
.96091 .01761 L
Mistroke
.96106 .01759 L
.9612 .01758 L
.96174 .01751 L
.96205 .01746 L
.96233 .0174 L
.96341 .0171 L
.96457 .01665 L
.96566 .01614 L
.96687 .0155 L
.96753 .01513 L
.96785 .01495 L
.96799 .01487 L
.96814 .01478 L
.96829 .01474 L
.96843 .01482 L
.9687 .01497 L
.9693 .01531 L
.97057 .016 L
.97173 .01656 L
.97281 .01699 L
.97358 .01724 L
.97442 .01744 L
.97465 .01749 L
.97489 .01753 L
.97511 .01755 L
.97534 .01758 L
.97546 .01759 L
.97557 .0176 L
.97568 .01761 L
.97578 .01761 L
.97588 .01762 L
.97598 .01762 L
.97608 .01762 L
.97619 .01762 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.00459847 0.64881 0.188537 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.491929 0.0484262 0.0147151 0.0443004 [
[.00767 -0.0125 -9 -9 ]
[.00767 -0.0125 9 0 ]
[.2498 -0.0125 -6 -9 ]
[.2498 -0.0125 6 0 ]
[.49193 -0.0125 -3 -9 ]
[.49193 -0.0125 3 0 ]
[.73406 -0.0125 -3 -9 ]
[.73406 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .10332 -6 -4.5 ]
[-0.0125 .10332 0 4.5 ]
[-0.0125 .19192 -6 -4.5 ]
[-0.0125 .19192 0 4.5 ]
[-0.0125 .28052 -6 -4.5 ]
[-0.0125 .28052 0 4.5 ]
[-0.0125 .36912 -6 -4.5 ]
[-0.0125 .36912 0 4.5 ]
[-0.0125 .45772 -12 -4.5 ]
[-0.0125 .45772 0 4.5 ]
[-0.0125 .54632 -12 -4.5 ]
[-0.0125 .54632 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.00767 0 m
.00767 .00625 L
s
[(-10)] .00767 -0.0125 0 1 Mshowa
.2498 0 m
.2498 .00625 L
s
[(-5)] .2498 -0.0125 0 1 Mshowa
.49193 0 m
.49193 .00625 L
s
[(0)] .49193 -0.0125 0 1 Mshowa
.73406 0 m
.73406 .00625 L
s
[(5)] .73406 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05609 0 m
.05609 .00375 L
s
.10452 0 m
.10452 .00375 L
s
.15295 0 m
.15295 .00375 L
s
.20137 0 m
.20137 .00375 L
s
.29822 0 m
.29822 .00375 L
s
.34665 0 m
.34665 .00375 L
s
.39508 0 m
.39508 .00375 L
s
.4435 0 m
.4435 .00375 L
s
.54036 0 m
.54036 .00375 L
s
.58878 0 m
.58878 .00375 L
s
.63721 0 m
.63721 .00375 L
s
.68563 0 m
.68563 .00375 L
s
.78249 0 m
.78249 .00375 L
s
.83091 0 m
.83091 .00375 L
s
.87934 0 m
.87934 .00375 L
s
.92776 0 m
.92776 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .10332 m
.00625 .10332 L
s
[(2)] -0.0125 .10332 1 0 Mshowa
0 .19192 m
.00625 .19192 L
s
[(4)] -0.0125 .19192 1 0 Mshowa
0 .28052 m
.00625 .28052 L
s
[(6)] -0.0125 .28052 1 0 Mshowa
0 .36912 m
.00625 .36912 L
s
[(8)] -0.0125 .36912 1 0 Mshowa
0 .45772 m
.00625 .45772 L
s
[(10)] -0.0125 .45772 1 0 Mshowa
0 .54632 m
.00625 .54632 L
s
[(12)] -0.0125 .54632 1 0 Mshowa
.125 Mabswid
0 .03687 m
.00375 .03687 L
s
0 .05902 m
.00375 .05902 L
s
0 .08117 m
.00375 .08117 L
s
0 .12547 m
.00375 .12547 L
s
0 .14762 m
.00375 .14762 L
s
0 .16977 m
.00375 .16977 L
s
0 .21407 m
.00375 .21407 L
s
0 .23622 m
.00375 .23622 L
s
0 .25837 m
.00375 .25837 L
s
0 .30267 m
.00375 .30267 L
s
0 .32482 m
.00375 .32482 L
s
0 .34697 m
.00375 .34697 L
s
0 .39127 m
.00375 .39127 L
s
0 .41342 m
.00375 .41342 L
s
0 .43557 m
.00375 .43557 L
s
0 .47987 m
.00375 .47987 L
s
0 .50202 m
.00375 .50202 L
s
0 .52417 m
.00375 .52417 L
s
0 .56847 m
.00375 .56847 L
s
0 .59062 m
.00375 .59062 L
s
0 .61277 m
.00375 .61277 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.00767 .61178 m
.00767 .61803 L
s
.2498 .61178 m
.2498 .61803 L
s
.49193 .61178 m
.49193 .61803 L
s
.73406 .61178 m
.73406 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.05609 .61428 m
.05609 .61803 L
s
.10452 .61428 m
.10452 .61803 L
s
.15295 .61428 m
.15295 .61803 L
s
.20137 .61428 m
.20137 .61803 L
s
.29822 .61428 m
.29822 .61803 L
s
.34665 .61428 m
.34665 .61803 L
s
.39508 .61428 m
.39508 .61803 L
s
.4435 .61428 m
.4435 .61803 L
s
.54036 .61428 m
.54036 .61803 L
s
.58878 .61428 m
.58878 .61803 L
s
.63721 .61428 m
.63721 .61803 L
s
.68563 .61428 m
.68563 .61803 L
s
.78249 .61428 m
.78249 .61803 L
s
.83091 .61428 m
.83091 .61803 L
s
.87934 .61428 m
.87934 .61803 L
s
.92776 .61428 m
.92776 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .10332 m
1 .10332 L
s
.99375 .19192 m
1 .19192 L
s
.99375 .28052 m
1 .28052 L
s
.99375 .36912 m
1 .36912 L
s
.99375 .45772 m
1 .45772 L
s
.99375 .54632 m
1 .54632 L
s
.125 Mabswid
.99625 .03687 m
1 .03687 L
s
.99625 .05902 m
1 .05902 L
s
.99625 .08117 m
1 .08117 L
s
.99625 .12547 m
1 .12547 L
s
.99625 .14762 m
1 .14762 L
s
.99625 .16977 m
1 .16977 L
s
.99625 .21407 m
1 .21407 L
s
.99625 .23622 m
1 .23622 L
s
.99625 .25837 m
1 .25837 L
s
.99625 .30267 m
1 .30267 L
s
.99625 .32482 m
1 .32482 L
s
.99625 .34697 m
1 .34697 L
s
.99625 .39127 m
1 .39127 L
s
.99625 .41342 m
1 .41342 L
s
.99625 .43557 m
1 .43557 L
s
.99625 .47987 m
1 .47987 L
s
.99625 .50202 m
1 .50202 L
s
.99625 .52417 m
1 .52417 L
s
.99625 .56847 m
1 .56847 L
s
.99625 .59062 m
1 .59062 L
s
.99625 .61277 m
1 .61277 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .01472 m
.02381 .01827 L
s
.03995 .01472 m
.03995 .01828 L
s
.05609 .01472 m
.05609 .01831 L
s
.07224 .01472 m
.07224 .01836 L
s
.08838 .01472 m
.08838 .01841 L
s
.10452 .01472 m
.10452 .01848 L
s
.12066 .01472 m
.12066 .01857 L
s
.1368 .01472 m
.1368 .01868 L
s
.15295 .01472 m
.15295 .0188 L
s
.16909 .01472 m
.16909 .01895 L
s
.18523 .01472 m
.18523 .01913 L
s
.20137 .01472 m
.20137 .01934 L
s
.21751 .01472 m
.21751 .01958 L
s
.23366 .01472 m
.23366 .01988 L
s
.2498 .01472 m
.2498 .02023 L
s
.26594 .01472 m
.26594 .02064 L
s
.28208 .01472 m
.28208 .02113 L
s
.29822 .01472 m
.29822 .02165 L
s
.31437 .01472 m
.31437 .02208 L
s
.33051 .01472 m
.33051 .02176 L
s
.34665 .01472 m
.34665 .01827 L
s
.36279 .01472 m
.36279 .09426 L
s
.37893 .01472 m
.37893 .60332 L
s
.39508 .01472 m
.39508 .59911 L
s
.41122 .01472 m
.41122 .09851 L
s
.42736 .01472 m
.42736 .02013 L
s
.4435 .01472 m
.4435 .0186 L
s
.45964 .01472 m
.45964 .01866 L
s
.47579 .01472 m
.47579 .01839 L
s
.49193 .01472 m
.49193 .01826 L
s
.50807 .01472 m
.50807 .01839 L
s
.52421 .01472 m
.52421 .01866 L
s
.54036 .01472 m
.54036 .0186 L
s
.5565 .01472 m
.5565 .02013 L
s
.57264 .01472 m
.57264 .09851 L
s
.58878 .01472 m
.58878 .59911 L
s
.60492 .01472 m
.60492 .60332 L
s
.62107 .01472 m
.62107 .09426 L
s
.63721 .01472 m
.63721 .01827 L
s
.65335 .01472 m
.65335 .02176 L
s
.66949 .01472 m
.66949 .02208 L
s
.68563 .01472 m
.68563 .02165 L
s
.70178 .01472 m
.70178 .02113 L
s
.71792 .01472 m
.71792 .02064 L
s
.73406 .01472 m
.73406 .02023 L
s
.7502 .01472 m
.7502 .01988 L
s
.76634 .01472 m
.76634 .01958 L
s
.78249 .01472 m
.78249 .01934 L
s
.79863 .01472 m
.79863 .01913 L
s
.81477 .01472 m
.81477 .01895 L
s
.83091 .01472 m
.83091 .0188 L
s
.84705 .01472 m
.84705 .01868 L
s
.8632 .01472 m
.8632 .01857 L
s
.87934 .01472 m
.87934 .01848 L
s
.89548 .01472 m
.89548 .01841 L
s
.91162 .01472 m
.91162 .01836 L
s
.92776 .01472 m
.92776 .01831 L
s
.94391 .01472 m
.94391 .01828 L
s
.96005 .01472 m
.96005 .01827 L
s
.97619 .01472 m
.97619 .01826 L
s
.015 w
.02381 .01827 Mdot
.03995 .01828 Mdot
.05609 .01831 Mdot
.07224 .01836 Mdot
.08838 .01841 Mdot
.10452 .01848 Mdot
.12066 .01857 Mdot
.1368 .01868 Mdot
.15295 .0188 Mdot
.16909 .01895 Mdot
.18523 .01913 Mdot
.20137 .01934 Mdot
.21751 .01958 Mdot
.23366 .01988 Mdot
.2498 .02023 Mdot
.26594 .02064 Mdot
.28208 .02113 Mdot
.29822 .02165 Mdot
.31437 .02208 Mdot
.33051 .02176 Mdot
.34665 .01827 Mdot
.36279 .09426 Mdot
.37893 .60332 Mdot
.39508 .59911 Mdot
.41122 .09851 Mdot
.42736 .02013 Mdot
.4435 .0186 Mdot
.45964 .01866 Mdot
.47579 .01839 Mdot
.49193 .01826 Mdot
.50807 .01839 Mdot
.52421 .01866 Mdot
.54036 .0186 Mdot
.5565 .02013 Mdot
.57264 .09851 Mdot
.58878 .59911 Mdot
.60492 .60332 Mdot
.62107 .09426 Mdot
.63721 .01827 Mdot
.65335 .02176 Mdot
.66949 .02208 Mdot
.68563 .02165 Mdot
.70178 .02113 Mdot
.71792 .02064 Mdot
.73406 .02023 Mdot
.7502 .01988 Mdot
.76634 .01958 Mdot
.78249 .01934 Mdot
.79863 .01913 Mdot
.81477 .01895 Mdot
.83091 .0188 Mdot
.84705 .01868 Mdot
.8632 .01857 Mdot
.87934 .01848 Mdot
.89548 .01841 Mdot
.91162 .01836 Mdot
.92776 .01831 Mdot
.94391 .01828 Mdot
.96005 .01827 Mdot
.97619 .01826 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.00459847 0.97619 0.188537 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.047619 0.0147151 0.0363327 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .10555 -18 -4.5 ]
[-0.0125 .10555 0 4.5 ]
[-0.0125 .19638 -6 -4.5 ]
[-0.0125 .19638 0 4.5 ]
[-0.0125 .28721 -18 -4.5 ]
[-0.0125 .28721 0 4.5 ]
[-0.0125 .37804 -12 -4.5 ]
[-0.0125 .37804 0 4.5 ]
[-0.0125 .46887 -24 -4.5 ]
[-0.0125 .46887 0 4.5 ]
[-0.0125 .5597 -12 -4.5 ]
[-0.0125 .5597 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .10555 m
.00625 .10555 L
s
[(2.5)] -0.0125 .10555 1 0 Mshowa
0 .19638 m
.00625 .19638 L
s
[(5)] -0.0125 .19638 1 0 Mshowa
0 .28721 m
.00625 .28721 L
s
[(7.5)] -0.0125 .28721 1 0 Mshowa
0 .37804 m
.00625 .37804 L
s
[(10)] -0.0125 .37804 1 0 Mshowa
0 .46887 m
.00625 .46887 L
s
[(12.5)] -0.0125 .46887 1 0 Mshowa
0 .5597 m
.00625 .5597 L
s
[(15)] -0.0125 .5597 1 0 Mshowa
.125 Mabswid
0 .03288 m
.00375 .03288 L
s
0 .05105 m
.00375 .05105 L
s
0 .06921 m
.00375 .06921 L
s
0 .08738 m
.00375 .08738 L
s
0 .12371 m
.00375 .12371 L
s
0 .14188 m
.00375 .14188 L
s
0 .16005 m
.00375 .16005 L
s
0 .17821 m
.00375 .17821 L
s
0 .21454 m
.00375 .21454 L
s
0 .23271 m
.00375 .23271 L
s
0 .25088 m
.00375 .25088 L
s
0 .26904 m
.00375 .26904 L
s
0 .30538 m
.00375 .30538 L
s
0 .32354 m
.00375 .32354 L
s
0 .34171 m
.00375 .34171 L
s
0 .35988 m
.00375 .35988 L
s
0 .39621 m
.00375 .39621 L
s
0 .41437 m
.00375 .41437 L
s
0 .43254 m
.00375 .43254 L
s
0 .45071 m
.00375 .45071 L
s
0 .48704 m
.00375 .48704 L
s
0 .50521 m
.00375 .50521 L
s
0 .52337 m
.00375 .52337 L
s
0 .54154 m
.00375 .54154 L
s
0 .57787 m
.00375 .57787 L
s
0 .59604 m
.00375 .59604 L
s
0 .6142 m
.00375 .6142 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .10555 m
1 .10555 L
s
.99375 .19638 m
1 .19638 L
s
.99375 .28721 m
1 .28721 L
s
.99375 .37804 m
1 .37804 L
s
.99375 .46887 m
1 .46887 L
s
.99375 .5597 m
1 .5597 L
s
.125 Mabswid
.99625 .03288 m
1 .03288 L
s
.99625 .05105 m
1 .05105 L
s
.99625 .06921 m
1 .06921 L
s
.99625 .08738 m
1 .08738 L
s
.99625 .12371 m
1 .12371 L
s
.99625 .14188 m
1 .14188 L
s
.99625 .16005 m
1 .16005 L
s
.99625 .17821 m
1 .17821 L
s
.99625 .21454 m
1 .21454 L
s
.99625 .23271 m
1 .23271 L
s
.99625 .25088 m
1 .25088 L
s
.99625 .26904 m
1 .26904 L
s
.99625 .30538 m
1 .30538 L
s
.99625 .32354 m
1 .32354 L
s
.99625 .34171 m
1 .34171 L
s
.99625 .35988 m
1 .35988 L
s
.99625 .39621 m
1 .39621 L
s
.99625 .41437 m
1 .41437 L
s
.99625 .43254 m
1 .43254 L
s
.99625 .45071 m
1 .45071 L
s
.99625 .48704 m
1 .48704 L
s
.99625 .50521 m
1 .50521 L
s
.99625 .52337 m
1 .52337 L
s
.99625 .54154 m
1 .54154 L
s
.99625 .57787 m
1 .57787 L
s
.99625 .59604 m
1 .59604 L
s
.99625 .6142 m
1 .6142 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
0 0 1 r
.5 Mabswid
[ .01 ] 0 setdash
.02381 .01762 m
.02395 .01762 L
.02408 .01762 L
.02423 .01761 L
.02437 .0176 L
.02462 .01758 L
.02489 .01756 L
.02519 .01751 L
.02551 .01746 L
.02608 .01733 L
.02722 .01699 L
.02847 .01647 L
.02973 .01584 L
.03043 .01546 L
.03109 .01509 L
.03139 .01492 L
.03155 .01483 L
.03171 .01474 L
.03179 .01474 L
.03189 .0148 L
.03205 .01489 L
.03238 .01508 L
.03355 .01573 L
.03596 .01687 L
.03717 .01727 L
.03785 .01744 L
.03819 .0175 L
.0385 .01755 L
.03879 .01758 L
.03894 .01759 L
.0391 .01761 L
.03918 .01761 L
.03926 .01762 L
.03941 .01762 L
.03949 .01762 L
.03958 .01763 L
.03967 .01763 L
.03976 .01763 L
.03991 .01762 L
.04006 .01762 L
.04019 .01761 L
.04033 .0176 L
.04065 .01757 L
.04095 .01754 L
.04147 .01745 L
.04204 .01732 L
.04319 .01696 L
.04573 .01578 L
.04631 .01546 L
.04694 .01511 L
Mistroke
.04724 .01493 L
.04739 .01485 L
.04752 .01477 L
.04765 .01473 L
.04778 .01481 L
.04805 .01497 L
.0492 .01562 L
.05046 .01627 L
.05165 .01681 L
.05274 .01719 L
.05332 .01736 L
.05388 .01748 L
.05417 .01753 L
.05447 .01757 L
.05463 .01759 L
.0548 .01761 L
.05495 .01762 L
.05511 .01763 L
.05525 .01764 L
.0554 .01764 L
.05553 .01764 L
.05566 .01764 L
.05581 .01764 L
.05595 .01763 L
.0561 .01762 L
.05625 .01761 L
.05652 .01759 L
.05676 .01756 L
.05732 .01747 L
.05789 .01734 L
.05849 .01716 L
.05959 .01676 L
.06208 .01552 L
.06267 .01519 L
.063 .015 L
.0633 .01482 L
.06346 .01473 L
.06355 .01475 L
.06363 .0148 L
.064 .01501 L
.06464 .01538 L
.06589 .01606 L
.06706 .01663 L
.06826 .0171 L
.06878 .01727 L
.06934 .01741 L
.06967 .01749 L
.06996 .01754 L
.07027 .01759 L
.07055 .01762 L
Mistroke
.07071 .01763 L
.07085 .01765 L
.07101 .01765 L
.07109 .01766 L
.07118 .01766 L
.07126 .01766 L
.07134 .01767 L
.07149 .01767 L
.07159 .01766 L
.07167 .01766 L
.07175 .01766 L
.07184 .01766 L
.07199 .01765 L
.07213 .01764 L
.07243 .01761 L
.07272 .01757 L
.07299 .01753 L
.07359 .0174 L
.07425 .01722 L
.07557 .01674 L
.07679 .01616 L
.07787 .01558 L
.07844 .01525 L
.07904 .01491 L
.07919 .01482 L
.07928 .01477 L
.07936 .01472 L
.07945 .01477 L
.07954 .01482 L
.07971 .01492 L
.08032 .01527 L
.08152 .01595 L
.0827 .01654 L
.08394 .01706 L
.085 .01739 L
.0856 .01753 L
.08588 .01758 L
.08617 .01762 L
.08633 .01764 L
.08648 .01766 L
.08663 .01767 L
.08677 .01768 L
.08693 .01769 L
.08702 .0177 L
.08711 .0177 L
.08726 .0177 L
.08734 .0177 L
.08742 .0177 L
.08758 .0177 L
.08772 .01769 L
Mistroke
.08786 .01768 L
.088 .01767 L
.08832 .01764 L
.08861 .0176 L
.08913 .01751 L
.0897 .01738 L
.09085 .017 L
.09339 .01579 L
.09397 .01546 L
.09459 .0151 L
.09489 .01492 L
.09504 .01483 L
.09518 .01475 L
.0953 .01475 L
.09543 .01483 L
.09571 .01499 L
.09685 .01566 L
.0981 .01634 L
.0993 .01689 L
.10038 .01729 L
.10097 .01746 L
.10153 .01758 L
.10181 .01763 L
.10211 .01768 L
.10227 .0177 L
.10244 .01771 L
.10259 .01773 L
.10275 .01774 L
.10289 .01774 L
.10304 .01775 L
.10317 .01775 L
.1033 .01775 L
.10345 .01774 L
.10358 .01774 L
.10374 .01773 L
.10389 .01772 L
.10416 .01769 L
.1044 .01766 L
.10496 .01757 L
.10552 .01743 L
.10613 .01725 L
.10722 .01683 L
.10971 .01555 L
.1103 .0152 L
.11063 .01501 L
.11093 .01482 L
.11102 .01477 L
.11111 .01472 L
.1112 .01477 L
.1113 .01483 L
Mistroke
.11162 .01502 L
.11226 .01541 L
.11343 .01608 L
.11469 .01671 L
.11593 .01723 L
.11652 .01742 L
.11706 .01756 L
.1176 .01767 L
.11789 .01772 L
.1182 .01776 L
.11832 .01777 L
.11846 .01778 L
.11858 .01779 L
.11871 .0178 L
.11885 .0178 L
.119 .01781 L
.11914 .01781 L
.11927 .0178 L
.11943 .0178 L
.1195 .01779 L
.11959 .01779 L
.11988 .01777 L
.12005 .01775 L
.12022 .01773 L
.12054 .01768 L
.12117 .01754 L
.12174 .01739 L
.12289 .01696 L
.12399 .01645 L
.12515 .01582 L
.12578 .01545 L
.12638 .01509 L
.12663 .01493 L
.12676 .01485 L
.12689 .01477 L
.12703 .01474 L
.12718 .01483 L
.12744 .015 L
.1286 .0157 L
.13086 .0169 L
.13148 .01716 L
.13213 .0174 L
.1327 .01757 L
.13331 .01771 L
.13364 .01777 L
.13394 .01781 L
.13408 .01783 L
.13424 .01785 L
.13439 .01786 L
.13453 .01787 L
Mistroke
.13462 .01787 L
.13471 .01787 L
.13479 .01788 L
.13487 .01788 L
.13495 .01788 L
.13504 .01788 L
.13514 .01788 L
.13523 .01787 L
.13531 .01787 L
.13539 .01787 L
.13554 .01786 L
.1357 .01784 L
.13588 .01783 L
.13617 .01779 L
.13649 .01773 L
.13714 .01759 L
.13774 .01741 L
.13831 .01721 L
.14074 .01601 L
.14182 .01537 L
.14211 .01519 L
.14241 .015 L
.14255 .01491 L
.1427 .01481 L
.14283 .01473 L
.14297 .01479 L
.14313 .01489 L
.14329 .01499 L
.14359 .01518 L
.14416 .01553 L
.14526 .01619 L
.14655 .01687 L
.14775 .01738 L
.14839 .01759 L
.14898 .01775 L
.14929 .01781 L
.14962 .01787 L
.1498 .0179 L
.14997 .01792 L
.15014 .01793 L
.15031 .01795 L
.15046 .01795 L
.1506 .01796 L
.15074 .01796 L
.15087 .01796 L
.15102 .01796 L
.15117 .01796 L
.15132 .01795 L
.15149 .01794 L
.15179 .01791 L
Mistroke
.15208 .01787 L
.15273 .01774 L
.15333 .01758 L
.15398 .01735 L
.15517 .01684 L
.1574 .01557 L
.15804 .01516 L
.15836 .01496 L
.1585 .01487 L
.15865 .01477 L
.15878 .01475 L
.15891 .01483 L
.15919 .01501 L
.15978 .01539 L
.16107 .0162 L
.1623 .01687 L
.16348 .0174 L
.1641 .01763 L
.16476 .01782 L
.16531 .01794 L
.16562 .01799 L
.16592 .01802 L
.16605 .01804 L
.16619 .01805 L
.16631 .01806 L
.16644 .01806 L
.16657 .01807 L
.16672 .01807 L
.16687 .01807 L
.16699 .01806 L
.16714 .01806 L
.16727 .01805 L
.16742 .01803 L
.16758 .01802 L
.1679 .01798 L
.1682 .01792 L
.16876 .0178 L
.1693 .01764 L
.1705 .01717 L
.17181 .01649 L
.17304 .01575 L
.17364 .01536 L
.17419 .015 L
.17435 .01489 L
.1745 .01479 L
.17465 .01475 L
.17474 .01481 L
.17483 .01487 L
.17551 .01533 L
.17672 .01611 L
Mistroke
.17795 .01683 L
.17928 .01747 L
.17989 .0177 L
.18054 .01791 L
.1811 .01804 L
.18141 .01809 L
.18171 .01814 L
.18185 .01815 L
.182 .01817 L
.18215 .01818 L
.18228 .01818 L
.18243 .01819 L
.18252 .01819 L
.1826 .01819 L
.18274 .01819 L
.1829 .01818 L
.18304 .01818 L
.1832 .01816 L
.18335 .01815 L
.18349 .01814 L
.18383 .01809 L
.18415 .01803 L
.1847 .01789 L
.18521 .01773 L
.18638 .01726 L
.18865 .01596 L
.18928 .01555 L
.18993 .0151 L
.1902 .01491 L
.19035 .0148 L
.19049 .01473 L
.19057 .01478 L
.19066 .01484 L
.19081 .01495 L
.19111 .01516 L
.19245 .01607 L
.1937 .01684 L
.19495 .01749 L
.19557 .01775 L
.19613 .01795 L
.19669 .01811 L
.19722 .01822 L
.19751 .01827 L
.19778 .0183 L
.19793 .01831 L
.19807 .01832 L
.19815 .01833 L
.19824 .01833 L
.19839 .01833 L
.19854 .01833 L
Mistroke
.19869 .01833 L
.19885 .01832 L
.19894 .01832 L
.19902 .01831 L
.19918 .0183 L
.19936 .01828 L
.19969 .01823 L
.19999 .01818 L
.2003 .0181 L
.20088 .01793 L
.20201 .01748 L
.20322 .01684 L
.20437 .01612 L
.20543 .01538 L
.20599 .01498 L
.20615 .01486 L
.2063 .01475 L
.20644 .01478 L
.20658 .01489 L
.20785 .0158 L
.20906 .01662 L
.21039 .0174 L
.21099 .0177 L
.21163 .01797 L
.21218 .01816 L
.21279 .01832 L
.21314 .0184 L
.21331 .01842 L
.21347 .01845 L
.21362 .01846 L
.21378 .01848 L
.21387 .01849 L
.21395 .01849 L
.21403 .0185 L
.21411 .0185 L
.21426 .01851 L
.21439 .01851 L
.21448 .01851 L
.21456 .0185 L
.2147 .0185 L
.21486 .01849 L
.215 .01848 L
.21532 .01844 L
.21562 .01839 L
.21589 .01834 L
.21649 .01817 L
.21702 .01799 L
.21758 .01776 L
.22007 .01631 L
.22122 .01548 L
Mistroke
.22155 .01523 L
.22187 .01499 L
.222 .01488 L
.22215 .01477 L
.22231 .01478 L
.22245 .01489 L
.22467 .01654 L
.22581 .01728 L
.22703 .01793 L
.22763 .01819 L
.22819 .01838 L
.22869 .01852 L
.22898 .01858 L
.22924 .01863 L
.22952 .01867 L
.22967 .01868 L
.22983 .0187 L
.22996 .0187 L
.23009 .01871 L
.23023 .01871 L
.23037 .01871 L
.23046 .01871 L
.23054 .0187 L
.23062 .0187 L
.23071 .01869 L
.23086 .01868 L
.23103 .01866 L
.23134 .01862 L
.23162 .01856 L
.23226 .01839 L
.23284 .01819 L
.23416 .01756 L
.23536 .01681 L
.23664 .01587 L
.23726 .01539 L
.23757 .01514 L
.23785 .01491 L
.23798 .01481 L
.23811 .01473 L
.23824 .01483 L
.23838 .01495 L
.23895 .01541 L
.24131 .01719 L
.24248 .0179 L
.24356 .01842 L
.24413 .01862 L
.24473 .01879 L
.24505 .01885 L
.24534 .0189 L
.24551 .01892 L
Mistroke
.24566 .01893 L
.24574 .01894 L
.24583 .01894 L
.24593 .01895 L
.24601 .01895 L
.24615 .01895 L
.2463 .01895 L
.24645 .01894 L
.24658 .01893 L
.2467 .01892 L
.24683 .01891 L
.24709 .01887 L
.24738 .01882 L
.24769 .01875 L
.24825 .01858 L
.24888 .01833 L
.24947 .01805 L
.25081 .01724 L
.25197 .01639 L
.25323 .01535 L
.25355 .01507 L
.25373 .01492 L
.25382 .01485 L
.2539 .01478 L
.25404 .01478 L
.25419 .01491 L
.25451 .01518 L
.25571 .0162 L
.25796 .01787 L
.25854 .01822 L
.25916 .01854 L
.25969 .01877 L
.26026 .01897 L
.26059 .01906 L
.26088 .01912 L
.26118 .01918 L
.26132 .0192 L
.26146 .01921 L
.26161 .01922 L
.2617 .01923 L
.26178 .01923 L
.26193 .01924 L
.26208 .01924 L
.26217 .01924 L
.26226 .01923 L
.26235 .01923 L
.26244 .01922 L
.2626 .01921 L
.26277 .01919 L
.26308 .01914 L
Mistroke
.26341 .01907 L
.264 .01889 L
.26463 .01864 L
.26533 .01829 L
.26776 .01658 L
.26889 .01559 L
.26946 .01506 L
.26962 .01492 L
.26971 .01484 L
.26979 .01476 L
.26995 .01481 L
.27009 .01494 L
.2714 .01615 L
.2726 .01718 L
.27377 .01807 L
.27502 .01881 L
.27553 .01906 L
.27607 .01927 L
.27639 .01936 L
.27668 .01944 L
.27697 .0195 L
.27724 .01954 L
.27739 .01955 L
.27747 .01956 L
.27755 .01957 L
.27771 .01957 L
.27785 .01958 L
.27798 .01958 L
.27811 .01957 L
.27825 .01957 L
.2784 .01955 L
.27856 .01954 L
.27873 .01951 L
.27904 .01945 L
.27935 .01938 L
.27963 .01929 L
.28071 .01884 L
.28125 .01854 L
.28185 .01815 L
.28309 .01719 L
.28438 .01602 L
.28492 .0155 L
.28521 .01521 L
.28549 .01494 L
.28565 .01478 L
.28574 .01474 L
.28582 .01482 L
.28612 .01512 L
.2867 .0157 L
.28912 .01792 L
Mistroke
.2903 .01879 L
.29137 .01939 L
.29193 .01963 L
.29247 .0198 L
.29276 .01987 L
.29303 .01992 L
.29317 .01994 L
.29332 .01995 L
.2934 .01996 L
.29349 .01997 L
.29364 .01997 L
.2938 .01997 L
.29394 .01997 L
.29403 .01997 L
.2941 .01996 L
.29419 .01996 L
.29427 .01995 L
.29444 .01993 L
.29459 .01991 L
.29494 .01984 L
.29521 .01976 L
.29552 .01966 L
.29613 .01941 L
.29735 .0187 L
.29847 .01783 L
.29978 .01662 L
.30041 .01597 L
.30099 .01536 L
.30126 .01506 L
.30141 .01491 L
.30156 .01474 L
.30169 .01483 L
.30184 .01499 L
.3021 .01527 L
.30328 .01653 L
.30459 .01782 L
.30578 .01884 L
.30636 .01925 L
.30699 .01964 L
.30753 .01992 L
.30813 .02015 L
.30846 .02025 L
.30877 .02032 L
.30894 .02035 L
.30909 .02037 L
.30926 .02039 L
.30935 .0204 L
.30944 .0204 L
.3096 .02041 L
.30975 .0204 L
Mistroke
.30983 .0204 L
.30991 .0204 L
.31007 .02039 L
.31022 .02037 L
.31037 .02035 L
.31065 .02029 L
.31096 .02021 L
.31125 .02012 L
.31179 .01989 L
.31238 .01958 L
.31302 .01917 L
.31522 .01722 L
.31645 .01588 L
.31674 .01555 L
.31705 .01519 L
.31731 .01489 L
.31746 .01472 L
.3176 .01488 L
.31824 .01562 L
.31893 .01641 L
.32013 .01772 L
.3214 .01891 L
.32259 .01981 L
.32311 .02012 L
.32367 .02038 L
.32395 .02049 L
.32427 .02059 L
.32456 .02066 L
.32483 .02071 L
.32497 .02073 L
.32513 .02075 L
.32527 .02075 L
.3254 .02076 L
.32555 .02076 L
.32564 .02075 L
.32572 .02075 L
.32587 .02074 L
.32602 .02072 L
.32617 .0207 L
.32633 .02067 L
.32662 .0206 L
.32696 .02049 L
.32727 .02037 L
.32842 .01974 L
.3295 .01889 L
.3317 .01665 L
.3323 .01595 L
.33262 .01557 L
.33295 .01518 L
.33309 .01501 L
Mistroke
.33324 .01483 L
.33333 .01472 L
.33341 .0148 L
.33356 .01499 L
.33412 .01566 L
.33651 .01824 L
.33781 .01933 L
.33839 .01972 L
.33904 .02006 L
.33933 .02018 L
.33964 .02029 L
.33991 .02037 L
.34021 .02043 L
.34038 .02046 L
.34047 .02047 L
.34054 .02048 L
.34069 .02049 L
.34078 .0205 L
.34086 .0205 L
.34101 .0205 L
.34114 .0205 L
.34129 .02049 L
.34145 .02048 L
.34159 .02046 L
.34171 .02044 L
.342 .02038 L
.34226 .02031 L
.34251 .02023 L
.34307 .02 L
.34367 .01968 L
.34481 .01889 L
.34606 .01781 L
.34738 .01652 L
.34796 .01594 L
.3486 .01531 L
.34888 .01503 L
.34904 .01488 L
.34918 .01474 L
.34932 .01482 L
.34947 .01496 L
.34973 .0152 L
.35093 .01619 L
.35157 .01663 L
.35224 .01702 L
.35281 .01728 L
.35312 .0174 L
.35345 .0175 L
.35377 .01759 L
.35408 .01765 L
.35437 .01769 L
Mistroke
.35453 .01771 L
.35467 .01772 L
.35482 .01773 L
.35495 .01774 L
.3551 .01774 L
.35525 .01774 L
.35539 .01774 L
.35551 .01774 L
.35565 .01773 L
.35579 .01772 L
.35831 .01763 L
.35948 .0178 L
.36011 .01794 L
.36071 .01805 L
.36087 .01808 L
.36102 .01809 L
.3611 .0181 L
.36119 .01811 L
.36135 .01812 L
.36145 .01812 L
.36153 .01812 L
.36163 .01812 L
.36172 .01811 L
.36181 .0181 L
.36189 .01809 L
.36206 .01806 L
.36221 .01803 L
.36235 .01799 L
.36267 .01786 L
.36298 .01768 L
.36331 .01743 L
.36363 .01712 L
.36393 .01677 L
.3646 .01571 L
.36475 .01542 L
.36491 .01509 L
.36506 .01476 L
.3652 .015 L
.36534 .01537 L
.3655 .01578 L
.36583 .01675 L
.36693 .02093 L
.36813 .02739 L
.36936 .03646 L
.37049 .04706 L
.37302 .07997 L
.37533 .12181 L
.37784 .17943 L
.38277 .32022 L
.38752 .46162 L
Mistroke
.38991 .52167 L
.39209 .56432 L
.39329 .58165 L
.39385 .58799 L
.39444 .59357 L
.39476 .59614 L
.39506 .59814 L
.39536 .59984 L
.39564 .6011 L
.39597 .60223 L
.39614 .60266 L
.39622 .60284 L
.39632 .603 L
.39647 .6032 L
.39662 .6033 L
.39671 .60332 L
.3968 .60331 L
.39695 .60323 L
.39709 .60308 L
.39724 .60284 L
.39738 .60254 L
.39751 .6022 L
.39781 .60118 L
.39812 .59976 L
.39871 .5961 L
.39936 .59066 L
.40051 .5774 L
.40158 .56117 L
.40405 .51111 L
.4063 .45369 L
.41112 .31169 L
.41577 .18256 L
.41812 .12899 L
.42071 .0823 L
.42189 .0653 L
.42317 .05005 L
.42436 .03842 L
.42547 .02978 L
.42669 .02235 L
.42732 .01931 L
.42766 .0179 L
.42802 .01652 L
.42818 .01598 L
.42834 .01544 L
.42848 .015 L
.42863 .01489 L
.42877 .0153 L
.42892 .01571 L
.4292 .0164 L
.42985 .01778 L
Mistroke
.43045 .01874 L
.43105 .01945 L
.43135 .01972 L
.43168 .01995 L
.43201 .02013 L
.4322 .02021 L
.43237 .02026 L
.43253 .02031 L
.43261 .02032 L
.4327 .02034 L
.43279 .02035 L
.43287 .02036 L
.43302 .02037 L
.43317 .02037 L
.43325 .02037 L
.43333 .02037 L
.43348 .02035 L
.43362 .02034 L
.43378 .02031 L
.43393 .02028 L
.43427 .02019 L
.43488 .01997 L
.43545 .01971 L
.44007 .01714 L
.44241 .01586 L
.44305 .01551 L
.44374 .01512 L
.44406 .01494 L
.44423 .01484 L
.44432 .01479 L
.44439 .01474 L
.44453 .01477 L
.44468 .01485 L
.44499 .01503 L
.44746 .0164 L
.44854 .01692 L
.44973 .01739 L
.45027 .01756 L
.45085 .01771 L
.45117 .01777 L
.45147 .01782 L
.45176 .01786 L
.45191 .01787 L
.45204 .01788 L
.4522 .01789 L
.45235 .0179 L
.4525 .0179 L
.45259 .0179 L
.45267 .0179 L
.4528 .0179 L
Mistroke
.45295 .01789 L
.4531 .01789 L
.45324 .01788 L
.45357 .01784 L
.45388 .0178 L
.45422 .01773 L
.45455 .01766 L
.45572 .01729 L
.45696 .01673 L
.45918 .01545 L
.45976 .01508 L
.46005 .01489 L
.46019 .0148 L
.46032 .01472 L
.46046 .01481 L
.46062 .01491 L
.46095 .01513 L
.46154 .0155 L
.46374 .01677 L
.46495 .01731 L
.46553 .01752 L
.46606 .01768 L
.46664 .01781 L
.46695 .01786 L
.46728 .0179 L
.46745 .01792 L
.46763 .01794 L
.46771 .01794 L
.4678 .01795 L
.46796 .01795 L
.46811 .01795 L
.46825 .01795 L
.4684 .01795 L
.46849 .01795 L
.46857 .01794 L
.46873 .01793 L
.46887 .01792 L
.46914 .01789 L
.46944 .01785 L
.46975 .01779 L
.47033 .01766 L
.47085 .0175 L
.47206 .01704 L
.47335 .0164 L
.47449 .01576 L
.47511 .01538 L
.47571 .01501 L
.47597 .01485 L
.47612 .01476 L
.47626 .01476 L
Mistroke
.47634 .01481 L
.47642 .01486 L
.47657 .01495 L
.47686 .01513 L
.47792 .01575 L
.47916 .01642 L
.48032 .01695 L
.48153 .01737 L
.48218 .01753 L
.48254 .0176 L
.48286 .01765 L
.48314 .01768 L
.4833 .0177 L
.48344 .01771 L
.4836 .01772 L
.48368 .01772 L
.48376 .01772 L
.48391 .01773 L
.48406 .01773 L
.48421 .01773 L
.48434 .01772 L
.48449 .01772 L
.48463 .01771 L
.48489 .01768 L
.48517 .01765 L
.48547 .01761 L
.4858 .01754 L
.48647 .01738 L
.48767 .01698 L
.48898 .01641 L
.49022 .01577 L
.49133 .01514 L
.49164 .01496 L
.4918 .01487 L
.49196 .01478 L
.49211 .01474 L
.49227 .01483 L
.49254 .01499 L
.49478 .01621 L
.49605 .01678 L
.49666 .01702 L
.49723 .0172 L
.49779 .01735 L
.49839 .01748 L
.49873 .01753 L
.49903 .01757 L
.49933 .0176 L
.49948 .01761 L
.49964 .01761 L
.49972 .01762 L
Mistroke
.49981 .01762 L
.49989 .01762 L
.49997 .01762 L
.50012 .01762 L
.50027 .01762 L
.50036 .01761 L
.50046 .01761 L
.50063 .0176 L
.5008 .01759 L
.50095 .01757 L
.50155 .01749 L
.50185 .01743 L
.50218 .01736 L
.50341 .01699 L
.50454 .01653 L
.50585 .01589 L
.50642 .01558 L
.50706 .01522 L
.50733 .01506 L
.50763 .01489 L
.50777 .01481 L
.50792 .01473 L
.50804 .01477 L
.50817 .01485 L
.50936 .01553 L
.51067 .01624 L
.51186 .0168 L
.51245 .01703 L
.51308 .01725 L
.51363 .01741 L
.51423 .01755 L
.51454 .01761 L
.51487 .01766 L
.51505 .01768 L
.51522 .01769 L
.51539 .01771 L
.51554 .01772 L
.51569 .01772 L
.51584 .01773 L
.51593 .01773 L
.51601 .01773 L
.51616 .01773 L
.51631 .01772 L
.51645 .01772 L
.5166 .01771 L
.51675 .01769 L
.51706 .01766 L
.51735 .01762 L
.5179 .01751 L
.51849 .01736 L
Mistroke
.51913 .01716 L
.52134 .01616 L
.52257 .01547 L
.52318 .0151 L
.52344 .01494 L
.52359 .01485 L
.52373 .01476 L
.52387 .01475 L
.52401 .01484 L
.52431 .01503 L
.52494 .01541 L
.52626 .01619 L
.5275 .01684 L
.52815 .01713 L
.52884 .0174 L
.52945 .0176 L
.53011 .01776 L
.5304 .01782 L
.53071 .01787 L
.53101 .01791 L
.53128 .01793 L
.53142 .01794 L
.53155 .01795 L
.5317 .01795 L
.53185 .01795 L
.53201 .01795 L
.53209 .01795 L
.53217 .01795 L
.53233 .01794 L
.53247 .01793 L
.53275 .0179 L
.533 .01787 L
.53357 .01776 L
.53419 .01761 L
.53486 .01738 L
.53608 .01686 L
.53847 .0155 L
.53905 .01512 L
.53937 .01492 L
.53953 .01481 L
.53968 .01472 L
.53976 .01477 L
.53985 .01482 L
.54004 .01495 L
.54037 .01516 L
.54101 .01557 L
.54225 .01631 L
.54359 .017 L
.54421 .01726 L
.54486 .01749 L
Mistroke
.54542 .01765 L
.54603 .01778 L
.54633 .01783 L
.54649 .01785 L
.54666 .01787 L
.54681 .01788 L
.54688 .01788 L
.54697 .01789 L
.54712 .0179 L
.54726 .0179 L
.54739 .0179 L
.54754 .0179 L
.5477 .0179 L
.54784 .01789 L
.54798 .01788 L
.5481 .01787 L
.54838 .01784 L
.5487 .01779 L
.549 .01774 L
.54968 .01758 L
.5509 .01716 L
.55317 .01607 L
.55447 .01534 L
.55477 .01517 L
.55509 .01499 L
.55524 .0149 L
.55539 .01481 L
.55552 .01474 L
.55566 .01477 L
.5558 .01486 L
.55596 .01495 L
.55623 .0151 L
.55686 .01546 L
.558 .01609 L
.56052 .01746 L
.56293 .01883 L
.56397 .01942 L
.56511 .01996 L
.56542 .02008 L
.56574 .02019 L
.56602 .02027 L
.56618 .0203 L
.56632 .02033 L
.56647 .02035 L
.56661 .02036 L
.56676 .02037 L
.56684 .02037 L
.56692 .02037 L
.56706 .02037 L
.56718 .02035 L
Mistroke
.56733 .02033 L
.56747 .02031 L
.56762 .02027 L
.56778 .02022 L
.5681 .02008 L
.5684 .0199 L
.56868 .01969 L
.56932 .01905 L
.56967 .01857 L
.57 .01805 L
.57058 .01692 L
.57089 .01618 L
.57119 .0154 L
.57131 .01505 L
.57144 .01476 L
.57159 .0152 L
.57172 .01562 L
.5723 .01772 L
.57349 .02332 L
.5748 .03167 L
.57604 .04203 L
.57716 .05372 L
.57969 .08862 L
.582 .13156 L
.58451 .18952 L
.58944 .32867 L
.59419 .46699 L
.59658 .52545 L
.59876 .56677 L
.59996 .58341 L
.60052 .58945 L
.60111 .59472 L
.60143 .59712 L
.60173 .59896 L
.60203 .6005 L
.60231 .60163 L
.60247 .60213 L
.60264 .60258 L
.60281 .60293 L
.6029 .60307 L
.60299 .60318 L
.60307 .60325 L
.60315 .60329 L
.6033 .60332 L
.60345 .60326 L
.60354 .60318 L
.60362 .60308 L
.60377 .60285 L
.60392 .60254 L
.60418 .60176 L
Mistroke
.60447 .60062 L
.60479 .59903 L
.60535 .59527 L
.60588 .59075 L
.60708 .57676 L
.60836 .55655 L
.61094 .50161 L
.61337 .43642 L
.61802 .2962 L
.62037 .22729 L
.62296 .15987 L
.62544 .10655 L
.62771 .0691 L
.63006 .04155 L
.63136 .03086 L
.63258 .02331 L
.63375 .01819 L
.63433 .01626 L
.63449 .0158 L
.63467 .01534 L
.63475 .01514 L
.63483 .01493 L
.63498 .01485 L
.63512 .01516 L
.63525 .01542 L
.63553 .01595 L
.63604 .01673 L
.63633 .01708 L
.63664 .01739 L
.63693 .01762 L
.6372 .01779 L
.63748 .01793 L
.63764 .01798 L
.63779 .01803 L
.63792 .01806 L
.63805 .01808 L
.6382 .0181 L
.63834 .01811 L
.63842 .01812 L
.6385 .01812 L
.63859 .01812 L
.63868 .01812 L
.63883 .01811 L
.63892 .0181 L
.639 .01809 L
.63929 .01805 L
.63959 .018 L
.64023 .01786 L
.64058 .01779 L
.64091 .01773 L
Mistroke
.64121 .01768 L
.64149 .01765 L
.64164 .01764 L
.6418 .01763 L
.64196 .01762 L
.64205 .01761 L
.64213 .01761 L
.64221 .01761 L
.64229 .01761 L
.64244 .01761 L
.64259 .01762 L
.64272 .01762 L
.64303 .01764 L
.64336 .01766 L
.64369 .01769 L
.64405 .01771 L
.64422 .01772 L
.64438 .01773 L
.64453 .01774 L
.64462 .01774 L
.64469 .01774 L
.64484 .01774 L
.64499 .01774 L
.64511 .01773 L
.64525 .01773 L
.6454 .01771 L
.64556 .0177 L
.64585 .01766 L
.64616 .0176 L
.64645 .01753 L
.64712 .01731 L
.64821 .01677 L
.64937 .01596 L
.64998 .01546 L
.6503 .01517 L
.65047 .01502 L
.65064 .01486 L
.6508 .01472 L
.65088 .0148 L
.65096 .01487 L
.65125 .01515 L
.65182 .01572 L
.65439 .01821 L
.65555 .01916 L
.65617 .01958 L
.65681 .01994 L
.65713 .02009 L
.65748 .02023 L
.6578 .02033 L
.65809 .0204 L
Mistroke
.65839 .02046 L
.65855 .02048 L
.65871 .02049 L
.65885 .0205 L
.65898 .0205 L
.65913 .0205 L
.65929 .0205 L
.65942 .02049 L
.65955 .02047 L
.65969 .02045 L
.65984 .02042 L
.66008 .02037 L
.66035 .02029 L
.66096 .02006 L
.66153 .01976 L
.6628 .01886 L
.66399 .01775 L
.66506 .0166 L
.66567 .0159 L
.66596 .01555 L
.66624 .01523 L
.66637 .01507 L
.66653 .01488 L
.66667 .01472 L
.6668 .01488 L
.66741 .0156 L
.66865 .01704 L
.66972 .01817 L
.67087 .01921 L
.67154 .0197 L
.67215 .02008 L
.67273 .02037 L
.67303 .02049 L
.67335 .02059 L
.67364 .02066 L
.6739 .02071 L
.67403 .02073 L
.67417 .02074 L
.6743 .02075 L
.67442 .02076 L
.67456 .02076 L
.67469 .02076 L
.67483 .02075 L
.67499 .02074 L
.67514 .02072 L
.6753 .02069 L
.67559 .02063 L
.6759 .02054 L
.6762 .02044 L
.67675 .02019 L
Mistroke
.67798 .01942 L
.67904 .01853 L
.68019 .01738 L
.68143 .016 L
.68204 .0153 L
.6823 .01499 L
.68245 .01482 L
.68259 .01478 L
.68274 .01495 L
.68289 .01512 L
.68318 .01545 L
.6838 .01616 L
.68513 .01758 L
.68638 .01871 L
.68703 .0192 L
.68772 .01964 L
.68833 .01995 L
.68865 .02008 L
.68899 .0202 L
.68931 .02028 L
.68959 .02034 L
.68973 .02036 L
.68988 .02038 L
.69002 .02039 L
.69016 .0204 L
.69031 .02041 L
.69045 .0204 L
.69058 .0204 L
.69072 .02039 L
.69087 .02038 L
.69103 .02035 L
.69132 .0203 L
.69162 .02023 L
.69189 .02014 L
.69241 .01994 L
.69304 .01963 L
.69361 .01928 L
.6949 .01828 L
.69717 .01606 L
.69779 .01539 L
.69813 .01502 L
.69822 .01493 L
.6983 .01483 L
.69846 .01476 L
.6986 .01492 L
.69876 .01509 L
.69909 .01544 L
.69966 .01605 L
.70089 .01726 L
.70219 .01837 L
Mistroke
.7033 .01911 L
.70393 .01944 L
.70451 .01967 L
.7048 .01977 L
.70512 .01985 L
.70526 .01988 L
.70542 .01991 L
.70555 .01993 L
.70569 .01995 L
.70583 .01996 L
.70596 .01997 L
.70608 .01997 L
.7062 .01997 L
.70634 .01997 L
.70647 .01997 L
.70661 .01996 L
.70677 .01994 L
.70693 .01992 L
.70708 .0199 L
.70742 .01983 L
.70771 .01975 L
.70803 .01964 L
.70917 .01911 L
.71032 .01836 L
.71155 .01736 L
.7127 .01629 L
.71376 .01524 L
.71391 .01509 L
.71407 .01493 L
.71422 .01478 L
.71436 .01479 L
.7145 .01493 L
.71466 .01509 L
.71499 .01541 L
.71633 .01668 L
.7175 .01767 L
.71875 .01854 L
.7194 .01889 L
.72 .01916 L
.72055 .01935 L
.72086 .01943 L
.72114 .01949 L
.72127 .01951 L
.7214 .01953 L
.72152 .01955 L
.72165 .01956 L
.7218 .01957 L
.72195 .01958 L
.72209 .01958 L
.72222 .01958 L
Mistroke
.72235 .01957 L
.72248 .01956 L
.72262 .01955 L
.72277 .01954 L
.72307 .01949 L
.72336 .01943 L
.72393 .01927 L
.72454 .01903 L
.72563 .01845 L
.72694 .01754 L
.72813 .01656 L
.72925 .01556 L
.72982 .01503 L
.72997 .01489 L
.73006 .01481 L
.73014 .01473 L
.7303 .01484 L
.73044 .01498 L
.73174 .01615 L
.73295 .01714 L
.7341 .01795 L
.73474 .01833 L
.73534 .01863 L
.7359 .01885 L
.73619 .01895 L
.7365 .01904 L
.73676 .01911 L
.73705 .01916 L
.73718 .01918 L
.73731 .0192 L
.73744 .01921 L
.73755 .01922 L
.7377 .01923 L
.73778 .01923 L
.73786 .01924 L
.73795 .01924 L
.73804 .01924 L
.73819 .01923 L
.73834 .01923 L
.73847 .01922 L
.73862 .0192 L
.73878 .01918 L
.73914 .01912 L
.73948 .01904 L
.74012 .01884 L
.74072 .01859 L
.74128 .01832 L
.74254 .01754 L
.74481 .01577 L
.74543 .01524 L
Mistroke
.74559 .0151 L
.74577 .01494 L
.74585 .01487 L
.74594 .0148 L
.74609 .01477 L
.74618 .01484 L
.74626 .01492 L
.74642 .01505 L
.74672 .01531 L
.7473 .01579 L
.74966 .01755 L
.75031 .01793 L
.751 .01828 L
.75165 .01855 L
.75225 .01873 L
.75255 .01881 L
.75287 .01887 L
.75318 .01891 L
.75336 .01893 L
.75345 .01894 L
.75353 .01894 L
.75369 .01895 L
.75384 .01895 L
.75398 .01895 L
.75412 .01895 L
.7542 .01894 L
.75428 .01894 L
.75442 .01893 L
.75458 .01891 L
.75475 .01889 L
.75502 .01884 L
.75532 .01878 L
.75593 .0186 L
.7565 .0184 L
.75702 .01816 L
.75947 .01663 L
.76056 .0158 L
.76115 .01533 L
.76144 .01509 L
.76171 .01487 L
.76184 .01476 L
.76198 .01478 L
.76213 .01489 L
.76228 .01502 L
.76291 .01552 L
.76401 .01637 L
.76532 .01726 L
.76651 .01791 L
.7671 .01817 L
.76773 .01839 L
Mistroke
.76802 .01848 L
.76833 .01855 L
.76861 .01861 L
.76888 .01865 L
.76902 .01867 L
.76918 .01868 L
.76926 .01869 L
.76934 .0187 L
.7695 .0187 L
.76965 .01871 L
.76978 .01871 L
.76994 .01871 L
.77008 .0187 L
.77016 .0187 L
.77024 .01869 L
.77041 .01868 L
.77072 .01864 L
.77107 .01857 L
.7714 .0185 L
.77201 .01832 L
.77267 .01807 L
.77386 .01747 L
.7761 .01599 L
.77665 .01558 L
.77724 .01513 L
.7774 .01501 L
.77757 .01487 L
.77772 .01476 L
.7778 .01474 L
.77788 .0148 L
.77849 .01526 L
.77979 .01621 L
.78102 .01702 L
.78221 .01766 L
.78283 .01793 L
.78349 .01817 L
.78405 .01832 L
.78437 .01839 L
.78466 .01844 L
.7848 .01845 L
.78493 .01847 L
.78505 .01848 L
.78518 .01849 L
.78532 .0185 L
.78545 .0185 L
.78558 .01851 L
.78574 .01851 L
.78588 .0185 L
.78602 .0185 L
.78617 .01849 L
Mistroke
.78633 .01847 L
.78665 .01843 L
.78695 .01838 L
.78752 .01825 L
.78806 .01808 L
.78927 .01757 L
.79058 .01685 L
.79181 .01604 L
.79297 .01521 L
.79327 .01499 L
.79342 .01489 L
.79355 .01479 L
.79371 .01476 L
.79379 .01482 L
.79388 .01488 L
.79418 .0151 L
.79551 .01604 L
.79675 .01683 L
.79809 .01753 L
.79871 .01779 L
.79936 .01801 L
.79991 .01815 L
.80023 .01822 L
.80052 .01826 L
.80067 .01828 L
.80084 .0183 L
.80098 .01831 L
.80113 .01832 L
.80121 .01833 L
.80129 .01833 L
.80144 .01833 L
.80152 .01833 L
.80161 .01833 L
.8017 .01833 L
.80178 .01833 L
.80194 .01832 L
.80209 .01831 L
.80222 .0183 L
.80236 .01828 L
.80268 .01824 L
.80298 .01818 L
.80349 .01806 L
.80406 .01789 L
.80522 .01741 L
.80652 .01672 L
.80776 .01593 L
.80887 .01517 L
.80917 .01496 L
.80934 .01484 L
.8095 .01473 L
Mistroke
.80964 .0148 L
.8098 .01491 L
.81008 .0151 L
.81231 .01656 L
.81358 .01724 L
.8142 .01751 L
.81476 .01773 L
.81532 .0179 L
.81593 .01804 L
.81626 .0181 L
.81641 .01812 L
.81657 .01814 L
.81671 .01816 L
.81686 .01817 L
.81694 .01818 L
.81702 .01818 L
.81717 .01819 L
.81732 .01819 L
.81748 .01819 L
.81763 .01819 L
.81776 .01818 L
.81785 .01818 L
.81792 .01817 L
.8181 .01816 L
.81841 .01812 L
.81871 .01807 L
.81904 .01801 L
.81971 .01783 L
.82035 .01762 L
.82094 .01737 L
.82206 .01682 L
.82329 .01611 L
.82396 .01568 L
.82459 .01526 L
.82513 .01489 L
.82528 .01479 L
.82544 .01475 L
.82558 .01484 L
.82573 .01494 L
.82698 .01577 L
.8292 .01703 L
.82984 .01732 L
.83044 .01755 L
.83099 .01773 L
.83157 .01788 L
.83187 .01794 L
.8322 .01799 L
.83234 .01801 L
.8325 .01803 L
.83264 .01804 L
Mistroke
.83278 .01805 L
.83287 .01806 L
.83295 .01806 L
.83304 .01806 L
.83313 .01807 L
.83321 .01807 L
.8333 .01807 L
.83339 .01807 L
.83346 .01806 L
.83361 .01806 L
.83369 .01806 L
.83377 .01805 L
.83393 .01804 L
.83409 .01802 L
.8344 .01798 L
.83473 .01793 L
.83532 .0178 L
.83596 .01761 L
.83666 .01735 L
.83908 .0161 L
.84022 .0154 L
.84052 .0152 L
.84084 .01499 L
.841 .01489 L
.84114 .0148 L
.84128 .01472 L
.84142 .01481 L
.84205 .01522 L
.84273 .01565 L
.84393 .01637 L
.84517 .017 L
.84633 .01747 L
.84692 .01765 L
.84754 .0178 L
.8479 .01786 L
.84824 .01791 L
.84838 .01793 L
.84854 .01794 L
.84863 .01795 L
.84871 .01795 L
.84887 .01796 L
.84902 .01796 L
.84915 .01796 L
.8493 .01796 L
.84939 .01796 L
.84946 .01796 L
.84962 .01795 L
.84978 .01794 L
.84994 .01792 L
.85009 .01791 L
Mistroke
.85063 .01783 L
.8509 .01777 L
.8512 .0177 L
.8525 .01728 L
.85371 .01674 L
.85496 .01606 L
.85615 .01534 L
.85667 .01501 L
.85681 .01493 L
.85695 .01483 L
.85709 .01475 L
.85722 .01477 L
.85738 .01486 L
.85754 .01497 L
.85783 .01515 L
.85839 .01549 L
.85962 .01622 L
.86078 .01682 L
.86192 .01729 L
.86297 .01761 L
.86351 .01773 L
.86379 .01778 L
.86409 .01782 L
.86424 .01784 L
.8644 .01785 L
.86457 .01786 L
.86472 .01787 L
.86487 .01788 L
.86501 .01788 L
.86516 .01788 L
.86524 .01787 L
.86532 .01787 L
.86548 .01787 L
.86555 .01786 L
.86564 .01785 L
.86594 .01783 L
.86611 .01781 L
.86629 .01778 L
.86661 .01772 L
.86725 .01758 L
.86784 .01741 L
.86903 .01695 L
.87013 .01641 L
.87142 .01569 L
.87205 .01531 L
.87233 .01514 L
.87263 .01495 L
.87278 .01486 L
.87293 .01477 L
.87308 .01475 L
Mistroke
.87321 .01484 L
.87383 .01521 L
.87511 .01597 L
.8762 .01655 L
.87736 .01707 L
.87793 .01728 L
.87856 .01747 L
.87913 .01761 L
.87966 .01771 L
.87997 .01775 L
.88014 .01777 L
.88029 .01778 L
.88043 .01779 L
.88057 .0178 L
.88073 .0178 L
.88087 .01781 L
.88095 .01781 L
.88104 .0178 L
.88119 .0178 L
.88128 .0178 L
.88136 .01779 L
.88154 .01778 L
.8817 .01777 L
.88184 .01775 L
.88217 .01771 L
.88275 .01761 L
.88336 .01745 L
.88447 .01708 L
.88565 .01655 L
.88697 .01585 L
.8881 .01519 L
.88838 .01502 L
.88867 .01485 L
.88876 .01479 L
.88884 .01474 L
.889 .01478 L
.88914 .01487 L
.8893 .01496 L
.89061 .01573 L
.89181 .01638 L
.89305 .01695 L
.89421 .01736 L
.89479 .01751 L
.89541 .01763 L
.89577 .01768 L
.89594 .0177 L
.89611 .01772 L
.89625 .01773 L
.89641 .01774 L
.8965 .01774 L
Mistroke
.89658 .01774 L
.89674 .01775 L
.89688 .01775 L
.89703 .01774 L
.89717 .01774 L
.8973 .01773 L
.89745 .01772 L
.89762 .01771 L
.89792 .01767 L
.89823 .01763 L
.89857 .01756 L
.89916 .01742 L
.90022 .01708 L
.90139 .01658 L
.90253 .016 L
.90373 .01533 L
.90435 .01496 L
.90452 .01486 L
.90462 .0148 L
.90471 .01475 L
.90479 .01473 L
.90488 .01479 L
.90504 .01488 L
.90624 .01558 L
.90864 .0168 L
.90985 .01724 L
.91054 .01744 L
.91087 .01751 L
.91118 .01757 L
.91149 .01762 L
.91178 .01765 L
.91193 .01767 L
.9121 .01768 L
.91219 .01769 L
.91227 .01769 L
.91235 .01769 L
.91243 .0177 L
.91258 .0177 L
.91271 .0177 L
.91287 .0177 L
.91301 .01769 L
.91316 .01769 L
.91333 .01768 L
.91363 .01765 L
.91389 .01761 L
.91419 .01757 L
.91479 .01744 L
.91534 .0173 L
.91586 .01713 L
.9183 .01604 L
Mistroke
.91938 .01544 L
.91997 .0151 L
.92027 .01493 L
.92039 .01486 L
.92053 .01477 L
.92068 .01474 L
.92083 .01483 L
.92116 .01502 L
.92172 .01535 L
.92282 .01596 L
.92413 .0166 L
.92532 .01708 L
.9259 .01727 L
.92653 .01743 L
.92682 .01749 L
.92712 .01755 L
.92741 .01759 L
.92767 .01762 L
.92781 .01763 L
.92797 .01765 L
.92812 .01766 L
.92821 .01766 L
.92829 .01766 L
.92844 .01766 L
.92857 .01767 L
.92872 .01766 L
.92887 .01766 L
.92895 .01766 L
.92903 .01765 L
.9292 .01764 L
.9295 .01761 L
.92986 .01757 L
.93019 .01751 L
.93079 .01738 L
.93145 .0172 L
.93264 .01676 L
.93487 .01565 L
.93551 .01529 L
.93583 .01511 L
.93612 .01494 L
.93638 .01479 L
.93652 .01472 L
.93666 .0148 L
.93725 .01514 L
.93857 .01588 L
.93978 .01648 L
.94091 .01696 L
.9415 .01716 L
.94213 .01734 L
.94245 .01742 L
Mistroke
.94281 .01749 L
.94313 .01754 L
.94343 .01758 L
.94373 .01761 L
.94389 .01762 L
.94398 .01763 L
.94406 .01763 L
.94421 .01764 L
.94435 .01764 L
.94443 .01764 L
.94451 .01764 L
.94466 .01764 L
.9448 .01763 L
.94495 .01763 L
.94509 .01762 L
.94522 .01761 L
.94553 .01757 L
.94583 .01753 L
.94643 .01742 L
.94707 .01725 L
.94823 .01686 L
.9493 .01639 L
.95058 .01573 L
.95121 .01539 L
.95178 .01506 L
.95205 .0149 L
.95219 .01483 L
.95231 .01476 L
.95244 .01475 L
.95257 .01483 L
.95286 .01499 L
.95403 .01565 L
.95634 .01677 L
.95697 .01701 L
.95764 .01723 L
.95827 .01739 L
.95884 .0175 L
.95912 .01755 L
.95942 .01758 L
.95956 .01759 L
.95971 .01761 L
.95985 .01761 L
.95998 .01762 L
.96014 .01762 L
.96028 .01763 L
.96044 .01763 L
.96052 .01762 L
.96061 .01762 L
.96075 .01762 L
.96091 .01761 L
Mistroke
.96106 .01759 L
.9612 .01758 L
.96174 .01751 L
.96205 .01746 L
.96233 .0174 L
.96341 .0171 L
.96457 .01665 L
.96566 .01615 L
.96687 .0155 L
.96753 .01513 L
.96785 .01495 L
.96799 .01487 L
.96814 .01478 L
.96829 .01474 L
.96843 .01482 L
.9687 .01497 L
.9693 .01531 L
.97057 .016 L
.97173 .01656 L
.97281 .01699 L
.97358 .01724 L
.97442 .01744 L
.97465 .01749 L
.97489 .01753 L
.97511 .01756 L
.97534 .01758 L
.97546 .01759 L
.97557 .0176 L
.97568 .01761 L
.97578 .01761 L
.97588 .01762 L
.97598 .01762 L
.97608 .01762 L
.97619 .01762 L
Mfstroke
1 0 0 r
[ ] 0 setdash
.03968 .01472 m
.03968 .01763 L
s
.05556 .01472 m
.05556 .01764 L
s
.07143 .01472 m
.07143 .01767 L
s
.0873 .01472 m
.0873 .0177 L
s
.10317 .01472 m
.10317 .01775 L
s
.11905 .01472 m
.11905 .01781 L
s
.13492 .01472 m
.13492 .01788 L
s
.15079 .01472 m
.15079 .01796 L
s
.16667 .01472 m
.16667 .01807 L
s
.18254 .01472 m
.18254 .01819 L
s
.19841 .01472 m
.19841 .01833 L
s
.21429 .01472 m
.21429 .01851 L
s
.23016 .01472 m
.23016 .01871 L
s
.24603 .01472 m
.24603 .01895 L
s
.2619 .01472 m
.2619 .01924 L
s
.27778 .01472 m
.27778 .01958 L
s
.29365 .01472 m
.29365 .01997 L
s
.30952 .01472 m
.30952 .0204 L
s
.3254 .01472 m
.3254 .02076 L
s
.34127 .01472 m
.34127 .02049 L
s
.35714 .01472 m
.35714 .01763 L
s
.37302 .01472 m
.37302 .07995 L
s
.38889 .01472 m
.38889 .49745 L
s
.40476 .01472 m
.40476 .494 L
s
.42063 .01472 m
.42063 .08344 L
s
.43651 .01472 m
.43651 .01915 L
s
.45238 .01472 m
.45238 .0179 L
s
.46825 .01472 m
.46825 .01795 L
s
.48413 .01472 m
.48413 .01773 L
s
.5 .01472 m
.5 .01762 L
s
.51587 .01472 m
.51587 .01773 L
s
.53175 .01472 m
.53175 .01795 L
s
.54762 .01472 m
.54762 .0179 L
s
.56349 .01472 m
.56349 .01915 L
s
.57937 .01472 m
.57937 .08344 L
s
.59524 .01472 m
.59524 .494 L
s
.61111 .01472 m
.61111 .49745 L
s
.62698 .01472 m
.62698 .07995 L
s
.64286 .01472 m
.64286 .01763 L
s
.65873 .01472 m
.65873 .02049 L
s
.6746 .01472 m
.6746 .02076 L
s
.69048 .01472 m
.69048 .0204 L
s
.70635 .01472 m
.70635 .01997 L
s
.72222 .01472 m
.72222 .01958 L
s
.7381 .01472 m
.7381 .01924 L
s
.75397 .01472 m
.75397 .01895 L
s
.76984 .01472 m
.76984 .01871 L
s
.78571 .01472 m
.78571 .01851 L
s
.80159 .01472 m
.80159 .01833 L
s
.81746 .01472 m
.81746 .01819 L
s
.83333 .01472 m
.83333 .01807 L
s
.84921 .01472 m
.84921 .01796 L
s
.86508 .01472 m
.86508 .01788 L
s
.88095 .01472 m
.88095 .01781 L
s
.89683 .01472 m
.89683 .01775 L
s
.9127 .01472 m
.9127 .0177 L
s
.92857 .01472 m
.92857 .01767 L
s
.94444 .01472 m
.94444 .01764 L
s
.96032 .01472 m
.96032 .01763 L
s
.97619 .01472 m
.97619 .01762 L
s
.015 w
.03968 .01763 Mdot
.05556 .01764 Mdot
.07143 .01767 Mdot
.0873 .0177 Mdot
.10317 .01775 Mdot
.11905 .01781 Mdot
.13492 .01788 Mdot
.15079 .01796 Mdot
.16667 .01807 Mdot
.18254 .01819 Mdot
.19841 .01833 Mdot
.21429 .01851 Mdot
.23016 .01871 Mdot
.24603 .01895 Mdot
.2619 .01924 Mdot
.27778 .01958 Mdot
.29365 .01997 Mdot
.30952 .0204 Mdot
.3254 .02076 Mdot
.34127 .02049 Mdot
.35714 .01763 Mdot
.37302 .07995 Mdot
.38889 .49745 Mdot
.40476 .494 Mdot
.42063 .08344 Mdot
.43651 .01915 Mdot
.45238 .0179 Mdot
.46825 .01795 Mdot
.48413 .01773 Mdot
.5 .01762 Mdot
.51587 .01773 Mdot
.53175 .01795 Mdot
.54762 .0179 Mdot
.56349 .01915 Mdot
.57937 .08344 Mdot
.59524 .494 Mdot
.61111 .49745 Mdot
.62698 .07995 Mdot
.64286 .01763 Mdot
.65873 .02049 Mdot
.6746 .02076 Mdot
.69048 .0204 Mdot
.70635 .01997 Mdot
.72222 .01958 Mdot
.7381 .01924 Mdot
.75397 .01895 Mdot
.76984 .01871 Mdot
.78571 .01851 Mdot
.80159 .01833 Mdot
.81746 .01819 Mdot
.83333 .01807 Mdot
.84921 .01796 Mdot
.86508 .01788 Mdot
.88095 .01781 Mdot
.89683 .01775 Mdot
.9127 .0177 Mdot
.92857 .01767 Mdot
.94444 .01764 Mdot
.96032 .01763 Mdot
.97619 .01762 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{756, 146},
  ImageCacheValid->False]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Show all", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Show[gw1];\)\), "\[IndentingNewLine]", 
    \(\(Show[gw2];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .19314 
%%ImageSize: 756 146.011 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.00459847 0.31746 [
[ 0 0 0 0 ]
[ 1 .19314 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .19314 L
0 .19314 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00459847 0.321429 0.188537 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.047619 0.0146992 0.0196085 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .0147 -6 -4.5 ]
[-0.0125 .0147 0 4.5 ]
[-0.0125 .11274 -6 -4.5 ]
[-0.0125 .11274 0 4.5 ]
[-0.0125 .21078 -12 -4.5 ]
[-0.0125 .21078 0 4.5 ]
[-0.0125 .30883 -12 -4.5 ]
[-0.0125 .30883 0 4.5 ]
[-0.0125 .40687 -12 -4.5 ]
[-0.0125 .40687 0 4.5 ]
[-0.0125 .50491 -12 -4.5 ]
[-0.0125 .50491 0 4.5 ]
[-0.0125 .60295 -12 -4.5 ]
[-0.0125 .60295 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .0147 m
.00625 .0147 L
s
[(0)] -0.0125 .0147 1 0 Mshowa
0 .11274 m
.00625 .11274 L
s
[(5)] -0.0125 .11274 1 0 Mshowa
0 .21078 m
.00625 .21078 L
s
[(10)] -0.0125 .21078 1 0 Mshowa
0 .30883 m
.00625 .30883 L
s
[(15)] -0.0125 .30883 1 0 Mshowa
0 .40687 m
.00625 .40687 L
s
[(20)] -0.0125 .40687 1 0 Mshowa
0 .50491 m
.00625 .50491 L
s
[(25)] -0.0125 .50491 1 0 Mshowa
0 .60295 m
.00625 .60295 L
s
[(30)] -0.0125 .60295 1 0 Mshowa
.125 Mabswid
0 .03431 m
.00375 .03431 L
s
0 .05392 m
.00375 .05392 L
s
0 .07352 m
.00375 .07352 L
s
0 .09313 m
.00375 .09313 L
s
0 .13235 m
.00375 .13235 L
s
0 .15196 m
.00375 .15196 L
s
0 .17157 m
.00375 .17157 L
s
0 .19118 m
.00375 .19118 L
s
0 .23039 m
.00375 .23039 L
s
0 .25 m
.00375 .25 L
s
0 .26961 m
.00375 .26961 L
s
0 .28922 m
.00375 .28922 L
s
0 .32844 m
.00375 .32844 L
s
0 .34804 m
.00375 .34804 L
s
0 .36765 m
.00375 .36765 L
s
0 .38726 m
.00375 .38726 L
s
0 .42648 m
.00375 .42648 L
s
0 .44609 m
.00375 .44609 L
s
0 .46569 m
.00375 .46569 L
s
0 .4853 m
.00375 .4853 L
s
0 .52452 m
.00375 .52452 L
s
0 .54413 m
.00375 .54413 L
s
0 .56374 m
.00375 .56374 L
s
0 .58335 m
.00375 .58335 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .0147 m
1 .0147 L
s
.99375 .11274 m
1 .11274 L
s
.99375 .21078 m
1 .21078 L
s
.99375 .30883 m
1 .30883 L
s
.99375 .40687 m
1 .40687 L
s
.99375 .50491 m
1 .50491 L
s
.99375 .60295 m
1 .60295 L
s
.125 Mabswid
.99625 .03431 m
1 .03431 L
s
.99625 .05392 m
1 .05392 L
s
.99625 .07352 m
1 .07352 L
s
.99625 .09313 m
1 .09313 L
s
.99625 .13235 m
1 .13235 L
s
.99625 .15196 m
1 .15196 L
s
.99625 .17157 m
1 .17157 L
s
.99625 .19118 m
1 .19118 L
s
.99625 .23039 m
1 .23039 L
s
.99625 .25 m
1 .25 L
s
.99625 .26961 m
1 .26961 L
s
.99625 .28922 m
1 .28922 L
s
.99625 .32844 m
1 .32844 L
s
.99625 .34804 m
1 .34804 L
s
.99625 .36765 m
1 .36765 L
s
.99625 .38726 m
1 .38726 L
s
.99625 .42648 m
1 .42648 L
s
.99625 .44609 m
1 .44609 L
s
.99625 .46569 m
1 .46569 L
s
.99625 .4853 m
1 .4853 L
s
.99625 .52452 m
1 .52452 L
s
.99625 .54413 m
1 .54413 L
s
.99625 .56374 m
1 .56374 L
s
.99625 .58335 m
1 .58335 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
0 0 1 r
.5 Mabswid
[ .01 ] 0 setdash
.02381 .03431 m
.02395 .0343 L
.02408 .03428 L
.02423 .03424 L
.02437 .03419 L
.02462 .03406 L
.02489 .03386 L
.02519 .03358 L
.02551 .03321 L
.02608 .03237 L
.02722 .03002 L
.02847 .02655 L
.02973 .02231 L
.03043 .01975 L
.03109 .01723 L
.03139 .01608 L
.03155 .01545 L
.03171 .01485 L
.03179 .01489 L
.03189 .01525 L
.03205 .01589 L
.03238 .01714 L
.03355 .02156 L
.03596 .02922 L
.03717 .03195 L
.03785 .03306 L
.03819 .03348 L
.0385 .0338 L
.03879 .03403 L
.03894 .03413 L
.0391 .03421 L
.03918 .03424 L
.03926 .03427 L
.03941 .03431 L
.03949 .03433 L
.03958 .03434 L
.03967 .03434 L
.03976 .03434 L
.03991 .03432 L
.04006 .03429 L
.04019 .03424 L
.04033 .03418 L
.04065 .03398 L
.04095 .03373 L
.04147 .03314 L
.04204 .03226 L
.04319 .02981 L
.04573 .02188 L
.04631 .01972 L
.04694 .01735 L
Mistroke
.04724 .01618 L
.04739 .01561 L
.04752 .01508 L
.04765 .01481 L
.04778 .01532 L
.04805 .01639 L
.0492 .02077 L
.05046 .02519 L
.05165 .02881 L
.05274 .03143 L
.05332 .03253 L
.05388 .03336 L
.05417 .03369 L
.05447 .03398 L
.05463 .03411 L
.0548 .03422 L
.05495 .0343 L
.05511 .03436 L
.05525 .03441 L
.0554 .03443 L
.05553 .03444 L
.05566 .03444 L
.05581 .03442 L
.05595 .03439 L
.0561 .03433 L
.05625 .03426 L
.05652 .0341 L
.05676 .03389 L
.05732 .03327 L
.05789 .0324 L
.05849 .03122 L
.05959 .02851 L
.06208 .02016 L
.06267 .01789 L
.063 .01663 L
.0633 .01543 L
.06346 .01481 L
.06355 .01493 L
.06363 .01526 L
.064 .01668 L
.06464 .01916 L
.06589 .02379 L
.06706 .0276 L
.06826 .03079 L
.06878 .03191 L
.06934 .03292 L
.06967 .0334 L
.06996 .03377 L
.07027 .03408 L
.07055 .03431 L
Mistroke
.07071 .03441 L
.07085 .03448 L
.07101 .03454 L
.07109 .03457 L
.07118 .03459 L
.07126 .0346 L
.07134 .03461 L
.07149 .03462 L
.07159 .03461 L
.07167 .0346 L
.07175 .03458 L
.07184 .03456 L
.07199 .0345 L
.07213 .03444 L
.07243 .03424 L
.07272 .03399 L
.07299 .0337 L
.07359 .03285 L
.07425 .03163 L
.07557 .02834 L
.07679 .02447 L
.07787 .02053 L
.07844 .01834 L
.07904 .01599 L
.07919 .01538 L
.07928 .01504 L
.07936 .01472 L
.07945 .01505 L
.07954 .01539 L
.07971 .01606 L
.08032 .01847 L
.08152 .02302 L
.0827 .02701 L
.08394 .03052 L
.085 .03277 L
.0856 .03371 L
.08588 .03405 L
.08617 .03434 L
.08633 .03448 L
.08648 .03459 L
.08663 .03468 L
.08677 .03474 L
.08693 .03481 L
.08702 .03483 L
.08711 .03485 L
.08726 .03487 L
.08734 .03487 L
.08742 .03486 L
.08758 .03484 L
.08772 .0348 L
Mistroke
.08786 .03476 L
.088 .03469 L
.08832 .03448 L
.08861 .03421 L
.08913 .03359 L
.0897 .03268 L
.09085 .03014 L
.09339 .02196 L
.09397 .01974 L
.09459 .01729 L
.09489 .01609 L
.09504 .01549 L
.09518 .01495 L
.0953 .01495 L
.09543 .01548 L
.09571 .01659 L
.09685 .0211 L
.0981 .02565 L
.0993 .02938 L
.10038 .03209 L
.10097 .03323 L
.10153 .03408 L
.10181 .03442 L
.10211 .03472 L
.10227 .03485 L
.10244 .03496 L
.10259 .03505 L
.10275 .03511 L
.10289 .03516 L
.10304 .03518 L
.10317 .0352 L
.1033 .03519 L
.10345 .03517 L
.10358 .03514 L
.10374 .03508 L
.10389 .03501 L
.10416 .03483 L
.1044 .03462 L
.10496 .03397 L
.10552 .03307 L
.10613 .03185 L
.10722 .02903 L
.10971 .02035 L
.1103 .01799 L
.11063 .01668 L
.11093 .01543 L
.11102 .01508 L
.11111 .01472 L
.1112 .01508 L
.1113 .01545 L
Mistroke
.11162 .01679 L
.11226 .01939 L
.11343 .02391 L
.11469 .02822 L
.11593 .03168 L
.11652 .03298 L
.11706 .03396 L
.1176 .03472 L
.11789 .03503 L
.1182 .03529 L
.11832 .03538 L
.11846 .03545 L
.11858 .03551 L
.11871 .03555 L
.11885 .03559 L
.119 .03561 L
.11914 .03561 L
.11927 .0356 L
.11943 .03556 L
.1195 .03554 L
.11959 .03551 L
.11988 .03535 L
.12005 .03523 L
.12022 .03508 L
.12054 .03474 L
.12117 .03385 L
.12174 .03277 L
.12289 .02992 L
.12399 .02647 L
.12515 .0222 L
.12578 .01967 L
.12638 .01721 L
.12663 .01618 L
.12676 .01562 L
.12689 .01509 L
.12703 .01488 L
.12718 .0155 L
.12744 .0166 L
.1286 .02138 L
.13086 .02947 L
.13148 .03124 L
.13213 .03286 L
.1327 .03401 L
.13331 .03499 L
.13364 .03539 L
.13394 .03569 L
.13408 .0358 L
.13424 .03591 L
.13439 .03599 L
.13453 .03605 L
Mistroke
.13462 .03607 L
.13471 .0361 L
.13479 .03611 L
.13487 .03612 L
.13495 .03612 L
.13504 .03612 L
.13514 .03611 L
.13523 .03609 L
.13531 .03607 L
.13539 .03605 L
.13554 .03598 L
.1357 .03589 L
.13588 .03577 L
.13617 .03552 L
.13649 .03515 L
.13714 .03416 L
.13774 .03296 L
.13831 .03159 L
.14074 .0235 L
.14182 .01912 L
.14211 .01792 L
.14241 .0166 L
.14255 .016 L
.1427 .01535 L
.14283 .0148 L
.14297 .0152 L
.14313 .01586 L
.14329 .01657 L
.14359 .01786 L
.14416 .02023 L
.14526 .02467 L
.14655 .0293 L
.14775 .03277 L
.14839 .03422 L
.14898 .03526 L
.14929 .03571 L
.14962 .0361 L
.1498 .03628 L
.14997 .03642 L
.15014 .03653 L
.15031 .03662 L
.15046 .03668 L
.1506 .03672 L
.15074 .03674 L
.15087 .03675 L
.15102 .03673 L
.15117 .0367 L
.15132 .03665 L
.15149 .03657 L
.15179 .03636 L
Mistroke
.15208 .03609 L
.15273 .03522 L
.15333 .03412 L
.15398 .03261 L
.15517 .0291 L
.1574 .02049 L
.15804 .01772 L
.15836 .01634 L
.1585 .01573 L
.15865 .01506 L
.15878 .01494 L
.15891 .0155 L
.15919 .01673 L
.15978 .01931 L
.16107 .02477 L
.1623 .02937 L
.16348 .03297 L
.1641 .0345 L
.16476 .03579 L
.16531 .03661 L
.16562 .03696 L
.16592 .03721 L
.16605 .03729 L
.16619 .03737 L
.16631 .03742 L
.16644 .03746 L
.16657 .03748 L
.16672 .03749 L
.16687 .03749 L
.16699 .03746 L
.16714 .03742 L
.16727 .03736 L
.16742 .03728 L
.16758 .03717 L
.1679 .03688 L
.1682 .03653 L
.16876 .03566 L
.1693 .03458 L
.1705 .03138 L
.17181 .0268 L
.17304 .02176 L
.17364 .01911 L
.17419 .01661 L
.17435 .01587 L
.1745 .01518 L
.17465 .01493 L
.17474 .01531 L
.17483 .01572 L
.17551 .01888 L
.17672 .02419 L
Mistroke
.17795 .02909 L
.17928 .03348 L
.17989 .03508 L
.18054 .03645 L
.1811 .03735 L
.18141 .03774 L
.18171 .03802 L
.18185 .03813 L
.182 .03822 L
.18215 .03829 L
.18228 .03834 L
.18243 .03838 L
.18252 .03839 L
.1826 .03839 L
.18274 .03838 L
.1829 .03835 L
.18304 .0383 L
.1832 .03823 L
.18335 .03813 L
.18349 .03803 L
.18383 .0377 L
.18415 .0373 L
.1847 .03638 L
.18521 .03529 L
.18638 .03205 L
.18865 .0232 L
.18928 .02038 L
.18993 .0173 L
.1902 .01601 L
.19035 .01529 L
.19049 .01478 L
.19057 .01516 L
.19066 .01558 L
.19081 .0163 L
.19111 .01772 L
.19245 .02398 L
.1937 .02924 L
.19495 .03369 L
.19557 .03547 L
.19613 .03684 L
.19665 .03786 L
.19722 .03869 L
.19753 .03903 L
.19768 .03915 L
.19782 .03925 L
.19795 .03933 L
.1981 .03939 L
.19825 .03944 L
.19839 .03946 L
.19854 .03947 L
Mistroke
.19869 .03945 L
.19885 .03941 L
.19894 .03937 L
.19902 .03933 L
.19918 .03924 L
.19936 .0391 L
.19969 .03878 L
.19999 .03839 L
.2003 .03788 L
.20088 .03674 L
.20201 .03367 L
.20322 .02927 L
.20437 .02434 L
.20543 .01928 L
.20599 .01651 L
.20615 .01571 L
.2063 .01495 L
.20644 .01513 L
.20658 .01588 L
.20785 .02214 L
.20906 .02778 L
.21039 .03315 L
.21099 .03517 L
.21163 .03704 L
.21218 .03837 L
.21279 .0395 L
.21314 .04 L
.21347 .04035 L
.21363 .04048 L
.21378 .04059 L
.21386 .04063 L
.21395 .04068 L
.21411 .04073 L
.21426 .04076 L
.21434 .04077 L
.21442 .04077 L
.21458 .04075 L
.21466 .04072 L
.21474 .0407 L
.21489 .04063 L
.21504 .04054 L
.21532 .0403 L
.21561 .03999 L
.21591 .03956 L
.21646 .03856 L
.21711 .037 L
.21771 .03523 L
.22025 .02483 L
.22135 .01926 L
.22167 .0176 L
Mistroke
.22197 .01602 L
.2221 .01532 L
.22224 .01481 L
.2224 .01562 L
.22254 .01636 L
.22383 .02314 L
.22503 .02901 L
.22617 .03388 L
.2268 .03617 L
.2274 .03806 L
.22795 .03952 L
.22855 .04079 L
.22882 .04123 L
.2291 .04162 L
.22934 .04189 L
.22961 .04211 L
.22975 .0422 L
.22989 .04226 L
.23004 .04231 L
.23012 .04233 L
.2302 .04234 L
.23035 .04233 L
.23044 .04232 L
.23052 .0423 L
.23067 .04225 L
.23082 .04217 L
.23096 .04208 L
.2311 .04196 L
.23135 .04169 L
.23166 .04128 L
.23194 .04082 L
.23255 .03952 L
.23323 .03767 L
.23445 .03326 L
.23683 .02175 L
.23751 .01799 L
.23767 .01708 L
.23785 .01611 L
.23799 .01528 L
.23808 .01481 L
.23815 .01503 L
.2383 .01585 L
.23843 .01661 L
.23873 .01829 L
.23936 .02179 L
.24057 .02826 L
.24185 .03435 L
.24295 .0386 L
.24358 .04057 L
.24416 .04203 L
Mistroke
.24472 .0431 L
.245 .04351 L
.24531 .04386 L
.24547 .044 L
.24562 .04411 L
.2457 .04415 L
.24579 .04419 L
.24588 .04422 L
.24595 .04424 L
.24609 .04426 L
.24624 .04426 L
.2464 .04423 L
.24655 .04417 L
.24669 .0441 L
.24684 .04399 L
.24711 .04373 L
.24738 .04339 L
.24763 .043 L
.24819 .04187 L
.24879 .04029 L
.25003 .03585 L
.25138 .02957 L
.25254 .02321 L
.25315 .01961 L
.25349 .01758 L
.25366 .01658 L
.25381 .01565 L
.25396 .01473 L
.25404 .01513 L
.25412 .01565 L
.25446 .01772 L
.25506 .02131 L
.25622 .02809 L
.25755 .03503 L
.25876 .04026 L
.25934 .04225 L
.25996 .04402 L
.26025 .04469 L
.26055 .0453 L
.26084 .04577 L
.2611 .04612 L
.26126 .04629 L
.26143 .04643 L
.2616 .04655 L
.2617 .04659 L
.26178 .04662 L
.26187 .04665 L
.26194 .04666 L
.26209 .04666 L
.26225 .04664 L
Mistroke
.26234 .04661 L
.26242 .04657 L
.26257 .04649 L
.2627 .04639 L
.263 .04608 L
.2633 .04567 L
.26362 .04511 L
.26422 .04372 L
.26477 .04205 L
.26604 .03704 L
.26735 .03031 L
.26858 .02288 L
.26916 .0192 L
.26947 .01715 L
.26962 .01614 L
.26976 .01521 L
.26992 .0152 L
.27 .01576 L
.27008 .01629 L
.27043 .0186 L
.27105 .02264 L
.27329 .03617 L
.27445 .0418 L
.27508 .04434 L
.27568 .04631 L
.27624 .04777 L
.27653 .04838 L
.27684 .04891 L
.27711 .04925 L
.27724 .04939 L
.27739 .04952 L
.27753 .0496 L
.27765 .04966 L
.27778 .0497 L
.2779 .04972 L
.27804 .04971 L
.27818 .04968 L
.27832 .04961 L
.27845 .04953 L
.2786 .04942 L
.27875 .04926 L
.27906 .04885 L
.27937 .0483 L
.27971 .04758 L
.2803 .04591 L
.28147 .04139 L
.28253 .03599 L
.28365 .02913 L
.28484 .02099 L
.28514 .01885 L
Mistroke
.28546 .01652 L
.28556 .01583 L
.28565 .01518 L
.28573 .01481 L
.28582 .01545 L
.28615 .01787 L
.28735 .02656 L
.28968 .0415 L
.29032 .0448 L
.29101 .04785 L
.29161 .05002 L
.29193 .05097 L
.29226 .05184 L
.29259 .05253 L
.29289 .05302 L
.29303 .05321 L
.29318 .05338 L
.29333 .05351 L
.29346 .0536 L
.29362 .05367 L
.2937 .0537 L
.29378 .05371 L
.29387 .05371 L
.29396 .0537 L
.29404 .05368 L
.29412 .05365 L
.29427 .05357 L
.29436 .05351 L
.29444 .05344 L
.29473 .05311 L
.29502 .05265 L
.29529 .05211 L
.2959 .0505 L
.29643 .04864 L
.29699 .04625 L
.29936 .03206 L
.30042 .0241 L
.30098 .01965 L
.30129 .01717 L
.30144 .01594 L
.30157 .01481 L
.30172 .01581 L
.30188 .01714 L
.30223 .01997 L
.30283 .02493 L
.30403 .03436 L
.30511 .04212 L
.30627 .04918 L
.30689 .05229 L
.30745 .05466 L
Mistroke
.30801 .05656 L
.30855 .05789 L
.30885 .05844 L
.30902 .05868 L
.30917 .05885 L
.3093 .05897 L
.30945 .05906 L
.3096 .05913 L
.30975 .05915 L
.30983 .05914 L
.30991 .05913 L
.31007 .05906 L
.31016 .05901 L
.31025 .05894 L
.31041 .05877 L
.31072 .05834 L
.31105 .0577 L
.31164 .05606 L
.31219 .054 L
.31345 .04751 L
.31468 .03905 L
.316 .02818 L
.31659 .0228 L
.31692 .01978 L
.31723 .0169 L
.31739 .0154 L
.31748 .01485 L
.31756 .01562 L
.31792 .01909 L
.31856 .0252 L
.32099 .04668 L
.3221 .05466 L
.32328 .06124 L
.32363 .06275 L
.32396 .06397 L
.32428 .06497 L
.32457 .06571 L
.32485 .06626 L
.325 .06649 L
.32515 .06668 L
.32531 .06682 L
.32545 .06691 L
.32554 .06695 L
.32562 .06697 L
.32578 .06696 L
.32591 .06692 L
.32606 .06683 L
.3262 .0667 L
.32633 .06655 L
.32663 .06607 L
Mistroke
.32694 .06537 L
.32753 .0635 L
.32818 .06066 L
.32933 .05365 L
.3304 .04511 L
.33166 .03296 L
.33229 .02637 L
.33286 .02004 L
.33299 .01858 L
.33313 .017 L
.33326 .01551 L
.33338 .01526 L
.33352 .0168 L
.33365 .01827 L
.33394 .0216 L
.3351 .03489 L
.33635 .04835 L
.33752 .05957 L
.33866 .06852 L
.33916 .07169 L
.33971 .07458 L
.34027 .07682 L
.34057 .07774 L
.34085 .07841 L
.34101 .0787 L
.34116 .07891 L
.3413 .07906 L
.34145 .07917 L
.34152 .0792 L
.34161 .07922 L
.3417 .07922 L
.34178 .07921 L
.34193 .07914 L
.34209 .079 L
.34224 .07879 L
.34239 .07855 L
.34273 .07778 L
.34306 .07675 L
.34341 .07536 L
.34404 .07204 L
.34462 .06819 L
.34582 .05767 L
.34693 .04538 L
.34756 .03756 L
.34823 .02858 L
.34855 .02405 L
.34886 .01967 L
.349 .01775 L
.34914 .01568 L
.3493 .01599 L
Mistroke
.34944 .01811 L
.35171 .0512 L
.353 .06855 L
.3542 .08213 L
.35544 .09296 L
.35609 .09698 L
.35642 .09853 L
.35661 .09926 L
.35678 .09985 L
.35694 .10028 L
.3571 .10066 L
.35725 .10093 L
.35739 .10111 L
.35754 .10124 L
.35763 .10127 L
.35771 .10129 L
.35779 .10128 L
.35787 .10125 L
.35796 .10119 L
.35804 .1011 L
.35819 .10091 L
.35834 .10063 L
.35861 .09993 L
.35893 .09877 L
.35922 .09741 L
.35981 .09376 L
.36043 .08862 L
.36154 .07624 L
.36274 .05874 L
.36405 .03533 L
.36435 .02944 L
.36468 .02286 L
.36483 .01979 L
.36492 .01809 L
.36499 .0165 L
.36513 .01574 L
.36528 .0189 L
.3664 .04292 L
.36892 .09602 L
.37011 .11763 L
.37076 .12781 L
.37136 .13601 L
.37192 .1424 L
.37242 .14706 L
.37269 .14907 L
.37299 .15087 L
.37315 .15168 L
.3733 .15231 L
.37344 .1528 L
.37359 .15322 L
Mistroke
.37374 .15352 L
.37388 .15369 L
.37402 .15375 L
.37415 .15371 L
.37431 .15355 L
.37445 .15329 L
.37452 .1531 L
.37461 .15286 L
.37476 .15232 L
.37503 .15098 L
.37533 .1491 L
.37585 .14446 L
.37647 .13694 L
.37704 .12787 L
.37834 .09992 L
.3796 .06331 L
.38022 .04208 L
.3805 .03212 L
.38064 .02668 L
.3808 .0207 L
.38094 .01524 L
.38107 .01925 L
.38132 .02945 L
.38187 .05278 L
.38304 .10587 L
.38782 .34906 L
.39023 .46122 L
.39242 .54046 L
.39301 .55679 L
.39364 .57188 L
.39419 .58263 L
.39479 .59192 L
.39512 .59587 L
.39543 .59881 L
.39576 .60112 L
.39594 .60206 L
.39602 .60239 L
.39611 .60269 L
.39626 .60308 L
.39641 .60328 L
.39656 .60332 L
.39665 .60326 L
.39673 .60315 L
.39688 .60282 L
.39701 .60237 L
.39716 .60171 L
.39732 .60083 L
.39763 .59856 L
.39792 .59574 L
.39847 .58876 L
Mistroke
.39906 .5788 L
.3997 .56524 L
.40085 .53401 L
.40191 .4982 L
.40666 .28443 L
.40904 .16757 L
.41122 .07056 L
.4118 .04774 L
.4121 .03623 L
.41242 .02441 L
.4125 .02167 L
.41258 .01874 L
.41273 .0159 L
.41288 .02089 L
.41301 .02539 L
.41356 .04282 L
.41487 .07799 L
.4155 .09189 L
.41608 .10265 L
.41661 .11083 L
.41718 .11803 L
.41749 .12125 L
.41778 .12377 L
.41806 .12576 L
.41835 .12747 L
.41851 .12819 L
.41865 .12874 L
.41879 .12921 L
.41893 .12955 L
.41908 .12982 L
.41915 .12993 L
.41924 .13001 L
.41932 .13005 L
.41941 .13007 L
.41956 .13001 L
.41972 .12984 L
.4198 .12972 L
.41988 .12955 L
.42018 .12873 L
.42034 .1281 L
.42052 .1273 L
.42085 .12554 L
.42148 .12093 L
.42207 .11542 L
.4234 .09921 L
.42583 .06101 L
.4271 .0391 L
.42773 .02848 L
.428 .02391 L
.42831 .01898 L
Mistroke
.42844 .01685 L
.42858 .0148 L
.42871 .01691 L
.42883 .0188 L
.42939 .02725 L
.43055 .04337 L
.43167 .05627 L
.43286 .06674 L
.43348 .07079 L
.43381 .07254 L
.43416 .0741 L
.43449 .07525 L
.43478 .07606 L
.43493 .07637 L
.43508 .07665 L
.43523 .07685 L
.43536 .07699 L
.43552 .0771 L
.4356 .07713 L
.43568 .07714 L
.43583 .07712 L
.43598 .07705 L
.43606 .07699 L
.43614 .07691 L
.4363 .07672 L
.43646 .07646 L
.43664 .0761 L
.43694 .07533 L
.43726 .07429 L
.43784 .07187 L
.4389 .06572 L
.44008 .05681 L
.44131 .04577 L
.44261 .03302 L
.44372 .02189 L
.44402 .01887 L
.44419 .01723 L
.44434 .01568 L
.44449 .01514 L
.44465 .01667 L
.44493 .01932 L
.44715 .03795 L
.44841 .0459 L
.44903 .04893 L
.44959 .05117 L
.44987 .05211 L
.45018 .05298 L
.45048 .05366 L
.45074 .05416 L
.45106 .05459 L
Mistroke
.45123 .05476 L
.45131 .05482 L
.45139 .05488 L
.45154 .05495 L
.45168 .05498 L
.45182 .05498 L
.45191 .05497 L
.45199 .05494 L
.45214 .05487 L
.45223 .05481 L
.45231 .05474 L
.45263 .05439 L
.45291 .05395 L
.45321 .05336 L
.45383 .05172 L
.45452 .04932 L
.45574 .04374 L
.45686 .03744 L
.45816 .02914 L
.45938 .021 L
.45965 .01916 L
.45994 .01718 L
.46008 .01627 L
.46022 .01532 L
.46035 .01488 L
.46048 .01577 L
.4611 .01974 L
.46166 .02319 L
.46297 .03043 L
.46416 .03581 L
.46473 .03793 L
.46536 .03983 L
.46596 .04123 L
.46651 .04218 L
.46666 .04239 L
.46684 .04258 L
.46699 .04272 L
.46715 .04284 L
.46729 .04293 L
.46745 .043 L
.46759 .04304 L
.46773 .04305 L
.46781 .04305 L
.4679 .04304 L
.46798 .04302 L
.46806 .043 L
.4682 .04294 L
.46835 .04285 L
.46852 .04273 L
.46867 .04258 L
Mistroke
.46903 .04217 L
.46962 .04117 L
.47028 .03968 L
.47147 .03605 L
.4737 .02675 L
.47492 .02089 L
.47552 .01795 L
.47579 .01667 L
.47593 .01599 L
.47607 .01526 L
.47616 .01485 L
.47623 .01491 L
.47638 .01563 L
.47671 .01719 L
.4774 .02038 L
.4786 .0255 L
.47972 .02956 L
.48091 .03295 L
.48152 .03429 L
.48185 .03488 L
.48221 .03541 L
.48253 .03581 L
.48283 .03609 L
.48311 .03629 L
.48325 .03637 L
.48341 .03643 L
.48357 .03648 L
.48371 .0365 L
.48379 .0365 L
.48388 .0365 L
.48396 .03649 L
.48405 .03648 L
.4842 .03644 L
.48434 .03638 L
.4845 .0363 L
.48465 .0362 L
.48493 .03598 L
.48519 .03571 L
.48577 .03491 L
.48642 .03375 L
.487 .03244 L
.4883 .02878 L
.48953 .02458 L
.49082 .01964 L
.49136 .01753 L
.49165 .01635 L
.49193 .01524 L
.49208 .01478 L
.49217 .01514 L
.49226 .01546 L
Mistroke
.49255 .01665 L
.49314 .01893 L
.4943 .0232 L
.49554 .02726 L
.49664 .0302 L
.49779 .03251 L
.49836 .0333 L
.49868 .03365 L
.49897 .03391 L
.49925 .03409 L
.49937 .03416 L
.49949 .03421 L
.49963 .03426 L
.49978 .03429 L
.49991 .0343 L
.50005 .03431 L
.5002 .03429 L
.50035 .03426 L
.50042 .03424 L
.50051 .03421 L
.50066 .03414 L
.50096 .03396 L
.50123 .03374 L
.50187 .03301 L
.50254 .03194 L
.50366 .02946 L
.50488 .02596 L
.50602 .02207 L
.50708 .01806 L
.50764 .01587 L
.5078 .01524 L
.50795 .01477 L
.50809 .01531 L
.50824 .0159 L
.5095 .0209 L
.51071 .02544 L
.51204 .02984 L
.51264 .03152 L
.51328 .03309 L
.51383 .03423 L
.51444 .03523 L
.51479 .03568 L
.51512 .03602 L
.51543 .03625 L
.5156 .03635 L
.51576 .03642 L
.51592 .03647 L
.51606 .03649 L
.51622 .0365 L
.5163 .0365 L
Mistroke
.51639 .03648 L
.51653 .03645 L
.51669 .0364 L
.51684 .03632 L
.51697 .03624 L
.51725 .03603 L
.51755 .03571 L
.51817 .03484 L
.51874 .03376 L
.51928 .0325 L
.52048 .02888 L
.52178 .02394 L
.52239 .02133 L
.52303 .01839 L
.52335 .01691 L
.5235 .01618 L
.52364 .01549 L
.52377 .01487 L
.52391 .01519 L
.52405 .01586 L
.5242 .01659 L
.52542 .02254 L
.52674 .0288 L
.52795 .03388 L
.52909 .0379 L
.52972 .03968 L
.53041 .04123 L
.53071 .04177 L
.53103 .04225 L
.53134 .04259 L
.53161 .04283 L
.53176 .04292 L
.53189 .04298 L
.53204 .04303 L
.53213 .04304 L
.5322 .04305 L
.53236 .04304 L
.53244 .04303 L
.53252 .04301 L
.53267 .04295 L
.53283 .04286 L
.53296 .04277 L
.5331 .04264 L
.53336 .04236 L
.53366 .04193 L
.53394 .04144 L
.53456 .04005 L
.53523 .03805 L
.53645 .03322 L
.53767 .02704 L
Mistroke
.53882 .02022 L
.53913 .01827 L
.53946 .01615 L
.53954 .01561 L
.53963 .01503 L
.53973 .015 L
.53982 .0156 L
.54015 .0178 L
.54135 .02591 L
.54374 .04094 L
.54509 .04772 L
.54573 .05028 L
.54634 .05223 L
.54687 .05353 L
.54717 .05409 L
.54745 .05449 L
.54758 .05464 L
.54773 .05478 L
.54781 .05484 L
.54789 .05489 L
.54804 .05495 L
.5482 .05498 L
.54828 .05498 L
.54836 .05497 L
.54851 .05493 L
.54867 .05484 L
.54882 .05472 L
.54896 .05457 L
.54928 .05412 L
.54957 .05356 L
.54985 .0529 L
.55047 .05097 L
.55114 .04815 L
.55372 .0313 L
.55431 .02628 L
.55493 .02063 L
.55519 .01821 L
.55533 .01686 L
.55547 .01557 L
.55562 .01536 L
.55577 .01677 L
.55605 .01955 L
.55722 .03129 L
.55848 .04381 L
.56077 .06348 L
.56194 .07076 L
.56253 .07349 L
.56287 .07473 L
.56318 .07566 L
.56345 .07628 L
Mistroke
.56358 .07654 L
.56373 .07676 L
.56388 .07693 L
.56401 .07705 L
.5641 .0771 L
.56418 .07713 L
.56432 .07714 L
.56446 .07711 L
.56459 .07703 L
.56471 .07692 L
.56484 .07676 L
.56498 .07654 L
.56513 .07625 L
.5654 .07559 L
.56571 .07459 L
.56604 .07327 L
.56662 .07018 L
.56726 .06586 L
.56796 .05991 L
.56922 .04619 L
.57038 .03064 L
.57097 .02188 L
.57112 .0196 L
.57126 .01742 L
.57138 .01545 L
.57152 .01612 L
.57166 .01843 L
.57179 .02058 L
.57209 .02544 L
.57271 .03596 L
.57523 .0785 L
.57631 .09519 L
.57749 .11051 L
.57816 .11765 L
.57877 .12292 L
.57906 .12498 L
.57939 .12685 L
.57969 .12824 L
.57997 .12919 L
.58013 .12957 L
.58021 .12973 L
.58029 .12986 L
.58043 .13001 L
.58059 .13007 L
.58067 .13006 L
.58075 .13001 L
.5809 .12985 L
.58099 .12971 L
.58107 .12955 L
.58125 .12908 L
Mistroke
.58152 .12805 L
.58183 .12647 L
.58215 .12431 L
.58245 .12181 L
.58301 .11583 L
.58353 .10886 L
.58469 .08786 L
.58588 .05905 L
.58644 .04267 L
.58698 .02572 L
.58712 .0208 L
.58728 .01548 L
.58736 .01674 L
.58745 .01989 L
.58761 .02551 L
.58818 .04692 L
.58947 .09984 L
.59434 .33356 L
.59658 .43768 L
.59902 .52994 L
.59966 .54891 L
.60035 .56624 L
.60094 .5787 L
.60158 .5894 L
.60192 .59391 L
.60223 .59729 L
.60253 .59982 L
.60268 .60085 L
.60285 .60176 L
.603 .60241 L
.60313 .60285 L
.60327 .60314 L
.6034 .6033 L
.60355 .60331 L
.60369 .60317 L
.60384 .60285 L
.60392 .60262 L
.604 .60231 L
.60428 .60087 L
.60445 .59978 L
.60459 .59859 L
.60522 .59176 L
.60576 .58349 L
.60634 .57231 L
.60766 .53803 L
.60886 .4974 L
.61368 .27194 L
.6159 .15792 L
.61716 .09674 L
.61777 .06858 L
Mistroke
.61833 .0441 L
.61862 .03215 L
.61877 .02599 L
.61893 .01954 L
.61906 .01537 L
.61922 .02135 L
.61949 .03163 L
.62073 .07393 L
.62204 .10918 L
.62263 .12171 L
.62327 .13304 L
.62389 .14151 L
.62446 .14738 L
.62477 .14979 L
.62506 .15149 L
.62522 .15222 L
.62539 .15285 L
.62547 .15308 L
.62555 .15329 L
.6257 .15357 L
.62584 .15371 L
.62597 .15375 L
.62611 .15369 L
.62625 .15353 L
.62638 .15329 L
.6265 .15299 L
.62677 .15205 L
.62706 .15059 L
.62733 .1489 L
.62793 .14388 L
.62852 .13747 L
.62915 .12924 L
.63026 .11129 L
.63277 .06085 L
.63391 .03606 L
.63424 .02898 L
.63456 .02234 L
.63469 .01947 L
.63484 .01645 L
.63499 .01623 L
.63514 .01925 L
.63735 .06017 L
.63848 .07655 L
.63908 .08361 L
.6397 .08982 L
.64025 .09419 L
.64054 .09608 L
.64085 .09778 L
.64114 .09905 L
.6414 .09995 L
Mistroke
.64153 .10031 L
.64166 .10063 L
.64179 .10087 L
.64191 .10105 L
.64206 .1012 L
.64219 .10127 L
.64234 .10128 L
.6425 .10121 L
.64264 .10108 L
.64279 .10087 L
.64293 .1006 L
.64305 .1003 L
.64336 .09936 L
.6437 .09799 L
.64431 .09465 L
.64495 .08997 L
.64563 .08387 L
.64685 .0704 L
.64808 .05418 L
.64925 .03742 L
.64976 .02992 L
.6503 .02196 L
.65058 .01783 L
.65066 .0167 L
.65074 .01549 L
.65089 .01609 L
.65104 .0182 L
.65117 .02019 L
.65144 .02389 L
.6538 .05368 L
.655 .0652 L
.65569 .07031 L
.65632 .07405 L
.65693 .07671 L
.65728 .07779 L
.65744 .0782 L
.65759 .07852 L
.65774 .07877 L
.65787 .07895 L
.65802 .0791 L
.65818 .07919 L
.65833 .07923 L
.65842 .07922 L
.65849 .07919 L
.65864 .07911 L
.65879 .07896 L
.65893 .07878 L
.65906 .07858 L
.65934 .07797 L
.6596 .07726 L
Mistroke
.65986 .07637 L
.66042 .07393 L
.66104 .07048 L
.66228 .06132 L
.6634 .05087 L
.66472 .03691 L
.66529 .03041 L
.66593 .02314 L
.66621 .01993 L
.66636 .01816 L
.66651 .01648 L
.66665 .01493 L
.66679 .01615 L
.66705 .01907 L
.66824 .032 L
.66956 .04472 L
.67075 .0542 L
.67134 .058 L
.67198 .0614 L
.67258 .06389 L
.67313 .06554 L
.67343 .06618 L
.67358 .06642 L
.67372 .06661 L
.67379 .0667 L
.67388 .06678 L
.67403 .06689 L
.67411 .06693 L
.6742 .06696 L
.67428 .06697 L
.67436 .06697 L
.67444 .06695 L
.67453 .06692 L
.67468 .06683 L
.67477 .06676 L
.67485 .06668 L
.67503 .06645 L
.67533 .06591 L
.67566 .06514 L
.6763 .06302 L
.6769 .06041 L
.67824 .0524 L
.68067 .03237 L
.68176 .0221 L
.68208 .0191 L
.68223 .01762 L
.68238 .01626 L
.68251 .01502 L
.68264 .01568 L
.68278 .01699 L
Mistroke
.68294 .01843 L
.68422 .03011 L
.68543 .03987 L
.68656 .0476 L
.68776 .05379 L
.68838 .05613 L
.68871 .0571 L
.68907 .05794 L
.68923 .05826 L
.68939 .05852 L
.68955 .05872 L
.68969 .05888 L
.68983 .05899 L
.68997 .05908 L
.69011 .05913 L
.69027 .05915 L
.69043 .05912 L
.69057 .05905 L
.69073 .05894 L
.6909 .05878 L
.69121 .05834 L
.69149 .05781 L
.69207 .05631 L
.69261 .05443 L
.69382 .04869 L
.69513 .04048 L
.69638 .03125 L
.69754 .02191 L
.69812 .01709 L
.6982 .01643 L
.69829 .01571 L
.69845 .015 L
.6986 .01627 L
.69875 .01744 L
.70008 .02794 L
.70233 .04283 L
.70295 .04597 L
.70361 .0488 L
.70424 .0509 L
.70454 .05171 L
.70481 .05233 L
.70509 .05284 L
.70539 .05325 L
.70555 .05343 L
.7057 .05355 L
.70585 .05364 L
.706 .05369 L
.70613 .05371 L
.70627 .0537 L
.7064 .05367 L
Mistroke
.70652 .05361 L
.70666 .05352 L
.70682 .05338 L
.7071 .05304 L
.70743 .0525 L
.70773 .05187 L
.70839 .05 L
.70901 .04774 L
.7096 .04518 L
.71202 .03091 L
.7131 .02334 L
.71369 .01904 L
.71398 .01691 L
.71411 .01597 L
.71425 .01494 L
.7144 .0155 L
.71455 .01661 L
.71487 .01893 L
.71543 .02291 L
.71653 .03029 L
.71783 .03793 L
.71902 .04349 L
.7196 .04558 L
.72022 .0474 L
.72051 .04806 L
.72081 .04865 L
.7211 .04908 L
.72136 .04938 L
.72152 .04951 L
.72161 .04957 L
.72169 .04962 L
.72183 .04968 L
.72198 .04971 L
.72207 .04972 L
.72215 .04971 L
.72231 .04968 L
.7224 .04964 L
.72248 .0496 L
.72266 .04948 L
.7228 .04934 L
.72294 .0492 L
.72325 .04876 L
.72355 .04822 L
.72388 .0475 L
.72503 .04392 L
.72569 .04123 L
.72629 .03834 L
.7276 .03112 L
.72884 .02339 L
.72941 .01963 L
Mistroke
.72973 .01755 L
.73002 .01561 L
.73017 .0148 L
.73026 .01537 L
.73034 .01589 L
.73069 .01818 L
.7313 .02215 L
.73355 .03504 L
.73473 .0403 L
.7353 .04231 L
.73584 .04387 L
.73614 .04461 L
.73647 .04528 L
.73675 .04575 L
.73705 .04615 L
.73721 .04631 L
.73738 .04645 L
.73747 .04651 L
.73755 .04656 L
.73764 .0466 L
.73772 .04663 L
.73787 .04666 L
.73795 .04667 L
.73804 .04666 L
.73818 .04664 L
.73834 .04658 L
.73849 .04649 L
.73862 .04639 L
.73893 .04608 L
.73923 .04566 L
.73956 .04509 L
.74014 .04375 L
.74067 .04221 L
.74197 .03725 L
.74319 .03129 L
.74437 .02472 L
.74501 .02091 L
.74532 .01902 L
.74561 .01728 L
.74573 .01651 L
.74587 .01568 L
.746 .0149 L
.74612 .01523 L
.74625 .016 L
.74639 .01684 L
.74667 .01854 L
.74783 .02532 L
.74897 .03131 L
.75016 .03665 L
.75079 .03895 L
Mistroke
.75147 .04103 L
.7521 .04249 L
.75238 .04301 L
.75268 .04347 L
.75283 .04366 L
.75299 .04384 L
.75314 .04398 L
.75328 .04408 L
.75345 .04417 L
.75354 .04421 L
.75362 .04424 L
.75378 .04426 L
.75386 .04427 L
.75394 .04426 L
.7541 .04423 L
.75425 .04418 L
.75438 .04411 L
.75452 .04401 L
.75484 .0437 L
.75514 .04332 L
.75566 .04241 L
.75623 .04108 L
.75738 .03742 L
.75993 .02567 L
.76052 .0225 L
.76114 .01903 L
.76139 .01759 L
.76167 .01604 L
.76183 .01514 L
.76197 .01507 L
.76211 .01585 L
.76225 .01667 L
.76341 .02302 L
.76466 .02936 L
.76586 .03451 L
.76695 .03819 L
.76754 .03974 L
.7681 .04089 L
.76839 .04135 L
.76869 .04174 L
.76885 .04191 L
.76902 .04206 L
.76918 .04217 L
.76933 .04225 L
.76947 .0423 L
.76961 .04233 L
.76976 .04234 L
.76989 .04233 L
.77002 .0423 L
.77013 .04225 L
Mistroke
.77027 .04219 L
.7704 .04211 L
.77068 .04186 L
.77095 .04156 L
.77154 .04061 L
.77211 .03937 L
.77272 .03771 L
.77382 .03391 L
.77631 .02241 L
.77691 .0193 L
.77724 .01757 L
.77754 .01595 L
.7777 .0151 L
.77779 .01477 L
.77787 .0152 L
.77824 .01713 L
.77888 .02047 L
.78014 .02667 L
.78131 .03172 L
.78241 .03563 L
.78298 .03725 L
.78359 .03868 L
.78394 .03933 L
.78427 .03983 L
.78458 .0402 L
.78473 .04036 L
.7849 .0405 L
.78506 .0406 L
.7852 .04067 L
.78534 .04072 L
.78547 .04075 L
.78562 .04077 L
.78577 .04076 L
.78592 .04072 L
.786 .04069 L
.78609 .04066 L
.78624 .04058 L
.78637 .04048 L
.78668 .0402 L
.78699 .03983 L
.78731 .03934 L
.78789 .0382 L
.78842 .0369 L
.78972 .03276 L
.79094 .0278 L
.79211 .02237 L
.79275 .01922 L
.79306 .01766 L
.79335 .01622 L
.79347 .01559 L
Mistroke
.79361 .01491 L
.79374 .01514 L
.79386 .01574 L
.79441 .01847 L
.79557 .02406 L
.79685 .02956 L
.79805 .03384 L
.79913 .03675 L
.79974 .03795 L
.80029 .03875 L
.80059 .03906 L
.80086 .03927 L
.80101 .03935 L
.80109 .03938 L
.80117 .03941 L
.80133 .03945 L
.80147 .03947 L
.8016 .03947 L
.80174 .03944 L
.80187 .03941 L
.80199 .03936 L
.80212 .03929 L
.80227 .03919 L
.80257 .03893 L
.80289 .03855 L
.80319 .03812 L
.80386 .03686 L
.80506 .03365 L
.80757 .02388 L
.80867 .01877 L
.80897 .01733 L
.80914 .01654 L
.8093 .01578 L
.80944 .01508 L
.80953 .01472 L
.8096 .01508 L
.80988 .01642 L
.81214 .02659 L
.81329 .03093 L
.81453 .03466 L
.81519 .03617 L
.81548 .03672 L
.8158 .03723 L
.81609 .0376 L
.81639 .03793 L
.81656 .03807 L
.81671 .03818 L
.81685 .03826 L
.81701 .03832 L
.81714 .03836 L
Mistroke
.81729 .03839 L
.81743 .03839 L
.81756 .03838 L
.81771 .03835 L
.81785 .0383 L
.81801 .03822 L
.81816 .03812 L
.81843 .0379 L
.81868 .03763 L
.81925 .03681 L
.81986 .03563 L
.82053 .03401 L
.82173 .03026 L
.82397 .02119 L
.82452 .0187 L
.82483 .01731 L
.82512 .01599 L
.82528 .01524 L
.82537 .01482 L
.82546 .01497 L
.82561 .01567 L
.82577 .0164 L
.82637 .01915 L
.8276 .02444 L
.82891 .02947 L
.83014 .03322 L
.83068 .03453 L
.83126 .0357 L
.83153 .03615 L
.83182 .03655 L
.83207 .03684 L
.83234 .0371 L
.83249 .03722 L
.83264 .03731 L
.83278 .03739 L
.83293 .03744 L
.83306 .03747 L
.83318 .03749 L
.83332 .03749 L
.83347 .03748 L
.83355 .03746 L
.83363 .03744 L
.83377 .03738 L
.83393 .0373 L
.8341 .03719 L
.83441 .03693 L
.83469 .03661 L
.83534 .03563 L
.83602 .03423 L
.83717 .03108 L
Mistroke
.83844 .02666 L
.83965 .02177 L
.84025 .0192 L
.8408 .01678 L
.84111 .01542 L
.84126 .01474 L
.84135 .01505 L
.84143 .01542 L
.84212 .01844 L
.84332 .02352 L
.84451 .02802 L
.84576 .03193 L
.84683 .03444 L
.84743 .03547 L
.84771 .03584 L
.84799 .03616 L
.84815 .03631 L
.84831 .03644 L
.84846 .03654 L
.8486 .03661 L
.84877 .03668 L
.84886 .03671 L
.84895 .03673 L
.8491 .03674 L
.84919 .03675 L
.84927 .03674 L
.84941 .03672 L
.84954 .03668 L
.84969 .03662 L
.84985 .03654 L
.85017 .03631 L
.85046 .03601 L
.85099 .03532 L
.85156 .03431 L
.85271 .03155 L
.85527 .02261 L
.85585 .02019 L
.85648 .01756 L
.85673 .01646 L
.85687 .01585 L
.85701 .01528 L
.85717 .0148 L
.85731 .01542 L
.85759 .01664 L
.85875 .02149 L
.86001 .02632 L
.86121 .03025 L
.8623 .03304 L
.86289 .03422 L
.86345 .03508 L
Mistroke
.86376 .03545 L
.86405 .03571 L
.86436 .03593 L
.86452 .03601 L
.8646 .03604 L
.86469 .03607 L
.86484 .03611 L
.86498 .03612 L
.86511 .03612 L
.86524 .03611 L
.86538 .03607 L
.86553 .03602 L
.86569 .03595 L
.86583 .03586 L
.8661 .03565 L
.86635 .03541 L
.86691 .03468 L
.86748 .03368 L
.86809 .03235 L
.86919 .02932 L
.87169 .02022 L
.87229 .01775 L
.87261 .01638 L
.87277 .01571 L
.87292 .0151 L
.873 .01475 L
.87308 .01497 L
.87316 .01532 L
.87325 .01569 L
.87362 .01721 L
.87426 .01985 L
.87554 .02478 L
.87669 .02869 L
.87728 .03041 L
.87792 .03202 L
.87847 .03319 L
.87907 .03423 L
.87938 .03465 L
.87971 .03502 L
.87989 .03518 L
.88006 .03531 L
.88023 .03542 L
.88039 .0355 L
.88053 .03555 L
.88069 .03559 L
.88084 .03561 L
.88093 .03561 L
.88101 .03561 L
.88116 .03559 L
.88129 .03555 L
Mistroke
.88145 .03549 L
.8816 .03542 L
.88191 .03521 L
.88221 .03494 L
.88275 .03425 L
.88335 .03325 L
.88399 .03188 L
.8862 .02522 L
.88745 .02054 L
.88805 .01811 L
.88861 .01586 L
.88875 .01527 L
.88891 .01477 L
.88905 .01537 L
.88919 .01593 L
.88982 .01847 L
.89115 .02361 L
.89223 .02735 L
.89339 .03071 L
.89406 .03226 L
.89468 .03341 L
.89526 .03426 L
.89556 .03458 L
.89588 .03486 L
.89603 .03496 L
.89618 .03505 L
.89627 .03508 L
.89636 .03512 L
.89652 .03516 L
.89666 .03519 L
.89675 .03519 L
.89683 .0352 L
.89697 .03518 L
.89712 .03515 L
.89725 .03511 L
.8974 .03505 L
.89765 .0349 L
.89796 .03465 L
.89824 .03436 L
.89887 .0335 L
.89954 .03225 L
.90077 .0292 L
.90313 .02117 L
.90377 .01865 L
.90413 .01724 L
.90447 .01589 L
.90462 .01528 L
.9047 .01494 L
.90478 .01477 L
.90486 .01511 L
Mistroke
.90496 .01548 L
.90512 .01614 L
.90572 .01851 L
.90693 .02313 L
.9082 .02745 L
.90938 .03073 L
.90996 .03202 L
.91048 .03299 L
.91104 .03382 L
.91156 .03438 L
.91185 .0346 L
.91211 .03474 L
.91225 .0348 L
.9124 .03484 L
.91256 .03486 L
.91271 .03487 L
.91286 .03485 L
.91295 .03484 L
.91303 .03482 L
.91317 .03477 L
.91333 .0347 L
.91362 .03451 L
.91389 .03429 L
.91454 .03351 L
.91515 .0325 L
.91633 .02982 L
.91758 .02612 L
.91875 .02202 L
.91981 .01796 L
.92009 .01684 L
.92024 .01626 L
.9204 .01563 L
.92054 .01508 L
.92069 .01492 L
.92083 .01547 L
.92096 .01598 L
.92219 .02075 L
.9244 .02824 L
.925 .02988 L
.92565 .03142 L
.92623 .03254 L
.92684 .03348 L
.92715 .03386 L
.92745 .03414 L
.92771 .03434 L
.92785 .03443 L
.928 .0345 L
.92814 .03455 L
.92827 .03459 L
.92841 .03461 L
Mistroke
.92856 .03462 L
.9287 .03461 L
.92883 .03459 L
.92895 .03456 L
.92908 .03451 L
.92922 .03445 L
.92936 .03437 L
.92966 .03414 L
.92993 .03389 L
.93021 .03356 L
.93081 .03268 L
.93146 .03142 L
.93277 .02809 L
.93399 .02418 L
.93526 .01954 L
.93589 .01714 L
.93616 .01607 L
.9363 .0155 L
.93646 .01489 L
.9366 .01506 L
.93673 .01557 L
.93698 .01656 L
.93754 .0187 L
.9387 .02303 L
.93981 .02674 L
.941 .03004 L
.94168 .03158 L
.94229 .0327 L
.94259 .03315 L
.94291 .03356 L
.94322 .03388 L
.9435 .03411 L
.94378 .03428 L
.94394 .03435 L
.94409 .0344 L
.94423 .03443 L
.94436 .03444 L
.9445 .03444 L
.94465 .03443 L
.94479 .03439 L
.94488 .03437 L
.94495 .03434 L
.94524 .03419 L
.9454 .03409 L
.94557 .03395 L
.94591 .03361 L
.94654 .03275 L
.94722 .03151 L
.94845 .02854 L
.95085 .02056 L
Mistroke
.95151 .01807 L
.95187 .01668 L
.95205 .01599 L
.95221 .01537 L
.95236 .01479 L
.9525 .01515 L
.95264 .01572 L
.9528 .01635 L
.95346 .01886 L
.95575 .02687 L
.95706 .03041 L
.9577 .03177 L
.95829 .03278 L
.95884 .03352 L
.95912 .0338 L
.95943 .03404 L
.95959 .03414 L
.95974 .03422 L
.95982 .03425 L
.95991 .03428 L
.96007 .03432 L
.96022 .03434 L
.96038 .03434 L
.96052 .03433 L
.96067 .03429 L
.96075 .03427 L
.96084 .03424 L
.961 .03416 L
.9613 .03397 L
.96165 .03366 L
.96198 .03329 L
.96257 .03242 L
.9632 .03122 L
.96444 .02814 L
.96578 .02392 L
.96694 .01973 L
.96756 .01739 L
.9679 .01609 L
.96806 .01544 L
.96822 .01484 L
.96837 .01514 L
.96844 .01544 L
.96853 .01577 L
.96887 .01708 L
.96946 .01934 L
.97062 .02356 L
.97195 .0278 L
.97316 .03089 L
.97387 .03228 L
.97462 .03337 L
Mistroke
.97501 .03377 L
.97537 .03405 L
.97558 .03416 L
.97577 .03424 L
.97587 .03427 L
.97598 .03429 L
.97609 .0343 L
.97619 .03431 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.00459847 0.64881 0.188537 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.491929 0.0484262 0.0147151 0.0298707 [
[.00767 -0.0125 -9 -9 ]
[.00767 -0.0125 9 0 ]
[.2498 -0.0125 -6 -9 ]
[.2498 -0.0125 6 0 ]
[.49193 -0.0125 -3 -9 ]
[.49193 -0.0125 3 0 ]
[.73406 -0.0125 -3 -9 ]
[.73406 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .16407 -6 -4.5 ]
[-0.0125 .16407 0 4.5 ]
[-0.0125 .31342 -12 -4.5 ]
[-0.0125 .31342 0 4.5 ]
[-0.0125 .46278 -12 -4.5 ]
[-0.0125 .46278 0 4.5 ]
[-0.0125 .61213 -12 -4.5 ]
[-0.0125 .61213 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.00767 0 m
.00767 .00625 L
s
[(-10)] .00767 -0.0125 0 1 Mshowa
.2498 0 m
.2498 .00625 L
s
[(-5)] .2498 -0.0125 0 1 Mshowa
.49193 0 m
.49193 .00625 L
s
[(0)] .49193 -0.0125 0 1 Mshowa
.73406 0 m
.73406 .00625 L
s
[(5)] .73406 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05609 0 m
.05609 .00375 L
s
.10452 0 m
.10452 .00375 L
s
.15295 0 m
.15295 .00375 L
s
.20137 0 m
.20137 .00375 L
s
.29822 0 m
.29822 .00375 L
s
.34665 0 m
.34665 .00375 L
s
.39508 0 m
.39508 .00375 L
s
.4435 0 m
.4435 .00375 L
s
.54036 0 m
.54036 .00375 L
s
.58878 0 m
.58878 .00375 L
s
.63721 0 m
.63721 .00375 L
s
.68563 0 m
.68563 .00375 L
s
.78249 0 m
.78249 .00375 L
s
.83091 0 m
.83091 .00375 L
s
.87934 0 m
.87934 .00375 L
s
.92776 0 m
.92776 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .16407 m
.00625 .16407 L
s
[(5)] -0.0125 .16407 1 0 Mshowa
0 .31342 m
.00625 .31342 L
s
[(10)] -0.0125 .31342 1 0 Mshowa
0 .46278 m
.00625 .46278 L
s
[(15)] -0.0125 .46278 1 0 Mshowa
0 .61213 m
.00625 .61213 L
s
[(20)] -0.0125 .61213 1 0 Mshowa
.125 Mabswid
0 .04459 m
.00375 .04459 L
s
0 .07446 m
.00375 .07446 L
s
0 .10433 m
.00375 .10433 L
s
0 .1342 m
.00375 .1342 L
s
0 .19394 m
.00375 .19394 L
s
0 .22381 m
.00375 .22381 L
s
0 .25368 m
.00375 .25368 L
s
0 .28355 m
.00375 .28355 L
s
0 .34329 m
.00375 .34329 L
s
0 .37316 m
.00375 .37316 L
s
0 .40303 m
.00375 .40303 L
s
0 .43291 m
.00375 .43291 L
s
0 .49265 m
.00375 .49265 L
s
0 .52252 m
.00375 .52252 L
s
0 .55239 m
.00375 .55239 L
s
0 .58226 m
.00375 .58226 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.00767 .61178 m
.00767 .61803 L
s
.2498 .61178 m
.2498 .61803 L
s
.49193 .61178 m
.49193 .61803 L
s
.73406 .61178 m
.73406 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.05609 .61428 m
.05609 .61803 L
s
.10452 .61428 m
.10452 .61803 L
s
.15295 .61428 m
.15295 .61803 L
s
.20137 .61428 m
.20137 .61803 L
s
.29822 .61428 m
.29822 .61803 L
s
.34665 .61428 m
.34665 .61803 L
s
.39508 .61428 m
.39508 .61803 L
s
.4435 .61428 m
.4435 .61803 L
s
.54036 .61428 m
.54036 .61803 L
s
.58878 .61428 m
.58878 .61803 L
s
.63721 .61428 m
.63721 .61803 L
s
.68563 .61428 m
.68563 .61803 L
s
.78249 .61428 m
.78249 .61803 L
s
.83091 .61428 m
.83091 .61803 L
s
.87934 .61428 m
.87934 .61803 L
s
.92776 .61428 m
.92776 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16407 m
1 .16407 L
s
.99375 .31342 m
1 .31342 L
s
.99375 .46278 m
1 .46278 L
s
.99375 .61213 m
1 .61213 L
s
.125 Mabswid
.99625 .04459 m
1 .04459 L
s
.99625 .07446 m
1 .07446 L
s
.99625 .10433 m
1 .10433 L
s
.99625 .1342 m
1 .1342 L
s
.99625 .19394 m
1 .19394 L
s
.99625 .22381 m
1 .22381 L
s
.99625 .25368 m
1 .25368 L
s
.99625 .28355 m
1 .28355 L
s
.99625 .34329 m
1 .34329 L
s
.99625 .37316 m
1 .37316 L
s
.99625 .40303 m
1 .40303 L
s
.99625 .43291 m
1 .43291 L
s
.99625 .49265 m
1 .49265 L
s
.99625 .52252 m
1 .52252 L
s
.99625 .55239 m
1 .55239 L
s
.99625 .58226 m
1 .58226 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .01472 m
.02381 .04464 L
s
.03995 .01472 m
.03995 .04479 L
s
.05609 .01472 m
.05609 .04506 L
s
.07224 .01472 m
.07224 .04544 L
s
.08838 .01472 m
.08838 .04594 L
s
.10452 .01472 m
.10452 .04657 L
s
.12066 .01472 m
.12066 .04735 L
s
.1368 .01472 m
.1368 .0483 L
s
.15295 .01472 m
.15295 .04944 L
s
.16909 .01472 m
.16909 .05081 L
s
.18523 .01472 m
.18523 .05245 L
s
.20137 .01472 m
.20137 .05442 L
s
.21751 .01472 m
.21751 .05681 L
s
.23366 .01472 m
.23366 .05974 L
s
.2498 .01472 m
.2498 .06339 L
s
.26594 .01472 m
.26594 .06803 L
s
.28208 .01472 m
.28208 .0741 L
s
.29822 .01472 m
.29822 .08235 L
s
.31437 .01472 m
.31437 .09421 L
s
.33051 .01472 m
.33051 .11272 L
s
.34665 .01472 m
.34665 .14578 L
s
.36279 .01472 m
.36279 .22238 L
s
.37893 .01472 m
.37893 .60332 L
s
.39508 .01472 m
.39508 .56642 L
s
.41122 .01472 m
.41122 .18539 L
s
.42736 .01472 m
.42736 .10866 L
s
.4435 .01472 m
.4435 .07562 L
s
.45964 .01472 m
.45964 .05769 L
s
.47579 .01472 m
.47579 .04786 L
s
.49193 .01472 m
.49193 .04459 L
s
.50807 .01472 m
.50807 .04786 L
s
.52421 .01472 m
.52421 .05769 L
s
.54036 .01472 m
.54036 .07562 L
s
.5565 .01472 m
.5565 .10866 L
s
.57264 .01472 m
.57264 .18539 L
s
.58878 .01472 m
.58878 .56642 L
s
.60492 .01472 m
.60492 .60332 L
s
.62107 .01472 m
.62107 .22238 L
s
.63721 .01472 m
.63721 .14578 L
s
.65335 .01472 m
.65335 .11272 L
s
.66949 .01472 m
.66949 .09421 L
s
.68563 .01472 m
.68563 .08235 L
s
.70178 .01472 m
.70178 .0741 L
s
.71792 .01472 m
.71792 .06803 L
s
.73406 .01472 m
.73406 .06339 L
s
.7502 .01472 m
.7502 .05974 L
s
.76634 .01472 m
.76634 .05681 L
s
.78249 .01472 m
.78249 .05442 L
s
.79863 .01472 m
.79863 .05245 L
s
.81477 .01472 m
.81477 .05081 L
s
.83091 .01472 m
.83091 .04944 L
s
.84705 .01472 m
.84705 .0483 L
s
.8632 .01472 m
.8632 .04735 L
s
.87934 .01472 m
.87934 .04657 L
s
.89548 .01472 m
.89548 .04594 L
s
.91162 .01472 m
.91162 .04544 L
s
.92776 .01472 m
.92776 .04506 L
s
.94391 .01472 m
.94391 .04479 L
s
.96005 .01472 m
.96005 .04464 L
s
.97619 .01472 m
.97619 .04459 L
s
.015 w
.02381 .04464 Mdot
.03995 .04479 Mdot
.05609 .04506 Mdot
.07224 .04544 Mdot
.08838 .04594 Mdot
.10452 .04657 Mdot
.12066 .04735 Mdot
.1368 .0483 Mdot
.15295 .04944 Mdot
.16909 .05081 Mdot
.18523 .05245 Mdot
.20137 .05442 Mdot
.21751 .05681 Mdot
.23366 .05974 Mdot
.2498 .06339 Mdot
.26594 .06803 Mdot
.28208 .0741 Mdot
.29822 .08235 Mdot
.31437 .09421 Mdot
.33051 .11272 Mdot
.34665 .14578 Mdot
.36279 .22238 Mdot
.37893 .60332 Mdot
.39508 .56642 Mdot
.41122 .18539 Mdot
.42736 .10866 Mdot
.4435 .07562 Mdot
.45964 .05769 Mdot
.47579 .04786 Mdot
.49193 .04459 Mdot
.50807 .04786 Mdot
.52421 .05769 Mdot
.54036 .07562 Mdot
.5565 .10866 Mdot
.57264 .18539 Mdot
.58878 .56642 Mdot
.60492 .60332 Mdot
.62107 .22238 Mdot
.63721 .14578 Mdot
.65335 .11272 Mdot
.66949 .09421 Mdot
.68563 .08235 Mdot
.70178 .0741 Mdot
.71792 .06803 Mdot
.73406 .06339 Mdot
.7502 .05974 Mdot
.76634 .05681 Mdot
.78249 .05442 Mdot
.79863 .05245 Mdot
.81477 .05081 Mdot
.83091 .04944 Mdot
.84705 .0483 Mdot
.8632 .04735 Mdot
.87934 .04657 Mdot
.89548 .04594 Mdot
.91162 .04544 Mdot
.92776 .04506 Mdot
.94391 .04479 Mdot
.96005 .04464 Mdot
.97619 .04459 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.00459847 0.97619 0.188537 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.047619 0.0147151 0.019608 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .11275 -6 -4.5 ]
[-0.0125 .11275 0 4.5 ]
[-0.0125 .21079 -12 -4.5 ]
[-0.0125 .21079 0 4.5 ]
[-0.0125 .30883 -12 -4.5 ]
[-0.0125 .30883 0 4.5 ]
[-0.0125 .40687 -12 -4.5 ]
[-0.0125 .40687 0 4.5 ]
[-0.0125 .50491 -12 -4.5 ]
[-0.0125 .50491 0 4.5 ]
[-0.0125 .60295 -12 -4.5 ]
[-0.0125 .60295 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .11275 m
.00625 .11275 L
s
[(5)] -0.0125 .11275 1 0 Mshowa
0 .21079 m
.00625 .21079 L
s
[(10)] -0.0125 .21079 1 0 Mshowa
0 .30883 m
.00625 .30883 L
s
[(15)] -0.0125 .30883 1 0 Mshowa
0 .40687 m
.00625 .40687 L
s
[(20)] -0.0125 .40687 1 0 Mshowa
0 .50491 m
.00625 .50491 L
s
[(25)] -0.0125 .50491 1 0 Mshowa
0 .60295 m
.00625 .60295 L
s
[(30)] -0.0125 .60295 1 0 Mshowa
.125 Mabswid
0 .03432 m
.00375 .03432 L
s
0 .05393 m
.00375 .05393 L
s
0 .07354 m
.00375 .07354 L
s
0 .09315 m
.00375 .09315 L
s
0 .13236 m
.00375 .13236 L
s
0 .15197 m
.00375 .15197 L
s
0 .17158 m
.00375 .17158 L
s
0 .19119 m
.00375 .19119 L
s
0 .2304 m
.00375 .2304 L
s
0 .25001 m
.00375 .25001 L
s
0 .26962 m
.00375 .26962 L
s
0 .28923 m
.00375 .28923 L
s
0 .32844 m
.00375 .32844 L
s
0 .34805 m
.00375 .34805 L
s
0 .36766 m
.00375 .36766 L
s
0 .38727 m
.00375 .38727 L
s
0 .42648 m
.00375 .42648 L
s
0 .44609 m
.00375 .44609 L
s
0 .4657 m
.00375 .4657 L
s
0 .48531 m
.00375 .48531 L
s
0 .52452 m
.00375 .52452 L
s
0 .54413 m
.00375 .54413 L
s
0 .56374 m
.00375 .56374 L
s
0 .58335 m
.00375 .58335 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .11275 m
1 .11275 L
s
.99375 .21079 m
1 .21079 L
s
.99375 .30883 m
1 .30883 L
s
.99375 .40687 m
1 .40687 L
s
.99375 .50491 m
1 .50491 L
s
.99375 .60295 m
1 .60295 L
s
.125 Mabswid
.99625 .03432 m
1 .03432 L
s
.99625 .05393 m
1 .05393 L
s
.99625 .07354 m
1 .07354 L
s
.99625 .09315 m
1 .09315 L
s
.99625 .13236 m
1 .13236 L
s
.99625 .15197 m
1 .15197 L
s
.99625 .17158 m
1 .17158 L
s
.99625 .19119 m
1 .19119 L
s
.99625 .2304 m
1 .2304 L
s
.99625 .25001 m
1 .25001 L
s
.99625 .26962 m
1 .26962 L
s
.99625 .28923 m
1 .28923 L
s
.99625 .32844 m
1 .32844 L
s
.99625 .34805 m
1 .34805 L
s
.99625 .36766 m
1 .36766 L
s
.99625 .38727 m
1 .38727 L
s
.99625 .42648 m
1 .42648 L
s
.99625 .44609 m
1 .44609 L
s
.99625 .4657 m
1 .4657 L
s
.99625 .48531 m
1 .48531 L
s
.99625 .52452 m
1 .52452 L
s
.99625 .54413 m
1 .54413 L
s
.99625 .56374 m
1 .56374 L
s
.99625 .58335 m
1 .58335 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
0 0 1 r
.5 Mabswid
[ .01 ] 0 setdash
.02381 .03432 m
.02395 .03432 L
.02408 .03429 L
.02423 .03426 L
.02437 .0342 L
.02462 .03407 L
.02489 .03387 L
.02519 .03359 L
.02551 .03323 L
.02608 .03238 L
.02722 .03003 L
.02847 .02656 L
.02973 .02232 L
.03043 .01977 L
.03109 .01724 L
.03139 .0161 L
.03155 .01546 L
.03171 .01487 L
.03179 .0149 L
.03189 .01527 L
.03205 .01591 L
.03238 .01716 L
.03355 .02158 L
.03596 .02924 L
.03717 .03196 L
.03785 .03308 L
.03819 .0335 L
.0385 .03381 L
.03879 .03405 L
.03894 .03414 L
.0391 .03422 L
.03918 .03426 L
.03926 .03429 L
.03941 .03433 L
.03949 .03434 L
.03958 .03435 L
.03967 .03436 L
.03976 .03436 L
.03991 .03434 L
.04006 .0343 L
.04019 .03426 L
.04033 .0342 L
.04065 .034 L
.04095 .03375 L
.04147 .03315 L
.04204 .03227 L
.04319 .02983 L
.04573 .0219 L
.04631 .01974 L
.04694 .01737 L
Mistroke
.04724 .0162 L
.04739 .01562 L
.04752 .01509 L
.04765 .01482 L
.04778 .01533 L
.04805 .01641 L
.0492 .02079 L
.05046 .0252 L
.05165 .02882 L
.05274 .03144 L
.05332 .03255 L
.05388 .03337 L
.05417 .03371 L
.05447 .034 L
.05463 .03412 L
.0548 .03423 L
.05495 .03431 L
.05511 .03438 L
.05525 .03442 L
.0554 .03445 L
.05553 .03446 L
.05566 .03446 L
.05581 .03444 L
.05595 .0344 L
.0561 .03435 L
.05625 .03428 L
.05652 .03411 L
.05676 .03391 L
.05732 .03328 L
.05789 .03241 L
.05849 .03124 L
.05959 .02852 L
.06208 .02018 L
.06267 .01791 L
.063 .01665 L
.0633 .01545 L
.06346 .01483 L
.06355 .01495 L
.06363 .01527 L
.064 .01669 L
.06464 .01918 L
.06589 .0238 L
.06706 .02762 L
.06826 .03081 L
.06878 .03193 L
.06934 .03294 L
.06967 .03341 L
.06996 .03378 L
.07027 .03409 L
.07055 .03432 L
Mistroke
.07071 .03442 L
.07085 .03449 L
.07101 .03456 L
.07109 .03459 L
.07118 .03461 L
.07126 .03462 L
.07134 .03463 L
.07149 .03463 L
.07159 .03463 L
.07167 .03461 L
.07175 .0346 L
.07184 .03457 L
.07199 .03452 L
.07213 .03445 L
.07243 .03426 L
.07272 .03401 L
.07299 .03371 L
.07359 .03287 L
.07425 .03165 L
.07557 .02836 L
.07679 .02448 L
.07787 .02055 L
.07844 .01836 L
.07904 .01601 L
.07919 .01539 L
.07928 .01506 L
.07936 .01474 L
.07945 .01507 L
.07954 .01541 L
.07971 .01608 L
.08032 .01849 L
.08152 .02303 L
.0827 .02703 L
.08394 .03054 L
.085 .03279 L
.0856 .03372 L
.08588 .03406 L
.08617 .03436 L
.08633 .03449 L
.08648 .0346 L
.08663 .03469 L
.08677 .03476 L
.08693 .03482 L
.08702 .03484 L
.08711 .03486 L
.08726 .03488 L
.08734 .03488 L
.08742 .03488 L
.08758 .03486 L
.08772 .03482 L
Mistroke
.08786 .03477 L
.088 .0347 L
.08832 .03449 L
.08861 .03423 L
.08913 .03361 L
.0897 .03269 L
.09085 .03016 L
.09339 .02198 L
.09397 .01976 L
.09459 .01731 L
.09489 .0161 L
.09504 .01551 L
.09518 .01496 L
.0953 .01497 L
.09543 .0155 L
.09571 .0166 L
.09685 .02111 L
.0981 .02567 L
.0993 .0294 L
.10038 .03211 L
.10097 .03324 L
.10153 .03409 L
.10181 .03444 L
.10211 .03473 L
.10227 .03486 L
.10244 .03498 L
.10259 .03506 L
.10275 .03513 L
.10289 .03517 L
.10304 .0352 L
.10317 .03521 L
.1033 .03521 L
.10345 .03519 L
.10358 .03515 L
.10374 .03509 L
.10389 .03502 L
.10416 .03485 L
.1044 .03464 L
.10496 .03398 L
.10552 .03308 L
.10613 .03186 L
.10722 .02904 L
.10971 .02036 L
.1103 .01801 L
.11063 .01669 L
.11093 .01545 L
.11102 .0151 L
.11111 .01473 L
.1112 .0151 L
.1113 .01547 L
Mistroke
.11162 .01681 L
.11226 .0194 L
.11343 .02393 L
.11469 .02823 L
.11593 .0317 L
.11652 .03299 L
.11706 .03398 L
.1176 .03474 L
.11789 .03505 L
.1182 .03531 L
.11832 .03539 L
.11846 .03547 L
.11858 .03552 L
.11871 .03557 L
.11885 .0356 L
.119 .03562 L
.11914 .03563 L
.11927 .03561 L
.11943 .03558 L
.1195 .03555 L
.11959 .03552 L
.11988 .03537 L
.12005 .03525 L
.12022 .03509 L
.12054 .03476 L
.12117 .03386 L
.12174 .03279 L
.12289 .02994 L
.12399 .02649 L
.12515 .02221 L
.12578 .01968 L
.12638 .01722 L
.12663 .01619 L
.12676 .01563 L
.12689 .01511 L
.12703 .01489 L
.12718 .01552 L
.12744 .01661 L
.1286 .0214 L
.13086 .02948 L
.13148 .03126 L
.13213 .03287 L
.1327 .03403 L
.13331 .035 L
.13364 .03541 L
.13394 .0357 L
.13408 .03582 L
.13424 .03592 L
.13439 .036 L
.13453 .03606 L
Mistroke
.13462 .03609 L
.13471 .03611 L
.13479 .03613 L
.13487 .03614 L
.13495 .03614 L
.13504 .03614 L
.13514 .03613 L
.13523 .03611 L
.13531 .03609 L
.13539 .03606 L
.13554 .036 L
.1357 .03591 L
.13588 .03579 L
.13617 .03553 L
.13649 .03517 L
.13714 .03418 L
.13774 .03297 L
.13831 .0316 L
.14074 .02351 L
.14182 .01913 L
.14211 .01793 L
.14241 .01662 L
.14255 .01601 L
.1427 .01537 L
.14283 .01482 L
.14297 .01521 L
.14313 .01588 L
.14329 .01659 L
.14359 .01787 L
.14416 .02025 L
.14526 .02469 L
.14655 .02932 L
.14775 .03278 L
.14839 .03423 L
.14898 .03528 L
.14929 .03572 L
.14962 .03612 L
.1498 .0363 L
.14997 .03644 L
.15014 .03655 L
.15031 .03664 L
.15046 .0367 L
.1506 .03674 L
.15074 .03676 L
.15087 .03676 L
.15102 .03675 L
.15117 .03672 L
.15132 .03666 L
.15149 .03658 L
.15179 .03637 L
Mistroke
.15208 .0361 L
.15273 .03524 L
.15333 .03414 L
.15398 .03263 L
.15517 .02911 L
.1574 .02051 L
.15804 .01774 L
.15836 .01636 L
.1585 .01575 L
.15865 .01508 L
.15878 .01495 L
.15891 .01552 L
.15919 .01675 L
.15978 .01933 L
.16107 .02479 L
.1623 .02938 L
.16348 .03299 L
.1641 .03451 L
.16476 .03581 L
.16531 .03662 L
.16562 .03697 L
.16592 .03722 L
.16605 .03731 L
.16619 .03738 L
.16631 .03743 L
.16644 .03747 L
.16657 .0375 L
.16672 .03751 L
.16687 .0375 L
.16699 .03748 L
.16714 .03743 L
.16727 .03738 L
.16742 .0373 L
.16758 .03719 L
.1679 .03689 L
.1682 .03655 L
.16876 .03567 L
.1693 .03459 L
.1705 .03139 L
.17181 .02682 L
.17304 .02178 L
.17364 .01912 L
.17419 .01662 L
.17435 .01589 L
.1745 .0152 L
.17465 .01495 L
.17474 .01533 L
.17483 .01574 L
.17551 .01889 L
.17672 .0242 L
Mistroke
.17795 .0291 L
.17928 .03349 L
.17989 .03509 L
.18054 .03647 L
.1811 .03736 L
.18141 .03775 L
.18171 .03804 L
.18185 .03814 L
.182 .03824 L
.18215 .03831 L
.18228 .03836 L
.18243 .03839 L
.18252 .0384 L
.1826 .03841 L
.18274 .0384 L
.1829 .03837 L
.18304 .03832 L
.1832 .03824 L
.18335 .03815 L
.18349 .03804 L
.18383 .03772 L
.18415 .03731 L
.1847 .0364 L
.18521 .03531 L
.18638 .03207 L
.18865 .02322 L
.18928 .02039 L
.18993 .01731 L
.1902 .01602 L
.19035 .01531 L
.19049 .0148 L
.19057 .01518 L
.19066 .01559 L
.19081 .01632 L
.19111 .01774 L
.19245 .024 L
.1937 .02925 L
.19495 .03371 L
.19557 .03549 L
.19613 .03685 L
.19665 .03787 L
.19722 .03871 L
.19753 .03904 L
.19768 .03917 L
.19782 .03927 L
.19795 .03935 L
.1981 .03941 L
.19825 .03946 L
.19839 .03948 L
.19854 .03948 L
Mistroke
.19869 .03947 L
.19885 .03942 L
.19894 .03939 L
.19902 .03935 L
.19918 .03925 L
.19936 .03912 L
.19969 .03879 L
.19999 .0384 L
.2003 .0379 L
.20088 .03676 L
.20201 .03368 L
.20322 .02929 L
.20437 .02436 L
.20543 .0193 L
.20599 .01653 L
.20615 .01573 L
.2063 .01496 L
.20644 .01515 L
.20658 .01589 L
.20785 .02216 L
.20906 .02779 L
.21039 .03316 L
.21099 .03519 L
.21163 .03705 L
.21218 .03838 L
.21279 .03951 L
.21314 .04001 L
.21347 .04036 L
.21363 .0405 L
.21378 .0406 L
.21386 .04065 L
.21395 .04069 L
.21411 .04075 L
.21426 .04077 L
.21434 .04078 L
.21442 .04078 L
.21458 .04076 L
.21466 .04074 L
.21474 .04071 L
.21489 .04065 L
.21504 .04055 L
.21532 .04032 L
.21561 .04001 L
.21591 .03958 L
.21646 .03858 L
.21711 .03702 L
.21771 .03525 L
.22025 .02485 L
.22135 .01928 L
.22167 .01762 L
Mistroke
.22197 .01603 L
.2221 .01534 L
.22224 .01483 L
.2224 .01563 L
.22254 .01638 L
.22383 .02315 L
.22503 .02902 L
.22617 .03389 L
.2268 .03619 L
.2274 .03807 L
.22795 .03954 L
.22855 .0408 L
.22882 .04124 L
.2291 .04163 L
.22934 .0419 L
.22961 .04212 L
.22975 .04222 L
.22989 .04228 L
.23004 .04233 L
.23012 .04234 L
.2302 .04235 L
.23035 .04235 L
.23044 .04234 L
.23052 .04232 L
.23067 .04226 L
.23082 .04218 L
.23096 .04209 L
.2311 .04197 L
.23135 .04171 L
.23166 .0413 L
.23194 .04084 L
.23255 .03953 L
.23323 .03769 L
.23445 .03327 L
.23683 .02177 L
.23751 .01801 L
.23767 .01709 L
.23785 .01613 L
.23799 .0153 L
.23808 .01483 L
.23815 .01504 L
.2383 .01587 L
.23843 .01662 L
.23873 .01831 L
.23936 .0218 L
.24057 .02827 L
.24185 .03436 L
.24295 .03862 L
.24358 .04059 L
.24416 .04204 L
Mistroke
.24472 .04312 L
.245 .04353 L
.24531 .04388 L
.24547 .04402 L
.24562 .04412 L
.2457 .04417 L
.24579 .04421 L
.24588 .04424 L
.24595 .04426 L
.24609 .04428 L
.24624 .04428 L
.2464 .04424 L
.24655 .04419 L
.24669 .04411 L
.24684 .044 L
.24711 .04374 L
.24738 .0434 L
.24763 .04302 L
.24819 .04188 L
.24879 .04031 L
.25003 .03587 L
.25138 .02959 L
.25254 .02322 L
.25315 .01962 L
.25349 .0176 L
.25366 .0166 L
.25381 .01567 L
.25396 .01475 L
.25404 .01515 L
.25412 .01566 L
.25446 .01773 L
.25506 .02132 L
.25622 .0281 L
.25755 .03505 L
.25876 .04027 L
.25934 .04226 L
.25996 .04404 L
.26025 .04471 L
.26055 .04532 L
.26084 .04579 L
.2611 .04614 L
.26126 .0463 L
.26143 .04645 L
.2616 .04656 L
.2617 .04661 L
.26178 .04664 L
.26187 .04666 L
.26194 .04667 L
.26209 .04668 L
.26225 .04665 L
Mistroke
.26234 .04662 L
.26242 .04659 L
.26257 .04651 L
.2627 .04641 L
.263 .0461 L
.2633 .04569 L
.26362 .04512 L
.26422 .04373 L
.26477 .04207 L
.26604 .03706 L
.26735 .03032 L
.26858 .0229 L
.26916 .01922 L
.26947 .01716 L
.26962 .01615 L
.26976 .01523 L
.26992 .01521 L
.27 .01577 L
.27008 .0163 L
.27043 .01861 L
.27105 .02266 L
.27329 .03619 L
.27445 .04182 L
.27508 .04435 L
.27568 .04633 L
.27624 .04779 L
.27653 .0484 L
.27684 .04892 L
.27711 .04926 L
.27724 .04941 L
.27739 .04953 L
.27753 .04962 L
.27765 .04968 L
.27778 .04972 L
.2779 .04973 L
.27804 .04973 L
.27818 .04969 L
.27832 .04963 L
.27845 .04955 L
.2786 .04943 L
.27875 .04928 L
.27906 .04886 L
.27937 .04832 L
.27971 .04759 L
.2803 .04593 L
.28147 .04141 L
.28253 .036 L
.28365 .02915 L
.28484 .02101 L
.28514 .01886 L
Mistroke
.28546 .01654 L
.28556 .01585 L
.28565 .01519 L
.28573 .01483 L
.28582 .01547 L
.28615 .01788 L
.28735 .02658 L
.28968 .04151 L
.29032 .04481 L
.29101 .04786 L
.29161 .05003 L
.29193 .05099 L
.29226 .05186 L
.29259 .05254 L
.29289 .05303 L
.29303 .05323 L
.29318 .0534 L
.29333 .05353 L
.29346 .05362 L
.29362 .05369 L
.2937 .05371 L
.29378 .05372 L
.29387 .05373 L
.29396 .05372 L
.29404 .0537 L
.29412 .05367 L
.29427 .05358 L
.29436 .05352 L
.29444 .05345 L
.29473 .05312 L
.29502 .05266 L
.29529 .05212 L
.2959 .05051 L
.29643 .04866 L
.29699 .04626 L
.29936 .03208 L
.30042 .02411 L
.30098 .01966 L
.30129 .01718 L
.30144 .01596 L
.30157 .01483 L
.30172 .01583 L
.30188 .01716 L
.30223 .01999 L
.30283 .02495 L
.30403 .03437 L
.30511 .04214 L
.30627 .04919 L
.30689 .05231 L
.30745 .05467 L
Mistroke
.30801 .05658 L
.30855 .05791 L
.30885 .05846 L
.30902 .05869 L
.30917 .05887 L
.3093 .05898 L
.30945 .05908 L
.3096 .05914 L
.30975 .05916 L
.30983 .05916 L
.30991 .05914 L
.31007 .05908 L
.31016 .05902 L
.31025 .05895 L
.31041 .05879 L
.31072 .05836 L
.31105 .05771 L
.31164 .05607 L
.31219 .05401 L
.31345 .04752 L
.31468 .03907 L
.316 .0282 L
.31659 .02282 L
.31692 .01979 L
.31723 .01692 L
.31739 .01542 L
.31748 .01486 L
.31756 .01564 L
.31792 .01911 L
.31856 .02521 L
.32099 .04669 L
.3221 .05467 L
.32328 .06126 L
.32363 .06277 L
.32396 .06399 L
.32428 .06498 L
.32457 .06573 L
.32485 .06628 L
.325 .0665 L
.32515 .06669 L
.32531 .06684 L
.32545 .06693 L
.32554 .06696 L
.32562 .06698 L
.32578 .06698 L
.32591 .06693 L
.32606 .06684 L
.3262 .06672 L
.32633 .06657 L
.32663 .06609 L
Mistroke
.32694 .06538 L
.32753 .06351 L
.32818 .06067 L
.32933 .05367 L
.3304 .04513 L
.33166 .03298 L
.33229 .02639 L
.33286 .02005 L
.33299 .01859 L
.33313 .01702 L
.33326 .01552 L
.33338 .01528 L
.33352 .01682 L
.33365 .01829 L
.33394 .02161 L
.3351 .03491 L
.33635 .04836 L
.33752 .05959 L
.33866 .06854 L
.33916 .07171 L
.33971 .07459 L
.34027 .07683 L
.34057 .07776 L
.34085 .07842 L
.34101 .07871 L
.34116 .07893 L
.3413 .07908 L
.34145 .07918 L
.34152 .07922 L
.34161 .07924 L
.3417 .07924 L
.34178 .07922 L
.34193 .07915 L
.34209 .07901 L
.34224 .07881 L
.34239 .07856 L
.34273 .07779 L
.34306 .07677 L
.34341 .07537 L
.34404 .07206 L
.34462 .0682 L
.34582 .05768 L
.34693 .0454 L
.34756 .03758 L
.34823 .02859 L
.34855 .02407 L
.34886 .01969 L
.349 .01776 L
.34914 .0157 L
.3493 .01601 L
Mistroke
.34944 .01813 L
.35171 .05122 L
.353 .06857 L
.3542 .08215 L
.35544 .09297 L
.35609 .097 L
.35642 .09855 L
.35661 .09927 L
.35678 .09986 L
.35694 .10029 L
.3571 .10067 L
.35725 .10094 L
.35739 .10113 L
.35754 .10125 L
.35763 .10129 L
.35771 .1013 L
.35779 .10129 L
.35787 .10126 L
.35796 .1012 L
.35804 .10112 L
.35819 .10093 L
.35834 .10065 L
.35861 .09995 L
.35893 .09878 L
.35922 .09742 L
.35981 .09377 L
.36043 .08864 L
.36154 .07626 L
.36274 .05875 L
.36405 .03534 L
.36435 .02945 L
.36468 .02287 L
.36483 .0198 L
.36492 .01811 L
.36499 .01651 L
.36513 .01576 L
.36528 .01891 L
.3664 .04294 L
.36892 .09604 L
.37011 .11764 L
.37076 .12782 L
.37136 .13603 L
.37192 .14241 L
.37242 .14707 L
.37269 .14909 L
.37299 .15088 L
.37315 .15169 L
.3733 .15232 L
.37344 .15281 L
.37359 .15323 L
Mistroke
.37374 .15353 L
.37388 .1537 L
.37402 .15376 L
.37415 .15373 L
.37431 .15356 L
.37445 .1533 L
.37452 .15311 L
.37461 .15287 L
.37476 .15233 L
.37503 .151 L
.37533 .14911 L
.37585 .14447 L
.37647 .13695 L
.37704 .12789 L
.37834 .09994 L
.3796 .06333 L
.38022 .0421 L
.3805 .03213 L
.38064 .02669 L
.3808 .02072 L
.38094 .01525 L
.38107 .01926 L
.38132 .02946 L
.38187 .05279 L
.38304 .10588 L
.38782 .34907 L
.39023 .46122 L
.39242 .54046 L
.39301 .5568 L
.39364 .57188 L
.39419 .58263 L
.39479 .59192 L
.39512 .59587 L
.39543 .59881 L
.39576 .60112 L
.39594 .60206 L
.39602 .60239 L
.39611 .60269 L
.39626 .60308 L
.39641 .60328 L
.39656 .60332 L
.39665 .60326 L
.39673 .60315 L
.39688 .60282 L
.39701 .60237 L
.39716 .60171 L
.39732 .60083 L
.39763 .59856 L
.39792 .59574 L
.39847 .58876 L
Mistroke
.39906 .5788 L
.3997 .56524 L
.40085 .53402 L
.40191 .4982 L
.40666 .28444 L
.40904 .16758 L
.41122 .07058 L
.4118 .04775 L
.4121 .03624 L
.41242 .02442 L
.4125 .02168 L
.41258 .01875 L
.41273 .01591 L
.41288 .0209 L
.41301 .02541 L
.41356 .04283 L
.41487 .078 L
.4155 .0919 L
.41608 .10266 L
.41661 .11084 L
.41718 .11805 L
.41749 .12127 L
.41778 .12378 L
.41806 .12577 L
.41835 .12748 L
.41851 .1282 L
.41865 .12876 L
.41879 .12922 L
.41893 .12956 L
.41908 .12984 L
.41915 .12994 L
.41924 .13002 L
.41932 .13007 L
.41941 .13008 L
.41956 .13002 L
.41972 .12986 L
.4198 .12973 L
.41988 .12956 L
.42018 .12874 L
.42034 .12811 L
.42052 .12732 L
.42085 .12555 L
.42148 .12094 L
.42207 .11543 L
.4234 .09922 L
.42583 .06103 L
.4271 .03912 L
.42773 .0285 L
.428 .02393 L
.42831 .01899 L
Mistroke
.42844 .01687 L
.42858 .01482 L
.42871 .01692 L
.42883 .01882 L
.42939 .02727 L
.43055 .04338 L
.43167 .05628 L
.43286 .06675 L
.43348 .0708 L
.43381 .07255 L
.43416 .07412 L
.43449 .07526 L
.43478 .07607 L
.43493 .07638 L
.43508 .07666 L
.43523 .07686 L
.43536 .07701 L
.43552 .07711 L
.4356 .07714 L
.43568 .07715 L
.43583 .07714 L
.43598 .07707 L
.43606 .077 L
.43614 .07693 L
.4363 .07674 L
.43646 .07648 L
.43664 .07612 L
.43694 .07535 L
.43726 .0743 L
.43784 .07189 L
.4389 .06574 L
.44008 .05683 L
.44131 .04578 L
.44261 .03304 L
.44372 .0219 L
.44402 .01889 L
.44419 .01724 L
.44434 .0157 L
.44449 .01516 L
.44465 .01669 L
.44493 .01933 L
.44715 .03797 L
.44841 .04591 L
.44903 .04894 L
.44959 .05119 L
.44987 .05212 L
.45018 .05299 L
.45048 .05368 L
.45074 .05417 L
.45106 .0546 L
Mistroke
.45123 .05477 L
.45131 .05484 L
.45139 .05489 L
.45154 .05496 L
.45168 .05499 L
.45182 .055 L
.45191 .05498 L
.45199 .05496 L
.45214 .05488 L
.45223 .05482 L
.45231 .05476 L
.45263 .05441 L
.45291 .05397 L
.45321 .05337 L
.45383 .05173 L
.45452 .04933 L
.45574 .04375 L
.45686 .03746 L
.45816 .02916 L
.45938 .02102 L
.45965 .01918 L
.45994 .01719 L
.46008 .01629 L
.46022 .01534 L
.46035 .0149 L
.46048 .01578 L
.4611 .01975 L
.46166 .0232 L
.46297 .03044 L
.46416 .03583 L
.46473 .03794 L
.46536 .03985 L
.46596 .04125 L
.46651 .04219 L
.46666 .0424 L
.46684 .04259 L
.46699 .04274 L
.46715 .04286 L
.46729 .04295 L
.46745 .04301 L
.46759 .04305 L
.46773 .04306 L
.46781 .04306 L
.4679 .04305 L
.46798 .04304 L
.46806 .04301 L
.4682 .04295 L
.46835 .04286 L
.46852 .04274 L
.46867 .0426 L
Mistroke
.46903 .04218 L
.46962 .04118 L
.47028 .0397 L
.47147 .03606 L
.4737 .02677 L
.47492 .02091 L
.47552 .01797 L
.47579 .01668 L
.47593 .016 L
.47607 .01528 L
.47616 .01487 L
.47623 .01493 L
.47638 .01565 L
.47671 .01721 L
.4774 .0204 L
.4786 .02552 L
.47972 .02958 L
.48091 .03296 L
.48152 .03431 L
.48185 .03489 L
.48221 .03543 L
.48253 .03582 L
.48283 .03611 L
.48311 .03631 L
.48325 .03639 L
.48341 .03645 L
.48357 .03649 L
.48371 .03651 L
.48379 .03652 L
.48388 .03651 L
.48396 .03651 L
.48405 .03649 L
.4842 .03645 L
.48434 .0364 L
.4845 .03632 L
.48465 .03622 L
.48493 .03599 L
.48519 .03573 L
.48577 .03493 L
.48642 .03376 L
.487 .03246 L
.4883 .0288 L
.48953 .0246 L
.49082 .01966 L
.49136 .01754 L
.49165 .01637 L
.49193 .01526 L
.49208 .0148 L
.49217 .01515 L
.49226 .01548 L
Mistroke
.49255 .01666 L
.49314 .01894 L
.4943 .02322 L
.49554 .02728 L
.49664 .03022 L
.49779 .03252 L
.49836 .03332 L
.49868 .03367 L
.49897 .03393 L
.49925 .03411 L
.49937 .03418 L
.49949 .03423 L
.49963 .03427 L
.49978 .0343 L
.49991 .03432 L
.50005 .03432 L
.5002 .03431 L
.50035 .03428 L
.50042 .03426 L
.50051 .03423 L
.50066 .03416 L
.50096 .03398 L
.50123 .03375 L
.50187 .03303 L
.50254 .03195 L
.50366 .02948 L
.50488 .02598 L
.50602 .02208 L
.50708 .01808 L
.50764 .01589 L
.5078 .01525 L
.50795 .01478 L
.50809 .01533 L
.50824 .01592 L
.5095 .02092 L
.51071 .02546 L
.51204 .02985 L
.51264 .03153 L
.51328 .03311 L
.51383 .03425 L
.51444 .03524 L
.51479 .0357 L
.51512 .03603 L
.51543 .03627 L
.5156 .03637 L
.51576 .03644 L
.51592 .03648 L
.51606 .03651 L
.51622 .03652 L
.5163 .03651 L
Mistroke
.51639 .0365 L
.51653 .03647 L
.51669 .03641 L
.51684 .03634 L
.51697 .03626 L
.51725 .03604 L
.51755 .03573 L
.51817 .03486 L
.51874 .03377 L
.51928 .03251 L
.52048 .0289 L
.52178 .02396 L
.52239 .02135 L
.52303 .0184 L
.52335 .01693 L
.5235 .01619 L
.52364 .01551 L
.52377 .01489 L
.52391 .01521 L
.52405 .01587 L
.5242 .01661 L
.52542 .02256 L
.52674 .02881 L
.52795 .0339 L
.52909 .03791 L
.52972 .0397 L
.53041 .04125 L
.53071 .04179 L
.53103 .04226 L
.53134 .04261 L
.53161 .04284 L
.53176 .04293 L
.53189 .043 L
.53204 .04304 L
.53213 .04306 L
.5322 .04306 L
.53236 .04306 L
.53244 .04304 L
.53252 .04302 L
.53267 .04297 L
.53283 .04288 L
.53296 .04278 L
.5331 .04266 L
.53336 .04238 L
.53366 .04194 L
.53394 .04145 L
.53456 .04006 L
.53523 .03807 L
.53645 .03324 L
.53767 .02705 L
Mistroke
.53882 .02024 L
.53913 .01828 L
.53946 .01617 L
.53954 .01563 L
.53963 .01505 L
.53973 .01502 L
.53982 .01562 L
.54015 .01782 L
.54135 .02592 L
.54374 .04095 L
.54509 .04773 L
.54573 .0503 L
.54634 .05224 L
.54687 .05355 L
.54717 .05411 L
.54745 .0545 L
.54758 .05466 L
.54773 .05479 L
.54781 .05486 L
.54789 .0549 L
.54804 .05497 L
.5482 .055 L
.54828 .055 L
.54836 .05499 L
.54851 .05494 L
.54867 .05485 L
.54882 .05473 L
.54896 .05458 L
.54928 .05414 L
.54957 .05358 L
.54985 .05292 L
.55047 .05098 L
.55114 .04817 L
.55372 .03132 L
.55431 .02629 L
.55493 .02064 L
.55519 .01822 L
.55533 .01688 L
.55547 .01559 L
.55562 .01538 L
.55577 .01678 L
.55605 .01956 L
.55722 .0313 L
.55848 .04382 L
.56077 .06349 L
.56194 .07077 L
.56253 .0735 L
.56287 .07475 L
.56318 .07567 L
.56345 .0763 L
Mistroke
.56358 .07655 L
.56373 .07677 L
.56388 .07695 L
.56401 .07706 L
.5641 .07711 L
.56418 .07714 L
.56432 .07715 L
.56446 .07712 L
.56459 .07704 L
.56471 .07693 L
.56484 .07677 L
.56498 .07656 L
.56513 .07627 L
.5654 .0756 L
.56571 .07461 L
.56604 .07328 L
.56662 .0702 L
.56726 .06587 L
.56796 .05992 L
.56922 .0462 L
.57038 .03065 L
.57097 .02189 L
.57112 .01962 L
.57126 .01744 L
.57138 .01546 L
.57152 .01613 L
.57166 .01845 L
.57179 .0206 L
.57209 .02546 L
.57271 .03598 L
.57523 .07851 L
.57631 .0952 L
.57749 .11052 L
.57816 .11766 L
.57877 .12293 L
.57906 .12499 L
.57939 .12686 L
.57969 .12825 L
.57997 .1292 L
.58013 .12958 L
.58021 .12975 L
.58029 .12987 L
.58043 .13002 L
.58059 .13008 L
.58067 .13007 L
.58075 .13003 L
.5809 .12986 L
.58099 .12973 L
.58107 .12957 L
.58125 .1291 L
Mistroke
.58152 .12806 L
.58183 .12648 L
.58215 .12432 L
.58245 .12182 L
.58301 .11584 L
.58353 .10887 L
.58469 .08787 L
.58588 .05906 L
.58644 .04268 L
.58698 .02574 L
.58712 .02082 L
.58728 .0155 L
.58736 .01676 L
.58745 .0199 L
.58761 .02553 L
.58818 .04694 L
.58947 .09985 L
.59434 .33357 L
.59658 .43768 L
.59902 .52994 L
.59966 .54891 L
.60035 .56624 L
.60094 .5787 L
.60158 .5894 L
.60192 .59391 L
.60223 .59729 L
.60253 .59982 L
.60268 .60085 L
.60285 .60176 L
.603 .60241 L
.60313 .60285 L
.60327 .60314 L
.6034 .6033 L
.60355 .60331 L
.60369 .60317 L
.60384 .60285 L
.60392 .60262 L
.604 .60231 L
.60428 .60087 L
.60445 .59978 L
.60459 .59859 L
.60522 .59176 L
.60576 .58349 L
.60634 .57231 L
.60766 .53803 L
.60886 .4974 L
.61368 .27195 L
.6159 .15793 L
.61716 .09676 L
.61777 .06859 L
Mistroke
.61833 .04411 L
.61862 .03216 L
.61877 .026 L
.61893 .01956 L
.61906 .01538 L
.61922 .02137 L
.61949 .03164 L
.62073 .07394 L
.62204 .10919 L
.62263 .12172 L
.62327 .13305 L
.62389 .14153 L
.62446 .14739 L
.62477 .14981 L
.62506 .1515 L
.62522 .15223 L
.62539 .15286 L
.62547 .15309 L
.62555 .1533 L
.6257 .15358 L
.62584 .15372 L
.62597 .15376 L
.62611 .1537 L
.62625 .15354 L
.62638 .1533 L
.6265 .15301 L
.62677 .15207 L
.62706 .15061 L
.62733 .14891 L
.62793 .1439 L
.62852 .13749 L
.62915 .12925 L
.63026 .1113 L
.63277 .06087 L
.63391 .03608 L
.63424 .02899 L
.63456 .02235 L
.63469 .01949 L
.63484 .01647 L
.63499 .01625 L
.63514 .01926 L
.63735 .06019 L
.63848 .07657 L
.63908 .08363 L
.6397 .08983 L
.64025 .0942 L
.64054 .09609 L
.64085 .09779 L
.64114 .09906 L
.6414 .09997 L
Mistroke
.64153 .10032 L
.64166 .10064 L
.64179 .10088 L
.64191 .10106 L
.64206 .10121 L
.64219 .10129 L
.64234 .1013 L
.6425 .10122 L
.64264 .10109 L
.64279 .10088 L
.64293 .10061 L
.64305 .10032 L
.64336 .09937 L
.6437 .09801 L
.64431 .09467 L
.64495 .08998 L
.64563 .08388 L
.64685 .07042 L
.64808 .0542 L
.64925 .03744 L
.64976 .02994 L
.6503 .02197 L
.65058 .01784 L
.65066 .01671 L
.65074 .0155 L
.65089 .0161 L
.65104 .01821 L
.65117 .02021 L
.65144 .02391 L
.6538 .0537 L
.655 .06522 L
.65569 .07032 L
.65632 .07406 L
.65693 .07672 L
.65728 .07781 L
.65744 .07822 L
.65759 .07854 L
.65774 .07879 L
.65787 .07896 L
.65802 .07911 L
.65818 .07921 L
.65833 .07924 L
.65842 .07923 L
.65849 .07921 L
.65864 .07913 L
.65879 .07898 L
.65893 .0788 L
.65906 .07859 L
.65934 .07798 L
.6596 .07728 L
Mistroke
.65986 .07638 L
.66042 .07394 L
.66104 .0705 L
.66228 .06133 L
.6634 .05089 L
.66472 .03692 L
.66529 .03042 L
.66593 .02315 L
.66621 .01994 L
.66636 .01817 L
.66651 .0165 L
.66665 .01495 L
.66679 .01616 L
.66705 .01909 L
.66824 .03201 L
.66956 .04474 L
.67075 .05421 L
.67134 .05802 L
.67198 .06141 L
.67258 .0639 L
.67313 .06555 L
.67343 .06619 L
.67358 .06644 L
.67372 .06662 L
.67379 .06671 L
.67388 .06679 L
.67403 .0669 L
.67411 .06695 L
.6742 .06697 L
.67428 .06698 L
.67436 .06698 L
.67444 .06697 L
.67453 .06694 L
.67468 .06685 L
.67477 .06677 L
.67485 .06669 L
.67503 .06646 L
.67533 .06593 L
.67566 .06516 L
.6763 .06304 L
.6769 .06042 L
.67824 .05242 L
.68067 .03239 L
.68176 .02212 L
.68208 .01912 L
.68223 .01764 L
.68238 .01627 L
.68251 .01504 L
.68264 .0157 L
.68278 .01701 L
Mistroke
.68294 .01845 L
.68422 .03012 L
.68543 .03989 L
.68656 .04761 L
.68776 .0538 L
.68838 .05615 L
.68871 .05712 L
.68907 .05795 L
.68923 .05827 L
.68939 .05853 L
.68955 .05874 L
.68969 .05889 L
.68983 .05901 L
.68997 .0591 L
.69011 .05915 L
.69027 .05916 L
.69043 .05913 L
.69057 .05907 L
.69073 .05896 L
.6909 .05879 L
.69121 .05836 L
.69149 .05782 L
.69207 .05633 L
.69261 .05444 L
.69382 .04871 L
.69513 .04049 L
.69638 .03127 L
.69754 .02192 L
.69812 .01711 L
.6982 .01645 L
.69829 .01572 L
.69845 .01501 L
.6986 .01629 L
.69875 .01746 L
.70008 .02795 L
.70233 .04285 L
.70295 .04598 L
.70361 .04881 L
.70424 .05092 L
.70454 .05173 L
.70481 .05234 L
.70509 .05285 L
.70539 .05327 L
.70555 .05344 L
.7057 .05357 L
.70585 .05365 L
.706 .05371 L
.70613 .05373 L
.70627 .05372 L
.7064 .05368 L
Mistroke
.70652 .05363 L
.70666 .05353 L
.70682 .0534 L
.7071 .05306 L
.70743 .05251 L
.70773 .05188 L
.70839 .05002 L
.70901 .04776 L
.7096 .0452 L
.71202 .03092 L
.7131 .02336 L
.71369 .01905 L
.71398 .01692 L
.71411 .01599 L
.71425 .01496 L
.7144 .01552 L
.71455 .01662 L
.71487 .01894 L
.71543 .02293 L
.71653 .0303 L
.71783 .03795 L
.71902 .04351 L
.7196 .0456 L
.72022 .04742 L
.72051 .04808 L
.72081 .04866 L
.7211 .0491 L
.72136 .04939 L
.72152 .04953 L
.72161 .04959 L
.72169 .04963 L
.72183 .04969 L
.72198 .04973 L
.72207 .04973 L
.72215 .04973 L
.72231 .04969 L
.7224 .04966 L
.72248 .04962 L
.72266 .04949 L
.7228 .04936 L
.72294 .04921 L
.72325 .04878 L
.72355 .04823 L
.72388 .04751 L
.72503 .04393 L
.72569 .04124 L
.72629 .03836 L
.7276 .03113 L
.72884 .0234 L
.72941 .01965 L
Mistroke
.72973 .01757 L
.73002 .01562 L
.73017 .01482 L
.73026 .01539 L
.73034 .0159 L
.73069 .0182 L
.7313 .02217 L
.73355 .03506 L
.73473 .04032 L
.7353 .04232 L
.73584 .04388 L
.73614 .04462 L
.73647 .0453 L
.73675 .04576 L
.73705 .04616 L
.73721 .04632 L
.73738 .04647 L
.73747 .04653 L
.73755 .04658 L
.73764 .04662 L
.73772 .04664 L
.73787 .04668 L
.73795 .04668 L
.73804 .04668 L
.73818 .04665 L
.73834 .04659 L
.73849 .04651 L
.73862 .04641 L
.73893 .04609 L
.73923 .04567 L
.73956 .04511 L
.74014 .04377 L
.74067 .04222 L
.74197 .03727 L
.74319 .03131 L
.74437 .02474 L
.74501 .02093 L
.74532 .01903 L
.74561 .01729 L
.74573 .01653 L
.74587 .0157 L
.746 .01491 L
.74612 .01525 L
.74625 .01601 L
.74639 .01686 L
.74667 .01856 L
.74783 .02534 L
.74897 .03132 L
.75016 .03666 L
.75079 .03896 L
Mistroke
.75147 .04104 L
.7521 .04251 L
.75238 .04303 L
.75268 .04348 L
.75283 .04367 L
.75299 .04385 L
.75314 .04399 L
.75328 .04409 L
.75345 .04419 L
.75354 .04422 L
.75362 .04425 L
.75378 .04428 L
.75386 .04428 L
.75394 .04428 L
.7541 .04425 L
.75425 .04419 L
.75438 .04412 L
.75452 .04402 L
.75484 .04372 L
.75514 .04333 L
.75566 .04242 L
.75623 .04109 L
.75738 .03744 L
.75993 .02568 L
.76052 .02251 L
.76114 .01905 L
.76139 .01761 L
.76167 .01605 L
.76183 .01516 L
.76197 .01509 L
.76211 .01587 L
.76225 .01669 L
.76341 .02304 L
.76466 .02937 L
.76586 .03452 L
.76695 .03821 L
.76754 .03976 L
.7681 .0409 L
.76839 .04136 L
.76869 .04176 L
.76885 .04192 L
.76902 .04207 L
.76918 .04218 L
.76933 .04226 L
.76947 .04231 L
.76961 .04234 L
.76976 .04235 L
.76989 .04234 L
.77002 .04231 L
.77013 .04227 L
Mistroke
.77027 .0422 L
.7704 .04212 L
.77068 .04187 L
.77095 .04157 L
.77154 .04062 L
.77211 .03938 L
.77272 .03772 L
.77382 .03392 L
.77631 .02242 L
.77691 .01932 L
.77724 .01759 L
.77754 .01596 L
.7777 .01512 L
.77779 .01478 L
.77787 .01522 L
.77824 .01714 L
.77888 .02049 L
.78014 .02668 L
.78131 .03174 L
.78241 .03565 L
.78298 .03727 L
.78359 .03869 L
.78394 .03935 L
.78427 .03984 L
.78458 .04022 L
.78473 .04038 L
.7849 .04051 L
.78506 .04062 L
.7852 .04069 L
.78534 .04074 L
.78547 .04077 L
.78562 .04078 L
.78577 .04077 L
.78592 .04074 L
.786 .04071 L
.78609 .04067 L
.78624 .04059 L
.78637 .0405 L
.78668 .04021 L
.78699 .03985 L
.78731 .03936 L
.78789 .03822 L
.78842 .03692 L
.78972 .03278 L
.79094 .02782 L
.79211 .02239 L
.79275 .01924 L
.79306 .01768 L
.79335 .01624 L
.79347 .01561 L
Mistroke
.79361 .01492 L
.79374 .01515 L
.79386 .01576 L
.79441 .01849 L
.79557 .02408 L
.79685 .02958 L
.79805 .03386 L
.79913 .03677 L
.79974 .03797 L
.80029 .03877 L
.80059 .03907 L
.80086 .03928 L
.80101 .03936 L
.80109 .0394 L
.80117 .03943 L
.80133 .03947 L
.80147 .03948 L
.8016 .03948 L
.80174 .03946 L
.80187 .03942 L
.80199 .03937 L
.80212 .0393 L
.80227 .03921 L
.80257 .03895 L
.80289 .03857 L
.80319 .03813 L
.80386 .03687 L
.80506 .03367 L
.80757 .0239 L
.80867 .01879 L
.80897 .01735 L
.80914 .01655 L
.8093 .0158 L
.80944 .0151 L
.80953 .01473 L
.8096 .0151 L
.80988 .01643 L
.81214 .0266 L
.81329 .03095 L
.81453 .03467 L
.81519 .03619 L
.81548 .03673 L
.8158 .03724 L
.81609 .03762 L
.81639 .03794 L
.81656 .03808 L
.81671 .03819 L
.81685 .03827 L
.81701 .03834 L
.81714 .03838 L
Mistroke
.81729 .0384 L
.81743 .03841 L
.81756 .0384 L
.81771 .03836 L
.81785 .03831 L
.81801 .03823 L
.81816 .03814 L
.81843 .03791 L
.81868 .03764 L
.81925 .03683 L
.81986 .03564 L
.82053 .03402 L
.82173 .03028 L
.82397 .0212 L
.82452 .01872 L
.82483 .01733 L
.82512 .016 L
.82528 .01525 L
.82537 .01483 L
.82546 .01499 L
.82561 .01568 L
.82577 .01641 L
.82637 .01917 L
.8276 .02446 L
.82891 .02948 L
.83014 .03324 L
.83068 .03455 L
.83126 .03572 L
.83153 .03616 L
.83182 .03657 L
.83207 .03686 L
.83234 .03712 L
.83249 .03724 L
.83264 .03733 L
.83278 .0374 L
.83293 .03746 L
.83306 .03749 L
.83318 .03751 L
.83332 .03751 L
.83347 .03749 L
.83355 .03748 L
.83363 .03745 L
.83377 .0374 L
.83393 .03732 L
.8341 .03721 L
.83441 .03694 L
.83469 .03663 L
.83534 .03565 L
.83602 .03425 L
.83717 .03109 L
Mistroke
.83844 .02668 L
.83965 .02178 L
.84025 .01922 L
.8408 .0168 L
.84111 .01544 L
.84126 .01475 L
.84135 .01507 L
.84143 .01544 L
.84212 .01846 L
.84332 .02353 L
.84451 .02803 L
.84576 .03195 L
.84683 .03445 L
.84743 .03549 L
.84771 .03586 L
.84799 .03618 L
.84815 .03632 L
.84831 .03645 L
.84846 .03655 L
.8486 .03663 L
.84877 .0367 L
.84886 .03672 L
.84895 .03674 L
.8491 .03676 L
.84919 .03676 L
.84927 .03676 L
.84941 .03673 L
.84954 .0367 L
.84969 .03664 L
.84985 .03656 L
.85017 .03632 L
.85046 .03603 L
.85099 .03534 L
.85156 .03433 L
.85271 .03156 L
.85527 .02262 L
.85585 .02021 L
.85648 .01757 L
.85673 .01648 L
.85687 .01587 L
.85701 .01529 L
.85717 .01482 L
.85731 .01544 L
.85759 .01665 L
.85875 .0215 L
.86001 .02634 L
.86121 .03026 L
.8623 .03306 L
.86289 .03424 L
.86345 .0351 L
Mistroke
.86376 .03546 L
.86405 .03573 L
.86436 .03595 L
.86452 .03602 L
.8646 .03606 L
.86469 .03609 L
.86484 .03612 L
.86498 .03614 L
.86511 .03614 L
.86524 .03612 L
.86538 .03609 L
.86553 .03604 L
.86569 .03596 L
.86583 .03587 L
.8661 .03566 L
.86635 .03542 L
.86691 .03469 L
.86748 .0337 L
.86809 .03236 L
.86919 .02934 L
.87169 .02023 L
.87229 .01777 L
.87261 .0164 L
.87277 .01573 L
.87292 .01511 L
.873 .01477 L
.87308 .01499 L
.87316 .01533 L
.87325 .01571 L
.87362 .01723 L
.87426 .01986 L
.87554 .0248 L
.87669 .0287 L
.87728 .03042 L
.87792 .03204 L
.87847 .03321 L
.87907 .03424 L
.87938 .03466 L
.87971 .03503 L
.87989 .0352 L
.88006 .03533 L
.88023 .03543 L
.88039 .03551 L
.88053 .03557 L
.88069 .0356 L
.88084 .03562 L
.88093 .03563 L
.88101 .03562 L
.88116 .0356 L
.88129 .03557 L
Mistroke
.88145 .03551 L
.8816 .03544 L
.88191 .03522 L
.88221 .03495 L
.88275 .03426 L
.88335 .03326 L
.88399 .0319 L
.8862 .02524 L
.88745 .02056 L
.88805 .01813 L
.88861 .01587 L
.88875 .01529 L
.88891 .01478 L
.88905 .01539 L
.88919 .01595 L
.88982 .01849 L
.89115 .02363 L
.89223 .02736 L
.89339 .03073 L
.89406 .03228 L
.89468 .03343 L
.89526 .03427 L
.89556 .0346 L
.89588 .03487 L
.89603 .03497 L
.89618 .03506 L
.89627 .0351 L
.89636 .03513 L
.89652 .03518 L
.89666 .0352 L
.89675 .03521 L
.89683 .03521 L
.89697 .0352 L
.89712 .03517 L
.89725 .03513 L
.8974 .03507 L
.89765 .03492 L
.89796 .03467 L
.89824 .03438 L
.89887 .03352 L
.89954 .03226 L
.90077 .02922 L
.90313 .02119 L
.90377 .01867 L
.90413 .01725 L
.90447 .0159 L
.90462 .01529 L
.9047 .01496 L
.90478 .01479 L
.90486 .01513 L
Mistroke
.90496 .0155 L
.90512 .01616 L
.90572 .01853 L
.90693 .02314 L
.9082 .02747 L
.90938 .03075 L
.90996 .03203 L
.91048 .03301 L
.91104 .03383 L
.91156 .03439 L
.91185 .03461 L
.91211 .03476 L
.91225 .03481 L
.9124 .03485 L
.91256 .03488 L
.91271 .03488 L
.91286 .03487 L
.91295 .03485 L
.91303 .03483 L
.91317 .03479 L
.91333 .03472 L
.91362 .03453 L
.91389 .0343 L
.91454 .03353 L
.91515 .03251 L
.91633 .02984 L
.91758 .02613 L
.91875 .02204 L
.91981 .01797 L
.92009 .01686 L
.92024 .01627 L
.9204 .01565 L
.92054 .0151 L
.92069 .01493 L
.92083 .01548 L
.92096 .016 L
.92219 .02076 L
.9244 .02826 L
.925 .02989 L
.92565 .03143 L
.92623 .03256 L
.92684 .0335 L
.92715 .03387 L
.92745 .03416 L
.92771 .03436 L
.92785 .03444 L
.928 .03451 L
.92814 .03457 L
.92827 .0346 L
.92841 .03463 L
Mistroke
.92856 .03463 L
.9287 .03463 L
.92883 .0346 L
.92895 .03457 L
.92908 .03453 L
.92922 .03446 L
.92936 .03438 L
.92966 .03416 L
.92993 .0339 L
.93021 .03358 L
.93081 .03269 L
.93146 .03144 L
.93277 .0281 L
.93399 .02419 L
.93526 .01956 L
.93589 .01715 L
.93616 .01608 L
.9363 .01552 L
.93646 .0149 L
.9366 .01508 L
.93673 .01559 L
.93698 .01657 L
.93754 .01872 L
.9387 .02304 L
.93981 .02675 L
.941 .03006 L
.94168 .03159 L
.94229 .03271 L
.94259 .03316 L
.94291 .03357 L
.94322 .03389 L
.9435 .03412 L
.94378 .0343 L
.94394 .03437 L
.94409 .03441 L
.94423 .03444 L
.94436 .03446 L
.9445 .03446 L
.94465 .03444 L
.94479 .03441 L
.94488 .03438 L
.94495 .03436 L
.94524 .03421 L
.9454 .0341 L
.94557 .03397 L
.94591 .03363 L
.94654 .03277 L
.94722 .03153 L
.94845 .02856 L
.95085 .02058 L
Mistroke
.95151 .01808 L
.95187 .01669 L
.95205 .01601 L
.95221 .01538 L
.95236 .01481 L
.9525 .01516 L
.95264 .01574 L
.9528 .01636 L
.95346 .01888 L
.95575 .02688 L
.95706 .03042 L
.9577 .03179 L
.95829 .0328 L
.95884 .03353 L
.95912 .03382 L
.95943 .03406 L
.95959 .03416 L
.95974 .03423 L
.95982 .03427 L
.95991 .0343 L
.96007 .03433 L
.96022 .03435 L
.96038 .03436 L
.96052 .03434 L
.96067 .03431 L
.96075 .03428 L
.96084 .03425 L
.961 .03418 L
.9613 .03398 L
.96165 .03367 L
.96198 .0333 L
.96257 .03243 L
.9632 .03124 L
.96444 .02816 L
.96578 .02393 L
.96694 .01975 L
.96756 .01741 L
.9679 .0161 L
.96806 .01546 L
.96822 .01486 L
.96837 .01516 L
.96844 .01545 L
.96853 .01578 L
.96887 .01709 L
.96946 .01936 L
.97062 .02358 L
.97195 .02781 L
.97316 .03091 L
.97387 .0323 L
.97462 .03338 L
Mistroke
.97501 .03379 L
.97537 .03407 L
.97558 .03418 L
.97577 .03425 L
.97587 .03428 L
.97598 .03431 L
.97609 .03432 L
.97619 .03432 L
Mfstroke
1 0 0 r
[ ] 0 setdash
.03968 .01472 m
.03968 .03436 L
s
.05556 .01472 m
.05556 .03446 L
s
.07143 .01472 m
.07143 .03463 L
s
.0873 .01472 m
.0873 .03488 L
s
.10317 .01472 m
.10317 .03521 L
s
.11905 .01472 m
.11905 .03563 L
s
.13492 .01472 m
.13492 .03614 L
s
.15079 .01472 m
.15079 .03676 L
s
.16667 .01472 m
.16667 .03751 L
s
.18254 .01472 m
.18254 .03841 L
s
.19841 .01472 m
.19841 .03948 L
s
.21429 .01472 m
.21429 .04078 L
s
.23016 .01472 m
.23016 .04235 L
s
.24603 .01472 m
.24603 .04427 L
s
.2619 .01472 m
.2619 .04667 L
s
.27778 .01472 m
.27778 .04972 L
s
.29365 .01472 m
.29365 .0537 L
s
.30952 .01472 m
.30952 .05912 L
s
.3254 .01472 m
.3254 .0669 L
s
.34127 .01472 m
.34127 .07905 L
s
.35714 .01472 m
.35714 .10075 L
s
.37302 .01472 m
.37302 .15104 L
s
.38889 .01472 m
.38889 .40109 L
s
.40476 .01472 m
.40476 .37687 L
s
.42063 .01472 m
.42063 .12675 L
s
.43651 .01472 m
.43651 .07639 L
s
.45238 .01472 m
.45238 .05469 L
s
.46825 .01472 m
.46825 .04293 L
s
.48413 .01472 m
.48413 .03647 L
s
.5 .01472 m
.5 .03432 L
s
.51587 .01472 m
.51587 .03647 L
s
.53175 .01472 m
.53175 .04293 L
s
.54762 .01472 m
.54762 .05469 L
s
.56349 .01472 m
.56349 .07639 L
s
.57937 .01472 m
.57937 .12675 L
s
.59524 .01472 m
.59524 .37687 L
s
.61111 .01472 m
.61111 .40109 L
s
.62698 .01472 m
.62698 .15104 L
s
.64286 .01472 m
.64286 .10075 L
s
.65873 .01472 m
.65873 .07905 L
s
.6746 .01472 m
.6746 .0669 L
s
.69048 .01472 m
.69048 .05912 L
s
.70635 .01472 m
.70635 .0537 L
s
.72222 .01472 m
.72222 .04972 L
s
.7381 .01472 m
.7381 .04667 L
s
.75397 .01472 m
.75397 .04427 L
s
.76984 .01472 m
.76984 .04235 L
s
.78571 .01472 m
.78571 .04078 L
s
.80159 .01472 m
.80159 .03948 L
s
.81746 .01472 m
.81746 .03841 L
s
.83333 .01472 m
.83333 .03751 L
s
.84921 .01472 m
.84921 .03676 L
s
.86508 .01472 m
.86508 .03614 L
s
.88095 .01472 m
.88095 .03563 L
s
.89683 .01472 m
.89683 .03521 L
s
.9127 .01472 m
.9127 .03488 L
s
.92857 .01472 m
.92857 .03463 L
s
.94444 .01472 m
.94444 .03446 L
s
.96032 .01472 m
.96032 .03436 L
s
.97619 .01472 m
.97619 .03432 L
s
.015 w
.03968 .03436 Mdot
.05556 .03446 Mdot
.07143 .03463 Mdot
.0873 .03488 Mdot
.10317 .03521 Mdot
.11905 .03563 Mdot
.13492 .03614 Mdot
.15079 .03676 Mdot
.16667 .03751 Mdot
.18254 .03841 Mdot
.19841 .03948 Mdot
.21429 .04078 Mdot
.23016 .04235 Mdot
.24603 .04427 Mdot
.2619 .04667 Mdot
.27778 .04972 Mdot
.29365 .0537 Mdot
.30952 .05912 Mdot
.3254 .0669 Mdot
.34127 .07905 Mdot
.35714 .10075 Mdot
.37302 .15104 Mdot
.38889 .40109 Mdot
.40476 .37687 Mdot
.42063 .12675 Mdot
.43651 .07639 Mdot
.45238 .05469 Mdot
.46825 .04293 Mdot
.48413 .03647 Mdot
.5 .03432 Mdot
.51587 .03647 Mdot
.53175 .04293 Mdot
.54762 .05469 Mdot
.56349 .07639 Mdot
.57937 .12675 Mdot
.59524 .37687 Mdot
.61111 .40109 Mdot
.62698 .15104 Mdot
.64286 .10075 Mdot
.65873 .07905 Mdot
.6746 .0669 Mdot
.69048 .05912 Mdot
.70635 .0537 Mdot
.72222 .04972 Mdot
.7381 .04667 Mdot
.75397 .04427 Mdot
.76984 .04235 Mdot
.78571 .04078 Mdot
.80159 .03948 Mdot
.81746 .03841 Mdot
.83333 .03751 Mdot
.84921 .03676 Mdot
.86508 .03614 Mdot
.88095 .03563 Mdot
.89683 .03521 Mdot
.9127 .03488 Mdot
.92857 .03463 Mdot
.94444 .03446 Mdot
.96032 .03436 Mdot
.97619 .03432 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{756, 146},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000;d0000TR000`400?l00000o`00003ooooooooo
ooooooKooooo003ooooooooooooom_ooool00?ooooooooooooofooooo`00ooooooooooooooKooooo
003ooooooooooooom_ooool002Sooooo0ol00004ooooo`;o0000:_ooool3o`0002_ooooo0_l0000]
ooooo`?o0000:_ooool3o`0000Cooooo0_l0000]ooooo`?o00001?ooool2o`0002_ooooo0ol0000[
ooooo`;o0000;Oooool3o`0002_ooooo0ol00004ooooo`;o0000<?ooool3o`0000Cooooo0_l0000Z
ooooo`?o0000:oooool2o`0002kooooo0ol0000Zooooo`?o00001?ooool2o`0001[ooooo000Yoooo
o`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000:?ooool01Ol0003ooooooooooooo
oooo000002Wooooo00Co0000oooooooooooo0000:oooool01Ol0003ooooooooooooooooo000002[o
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000]ooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo0000:Oooool01Ol0003ooooooooooooooooo000002Wooooo00Co
0000oooooooooooo0000:oooool01Ol0003ooooooooooooooooo000002_ooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool0000`ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo0000:?ooool01Ol0003ooooooooooooooooo000002Wooooo00Co0000oooooooooooo0000
;?ooool01Ol0003ooooooooooooooooo000002[ooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool0000Iooooo`008Oooool5o`0000?ooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool0000Rooooo`Go00001Oooool00ol0003oooooooooo`0Wooooo`04o`000?oooooooooo
o`0002oooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0002Gooooo1Ol00003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000
8oooool5o`0000Gooooo00?o0000ooooooooool09oooool01?l0003oooooooooool0000_ooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Xoooo
o`Go00000oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0002;ooooo1Ol00005
ooooo`03o`000?oooooooooo02Oooooo00Co0000oooooooooooo0000<?ooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00006Oooool002Wooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool0000/ooooo`03o`000?oooooooooo02Oooooo
00Co0000oooooooooooo0000;oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo0000;Oooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0002gooooo00?o0000ooooooooool09oooool01?l0003oooooooooool0000_ooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000`ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo0000;?ooool00ol0003oooooooooo`0Wooooo`04
o`000?ooooooooooo`00033ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0001Wooooo000Yooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo0000:?ooool4o`0002[ooooo00Co0000oooooooooooo0000:oooool4o`0002_ooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool0000]ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo0000:Oooool4o`0002[ooooo00Co0000oooooooooooo0000:oooool4o`00
02cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000`ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo0000:?ooool4o`0002[ooooo00Co0000oooooooooooo0000
;?ooool4o`0002_ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Iooooo`00
:?ooool2o`0000Cooooo00Co0000oooooooooooo0000:?ooool00ol0003oooooooooo`0[ooooo`04
o`000?ooooooooooo`0002_ooooo00?o0000ooooooooool0:oooool2o`0000Cooooo00Co0000oooo
oooooooo0000;?ooool2o`0000Cooooo00Co0000oooooooooooo0000:Oooool00ol0003ooooooooo
o`0[ooooo`04o`000?ooooooooooo`0002_ooooo00?o0000ooooooooool0;?ooool2o`0000Cooooo
00Co0000oooooooooooo0000;oooool2o`0000Cooooo00Co0000oooooooooooo0000:?ooool00ol0
003oooooooooo`0[ooooo`04o`000?ooooooooooo`0002cooooo00?o0000ooooooooool0:oooool2
o`0000Cooooo00Co0000oooooooooooo00006Oooool002Wooooo00?o0000ooooooooool00oooool2
o`0002Wooooo1Ol0000Zooooo`;o0000;?ooool5o`0002[ooooo00?o0000ooooooooool00oooool2
o`0002kooooo00?o0000ooooooooool00oooool2o`0002[ooooo1Ol0000Zooooo`;o0000;?ooool5
o`0002_ooooo00?o0000ooooooooool00oooool2o`00037ooooo00?o0000ooooooooool00oooool2
o`0002Wooooo1Ol0000Zooooo`;o0000;Oooool5o`0002[ooooo00?o0000ooooooooool00oooool2
o`0001[ooooo003ooooooooooooom_ooool00?ooooooooooooofooooo`00ooooooooooooooKooooo
003ooooooagooooob?l0003ooooooa7ooooo000Nooooo`;o00001Oooooo;o`0002Gooooo0_l00005
ooooo`;o00002Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool000009_oo
ool2o`0000Coooooc?l0000Hooooo`007Oooool01?l0003oooooooooool00004ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0]ooooo`03o`000?oo
oooooooo02gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo02;ooooo00Co0000oooooooooooo00001?ooool2o`00033ooooo00?o0000ooooooooool0
;Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02kooooo00Go0000oooooooooooo
ooooo`00000Uooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0]ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0;_ooool00ol0
003oooooooooo`0]ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05_ooool001go
oooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0Wooooo`03o`00oooooooooooo
03Sooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`0Rooooo`04o`000?oooooooooo
o`0000Cooooo0_l00003ooooo`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`00
0oooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000;ooooo00Goo`00oooo
ooooooooooooool00002ooooo`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`00
0oooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000?ooooo00Coo`00oooo
ooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`05ool00?oooooooooooooooooo0000
0_ooool01?oo003ooooooooooooo0002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo
003ooooooooooooo0002ooooo`04ool00?ooooooooooool000?ooooo00Coo`00ooooooooooooo`00
0_ooool01?oo003ooooooooooooo0003ooooo`04ool00?ooooooooooool000;ooooo00Coo`00oooo
ooooooooo`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`00
0_ooool01?oo003ooooooooooooo0003ooooo`04ool00?ooooooooooool000;ooooo00Coo`00oooo
ooooooooo`000oooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000;ooooo
00Goo`00ooooooooooooooooool00002ooooo`04ool00?ooooooooooool000;ooooo00Goo`00oooo
ooooooooooooool00002ooooo`;o00009Oooool01?l0003oooooooooool00003ooooo`03o`000?oo
oooooooo06;ooooo00?o0000ooooooooool0G?ooool00ol00?ooooooooooo`04ooooo`03o`000?oo
oooooooo01Kooooo000Mooooo`04o`000?ooooooooooo`0000Cooooo0_l00004ooooo`04o`00oooo
ooooooooo`00o`?ooooo00Co003ooooooooooooo003o0_ooool01?l00?ooooooooooool00?l2oooo
o`;o003o00?oooooo`00ool00?l00_ooool01?l00?ooooooooooool00?l2ooooo`03o`00oooooooo
oooo00;o003o0_ooool01?l00?ooooooooooool00?l2ooooo`04o`00ooooooooooooo`00o`;ooooo
0_l00?l2ooooo`04o`00ooooooooooooo`00o`;ooooo00Co003ooooooooooooo003o0oooool01?l0
0?ooooooooooool00?l5ooooo`04o`00ooooooooooooo`00o`?ooooo00Co003ooooooooooooo003o
0_ooool01ol00?ooooooooooool00?ooooooo`000?l00?l00_ooool2o`00o`;ooooo00Co003ooooo
oooooooo003o0_ooool01Ol00?oooooooooooooooooo003o00Gooooo00Co003ooooooooooooo003o
1_ooool01?l00?ooooooooooool00?l5ooooo`05o`00ooooooooooooooooool00?l00_ooool01?l0
0?ooooooooooool00?l2ooooo`04o`00ooooooooooooo`00o`?ooooo00Co003ooooooooooooo003o
0_ooool01?l00?ooooooooooool00?l2ooooo`;o003o00?oooooo`00ool00?l00_ooool01?l00?oo
ooooooooool00?l2ooooo`03o`00oooooooooooo00;o003o0_ooool00ol00?ooooooooooo`02oooo
o`;o00009?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00;ooooo00Coo`00
ooooooooooooo`000_ooool01?oo003ooooooooooooo0003ooooo`04ool00?ooooooooooool000;o
oooo00Coo`00ooooooooooooo`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00
ooooooooooooo`000_ooool01?oo003ooooooooooooo0003ooooo`04ool00?ooooooooooool000;o
oooo00Coo`00ooooooooooooo`000oooool01?oo003ooooooooooooo0002ooooo`04ool00?oooooo
ooooool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?ooooooooooool000;o
oooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?ooooooooooool000;ooooo00Coo`00
ooooooooooooo`000oooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000?o
oooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`05ool00?oooooo
oooooooooooo00000_ooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000?o
oooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0003ooooo`04ool00?oooooo
ooooool000;ooooo00Coo`00ooooooooooooo`000_ooool01Ooo003oooooooooooooooooo`0000;o
oooo00Coo`00ooooooooooooo`000_ooool01Ooo003oooooooooooooooooo`0000?ooooo00?o0000
ooooooooool08oooool01?l0003oooooooooool00003ooooo`;o00001?ooool2o`00o`08ool00?oo
oooo003oool00?oooooo003ooooooooo0002o`00o`0>ool00?l00?oo003oool00?oooooo003oool0
0?oooooo003ooooooooo003o003ooooooooo0002o`00o`0>ool00?oooooo003oool00?oooooo003o
ool00?oooooo003ooooooooo003o003ooooooooo0002o`00o`0Nool00?l00?oo003oool00?oooooo
003oool00?oooooo003ooooooooo003o003ooooooooo003o003ooooooooo003oooooo`00oooo003o
ooooo`00ooooooooo`00o`00ooooooooo`00o`00ooooooooo`000_ooool01?oo003oooooo`00oooo
0003ooooo`07ool00?l00?ooooooool00?l00?ooooooool00002o`00o`0Hool00?oooooo003oool0
0?oooooo003ooooooooo003o003ooooooooo003o003ooooooooo003oooooo`00oooo003oooooo`00
oooo003oooooo`00ooooooooo`000_ooool01ooo003o003oo`00oooo003oooooo`00oooo00000ooo
ool02_oo003o003ooooooooo003o003ooooooooo003oooooo`00oooo0002ooooo`0;ool00?oooooo
003ooooooooo003o003ooooooooo003oooooo`00oooo00000_l00?l02ooo003oooooo`00oooo003o
ooooo`00ooooooooo`00o`00ooooooooo`0000;o003o01_oo`00ooooool00?ooo`00ooooool00?oo
ooooool00?l00?ooooooool00?l00?ooooooool00?oooooo003oool00?oooooo003oool00?oooooo
003ooooooooo003o003ooooooooo00000_ooool3o`0001Sooooo000Mooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`02o`00o`03ooooool00?oo
003o00;ooooo00Co003ooooooooooooo003o0_ooool2o`00o`05ooooool00?oo003oooooool00?l0
0_ooool2o`00o`;ooooo00?o003oooooooooool00_l00?l01Ooooooo003oo`00oooooooo003o00?o
oooo00Co003ooooooooooooo003o0_ooool00ol00?ooooooooooo`02o`00o`;ooooo00Co003ooooo
oooooooo003o0_ooool01?l00?ooooooooooool00?l2ooooo`;o003o0_ooool00ol00?oooooooooo
o`03ooooo`04o`00ooooooooooooo`00o`?ooooo00Co003ooooooooooooo003o0_ooool01_l00?oo
ooooooooool00?ooooooo`0000;o003o0_ooool01?l00?ooooooooooool00?l2ooooo`04o`00oooo
ooooooooo`00o`?ooooo00?o003oooooooooool00oooool01?l00?ooooooooooool00?l2ooooo`;o
003o0_ooool01?l00?ooooooooooool00?l2ooooo`04o`00ooooooooooooo`00o`;ooooo0_l00?l2
ooooo`04o`00ooooooooooooo`00o`;ooooo00?o003oooooooooool00_l00?l01Ooooooo003oo`00
oooooooo003o00?ooooo00?o003oooooooooool00_l00?l2ooooo`03o`00oooooooo003o00;ooooo
0_l00?l2ooooo`03o`00oooooooooooo00;o003o00Coooooo`00oooooooooooo0_l00?l5ooooo`03
o`000?oooooooooo02;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`02oooo
o`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000oooool01?oo003ooooooooo
oooo0002ooooo`04ool00?ooooooooooool000;ooooo00Goo`00ooooooooooooooooool00002oooo
o`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000oooool01?oo003ooooooooo
oooo0002ooooo`04ool00?ooooooooooool000?ooooo00Coo`00ooooooooooooo`000_ooool01?oo
003ooooooooooooo0002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooo
oooo0002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo0002oooo
o`04ool00?ooooooooooool000?ooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooo
oooo0003ooooo`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000_ooool01Ooo
003oooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooo
oooo0003ooooo`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000oooool01?oo
003ooooooooooooo0002ooooo`04ool00?ooooooooooool000;ooooo00Goo`00oooooooooooooooo
ool00002ooooo`04ool00?ooooooooooool000;ooooo00Goo`00ooooooooooooooooool00003oooo
o`03o`000?oooooooooo02?ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`04
ooooo`06o`00oooo003o003oo`00oooo003ooooo0_l00?l01ooo003o003oo`00oooo003o003ooooo
oooo00000_l00?l02ooo003o003oo`00ooooooooo`00o`00ooooooooo`00o`00ooooooooo`0000;o
003o01_oo`00o`00ool00?ooo`00ooooool00?ooooooool00?l00?ooooooool00?oooooo003oool0
0?oooooo003oool00?oooooo003oool00?oooooo003ooooooooo003o003ooooooooo00000_l00?l0
3_oo003oooooo`00oooo003oooooo`00ooooooooo`00o`00ooooooooo`00o`00ooooooooo`000_oo
ool03_oo003oooooo`00oooo003oooooo`00ooooooooo`00o`00ooooooooo`00o`00ooooooooo`00
0_l00?l06?oo003o003ooooooooo003oooooo`00ooooooooo`00ooooool00?ooo`00o`00oooooooo
o`00ooooool00?ooo`00ooooool00?ooo`00ooooool00?ooooooool000;ooooo017oo`00ooooool0
0?ooo`00ooooool00?ooo`00ooooool00?ooooooool00?l00?ooooooool00?l00?ooooooool00002
o`00o`0;ool00?oooooo003oool00?oooooo003ooooooooo003o003ooooooooo00000_l00?l01?oo
003o003oo`00oooo0002o`00o`0;ool00?oooooo003ooooooooo003o003ooooooooo003oooooo`00
oooo00000_l00?l02?oo003oooooo`00ooooooooo`00o`00ooooooooo`000_l00?l01?oo003o003o
o`00oooo0002o`00o`05ool00?oooooo003ooooooooo00000_l00?l00ooo003oooooooooo`02oooo
o`03o`000?oooooooooo01Kooooo000Mooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooo
ooooool00_ooool00ol00?ooooooo`00o`02ooooo`03o`00oooooooo003o00?o003o1?ooool01Ol0
0?ooooooo`00ool00?oooooo00;o003o0_ooool00ol00?ooooooooooo`03o`00o`?ooooo0_l00?l0
1?oooooo003oo`00ooooool2o`00o`03ooooool00?oooooo00?ooooo00Ko003ooooooooooooo003o
ooooool00?l2ooooo`05o`00ooooooooooooooooool00?l00_ooool01?l00?ooooooooooool00?l3
ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooooooool00_l00?l00ooooooo003ooooo
o`02ooooo`03o`00oooooooooooo00;o003o00Coooooo`00ool00?oo00000_l00?l01?oooooo003o
ooooooooool2o`00o`;ooooo00Co003ooooooooooooo003o0_ooool2o`00o`Gooooo00Co003ooooo
oooooooo003o0_ooool2o`00o`03ooooool00?oooooo00Gooooo00Co003ooooooooooooo003o0ooo
ool00ol00?ooooooo`00o`03ooooo`03o`00oooooooooooo00;o003o1?ooool2o`00o`;ooooo00Co
003ooooooooooooooooo0_l00?l01?oooooo003oooooool00?l3ooooo`04o`00oooooooo003ooooo
o`;o003o00Koooooo`00ool00?ooooooo`00ooooool2o`00o`03ooooool00?oo003o00Gooooo00?o
0000ooooooooool08_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00;ooooo
00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0003ooooo`04ool00?oooooooooo
ool000;ooooo00Coo`00ooooooooooooo`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo
00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0003ooooo`04ool00?oooooooooo
ool000;ooooo00Coo`00ooooooooooooo`000oooool01?oo003ooooooooooooo0002ooooo`04ool0
0?ooooooooooool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?oooooooooo
ool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?ooooooooooool000;ooooo
00Coo`00ooooooooooooo`000oooool01?oo003ooooooooooooo0002ooooo`04ool00?oooooooooo
ool000?ooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`05ool0
0?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo0002ooooo`04ool00?oooooooooo
ool000?ooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0003ooooo`04ool0
0?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000_ooool01Ooo003ooooooooooooooooo
o`0000;ooooo00Coo`00ooooooooooooo`000_ooool01Ooo003oooooooooooooooooo`0000?ooooo
00?o0000ooooooooool08oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00?o
oooo00[o003oool00?oo003oo`00o`00oooo003o003oooooool00?ooo`000_l00?l01?oo003ooooo
o`00oooo0002o`00o`0>ool00?l00?ooooooo`00oooo003oooooo`00oooo003oooooo`00oooo003o
003ooooooooo0002o`00o`0Hool00?l00?oo003ooooooooo003o003ooooooooo003o003ooooooooo
003o003ooooooooo003o003ooooooooo003oooooo`00ooooooooo`00o`00ooooooooo`000_l00?l0
3_oo003o003oo`00oooo003oooooo`00ooooooooo`00o`00ooooooooo`00o`00ooooooooo`000_oo
ool03_oo003oooooo`00oooo003oooooo`00ooooooooo`00o`00ooooooooo`00ooooool00?ooo`00
0_l00?l00ooo003o003oool00002ool00006ooooool00?ooo`00o`00ooooooooo`000_l00?l02ooo
003o003oo`00oooo003oooooo`00oooo003oooooo`00ooooooooo`0000;ooooo00koo`00o`00oooo
ooooo`00ooooool00?ooo`00ooooool00?ooooooool00?l00?ooooooool000;ooooo00koo`00o`00
ool00?ooo`00ooooool00?ooo`00ooooool00?ooooooool00?l00?ooooooool000;o003o00Coo`00
o`00ool00?ooo`000_ooool02ooo003oooooo`00ool00?ooo`00ooooool00?ooo`00o`00oooooooo
o`0000;o003o00Soo`00o`00ooooooooooooool00?oooooo003oool000;o003o00Coo`00o`00ool0
0?ooo`000_l00?l00ooo003o003oooooo`06ool000?ooooo00?o0000ooooooooool05_ooool001ko
oooo0_l00005ooooo`03o`000?oooooooooo00;ooooo00Wo003oooooool00?oo003oooooool00?oo
ooooo`00ooooool00_l00?l01?oooooo003oo`00ooooool2o`00o`05ooooool00?oo003oo`00oooo
ool00_l00?l01?oooooo003oo`00ooooool2o`00o`04ooooool00?ooooooo`00o`;ooooo00?o003o
ooooooooool00_l00?l01Ooooooo003oo`00ool00?oooooo00;o003o00Coooooo`00ool00?oooooo
0_l00?l00ooooooo003oo`00o`02ooooo`04o`00ooooooooooooo`00o`;ooooo0_l00?l00ooooooo
003oo`00o`02ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool00_l00?l01?oooooo
003oo`00ooooool2o`00o`?ooooo0_l00?l01_oooooo003oo`00oooooooo003oooooo`Go003o0_oo
ool00ol00?ooooooooooo`02o`00o`;ooooo00?o003oooooooooool00oooool01?l00?oooooooooo
ool00?l2ooooo`;o003o00Coooooo`00ool00?oooooo0_l00?l2ooooo`03o`00oooooooooooo00;o
003o00Coooooo`00oooooooooooo0_l00?l00ooooooo003oooooo`03ooooo`06o`00oooooooo003o
o`00oooooooo003o0_ooool01_l00?ooooooo`00ool00?ooooooo`00o`;ooooo0_l00?l01_oooooo
003oo`00ool00?ooooooo`00o`;ooooo0_l00?l4ooooo`;o003o00?oooooo`00ool00?l00_ooool0
1?l00?ooooooooooooooool2o`0002Gooooo0_l00005ooooo`03o`000?oooooooooo00;ooooo00Co
o`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0003ooooo`04ool00?ooooooooooool0
00;ooooo00Coo`00ooooooooooooo`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Co
o`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0003ooooo`04ool00?ooooooooooool0
00;ooooo00Coo`00ooooooooooooo`000oooool01?oo003ooooooooooooo0002ooooo`04ool00?oo
ooooooooool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?ooooooooooool0
00;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?ooooooooooool000;ooooo00Co
o`00ooooooooooooo`000oooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool0
00?ooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`05ool00?oo
oooooooooooooooo00000_ooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool0
00?ooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0003ooooo`04ool00?oo
ooooooooool000;ooooo00Coo`00ooooooooooooo`000_ooool01Ooo003oooooooooooooooooo`00
00;ooooo00Coo`00ooooooooooooo`000_ooool01Ooo003oooooooooooooooooo`0000?ooooo00?o
0000ooooooooool09?ooool2o`0000Cooooo0_l00003ooooo`;o003o1_oo00000oooooooo`00ool0
000:ool00003oooooooo003oo`0000[oo`0000?o003oool00?l00?l00_ooool01?oo003oooooo`00
oooo0002o`00o`04ool00?l00?oo003oool000;o003o00Goo`00ooooool00?ooooooool00002o`00
o`0Aool00?oooooo003oool00?l00?ooooooool00?oooooo003ooooooooo003o003ooooooooo003o
003ooooooooo00000_ooool02?oo003oooooo`00oooo003oooooo`00ooooooooo`000_l00?l01Ooo
003o003oo`00oooo003ooooo00Koo`0000Koooooool00?oo003oo`00o`00oooo0002o`00o`0;ool0
0?oooooo003oool00?oooooo003oool00?oooooo003ooooooooo00000_ooool03_oo003o003oo`00
oooo003oooooo`00oooo003oooooo`00ooooooooo`00o`00ooooooooo`000_l00?l01?oo003o003o
oooooooo0002o`00o`05ool00?l00?oooooooooooooo00000_l00?l03?oo003o003ooooooooo003o
ooooo`00oooo003o003ooooooooo003o003oooooo`coo`0000?oooooool00?oo00003Ooo00000ooo
ooooo`00ool00004ool000;ooooo0_l0000Hooooo`009Oooool00ol0003oooooooooo`0>ooooo`;o
003o00?oooooo`00ool00?l01Oooool00ol00?ooooooooooo`02o`00o`04ooooool00?oooooooooo
o`;o003o0_ooool00ol00?ooooooo`00o`02o`00o`04ooooool00?oo003oooooo`;o003o00?ooooo
o`00ooooool00_l00?l2ooooo`04o`00oooooooo003oo`00o`Kooooo00?o003oooooool00?l00_oo
ool2o`00o`;ooooo00?o003oooooooooool00oooool01?l00?ooooooooooool00?l2ooooo`;o003o
00?oooooo`00ooooool00_l00?l5ooooo`03o`000?oooooooooo00;o003o00Koooooo`00ool00?oo
ooooo`00ooooool2o`00o`04ooooool00?oo003oooooo`;o003o1Oooool01?l00?ooooooooooool0
0?l5ooooo`;o003o00?oooooo`00ool00?l01_ooool02?l00?ooooooo`00ool00?ooooooo`00oooo
oooo003o0_ooool2o`00o`;ooooo00Co003oooooool00?oo003o0_ooool2o`00o`04ooooool00?oo
ooooooooo`;o003o0_ooool01?l00?ooooooooooool00?l2ooooo`03o`00oooooooooooo01;ooooo
00?o0000ooooooooool0:_ooool00ol0003oooooooooo`02ooooo`04ool00?ooooooooooool000;o
oooo00Coo`00ooooooooooooo`000oooool01?oo003ooooooooooooo0002ooooo`04ool00?oooooo
ooooool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?ooooooooooool000;o
oooo00Coo`00ooooooooooooo`000oooool01?oo003ooooooooooooo0002ooooo`04ool00?oooooo
ooooool000?ooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`05
ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo0002ooooo`05ool00?oooooo
oooooooooooo00000_ooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000?o
oooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0003ooooo`04ool00?oooooo
ooooool000;ooooo00Coo`00ooooooooooooo`000_ooool01Ooo003oooooooooooooooooo`0000;o
oooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0003ooooo`04ool00?oooooo
ooooool000;ooooo00Coo`00ooooooooooooo`000oooool01?oo003ooooooooooooo0002ooooo`04
ool00?ooooooooooool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?oooooo
ooooool000;ooooo00Goo`00ooooooooooooooooool00003ooooo`03o`000?oooooooooo02[ooooo
00?o0000ooooooooool01?ooool6ool00003oooooooo003oo`0000[oo`0000?oooooool00?oo0000
3Ooo00000oooooooo`00ool00007ool00005o`00oooo003o003ooooooooo00000_ooool05Ol00?oo
o`00o`00ool00?ooo`00o`00ooooooooo`00ooooool00?ooo`00ooooool00?ooooooool00?l00?oo
ooooool00?l00?ooooooool00002ooooo`08ool00?oooooo003oool00?oooooo003ooooooooo0002
o`00o`03ool00?l00?ooo`0000Soo`0000?oooooool00?oo00001?oo00003?l00?ooo`00o`00ool0
0?ooo`00ooooool00?ooo`00ooooool00?ooooooool000;ooooo00Ooo`00o`00ool00?ooo`00oooo
ool00?ooo`0000?ooooo00Coo`00o`00ooooooooo`000_l00?l01?oo003oooooo`00oooo0002oooo
o`06ool00?l00?ooooooo`00oooo003ooooo3?oo00000oooooooo`00ool0000:ool00003oooooooo
003oo`0000goo`0000?oooooool00?oo00001?oo0003ooooo`03o`000?oooooooooo01Kooooo000U
ooooo`03o`000?oooooooooo02Gooooo00Co003ooooooooooooo003o1Oooool2o`00o`;ooooo00Ko
003ooooooooooooo003oooooool00?l2ooooo`04o`00oooooooo003oo`00o`;ooooo0_l00?l01Ooo
oooo003oo`00oooooooo003o00?ooooo00?o003oooooooooool00oooool01Ol00?oooooooooooooo
oooo003o00;ooooo00?o003oooooool00?l00_ooool00ol00?ooooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o003oooooooooool00_ooool01ol00?oooooooooooooooooo003oooooool0
0?l01_ooool01?l00?ooooooooooool00?l2ooooo`;o003o0_ooool01ol00?ooooooo`00ool00?oo
ooooo`00ooooool00_l00?l00ooooooo003oooooo`03o`00o`;ooooo0_l00?l00ooooooo003oo`00
o`02ooooo`04o`00ooooooooooooo`00obOooooo00?o0000ooooooooool0:_ooool2o`0000;ooooo
0_oo00001?ooooooo`00ool00?ooool2ool00003oooooooo003oo`0000?ooooo00Coo`00oooooooo
ooooo`000_ooool01?oo003ooooooooooooo0002ooooo`05ool00?oooooooooooooooooo00000_oo
ool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000?ooooo00Coo`00oooooooo
ooooo`000_ooool01?oo003ooooooooooooo0003ooooo`04ool00?ooooooooooool000;ooooo00Co
o`00ooooooooooooo`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00oooooooo
ooooo`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00oooooooo003oo`000_oo
ool01?oo003ooooooooooooo0003ooooo`04ool00?ooooooooooool000;ooooo00Coo`00oooooooo
ooooo`000oooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000;ooooo00Go
o`00ooooooooooooooooool00002ooooo`04ool00?ooooooooooool000;ooooo00Coo`00oooooooo
ooooo`000oooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000?ooooo00Co
o`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`03ool00?oooooooooo00;o
o`0000Coooooool00?oo003ooooo0_oo00000oooooooo`00ool00002ooooo`;oo`000oooool00ol0
003oooooooooo`0Zooooo`03o`000?oooooooooo00Oooooo0ooo00000oooooooo`00ool0000:ool0
0003oooooooo003oo`0000goo`0000?oooooool00?oo00002_oo00002Oooooooo`00o`00oooooooo
003oool00?oooooo003oool00002o`00o`04ool00?l00?oo003oool000;o003o00Soooooool00?l0
0?ooooooool00?l00?ooooooool000;ooooo00coo`00ooooool00?ooo`00ooooool00?ooooooool0
0?oooooo003oool00?l00?l6ool00004ooooool0003oooooooooo`Koo`0000coooooool00?l00?oo
ooooool00?oooooo003oool00?oooooo003ooooooooo0002ooooo`0>ool00?oooooo003oool00?oo
oooo003oool00?oooooo003ooooooooo003o003ooooooooo0002o`00o`09ool00?l00?oo003oool0
0?l00?ooooooool00?l00?oooooo00ooo`0000?oooooool00?oo00002_oo00000oooooooo`00ool0
000=ool000[ooooo00?o0000ooooooooool05_ooool002Gooooo00?o0000ooooooooool0=Oooool0
1Ol00?oooooooooooooooooo003o00;ooooo00Co003oooooool00?oooooo0_l00?l2ooooo`04o`00
ooooooooooooo`00o`;ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`02o`00o`03
ooooool00?oooooo00[ooooo00?o0000ooooooooool01_ooool2o`00o`04ooooool00?ooooooo`00
o`;ooooo0_l00?l5ooooo`03o`00oooooooooooo00;o003o00Coooooo`00ool00?oooooo0_l00?l4
ooooo`05o`00oooooooo003oo`00ooooool00_l00?l2ooooo`03o`00oooooooooooo03;ooooo00?o
0000ooooooooool0:_ooool01?l0003oooooooooooooool2ool00004oooooooo003oo`00ooooo`;o
o`0000?oooooool00?oo00000_ooool2ool00004oooooooo003oo`00ooooo`;oo`0000Coooooool0
0?oo003ooooo0_oo0003ooooo`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`00
0_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`000_ooool01Ooo
003oooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooo
oooo0003ooooo`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000oooool01Ooo
003oooooool00?oo003ooooo00;oo`0000?oooooool00?oo00000_ooool01Ooo003ooooooooooooo
ooooo`0000;ooooo00Coo`00ooooooooooooo`000_ooool01Ooo003oooooooooooooooooo`0000;o
oooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0003ooooo`04ool00?oooooo
ooooool000;ooooo00Coo`00ooooooooooooo`000_ooool01Ooo003oooooooooooooooooo`0000;o
oooo00Coo`00ooooooooooooo`000_ooool00ooo003oooooooooo`02ool00004oooooooo003oo`00
ooooo`;oo`0000?oooooool00?oo00000_ooool2ool00004oooooooo003oo`00ooooo`;oo`0000Co
ooooool00?oo003ooooo0_oo0002ooooo`;oo`000oooool00ol0003oooooooooo`0Zooooo`03o`00
0?oooooooooo02Cooooo0ooo00000oooooooo`00ool0000=ool00006oooooooo003oo`00ool00?oo
ooooo`000_l00?l03_oo003o003oo`00oooo003oooooo`00ooooooooo`00o`00ooooooooo`00o`00
ooooooooo`000_ooool02?oo003oooooo`00oooo003oooooo`00ooooooooo`000_ooool00ooo003o
ooooool00002ool000Cooooo00?o0000ooooooooool00oooool3ool0000<o`00oooo003o003oo`00
oooo003o003ooooooooo003oooooo`00ooooooooo`000_ooool01?oo003o003ooooooooo0002o`00
o`05ool00?oooooo003ooooooooo00000_l00?l01Ooo003ooooooooooooo003o003o00Koo`0000?o
ooooool00?oo00003Ooo000Wooooo`03o`000?oooooooooo01Kooooo000Uooooo`03o`000?oooooo
oooo03Gooooo00?o003oooooooooool00_l00?l01?oooooo003oo`00ooooool2o`00o`?ooooo0_l0
0?l00ooooooo003oo`00o`02ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool00_l0
0?l01?oooooo003oooooool00?l9ooooo`03o`000?oooooooooo00Kooooo0_l00?l00ooooooo003o
ooooo`02o`00o`;ooooo00?o003oooooooooool00oooool01?l00?ooooooooooool00?l2ooooo`;o
003o00Koooooo`00ooooooooooooo`00ooooool2o`00o`03ooooool00?oo003o03Wooooo0_l0000/
ooooo`03o`000?oooooooooo00kooooo0_oo00001?ooooooo`00ool00?ooool2ool00004oooooooo
003oo`00ooooo`;oo`000_ooool2ool00004oooooooo003oo`00ooooo`;oo`000_ooool01?oo003o
oooooooooooo0003ooooo`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000ooo
ool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000;ooooo00Goo`00oooooooo
ooooooooool00002ooooo`04ool00?ooooooooooool000;ooooo00Koo`00ooooooooooooooooool0
0?ooool2ool000Cooooo0_oo0002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003o
oooooooooooo0002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo
0002ooooo`04ool00?ooooooooooool000?ooooo00Coo`00ooooooooooooo`000_ooool01?oo003o
oooooooooooo0002ooooo`06ool00?oooooooooooooooooo003ooooo0_oo00001?ooooooo`00ool0
0?ooool2ool000;ooooo0_oo00001?ooooooo`00ool00?ooool2ool00003oooooooo003oo`0000;o
oooo0_oo000Cooooo`03o`000?oooooooooo02[ooooo0_l0000booooo`Koo`0000?oooooool00?oo
00001?oo00001Ol00?ooo`00o`00ooooooooo`0000;o003o00Soooooool00?l00?ooooooool00?l0
0?ooooooool000;ooooo00Woo`00ooooool00?ooo`00ooooool00?ooooooool00?ooool00ooo0007
ooooo`03o`000?oooooooooo00Kooooo0ooo00002Ol00?ooo`00o`00ool00?ooo`00ooooool00?oo
ooooool00002ooooo`07ool00?l00?oo003oool00?l00?ooooooool00002o`00o`06oooooooo003o
oooooooooooo003o003o2Ooo00001?ooooooo`00ool00?oo000booooo`;o00006?ooool002Gooooo
00?o0000ooooooooool0>oooool2o`00o`Cooooo00?o003oooooool00?l00_ooool2o`00o`;ooooo
00?o003oooooooooool00oooool01?l00?ooooooooooool00?l2ooooo`03o`00oooooooo003o00Wo
oooo00?o0000ooooooooool01_ooool2o`00o`03ooooool00?oooooo00;o003o00?oooooo`00ool0
0?l01Oooool00ol00?ooooooooooo`02o`00o`Cooooo1?l00?l00ooooooo003oo`00o`0mooooo`03
o`000?oooooooooo02[ooooo00?o0000ooooooooool07_ooool2ool00004oooooooo003oo`00oooo
o`;oo`0000?oooooool00?oo00000_ooool2ool000;ooooo00Coo`00ooooooooooooo`000_ooool0
1?oo003ooooooooooooo0003ooooo`04ool00?ooooooooooool000;ooooo00Coo`00oooooooooooo
o`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`000_ooool0
0ooo003oooooooooo`02ool000[ooooo0_oo0003ooooo`04ool00?ooooooooooool000;ooooo00Co
o`00ooooooooooooo`000oooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool0
00;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?ooooooooooool000;ooooo00?o
o`00ooooooooool00_oo00001?ooooooo`00ool00?ooool2ool00004oooooooo003oo`00ooooo`;o
o`009?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03Cooooo0ooo00000ooooooo
o`00ool00004ool00006oooooooo003oooooo`00oooo003o003o0_ooool01?oo003o003oo`00oooo
0002o`00o`08ool00?ooooooooooool00?oooooo003oool00?l00?l2ooooo`03ool00?ooooooo`00
00;oo`001oooool00ol0003oooooooooo`06ooooo`?oo`0000Wo003oool00?l00?oo003oool00?oo
oooo003ooooooooo00000_ooool01?oo003o003oo`00oooo0002o`00o`09ool00?oooooooooooooo
oooo003oooooo`00oooo003o003o00Woo`00=oooool00ol0003oooooooooo`0Fooooo`009Oooool0
0ol0003oooooooooo`0nooooo`;o003o00?oooooo`00ooooool00_l00?l00ooooooo003oooooo`02
ooooo`03o`00oooooooooooo00?ooooo0_l00?l2ooooo`03o`00oooooooooooo00_ooooo00?o0000
ooooooooool03?ooool00ol00?ooooooo`00o`06ooooo`06o`00ooooooooooooooooool00?oooooo
0_l00?l3ooooo`;o003o@?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo02Oooooo
0_oo0002ooooo`;oo`0000?oooooool00?oo00000_ooool01?oo003ooooooooooooo0002ooooo`05
ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo0002ooooo`04ool00?oooooo
ooooool000?ooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`;o
o`002_ooool2ool000?ooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0003
ooooo`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000_ooool01Ooo003ooooo
ooooooooooooo`0000;ooooo00Goo`00ooooooooooooo`00ooooo`02ool000;ooooo0_oo00000ooo
ooooo`00ool0000]ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0>oooool6ool0
000<oooooooo003o003oooooool00?ooo`00o`00ooooooooo`00ooooool00?ooo`000_ooool01?oo
003oooooo`00oooo0002ooooo`03o`00oooo003ooooo00?oo`001oooool00ol0003oooooooooo`06
ooooo`?oo`0000Woooooool00?oooooo003oool00?oooooo003ooooooooo00000_ooool03?oo003o
ooooo`00oooo003oooooo`00oooo003o003oooooool00?ooo`00ooooo`Koo`00?Oooool00ol0003o
ooooooooo`0Fooooo`009Oooool00ol0003oooooooooo`0nooooo`;o003o00Goooooo`00oooooooo
ooooo`00o`02ooooo`04o`00oooooooo003oo`00o`Gooooo0_l00?l01?oooooo003oo`00ool00?l<
ooooo`03o`000?oooooooooo00Wooooo0_l00?l3ooooo`;o003o2?ooool2o`00o`05ooooool00?oo
003oooooool00?l0@oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo02kooooo0_oo
00000oooooooo`00ool00002ooooo`04ool00?ooooooooooool000?ooooo00Coo`00oooooooooooo
o`000_ooool01?oo003ooooooooooooo0002ooooo`05ool00?oooooooooooooooooo00000_ooool0
1?oo003ooooooooooooo0002ooooo`03ool00?oooooooooo017ooooo00Coo`00ooooooooooooo`00
0_ooool01?oo003ooooooooooooo0003ooooo`04ool00?ooooooooooool000;ooooo00Coo`00oooo
ooooooooo`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Goo`00oooooooo003oo`00
ooooo`02ool003Cooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0nooooo`?oo`00
00Woooooool00?ooooooooooo`00oooo003oooooo`00oooo00000_l00?l01?oo003ooooooooooooo
0002o`00o`05ool00?l00?ooooooo`00oooo00002oooool00ol0003oooooooooo`0:ooooo`08ool0
0?l00?ooooooool00?oooooo003ooooooooo0002ooooo`04ool00?l00?ooooooool000;o003o00Ko
o`00o`00oooooooo003oool00?ooool3ool0043ooooo00?o0000ooooooooool05_ooool002Gooooo
00?o0000ooooooooool0@_ooool3o`00o`05ooooool00?oo003oooooool00?l01_ooool2o`00o`04
ooooool00?oo003oo`00o`cooooo00?o0000ooooooooool02Oooool2o`00o`05ooooool00?oooooo
ooooool00?l01Oooool01?l00?ooooooooooool00?l2ooooo`?o003o@oooool2o`0002cooooo0_l0
000booooo`;oo`0000?oooooool00?oo00000_ooool01Ooo003oooooooooooooooooo`0000;ooooo
00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0003ooooo`04ool00?oooooooooo
ool000;ooooo00Coo`00ooooooooooooo`004oooool01?oo003ooooooooooooo0002ooooo`04ool0
0?ooooooooooool000?ooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0002
ooooo`06ool00?oooooooooooooooooo003ooooo0_oo00000oooooooo`00ool0000gooooo`03o`00
0?oooooooooo02[ooooo0_l0000oooooo`?oo`0000coooooool00?l00?ooooooo`00oooo003ooooo
o`00oooo003o003ooooooooo0002ooooo`06ool00?oooooo003oool00?l00?oooooo0ooo000:oooo
o`03o`000?oooooooooo00Wooooo0ooo00001_ooooooo`00ooooool00?ooooooool000;ooooo00co
o`00o`00ool00?ooo`00o`00ooooooooo`00o`00oooooooo003oool00?ooool3ool003oooooo0_l0
000Hooooo`009Oooool00ol0003oooooooooo`12ooooo`04o`00ooooooooooooooooo`;o003o00?o
ooooo`00ool00?l02?ooool00ol00?ooooooo`00o`0<ooooo`03o`000?oooooooooo00[ooooo00Co
003oooooool00?oooooo0_l00?l5ooooo`03o`00oooooooooooo00;o003o0oooool00ol00?oooooo
ooooo`12ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0=?ooool2ool000;ooooo
00Goo`00ooooooooooooooooool00002ooooo`04ool00?ooooooooooool000;ooooo00Coo`00oooo
ooooooooo`000oooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooo`00ool001;ooooo
0_oo0002ooooo`04ool00?ooooooooooool000;ooooo00Goo`00ooooooooooooooooool00002oooo
o`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000oooool01?oo003oooooool0
0?oo000jooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0@Oooool3ool000;ooooo
00Coo`00ooooool00?ooo`000_l00?l02Ooo003ooooooooooooo003o003ooooooooo003o003ooooo
o`03ool000[ooooo00?o0000ooooooooool02Oooool3ool00006oooooooo003oooooo`00oooooooo
o`000_ooool01?oo003o003oo`00oooo0002o`00o`03ool00?oooooooooo00?oo`00@oooool00ol0
003oooooooooo`0Fooooo`009Oooool00ol0003oooooooooo`12ooooo`05o`00oooooooo003ooooo
ool00?l00oooool00ol00?ooooooooooo`03ooooo`;o003o00?oooooo`00ooooool03Oooool00ol0
003oooooooooo`0<ooooo`03o`00oooooooo003o00Kooooo00Co003ooooooooooooooooo0_l00?l2
ooooo`03o`00oooooooooooo04;ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0g
ooooo`;oo`000oooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000;ooooo
00Goo`00ooooooooooooooooool00002ooooo`05ool00?ooooooooooool00?ooool00_oo000Boooo
o`;oo`000_ooool01?oo003ooooooooooooo0002ooooo`05ool00?oooooooooooooooooo00000_oo
ool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000;ooooo0_oo000mooooo`03
o`000?oooooooooo02[ooooo00?o0000ooooooooool0@Oooool3ool00003ooooool00?ooo`0000;o
oooo00Coo`00ooooool00?ooo`000_ooool01?oo003o003oo`00oooo0002ooooo`?oo`002_ooool0
0ol0003oooooooooo`09ooooo`?oo`0000Koooooool00?oooooo003ooooooooo0002ooooo`04ool0
0?l00?oo003oool000;ooooo00?oo`00o`00ooooool00ooo0013ooooo`03o`000?oooooooooo01Ko
oooo000Uooooo`03o`000?oooooooooo04Cooooo00Go003oooooool00?oo003oooooo`02o`00o`Go
oooo0_l00?l@ooooo`03o`000?oooooooooo00kooooo0_l00?l7ooooo`04o`00oooooooo003oo`00
odOooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0gooooo`;oo`000oooool01?oo
003ooooooooooooo0002ooooo`04ool00?ooooooooooool000;ooooo00Goo`00oooooooooooooooo
ool00002ooooo`04ool00?ooooooooooool001Wooooo00Coo`00ooooooooooooo`000_ooool01Ooo
003oooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooo
oooo0002ooooo`;oo`00?Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo047ooooo
0ooo00001_oooooo003oool00?oooooo003oool000;o003o00Coo`00ooooooooooooo`000_l00?l0
0ooo003o003oooooo`0=ooooo`03o`000?oooooooooo00gooooo00Goo`00ooooool00?ooooooool0
0002ooooo`09ool00?ooooooooooool00?l00?ooooooool00?l00?oooooo00?oo`00@oooool00ol0
003oooooooooo`0Fooooo`009Oooool00ol0003oooooooooo`15ooooo`?o003o00?oooooo`00oooo
ool01Oooool2o`00o`03ooooool00?oooooo00gooooo00?o0000ooooooooool03?ooool01?l00?oo
ooooooooool00?l5ooooo`03o`00oooooooo003o00;ooooo00?o003oooooooooool0A?ooool2o`00
02cooooo00?o0000ooooooooool0>oooool2ool000;ooooo00Coo`00ooooooooooooo`000_ooool0
1?oo003ooooooooooooo0003ooooo`04ool00?ooooooooooool000;ooooo00?oo`00ooooooooool0
5oooool01?oo003ooooooooooooo0002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo
003ooooooooooooo0002ooooo`04ool00?ooooooo`00ool0047ooooo00?o0000ooooooooool0:_oo
ool2o`0004Kooooo00So003oool00?oooooo003oool00?l00?ooooooool000;ooooo00Goo`00o`00
ool00?ooo`00o`00o`0>ooooo`03o`000?oooooooooo00gooooo00Goo`00ooooool00?ooooooool0
0002ooooo`08ool00?l00?oo003oool00?l00?ooooooool00?l00?m6ooooo`;o00006?ooool002Go
oooo00?o0000ooooooooool0AOooool3o`00o`03ooooool00?oo003o00Sooooo00?o003ooooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`04o`00oooooooo003oo`00o`Gooooo00Go003ooooo
ool00?ooooooo`00o`18ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0>oooool2
ool000;ooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0003ooooo`04ool0
0?ooooooooooool000;ooooo00?oo`00ooooooooool05oooool01?oo003ooooooooooooo0002oooo
o`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo0002ooooo`04ool00?oo
ooooo`00ool0047ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`15ooooo`?oo`00
00Go003oool00?l00?oo003oool00002ooooo`05ool00?ooooooooooool00?l00?l03_ooool00ol0
003oooooooooo`0=ooooo`05ool00?l00?oo003ooooooooo00000_ooool01Ooo003o003oo`00oooo
003o003o00?oo`00Aoooool00ol0003oooooooooo`0Fooooo`007Oooool3o`0000Gooooo00?o0000
ooooooooool0AOooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00?ooooo0ol00?l?
ooooo`03o`000?oooooooooo00cooooo00?o003oooooool00?l01_ooool2o`00o`;ooooo0_l00?m7
ooooo`03o`000?oooooooooo02[ooooo0_l00010ooooo`04ool00?ooooooooooool000;ooooo00Co
o`00ooooooooooooo`000oooool01?oo003ooooooooooooo0002ooooo`03ool00?oooooooooo01Oo
oooo00Coo`00ooooooooooooo`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00
ooooooooooooo`000_ooool00ooo003oooooooooo`12ooooo`03o`000?oooooooooo02?ooooo0ol0
0004ooooo`03o`000?oooooooooo04Gooooo0ooo00001Oooooooo`00ooooool00?ooo`0000;ooooo
00Goo`00o`00ool00?ooo`00o`00o`0>ooooo`03o`000?oooooooooo00gooooo00Goo`00o`00oooo
ooooooooool00002ooooo`05ool00?l00?oo003oool00?ooool00ooo0017ooooo`03o`000?oooooo
oooo01Kooooo000Looooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`17
ooooo`04o`00oooooooo003oo`00o`Gooooo0_l00?l@ooooo`03o`000?oooooooooo00kooooo0_l0
0?l7ooooo`03o`00oooooooooooo04Sooooo00?o0000ooooooooool0:_ooool00ol0003ooooooooo
o`0oooooo`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000oooool01Ooo003o
oooooooooooo003ooooo00;oo`006?ooool2ool000;ooooo00Coo`00ooooooooooooo`000oooool0
1?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool004Cooooo00?o0000ooooooooool0
8_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0AOooool3ool00005
o`00oooo003o003oo`00oooo00000_ooool01?oo003o003oo`00oooo000?ooooo`03o`000?oooooo
oooo00gooooo00Goo`00o`00oooooooo003oool00002ooooo`05ool00?ooooooooooool00?l00?l0
0ooo0017ooooo`03o`000?oooooooooo01Kooooo000Pooooo`03o`000?oooooooooo00;ooooo0_l0
0018ooooo`03o`00oooooooo003o00Kooooo0ol00?l?ooooo`03o`000?oooooooooo00gooooo00?o
003oooooool00?l01Oooool3o`00odWooooo0_l0000/ooooo`03o`000?oooooooooo03kooooo0_oo
0002ooooo`04ool00?ooooooooooool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04
ool00?ooooooo`00ool001Sooooo0_oo0002ooooo`04ool00?ooooooooooool000?ooooo00Coo`00
ooooooooooooo`000_ooool01?oo003oooooool00?oo0014ooooo`03o`000?oooooooooo02Kooooo
00Co0000oooooooooooooooo0_l00019ooooo`05o`00oooo003o003ooooooooo00000_ooool01Ooo
003o003ooooooooo003o003o00kooooo00?o0000ooooooooool03Oooool01Ooo003oooooooooool0
0?ooo`0000;ooooo00Goo`00o`00ool00?ooo`00o`00o`18ooooo`?o00006?ooool0023ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`18ooooo`?o003o1oooool00ol00?oooooooooo
o`0=ooooo`03o`000?oooooooooo00gooooo0ol00?l5ooooo`?o003oB_ooool00ol0003ooooooooo
o`0Zooooo`03o`000?oooooooooo03kooooo0_oo0002ooooo`04ool00?ooooooooooool000;ooooo
00Goo`00ooooooooooooooooool00002ooooo`03ool00?oooooooooo01gooooo00Coo`00oooooooo
ooooo`000oooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooo`00ool004Cooooo00?o
0000ooooooooool09_ooool01Ol0003ooooooooooooooooo000004[ooooo00Go003oool00?l00?oo
003oool00002ooooo`05ool00?ooooooooooool00?l00?l03_ooool00ol0003oooooooooo`0=oooo
o`05ool00?l00?ooooooo`00oooo00000_ooool01Ooo003o003oo`00oooo003o003o04[ooooo00?o
0000ooooooooool05_ooool001cooooo1?l00005ooooo`03o`000?oooooooooo04[ooooo00?o003o
ooooooooool00oooool3o`00o`oooooo00?o0000ooooooooool03Oooool2o`00o`Gooooo00?o003o
ooooool00?l0Boooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo04;ooooo00Coo`00
ooooooooooooo`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo00?oo`00ooooooooool0
7Oooool01?oo003ooooooooooooo0003ooooo`04ool00?ooooooooooool000;ooooo00?oo`00oooo
ooooool0AOooool00ol0003oooooooooo`0Rooooo`Co00001?ooool00ol0003oooooooooo`19oooo
o`04ool00?oooooo003oool000;ooooo00?oo`00o`00oooo00000_oo000>ooooo`03o`000?oooooo
oooo00cooooo0ooo0002ooooo`04ool00?ooooooooooool000;o003o00?oo`00ooooooooool0BOoo
ool00ol0003oooooooooo`0Fooooo`007?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo04Sooooo0ol00?l5ooooo`?o003o3oooool00ol0003oooooooooo`0=ooooo`?o003o1oooool0
0ol00?ooooooooooo`18ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0@_ooool0
1?oo003ooooooooooooo0002ooooo`05ool00?oooooooooooooooooo00000_ooool00ooo003ooooo
ooooo`0Mooooo`04ool00?ooooooooooool000?ooooo00Coo`00ooooooooooooo`000_ooool00ooo
003oooooooooo`15ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`18ooooo`05o`00oooo003o003oo`00oooo00000_ooool00ooo003o003oool00002
ool000kooooo00?o0000ooooooooool03?ooool3ool00003ooooool00?ooo`0000;ooooo00Goo`00
ooooooooooooo`00o`00o`1:ooooo`03o`000?oooooooooo01Kooooo000Looooo`Go00001?ooool0
0ol0003oooooooooo`18ooooo`;o003o1_ooool3o`00o`oooooo00?o0000ooooooooool03oooool0
0ol00?ooooooooooo`02ooooo`04o`00oooooooo003oo`00odWooooo0_l0000/ooooo`;o0000@ooo
ool01?oo003ooooooooooooo0002ooooo`05ool00?oooooooooooooooooo00000_ooool00ooo003o
ooooooooo`0Mooooo`04ool00?ooooooooooool000?ooooo00Coo`00ooooooooooooo`000_ooool0
0ooo003oooooooooo`15ooooo`03o`000?oooooooooo02;ooooo1Ol00003ooooo`;o0000BOooool0
1Ol00?ooo`00o`00ooooooooo`0000;ooooo00?oo`00o`00oooo00000_oo000>ooooo`03o`000?oo
oooooooo00cooooo0ooo00000ooooooo003oool00002ooooo`05ool00?l00?oo003oool00?l00?l0
BOooool2o`0001Sooooo000Uooooo`03o`000?oooooooooo04Sooooo0ol00?lGooooo`03o`000?oo
oooooooo00oooooo00?o003oooooooooool00_ooool01?l00?ooooooo`00ool00?m:ooooo`03o`00
0?oooooooooo02[ooooo00?o0000ooooooooool0@_ooool01?oo003ooooooooooooo0002ooooo`05
ool00?oooooooooooooooooo00000_ooool00ooo003oooooooooo`0Mooooo`04ool00?oooooooooo
ool000?ooooo00Coo`00ooooooooooooo`000_ooool00ooo003oooooooooo`15ooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool0B?ooool01Ol00?ooo`00ooooool00?ooo`0000;ooooo
00?oo`00ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`05o`00oooo003ooooooooooooo
00000_l00?l00ooo003oooooooooo`19ooooo`03o`000?oooooooooo01Kooooo000Uooooo`03o`00
0?oooooooooo04[ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00
0?oooooooooo01Cooooo00?o003oooooool00?l0Boooool00ol0003oooooooooo`0Zooooo`03o`00
0?oooooooooo047ooooo0_oo0002ooooo`04ool00?ooooooooooool000?ooooo00Coo`00oooooooo
ooooo`007oooool01?oo003ooooooooooooo0003ooooo`05ool00?ooooooooooool00?ooool00_oo
0017ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0BOooool01?oo003oooooo`00
oooo0002ooooo`03ool00?l00?oooooo013ooooo00?o0000ooooooooool04Oooool01ooo003ooooo
oooooooo003o003ooooooooo0000Boooool00ol0003oooooooooo`0Fooooo`009Oooool00ol0003o
ooooooooo`18ooooo`?o003o1Oooool00ol00?ooooooooooo`0?ooooo`03o`000?oooooooooo00oo
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`18ooooo`03o`000?oooooooooo02[o
oooo00?o0000ooooooooool0@Oooool2ool000;ooooo00Coo`00ooooooooooooo`000oooool01?oo
003ooooooooooooo000Oooooo`04ool00?ooooooooooool000?ooooo00Goo`00ooooooooooooo`00
ooooo`02ool004Oooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`18ooooo`?oo`00
00Ko003oool00?ooooooooooool00?l00?lAooooo`03o`000?oooooooooo013ooooo00Ko003oool0
0?ooooooooooool00?ooool3ool004[ooooo00?o0000ooooooooool05_ooool002Gooooo00?o0000
ooooooooool0B?ooool2o`00o`Kooooo00?o003oooooooooool03oooool00ol0003oooooooooo`0?
ooooo`03o`00oooooooooooo00;ooooo00Co003oooooool00?oo003oBOooool2o`0002Cooooo0ol0
0005ooooo`03o`000?oooooooooo04Gooooo00Coo`00ooooooooooooo`000oooool01?oo003ooooo
oooooooo000Oooooo`04ool00?ooooooooooool000?ooooo00Coo`00ooooooooooooo`00B_ooool0
0ol0003oooooooooo`0Zooooo`;o0000BOooool3ool00006oooooooo003ooooooooooooo003o003o
4Oooool00ol0003oooooooooo`0@ooooo`06o`00oooo003ooooooooooooo003o003o0ooo0019oooo
o`;o00006?ooool002Gooooo00?o0000ooooooooool0B?ooool00ol00?ooooooo`00o`0Gooooo`03
o`000?oooooooooo00oooooo00?o003oooooooooool00_ooool00ol00?ooooooo`00o`1;ooooo`03
o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo
04Gooooo00Coo`00ooooooooooooo`000oooool01?oo003ooooooooooooo000Oooooo`04ool00?oo
ooooooooool000?ooooo00Coo`00ooooooooooooo`00B_ooool00ol0003oooooooooo`0Zooooo`03
o`000?oooooooooo04Sooooo0ooo00001Ol00?ooo`00ooooooooooooo`0001;ooooo00?o0000oooo
ooooool04?ooool01_l00?ooo`00ooooooooooooo`00o`00o`?oo`00B_ooool00ol0003ooooooooo
o`0Fooooo`009Oooool00ol0003oooooooooo`1:ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool04?ooool00ol0003oooooooooo`0Dooooo`03o`00oooooooooooo04_ooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`02ooooo`;o0000A_ooool01?oo003ooooooooooooo
0003ooooo`04ool00?ooooooooooool001oooooo00Coo`00ooooooooooooo`000oooool01?oo003o
oooooooooooo0019ooooo`;o0000;?ooool00ol0003oooooooooo`1;ooooo`06o`00oooo003ooooo
oooooooo003o003o4Oooool00ol0003oooooooooo`0Aooooo`05ool00?ooooooooooool00?l00?l0
COooool00ol0003oooooooooo`0Fooooo`009Oooool00ol0003oooooooooo`1:ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool04?ooool00ol0003oooooooooo`0?ooooo`03o`00oooo
oooooooo053ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo04Gooooo00Coo`00ooooooooooooo`000oooool01?oo003ooooooooooooo000Oooooo`04
ool00?ooooooooooool000?ooooo00Coo`00ooooooooooooo`00B_ooool00ol0003oooooooooo`0Z
ooooo`03o`000?oooooooooo04_ooooo00Ko003oool00?ooooooooooool00?l00?lAooooo`03o`00
0?oooooooooo013ooooo00Go003oool00?ooooooooooool0001>ooooo`03o`000?oooooooooo01Ko
oooo000Uooooo`03o`000?oooooooooo04oooooo00?o003oooooooooool04?ooool00ol0003ooooo
ooooo`0?ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0B_ooool2o`0002?ooooo
1?l00005ooooo`03o`000?oooooooooo04Gooooo00Coo`00ooooooooooooo`000oooool01?oo003o
oooooooooooo000Oooooo`04ool00?ooooooooooool000?ooooo00Coo`00ooooooooooooo`00B_oo
ool00ol0003oooooooooo`0Zooooo`;o0000COooool01Ooo003ooooooooooooo003o003o017ooooo
00?o0000ooooooooool04?ooool01_l00?ooo`00ooooooooooooo`00o`00odcooooo0_l0000Hoooo
o`009Oooool00ol0003oooooooooo`1:ooooo`03o`00oooooooooooo01Gooooo00?o0000oooooooo
ool03oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo04_ooooo00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04Gooooo00Coo`00oooooooo
ooooo`000oooool01?oo003ooooooooooooo000Oooooo`04ool00?ooooooooooool000?ooooo00Co
o`00ooooooooooooo`00B_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo04_ooooo
00Go003oool00?ooooooooooool0000Booooo`03o`000?oooooooooo013ooooo00Ko003oool00?oo
ooooooooool00?l00?m=ooooo`03o`000?oooooooooo01Kooooo000Uooooo`03o`000?oooooooooo
04[ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0@ooooo`03o`000?oooooooooo
01Cooooo00?o003oooooooooool0Boooool00ol0003oooooooooo`0Qooooo`Go00001?ooool00ol0
003oooooooooo`15ooooo`04ool00?ooooooooooool000?ooooo00Coo`00oooooooo003oo`007_oo
ool2ool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`03ool00?oooooooooo04Sooooo
00?o0000ooooooooool0:_ooool00ol0003oooooooooo`1;ooooo`06o`00oooo003ooooooooooooo
003o003o4Oooool00ol0003oooooooooo`0Aooooo`05ool00?ooooooooooool00?l00?l0COooool0
0ol0003oooooooooo`0Fooooo`009Oooool00ol0003oooooooooo`1;ooooo`05o`00oooooooooooo
ooooool00?l04_ooool00ol0003oooooooooo`0?ooooo`03o`00oooooooooooo053ooooo00?o0000
ooooooooool0:_ooool00ol0003oooooooooo`15ooooo`04ool00?ooooooooooool000?ooooo00Co
o`00oooooooo003oo`007_ooool2ool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`03
ool00?oooooooooo04Sooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`1;ooooo`06
o`00oooo003ooooooooooooo003o003o4Oooool00ol0003oooooooooo`0@ooooo`05o`00oooo003o
oooooooooooo0000C_ooool00ol0003oooooooooo`0Fooooo`009Oooool00ol0003oooooooooo`1?
ooooo`03o`00oooooooooooo013ooooo00?o0000ooooooooool03oooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo04[ooooo0_l0000/ooooo`;o0000A_ooool01?oo003ooooooooooooo
0003ooooo`03ool00?oooooooooo02?ooooo00Goo`00ooooooooooooooooool00002ooooo`03ool0
0?oooooooooo04Sooooo00?o0000ooooooooool0:_ooool2o`0004gooooo00Goo`00oooooooooooo
o`00o`00o`0Aooooo`03o`000?oooooooooo013ooooo00Ko003oool00?ooooooooooool00?l00?m<
ooooo`;o00006?ooool002Gooooo00?o0000ooooooooool0Boooool00ol00?ooooooooooo`0Doooo
o`03o`000?oooooooooo00oooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1;oooo
o`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0AOooool01?oo003ooooooooooooo0003
ooooo`03ool00?oooooooooo02?ooooo00Goo`00ooooooooooooooooool00002ooooo`03ool00?oo
oooooooo04Sooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`1;ooooo`05o`00oooo
003ooooooooooooo00004_ooool00ol0003oooooooooo`0@ooooo`06o`00oooo003ooooooooooooo
003o003oCOooool00ol0003oooooooooo`0Fooooo`005oooool3o`0000Cooooo0_l00005ooooo`03
o`000?oooooooooo04_ooooo00Go003oooooooooooooooooo`00o`0Booooo`03o`000?oooooooooo
01Cooooo00?o003oooooooooool0Boooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo
04Gooooo00Coo`00ooooooooooooo`000oooool00ooo003oooooooooo`0Sooooo`05ool00?oooooo
oooooooooooo00000_ooool00ooo003oooooooooo`18ooooo`03o`000?oooooooooo01gooooo0ol0
0004ooooo`;o00001?ooool00ol0003oooooooooo`1;ooooo`06o`00oooo003ooooooooooooo003o
003o4Oooool00ol0003oooooooooo`0Aooooo`05ool00?ooooooooooool00?l00?l0COooool00ol0
003oooooooooo`0Fooooo`006?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooooooool0Boooool01Ol00?oooooooooooooooooo003o01;ooooo00?o0000
ooooooooool03oooool00ol00?ooooooooooo`1@ooooo`03o`000?oooooooooo02[ooooo00?o0000
ooooooooool0AOooool01?oo003ooooooooooooo0003ooooo`03ool00?oooooooooo02?ooooo00Go
o`00ooooooooooooooooool00002ooooo`03ool00?oooooooooo04Sooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooooooo
ool0Boooool01_l00?ooo`00ooooooooooooo`00o`00oa7ooooo00?o0000ooooooooool04?ooool0
1Ol00?ooo`00ooooooooooooo`0004kooooo00?o0000ooooooooool05_ooool001Sooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00004ooooo`;o0000D?ooool00ol00?oooooooooo
o`0@ooooo`03o`000?oooooooooo00oooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`1:ooooo`;o0000;?ooool00ol0003oooooooooo`15ooooo`04ool00?ooooooooooool000?ooooo
00?oo`00ooooooooool08oooool01Ooo003oooooooooooooooooo`0000;ooooo00?oo`00oooooooo
ool0B?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00000oooool2o`0004gooooo00Goo`00ooooooooooooo`00o`00o`0Aooooo`03o`000?oooooo
oooo013ooooo00Ko003oool00?ooooooooooool00?l00?m;ooooo`?o00006?ooool001Sooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo04_ooooo
00?o003oooooooooool05?ooool00ol0003oooooooooo`0?ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool0Boooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo04Gooooo
00Coo`00ooooooooooooo`000oooool00ooo003oooooooooo`0Sooooo`05ool00?oooooooooooooo
oooo00000_ooool00ooo003oooooooooo`18ooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool00_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo04_ooooo00Go003o
ool00?ooooooooooool0000Booooo`03o`000?oooooooooo013ooooo00Ko003oool00?oooooooooo
ool00?l00?m=ooooo`03o`000?oooooooooo01Kooooo000Hooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1;ooooo`05o`00oooooooooooooooo
ool00?l04_ooool00ol0003oooooooooo`0Dooooo`03o`00oooooooooooo04_ooooo00?o0000oooo
ooooool0:_ooool2o`0004Gooooo0_oo0002ooooo`05ool00?oooooooooooooooooo00009Oooool0
1_oo003oooooooooooooooooo`00ooooo`;oo`00B_ooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`1;ooooo`06
o`00oooo003ooooooooooooo003o003o4Oooool00ol0003oooooooooo`0Aooooo`05ool00?oooooo
ooooool00?l00?l0COooool00ol0003oooooooooo`0Fooooo`005oooool2o`0000Cooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`1;ooooo`05o`00ooooooooooooooooool00?l0
4_ooool00ol0003oooooooooo`0@ooooo`03o`00oooooooooooo04oooooo00?o0000ooooooooool0
:_ooool00ol0003oooooooooo`14ooooo`;oo`000_ooool01Ooo003oooooooooooooooooo`0002Go
oooo00Koo`00ooooooooooooooooool00?ooool2ool004[ooooo00?o0000ooooooooool07Oooool2
o`0000Cooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`1;ooooo`06o`00oooo
003ooooooooooooo003o003o4Oooool00ol0003oooooooooo`0@ooooo`05o`00oooo003ooooooooo
oooo0000C_ooool00ol0003oooooooooo`0Fooooo`006?ooool00ol0003oooooooooo`03ooooo`;o
00001Oooool00ol0003oooooooooo`1?ooooo`03o`00oooooooooooo013ooooo00?o0000oooooooo
ool04?ooool00ol00?ooooooooooo`1>ooooo`;o0000;?ooool00ol0003oooooooooo`18ooooo`05
ool00?oooooooooooooooooo00009Oooool01Ooo003oooooooooooooooooo`0004gooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`03ooooo`;o00001?ooool2o`0004gooooo00Goo`00
ooooooooooooo`00o`00o`0Aooooo`03o`000?oooooooooo013ooooo00Ko003oool00?oooooooooo
ool00?l00?m<ooooo`;o00006?ooool002Gooooo00?o0000ooooooooool0Boooool00ol00?oooooo
ooooo`0Dooooo`03o`000?oooooooooo013ooooo00Go003oooooooooooooooooo`00o`1=ooooo`03
o`000?oooooooooo02[ooooo00?o0000ooooooooool0B?ooool01Ooo003oooooooooooooooooo`00
02Gooooo00Goo`00ooooooooooooooooool0001=ooooo`03o`000?oooooooooo02[ooooo00?o0000
ooooooooool0Boooool01Ol00?ooo`00ooooooooooooo`0001;ooooo00?o0000ooooooooool04?oo
ool01_l00?ooo`00ooooooooooooo`00o`00odgooooo00?o0000ooooooooool05_ooool002Gooooo
00?o0000ooooooooool0Boooool01Ol00?oooooooooooooooooo003o01;ooooo00?o0000oooooooo
ool05?ooool00ol00?ooooooooooo`1;ooooo`03o`000?oooooooooo02[ooooo00?o0000oooooooo
ool0B?ooool01Ooo003oooooooooooooooooo`0002Gooooo00Goo`00ooooooooooooooooool0001=
ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0Boooool01_l00?ooo`00oooooooo
ooooo`00o`00oa7ooooo00?o0000ooooooooool04Oooool01Ooo003ooooooooooooo003o003o04go
oooo00?o0000ooooooooool05_ooool002Gooooo00?o0000ooooooooool0Boooool01Ol00?oooooo
oooooooooooo003o01;ooooo00?o0000ooooooooool04?ooool01Ol00?oooooooooooooooooo003o
04gooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`18ooooo`05ool00?oooooooooo
oooooooo00009Oooool01Ooo003oooooooooooooooooo`0004gooooo00?o0000ooooooooool0:_oo
ool00ol0003oooooooooo`1;ooooo`06o`00oooo003ooooooooooooo003o003o4Oooool00ol0003o
ooooooooo`0@ooooo`05o`00oooo003ooooooooooooo0000C_ooool00ol0003oooooooooo`0Foooo
o`009Oooool00ol0003oooooooooo`1?ooooo`03o`00oooooooooooo013ooooo00?o0000oooooooo
ool04?ooool00ol00?ooooooooooo`1>ooooo`;o0000;?ooool2o`0004Wooooo00Goo`00oooooooo
ooooooooool0000Uooooo`05ool00?oooooooooooooooooo0000COooool00ol0003oooooooooo`0Z
ooooo`;o0000COooool01Ooo003ooooooooooooo003o003o017ooooo00?o0000ooooooooool04?oo
ool01Ol00?ooo`00ooooooooooooo`0004gooooo0_l0000Hooooo`009Oooool00ol0003ooooooooo
o`1;ooooo`03o`00oooooooooooo01Cooooo00?o0000ooooooooool04?ooool01Ol00?oooooooooo
oooooooo003o04gooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`18ooooo`05ool0
0?oooooooooooooooooo00009Oooool01Ooo003oooooooooooooooooo`0004gooooo00?o0000oooo
ooooool0:_ooool00ol0003oooooooooo`1;ooooo`05o`00oooo003ooooooooooooo00004_ooool0
0ol0003oooooooooo`0@ooooo`05o`00oooo003ooooooooooooo0000C_ooool00ol0003ooooooooo
o`0Fooooo`009Oooool00ol0003oooooooooo`1;ooooo`05o`00ooooooooooooooooool00?l04_oo
ool00ol0003oooooooooo`0Dooooo`03o`00oooooooooooo04_ooooo00?o0000ooooooooool0:_oo
ool00ol0003oooooooooo`18ooooo`05ool00?oooooooooooooooooo00009Oooool01Ooo003ooooo
ooooooooooooo`0004gooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`1;ooooo`06
o`00oooo003ooooooooooooo003o003o4Oooool00ol0003oooooooooo`0Aooooo`04ool00?oooooo
ooooool004kooooo00?o0000ooooooooool05_ooool002Gooooo00?o0000ooooooooool0Boooool0
1Ol00?oooooooooooooooooo003o01;ooooo00?o0000ooooooooool04?ooool01Ol00?oooooooooo
oooooooo003o04gooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`18ooooo`05ool0
0?oooooooooooooooooo00009Oooool01Ooo003oooooooooooooooooo`0004gooooo00?o0000oooo
ooooool0:_ooool00ol0003oooooooooo`1;ooooo`06o`00oooo003ooooooooooooo003o003o4Ooo
ool00ol0003oooooooooo`0@ooooo`05o`00oooo003ooooooooooooo0000C_ooool00ol0003ooooo
ooooo`0Fooooo`009Oooool00ol0003oooooooooo`1?ooooo`03o`00oooooooooooo013ooooo00?o
0000ooooooooool04?ooool01Ol00?oooooooooooooooooo003o04cooooo0_l0000/ooooo`03o`00
0?oooooooooo04Sooooo00Goo`00ooooooooooooooooool0000Uooooo`05ool00?oooooooooooooo
oooo0000COooool00ol0003oooooooooo`0Zooooo`;o0000COooool01Ooo003ooooooooooooo003o
003o017ooooo00?o0000ooooooooool04?ooool01Ol00?ooo`00ooooooooooooo`0004gooooo0_l0
000Hooooo`009Oooool00ol0003oooooooooo`1;ooooo`03o`00oooooooooooo01Cooooo00?o0000
ooooooooool04?ooool01Ol00?oooooooooooooooooo003o04gooooo00?o0000ooooooooool0:_oo
ool00ol0003oooooooooo`18ooooo`05ool00?oooooooooooooooooo00009Oooool01Ooo003ooooo
ooooooooooooo`0004gooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`1;ooooo`05
o`00oooo003ooooooooooooo00004_ooool00ol0003oooooooooo`0@ooooo`05o`00oooo003ooooo
oooooooo0000C_ooool00ol0003oooooooooo`0Fooooo`009Oooool00ol0003oooooooooo`1;oooo
o`05o`00ooooooooooooooooool00?l04_ooool00ol0003oooooooooo`0Dooooo`03o`00oooooooo
oooo04_ooooo00?o0000ooooooooool0:_ooool2o`0004Wooooo00Goo`00ooooooooooooooooool0
000Uooooo`05ool00?oooooooooooooooooo0000COooool00ol0003oooooooooo`0Zooooo`03o`00
0?oooooooooo04_ooooo00Ko003oool00?ooooooooooool00?l00?lAooooo`03o`000?oooooooooo
017ooooo00Coo`00ooooooooooooo`00C_ooool00ol0003oooooooooo`0Fooooo`009Oooool00ol0
003oooooooooo`1;ooooo`05o`00ooooooooooooooooool00?l04_ooool00ol0003oooooooooo`0@
ooooo`05o`00ooooooooooooooooool00?l0COooool00ol0003oooooooooo`0Zooooo`03o`000?oo
oooooooo04Sooooo00Goo`00ooooooooooooooooool0000Uooooo`05ool00?oooooooooooooooooo
0000COooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo04_ooooo00Ko003oool00?oo
ooooooooool00?l00?lAooooo`03o`000?oooooooooo017ooooo00Coo`00ooooooooooooo`00C_oo
ool00ol0003oooooooooo`0Fooooo`009Oooool00ol0003oooooooooo`1?ooooo`03o`00oooooooo
oooo013ooooo00?o0000ooooooooool04?ooool00ol00?ooooooooooo`1>ooooo`;o0000;?ooool0
0ol0003oooooooooo`18ooooo`05ool00?oooooooooooooooooo00009Oooool01Ooo003ooooooooo
ooooooooo`0004gooooo00?o0000ooooooooool0:_ooool2o`0004gooooo00Coo`00oooooooooooo
o`004_ooool00ol0003oooooooooo`0@ooooo`05o`00oooo003ooooooooooooo0000COooool2o`00
01Sooooo000Uooooo`03o`000?oooooooooo04_ooooo00?o003oooooooooool05?ooool00ol0003o
ooooooooo`0@ooooo`05o`00ooooooooooooooooool00?l0COooool00ol0003oooooooooo`0Loooo
o`?o00001?ooool2o`0000Gooooo00?o0000ooooooooool0B?ooool01Ooo003ooooooooooooooooo
o`0002Gooooo00Goo`00ooooooooooooooooool0001=ooooo`03o`000?oooooooooo02[ooooo00?o
0000ooooooooool0Boooool01Ol00?ooo`00ooooooooooooo`0001;ooooo00?o0000ooooooooool0
4?ooool01Ol00?ooo`00ooooooooooooo`0004kooooo00?o0000ooooooooool05_ooool001Oooooo
0ol00003ooooo`?o00001Oooool00ol0003oooooooooo`1;ooooo`05o`00ooooooooooooooooool0
0?l04_ooool00ol0003oooooooooo`0Dooooo`03o`00oooooooooooo04_ooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooo
ooooool0B?ooool01Ooo003oooooooooooooooooo`0002Gooooo00Goo`00ooooooooooooooooool0
001=ooooo`03o`000?oooooooooo01gooooo0ol00003ooooo`?o00001?ooool00ol0003ooooooooo
o`1;ooooo`05o`00oooo003ooooooooooooo00004_ooool00ol0003oooooooooo`0@ooooo`05o`00
oooo003ooooooooooooo0000C_ooool00ol0003oooooooooo`0Fooooo`006?ooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1;ooooo`05
o`00ooooooooooooooooool00?l04_ooool00ol0003oooooooooo`0@ooooo`05o`00oooooooooooo
ooooool00?l0COooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`18ooooo`05ool00?oooooooooooooooooo0000
9Oooool01Ooo003oooooooooooooooooo`0004gooooo00?o0000ooooooooool07_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00001>ooooo`04ool00?oooooo
ooooool001;ooooo00?o0000ooooooooool04Oooool01?oo003ooooooooooooo001>ooooo`03o`00
0?oooooooooo01Kooooo000Hooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_oo
ool2o`00053ooooo00?o003oooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`00oooo
oooooooo04kooooo0_l0000Oooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000
1?ooool2o`0004Wooooo00Goo`00ooooooooooooooooool0000Uooooo`05ool00?oooooooooooooo
oooo0000C?ooool2o`00023ooooo00?o0000ooooooooool01Oooool01?l0003oooooooooooooool2
o`0004gooooo00Coo`00ooooooooooooo`004_ooool00ol0003oooooooooo`0@ooooo`05o`00oooo
003ooooooooooooo0000C?ooool3o`0001Sooooo000Hooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`1;ooooo`03o`00oooooooooooo01Cooooo00?o
0000ooooooooool04?ooool01Ol00?oooooooooooooooooo003o04gooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool0B?ooool01Ooo003oooooooooooooooooo`0002Gooooo00Goo`00ooooooooooooooooool0001=
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooo
oooo000004kooooo00Coo`00ooooooooooooo`004_ooool00ol0003oooooooooo`0@ooooo`05o`00
oooo003ooooooooooooo0000C_ooool00ol0003oooooooooo`0Fooooo`006?ooool01?l0003ooooo
ooooooooool4o`0000Gooooo00?o0000ooooooooool0Boooool01Ol00?oooooooooooooooooo003o
01;ooooo00?o0000ooooooooool05?ooool00ol00?ooooooooooo`1;ooooo`03o`000?oooooooooo
01cooooo0_l00004ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0B?ooool0
1Ooo003oooooooooooooooooo`0002Gooooo00Goo`00ooooooooooooooooool0001=ooooo`03o`00
0?oooooooooo01kooooo00Co0000oooooooooooooooo1?l00004ooooo`03o`000?oooooooooo04co
oooo00Coo`00ooooooooooooo`004_ooool00ol0003oooooooooo`0@ooooo`05o`00oooo003ooooo
oooooooo0000C_ooool00ol0003oooooooooo`0Fooooo`005oooool2o`0000?ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`1;ooooo`05o`00ooooooooooooooooool00?l04_ooool0
0ol0003oooooooooo`0Dooooo`03o`00oooooooooooo04_ooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`03ooooo`;o00001Oooool00ol0003oooooooooo`18ooooo`05ool00?oooooo
oooooooooooo00009Oooool01Ooo003oooooooooooooooooo`0004gooooo00?o0000ooooooooool0
7Oooool2o`0000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1<ooooo`04ool0
0?ooooooooooool001;ooooo00?o0000ooooooooool04Oooool01?oo003ooooooooooooo001>oooo
o`03o`000?oooooooooo01Kooooo000Hooooo`04o`000?ooooooooooooooo`Go00001?ooool00ol0
003oooooooooo`1?ooooo`03o`00oooooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0
0?ooooooooooo`1>ooooo`;o0000;?ooool00ol0003oooooooooo`18ooooo`05ool00?oooooooooo
oooooooo00009Oooool01Ooo003oooooooooooooooooo`0004gooooo00?o0000ooooooooool07_oo
ool01?l0003oooooooooooooool5o`0000?ooooo0_l0001=ooooo`04ool00?ooooooooooool001;o
oooo00?o0000ooooooooool04?ooool01Ol00?ooo`00ooooooooooooo`0004gooooo0_l0000Hoooo
o`009Oooool00ol0003oooooooooo`1;ooooo`03o`00oooooooooooo01Cooooo00?o0000oooooooo
ool04?ooool01Ol00?oooooooooooooooooo003o04gooooo00?o0000ooooooooool0:_ooool00ol0
003oooooooooo`18ooooo`05ool00?oooooooooooooooooo00009Oooool01Ooo003ooooooooooooo
ooooo`0004gooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`1<ooooo`04ool00?oo
ooooooooool001;ooooo00?o0000ooooooooool04Oooool01?oo003ooooooooooooo001>ooooo`03
o`000?oooooooooo01Kooooo000Uooooo`03o`000?oooooooooo04_ooooo00Go003ooooooooooooo
ooooo`00o`0Booooo`03o`000?oooooooooo013ooooo00Go003oooooooooooooooooo`00o`1=oooo
o`03o`000?oooooooooo02[ooooo0_l00019ooooo`05ool00?oooooooooooooooooo00009Oooool0
1Ooo003oooooooooooooooooo`0004gooooo00?o0000ooooooooool0:_ooool00ol0003ooooooooo
o`1<ooooo`04ool00?ooooooooooool001;ooooo00?o0000ooooooooool04Oooool01?oo003ooooo
oooooooo001>ooooo`03o`000?oooooooooo01Kooooo000Uooooo`03o`000?oooooooooo04_ooooo
00Go003oooooooooooooooooo`00o`0Booooo`03o`000?oooooooooo01Cooooo00?o003ooooooooo
ool0Boooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo04Sooooo00Goo`00oooooooo
ooooooooool0000Uooooo`05ool00?oooooooooooooooooo0000COooool00ol0003oooooooooo`0Z
ooooo`03o`000?oooooooooo04cooooo00Coo`00ooooooooooooo`004_ooool00ol0003ooooooooo
o`0Aooooo`04ool00?ooooooooooool004kooooo00?o0000ooooooooool05_ooool002Gooooo00?o
0000ooooooooool0Coooool00ol00?ooooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o
003oooooooooool0C_ooool2o`0002cooooo00?o0000ooooooooool0B?ooool01Ooo003ooooooooo
ooooooooo`0002Gooooo00Goo`00ooooooooooooooooool0001=ooooo`03o`000?oooooooooo02[o
oooo0_l0001=ooooo`04ool00?ooooooooooool001;ooooo00?o0000ooooooooool04Oooool01?oo
003ooooooooooooo001=ooooo`;o00006?ooool002Gooooo00?o0000ooooooooool0Boooool00ol0
0?ooooooooooo`0Dooooo`03o`000?oooooooooo013ooooo00Go003oooooooooooooooooo`00o`1=
ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0B?ooool01Ooo003ooooooooooooo
ooooo`0002Gooooo00Goo`00ooooooooooooooooool0001=ooooo`03o`000?oooooooooo02[ooooo
00?o0000ooooooooool0C?ooool01?oo003ooooooooooooo000Booooo`03o`000?oooooooooo017o
oooo00Coo`00ooooooooooooo`00C_ooool00ol0003oooooooooo`0Fooooo`009Oooool00ol0003o
ooooooooo`1;ooooo`05o`00ooooooooooooooooool00?l04_ooool00ol0003oooooooooo`0@oooo
o`05o`00ooooooooooooooooool00?l0COooool00ol0003oooooooooo`0Zooooo`03o`000?oooooo
oooo04Sooooo00Goo`00ooooooooooooooooool0000Uooooo`05ool00?oooooooooooooooooo0000
COooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo04cooooo00Coo`00oooooooooooo
o`004_ooool00ol0003oooooooooo`0Aooooo`04ool00?ooooooooooool004kooooo00?o0000oooo
ooooool05_ooool002Gooooo00?o0000ooooooooool0Boooool01Ol00?oooooooooooooooooo003o
01;ooooo00?o0000ooooooooool04oooool00ol00?ooooooooooo`1<ooooo`03o`000?oooooooooo
02[ooooo00?o0000ooooooooool0B?ooool01Ooo003oooooooooooooooooo`0002Gooooo00Goo`00
ooooooooooooooooool0001=ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0C?oo
ool01?oo003ooooooooooooo000Booooo`03o`000?oooooooooo017ooooo00Coo`00oooooooooooo
o`00C_ooool00ol0003oooooooooo`0Fooooo`009Oooool00ol0003oooooooooo`1?ooooo`03o`00
oooooooooooo013ooooo00?o0000ooooooooool04?ooool00ol00?ooooooooooo`1>ooooo`;o0000
;?ooool2o`0004Wooooo00Goo`00ooooooooooooooooool0000Uooooo`05ool00?oooooooooooooo
oooo0000COooool00ol0003oooooooooo`0Zooooo`;o0000COooool01?oo003ooooooooooooo000B
ooooo`03o`000?oooooooooo017ooooo00Coo`00ooooooooooooo`00COooool2o`0001Sooooo000U
ooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool04?ooool01?l00?ooooooooooool0
0?m>ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0B?ooool01Ooo003ooooooooo
ooooooooo`0002Gooooo00Goo`00ooooooooooooooooool0001=ooooo`03o`000?oooooooooo02[o
oooo00?o0000ooooooooool0C?ooool00ooo003oooooool00002ool0017ooooo00?o0000oooooooo
ool04?ooool3ool00003oooooooo003ooooo04gooooo00?o0000ooooooooool05_ooool002Gooooo
00?o0000ooooooooool0Boooool01Ol00?oooooooooooooooooo003o01;ooooo00?o0000oooooooo
ool04?ooool01?l00?ooooooooooool00?m>ooooo`03o`000?oooooooooo02[ooooo00?o0000oooo
ooooool0B?ooool01Ooo003oooooooooooooooooo`0002Gooooo00Goo`00ooooooooooooooooool0
001=ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0C?ooool00ooo003oooooool0
0002ool0017ooooo00?o0000ooooooooool04?ooool3ool00003oooooooo003ooooo04gooooo00?o
0000ooooooooool05_ooool002Gooooo00?o0000ooooooooool0Boooool01Ol00?oooooooooooooo
oooo003o01;ooooo00?o0000ooooooooool04oooool00ol00?ooooooooooo`1<ooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool0B?ooool01Ooo003oooooooooooooooooo`0002Gooooo
00Goo`00ooooooooooooooooool0001=ooooo`03o`000?oooooooooo02[ooooo00?o0000oooooooo
ool0C?ooool00ooo003oooooool00002ool0017ooooo00?o0000ooooooooool04?ooool3ool00003
oooooooo003ooooo04gooooo00?o0000ooooooooool05_ooool002Gooooo00?o0000ooooooooool0
Boooool01Ol00?oooooooooooooooooo003o01;ooooo00?o0000ooooooooool04?ooool00ol00?oo
ooooooooo`1>ooooo`;o0000;?ooool00ol0003oooooooooo`18ooooo`05ool00?oooooooooooooo
oooo00009Oooool01Ooo003oooooooooooooooooo`0004gooooo00?o0000ooooooooool0:_ooool2
o`0004gooooo00Coo`00oooooooooooo003o4_ooool00ol0003oooooooooo`0Aooooo`04o`00oooo
ooooooooool004gooooo0_l0000Hooooo`005_ooool5o`0000?ooooo0_l00005ooooo`03o`000?oo
oooooooo06;ooooo00?o0000ooooooooool04?ooool01?l00?ooooooooooool00?m>ooooo`03o`00
0?oooooooooo02[ooooo00?o0000ooooooooool0B?ooool01Ooo003oooooooooooooooooo`0002Go
oooo00Goo`00ooooooooooooooooool0001=ooooo`03o`000?oooooooooo01cooooo1Ol00003oooo
o`;o00001?ooool00ol0003oooooooooo`1<ooooo`03ool00?oooooooooo01?ooooo00?o0000oooo
ooooool04Oooool01?l00?oooooooooooooo001>ooooo`03o`000?oooooooooo01Kooooo000Goooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`1;ooooo`04o`00ooooooooooooo`00oa?ooooo00?o0000ooooooooool04?ooool01?l00?oooooo
ooooool00?m>ooooo`03o`000?oooooooooo02[ooooo0_l00019ooooo`05ool00?oooooooooooooo
oooo00009Oooool01Ooo003oooooooooooooooooo`0004gooooo00?o0000ooooooooool07Oooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0
Boooool3ool00003ooooool00?oooooo017ooooo00?o0000ooooooooool04Oooool00ol00?oooooo
ool00002ool004gooooo00?o0000ooooooooool05_ooool001Sooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo04_ooooo00Co003ooooooooooooo
003o4oooool00ol0003oooooooooo`0Cooooo`03o`00oooooooooooo04cooooo00?o0000oooooooo
ool0:_ooool00ol0003oooooooooo`18ooooo`05ool00?oooooooooooooooooo00009Oooool01Ooo
003oooooooooooooooooo`0004gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0Boooool3ool00003ooooool0
0?oooooo017ooooo00?o0000ooooooooool04oooool3ool004gooooo00?o0000ooooooooool05_oo
ool001Wooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00;ooooo0_l0
001<ooooo`04o`00ooooooooooooo`00oa?ooooo00?o0000ooooooooool04?ooool00ol00?oooooo
ooooo`1>ooooo`;o0000;?ooool00ol0003oooooooooo`18ooooo`05ool00?oooooooooooooooooo
00009Oooool01Ooo003oooooooooooooooooo`0004gooooo00?o0000ooooooooool07oooool01Ol0
003ooooooooooooooooo000000;ooooo00Co0000oooooooooooooooo0_l0001<ooooo`?oo`0000?o
ooooo`00ooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`00ooooooooo`0000;oo`00Booo
ool3o`0001Sooooo000Fooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool04?ooool01?l00?oooooo
ooooool00?m>ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0B?ooool01Ooo003o
ooooooooooooooooo`0002Gooooo00Goo`00ooooooooooooooooool0001=ooooo`03o`000?oooooo
oooo01cooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo
00?o0000ooooooooool0H_ooool00ol0003oooooooooo`0Aooooo`04o`00ooooooooooooo`00odko
oooo00?o0000ooooooooool05_ooool001Kooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0Boooool01?l00?ooooooooooool00?lC
ooooo`03o`000?oooooooooo013ooooo00Co003ooooooooooooo003oC_ooool00ol0003ooooooooo
o`0Zooooo`03o`000?oooooooooo04Sooooo00Goo`00ooooooooooooooooool0000Uooooo`05ool0
0?oooooooooooooooooo0000COooool00ol0003oooooooooo`0Looooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo04cooooo00Co003o
oooooooooooo003o4_ooool00ol0003oooooooooo`0Aooooo`04o`00ooooooooooooo`00odkooooo
00?o0000ooooooooool05_ooool001Oooooo0ol00004ooooo`;o00001Oooool00ol0003ooooooooo
o`1;ooooo`04o`00ooooooooooooo`00oa?ooooo00?o0000ooooooooool04oooool00ol00?oooooo
ooooo`1<ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0B?ooool01Ooo003ooooo
ooooooooooooo`0002Gooooo00Goo`00ooooooooooooooooool0001=ooooo`03o`000?oooooooooo
01gooooo0ol00004ooooo`;o00001?ooool00ol0003oooooooooo`1<ooooo`04o`00oooooooooooo
o`00oa;ooooo00?o0000ooooooooool05?ooool00ol00?ooooooooooo`1<ooooo`03o`000?oooooo
oooo01Kooooo000Uooooo`03o`000?oooooooooo04_ooooo00Co003ooooooooooooo003o4oooool0
0ol0003oooooooooo`0@ooooo`03o`00oooooooooooo04kooooo0_l0000/ooooo`;o0000BOooool0
1Ooo003oooooooooooooooooo`0002Gooooo00Goo`00ooooooooooooooooool0001=ooooo`03o`00
0?oooooooooo02[ooooo0_l0001=ooooo`04o`00ooooooooooooo`00oa;ooooo00?o0000oooooooo
ool04Oooool00ol00?ooooooooooo`1>ooooo`;o00006?ooool002Gooooo00?o0000ooooooooool0
H_ooool00ol0003oooooooooo`0@ooooo`04o`00ooooooooooooo`00odkooooo00?o0000oooooooo
ool0:_ooool00ol0003oooooooooo`18ooooo`05ool00?oooooooooooooooooo00009Oooool01Ooo
003oooooooooooooooooo`0004gooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`1R
ooooo`03o`000?oooooooooo017ooooo00Co003ooooooooooooo003oC_ooool00ol0003ooooooooo
o`0Fooooo`009Oooool00ol0003oooooooooo`1<ooooo`03o`00oooooooo003o01?ooooo00?o0000
ooooooooool04?ooool01?l00?ooooooooooool00?m>ooooo`03o`000?oooooooooo02[ooooo00?o
0000ooooooooool0B?ooool01Ooo003oooooooooooooooooo`0002Gooooo00Goo`00oooooooooooo
ooooool0001=ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0C?ooool01?l00?oo
ooooooooool00?lBooooo`03o`000?oooooooooo017ooooo00Co003ooooooooooooo003oC_ooool0
0ol0003oooooooooo`0Fooooo`009Oooool00ol0003oooooooooo`1<ooooo`03o`00oooooooo003o
01?ooooo00?o0000ooooooooool04oooool00ol00?ooooooooooo`1<ooooo`03o`000?oooooooooo
01cooooo0ol00003ooooo`?o00001Oooool00ol0003oooooooooo`18ooooo`05ool00?oooooooooo
oooooooo00009Oooool01Ooo003oooooooooooooooooo`0004gooooo00?o0000ooooooooool0:_oo
ool00ol0003oooooooooo`1<ooooo`04o`00ooooooooooooo`00oa;ooooo00?o0000ooooooooool0
5?ooool00ol00?ooooooooooo`1<ooooo`03o`000?oooooooooo01Kooooo000Uooooo`03o`000?oo
oooooooo04cooooo00?o003oooooool00?l04oooool00ol0003oooooooooo`0@ooooo`03o`00oooo
oooooooo04kooooo0_l0000Oooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo04Sooooo00Goo`00ooooooooooooooooool0000Uooooo`05
ool00?oooooooooooooooooo0000COooool00ol0003oooooooooo`0Zooooo`;o0000COooool01?l0
0?ooooooooooool00?lBooooo`03o`000?oooooooooo017ooooo00?o003oooooooooool0C_ooool2
o`0001Sooooo000Uooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool04?ooool01?l0
0?ooooooooooool00?m>ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo04Sooooo00Goo`00ooooooooooooooooool0
000Uooooo`05ool00?oooooooooooooooooo0000COooool00ol0003oooooooooo`0Zooooo`03o`00
0?oooooooooo06;ooooo00?o0000ooooooooool04Oooool01?l00?ooooooooooool00?m>ooooo`03
o`000?oooooooooo01Kooooo000Uooooo`03o`000?oooooooooo04cooooo00?o003oooooool00?l0
4oooool00ol0003oooooooooo`0Aooooo`03o`00oooooooo003o04kooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo0_l00019ooooo`05ool0
0?oooooooooooooooooo00009Oooool01Ooo003oooooooooooooooooo`0004cooooo0_l0000/oooo
o`03o`000?oooooooooo04cooooo00Co003ooooooooooooo003o4_ooool00ol0003oooooooooo`0A
ooooo`04o`00ooooooooooooo`00odkooooo00?o0000ooooooooool05_ooool002Gooooo00?o0000
ooooooooool0C?ooool00ol00?ooooooo`00o`0Cooooo`03o`000?oooooooooo01?ooooo00?o003o
ooooooooool0C?ooool00ol0003oooooooooo`0Mooooo`04o`000?ooooooooooooooo`Co00001Ooo
ool00ol0003oooooooooo`18ooooo`05ool00?oooooooooooooooooo00009Oooool01Ooo003ooooo
ooooooooooooo`0004gooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`1<ooooo`04
o`00ooooooooooooo`00oa;ooooo00?o0000ooooooooool05?ooool00ol00?ooooooooooo`1<oooo
o`03o`000?oooooooooo01Kooooo000Uooooo`03o`000?oooooooooo04cooooo00?o003oooooool0
0?l04oooool00ol0003oooooooooo`0Aooooo`03o`00oooooooooooo04gooooo0_l0000Nooooo`;o
00000oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04Sooooo00Goo`00oooooooo
ooooooooool0000Uooooo`05ool00?oooooooooooooooooo0000COooool00ol0003oooooooooo`0Z
ooooo`;o0000COooool01?l00?ooooooooooool00?lBooooo`03o`000?oooooooooo017ooooo00?o
003oooooooooool0C_ooool2o`0001Sooooo000Uooooo`03o`000?oooooooooo06;ooooo00?o0000
ooooooooool04Oooool00ol00?ooooooo`00o`1>ooooo`03o`000?oooooooooo01gooooo00Co0000
oooooooooooooooo1Ol00004ooooo`03o`000?oooooooooo04Sooooo00Goo`00oooooooooooooooo
ool0000Uooooo`05ool00?oooooooooooooooooo0000COooool00ol0003oooooooooo`0Zooooo`03
o`000?oooooooooo06;ooooo00?o0000ooooooooool04Oooool01?l00?ooooooooooool00?m>oooo
o`03o`000?oooooooooo01Kooooo000Uooooo`03o`000?oooooooooo04cooooo00?o003oooooool0
0?l04oooool00ol0003oooooooooo`0Aooooo`03o`00oooooooo003o04kooooo00?o0000oooooooo
ool0:_ooool00ol0003oooooooooo`18ooooo`05ool00?oooooooooooooooooo00009Oooool01Ooo
003oooooooooooooooooo`0004gooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`1<
ooooo`04o`00ooooooooooooo`00oa;ooooo00?o0000ooooooooool04Oooool01?l00?oooooooooo
ool00?m>ooooo`03o`000?oooooooooo01Kooooo000Uooooo`03o`000?oooooooooo04cooooo00?o
003oooooool00?l04oooool00ol0003oooooooooo`0Cooooo`03o`00oooooooooooo04cooooo00?o
0000ooooooooool0:_ooool00ol0003oooooooooo`18ooooo`05ool00?oooooooooooooooooo0000
9Oooool01Ooo003oooooooooooooooooo`0004gooooo00?o0000ooooooooool0:_ooool00ol0003o
ooooooooo`1<ooooo`04o`00ooooooooooooo`00oa;ooooo00?o0000ooooooooool05?ooool00ol0
0?ooooooooooo`1<ooooo`03o`000?oooooooooo01Kooooo000Uooooo`03o`000?oooooooooo04co
oooo00?o003oooooool00?l04oooool00ol0003oooooooooo`0Aooooo`03o`00oooooooooooo04go
oooo0_l0000/ooooo`;o0000BOooool01Ooo003oooooooooooooooooo`0002Gooooo00Goo`00oooo
ooooooooooooool0001=ooooo`03o`000?oooooooooo02[ooooo0_l0001=ooooo`04o`00oooooooo
ooooo`00oa;ooooo00?o0000ooooooooool04Oooool00ol00?ooooooooooo`1>ooooo`;o00006?oo
ool001Kooooo1Ol00002ooooo`?o00001Oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooo
oooo017ooooo00?o003oooooool00?l0C_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooo
oooo04Sooooo00Goo`00ooooooooooooooooool0000Uooooo`05ool00?oooooooooooooooooo0000
COooool00ol0003oooooooooo`0Looooo`Go00000_ooool3o`0000Cooooo00?o0000ooooooooool0
H_ooool00ol0003oooooooooo`0Aooooo`03o`00oooooooo003o04oooooo00?o0000ooooooooool0
5_ooool001Oooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0C?ooool00ol00?ooooooooooo`0Cooooo`03o`000?oooooooooo017o
oooo00?o003oooooool00?l0C_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo04So
oooo00Goo`00ooooooooooooooooool0000Uooooo`05ool00?oooooooooooooooooo0000COooool0
0ol0003oooooooooo`0Mooooo`06o`000?ooooooooooo`000?oooooo00000oooool01Ol0003ooooo
oooooooooooo000004kooooo00Co003ooooooooooooo003o4_ooool00ol0003oooooooooo`0Aoooo
o`03o`00oooooooo003o04oooooo00?o0000ooooooooool05_ooool001Sooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04cooooo00?o003oooooool0
0?l04oooool00ol0003oooooooooo`0Cooooo`03o`00oooooooooooo04cooooo00?o0000oooooooo
ool0:_ooool00ol0003oooooooooo`18ooooo`05ool00?oooooooooooooooooo00009Oooool01Ooo
003oooooooooooooooooo`0004gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`05
ooooo`05o`000?ooooooooooooooool00000C_ooool01?l00?ooooooooooool00?lBooooo`03o`00
0?oooooooooo01?ooooo00?o003oooooooooool0COooool00ol0003oooooooooo`0Fooooo`006Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo0_l0001=ooooo`03o`00oooo
oooo003o01?ooooo00?o0000ooooooooool04Oooool00ol00?ooooooooooo`1=ooooo`;o0000;?oo
ool00ol0003oooooooooo`18ooooo`05ool00?oooooooooooooooooo00009Oooool01Ooo003ooooo
ooooooooooooo`0004gooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`04ooooo`04
o`000?ooooooooooooooo`;o0000COooool00ol00?ooooooo`00o`0Cooooo`03o`000?oooooooooo
017ooooo00?o003oooooooooool0COooool3o`0001Sooooo000Fooooo`06o`000?oooooooooooooo
ool0003ooooo1?l00005ooooo`03o`000?oooooooooo04kooooo00?o003oooooooooool04Oooool0
0ol0003oooooooooo`0Aooooo`03o`00oooooooo003o04kooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`18ooooo`05ool00?oooooooooooooooooo00009Oooool01Ooo003ooooooooo
ooooooooo`0004gooooo00?o0000ooooooooool07?ooool01_l0003ooooooooooooooooo0000oooo
o`Co00001?ooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo017ooooo00?o003ooooo
ool00?l0Coooool00ol0003oooooooooo`0Fooooo`005_ooool01ol0003ooooooooooooooooo0000
ooooool000002?ooool00ol0003oooooooooo`1<ooooo`03o`00oooooooooooo01?ooooo00?o0000
ooooooooool04Oooool00ol00?ooooooo`00o`1>ooooo`03o`000?oooooooooo02[ooooo0_l00019
ooooo`05ool00?oooooooooooooooooo00009Oooool01Ooo003oooooooooooooooooo`0004gooooo
00?o0000ooooooooool07?ooool01ol0003ooooooooooooooooo0000ooooool000001oooool00ol0
003oooooooooo`1<ooooo`03o`00oooooooooooo01?ooooo00?o0000ooooooooool04Oooool00ol0
0?ooooooo`00o`1?ooooo`03o`000?oooooooooo01Kooooo000Gooooo`?o00000_ooool5o`0000Co
oooo00?o0000ooooooooool0C?ooool00ol00?ooooooo`00o`0Cooooo`03o`000?oooooooooo01?o
oooo00?o003oooooooooool0C?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo04So
oooo00Goo`00ooooooooooooooooool0000Uooooo`05ool00?oooooooooooooooooo0000COooool0
0ol0003oooooooooo`0Mooooo`?o00000_ooool5o`0000?ooooo00?o0000ooooooooool0C?ooool0
0ol00?ooooooo`00o`0Cooooo`03o`000?oooooooooo01?ooooo00?o003oooooooooool0COooool0
0ol0003oooooooooo`0Fooooo`009Oooool00ol0003oooooooooo`1<ooooo`03o`00oooooooo003o
01?ooooo00?o0000ooooooooool04Oooool00ol00?ooooooooooo`1=ooooo`;o0000;?ooool00ol0
003oooooooooo`18ooooo`05ool00?oooooooooooooooooo00009Oooool01Ooo003ooooooooooooo
ooooo`0004gooooo00?o0000ooooooooool0:_ooool2o`0004kooooo0_l00?lCooooo`03o`000?oo
oooooooo017ooooo00?o003oooooooooool0C_ooool2o`0001Sooooo000Uooooo`03o`000?oooooo
oooo04kooooo00?o003oooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`00oooooooo
003o04kooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`18ooooo`05ool00?oooooo
oooooooooooo00009Oooool01Ooo003oooooooooooooooooo`0004gooooo00?o0000ooooooooool0
:_ooool00ol0003oooooooooo`1>ooooo`03o`00oooooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol00?ooooooo`00o`1?ooooo`03o`000?oooooooooo01Kooooo000Uooooo`03o`000?oo
oooooooo04cooooo00?o003oooooooooool04oooool00ol0003oooooooooo`0Aooooo`03o`00oooo
oooo003o04kooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`18ooooo`05ool00?oo
oooooooooooooooo00009Oooool01Ooo003oooooooooooooooooo`0004gooooo00?o0000oooooooo
ool0:_ooool00ol0003oooooooooo`1=ooooo`03o`00oooooooooooo01;ooooo00?o0000oooooooo
ool04Oooool00ol00?ooooooo`00o`1?ooooo`03o`000?oooooooooo01Kooooo000Uooooo`03o`00
0?oooooooooo04cooooo00?o003oooooool00?l04oooool00ol0003oooooooooo`0Cooooo`03o`00
oooooooooooo04cooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`18ooooo`05ool0
0?oooooooooooooooooo00009Oooool01Ooo003oooooooooooooooooo`0004gooooo00?o0000oooo
ooooool0:_ooool00ol0003oooooooooo`1=ooooo`;o003o4oooool00ol0003oooooooooo`0Coooo
o`03o`00oooooooooooo04gooooo00?o0000ooooooooool05_ooool002Gooooo00?o0000oooooooo
ool0C?ooool00ol00?ooooooo`00o`0Cooooo`03o`000?oooooooooo017ooooo00?o003ooooooooo
ool0COooool2o`0002cooooo0_l00019ooooo`05ool00?oooooooooooooooooo00009Oooool01Ooo
003oooooooooooooooooo`0004gooooo00?o0000ooooooooool0:_ooool2o`0004kooooo0_l00?lC
ooooo`03o`000?oooooooooo01;ooooo00?o003oooooooooool0COooool2o`0001Sooooo000Uoooo
o`03o`000?oooooooooo04kooooo00?o003oooooooooool04Oooool00ol0003oooooooooo`0Aoooo
o`03o`00oooooooo003o04kooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`18oooo
o`05ool00?oooooooooooooooooo00009Oooool01Ooo003oooooooooooooooooo`0004gooooo00?o
0000ooooooooool0:_ooool00ol0003oooooooooo`1>ooooo`03o`00oooooooooooo017ooooo00?o
0000ooooooooool04_ooool2o`00odoooooo00?o0000ooooooooool05_ooool002Gooooo00?o0000
ooooooooool0C?ooool00ol00?ooooooooooo`0Cooooo`03o`000?oooooooooo017ooooo00?o003o
ooooool00?l0C_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo04Sooooo00?oo`00
ooooooooool00_oo000Tooooo`;oo`000oooool00ooo003oooooooooo`1;ooooo`03o`000?oooooo
oooo02[ooooo00?o0000ooooooooool0COooool00ol00?ooooooooooo`0Booooo`03o`000?oooooo
oooo01;ooooo0_l00?m?ooooo`03o`000?oooooooooo01Kooooo000Uooooo`03o`000?oooooooooo
04cooooo00?o003oooooool00?l04oooool00ol0003oooooooooo`0Booooo`03o`00oooooooooooo
04gooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`18ooooo`03ool00?oooooooooo
00;oo`009?ooool2ool000?ooooo00?oo`00ooooooooool0Boooool00ol0003oooooooooo`0Zoooo
o`03o`000?oooooooooo04gooooo0_l00?lCooooo`03o`000?oooooooooo01?ooooo00?o003ooooo
ooooool0COooool00ol0003oooooooooo`0Fooooo`009Oooool00ol0003oooooooooo`1<ooooo`03
o`00oooooooo003o01?ooooo00?o0000ooooooooool04Oooool00ol00?ooooooooooo`1=ooooo`;o
0000;?ooool00ol0003oooooooooo`18ooooo`03ool00?oooooooooo02_ooooo00?oo`00oooooooo
ool0Boooool00ol0003oooooooooo`0Zooooo`;o0000C_ooool2o`00oa?ooooo00?o0000oooooooo
ool04_ooool00ol00?ooooooooooo`1=ooooo`;o00006?ooool002Gooooo00?o0000ooooooooool0
C_ooool00ol00?ooooooooooo`0Aooooo`03o`000?oooooooooo017ooooo0_l00?m?ooooo`03o`00
0?oooooooooo02[ooooo00?o0000ooooooooool0B?ooool00ooo003oooooooooo`0[ooooo`03ool0
0?oooooooooo04_ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`1>ooooo`03o`00
oooooooooooo017ooooo00?o0000ooooooooool04_ooool2o`00odoooooo00?o0000ooooooooool0
5_ooool002Gooooo00?o0000ooooooooool0C?ooool00ol00?ooooooooooo`0Cooooo`03o`000?oo
oooooooo017ooooo0_l00?m?ooooo`03o`000?oooooooooo02[ooooo0_l00019ooooo`03ool00?oo
oooooooo02_ooooo00?oo`00ooooooooool0Boooool00ol0003oooooooooo`0Zooooo`03o`000?oo
oooooooo04gooooo0_l00?lCooooo`03o`000?oooooooooo01;ooooo0_l00?m?ooooo`03o`000?oo
oooooooo01Kooooo000Uooooo`03o`000?oooooooooo04cooooo0_l00?lDooooo`03o`000?oooooo
oooo01;ooooo00?o003oooooooooool0COooool00ol0003oooooooooo`0Zooooo`03o`000?oooooo
oooo04Sooooo00?oo`00ooooooooool0:oooool00ooo003oooooooooo`1;ooooo`03o`000?oooooo
oooo02[ooooo00?o0000ooooooooool0COooool2o`00oa?ooooo00?o0000ooooooooool04oooool0
0ol00?ooooooooooo`1=ooooo`03o`000?oooooooooo01Kooooo000Uooooo`03o`000?oooooooooo
04cooooo0_l00?lDooooo`03o`000?oooooooooo017ooooo00?o003oooooooooool0COooool2o`00
02cooooo00?o0000ooooooooool0B?ooool00ooo003oooooooooo`0[ooooo`03ool00?oooooooooo
04_ooooo00?o0000ooooooooool0:_ooool2o`0004kooooo0_l00?lCooooo`03o`000?oooooooooo
01;ooooo00?o003oooooooooool0COooool2o`0001Sooooo000Gooooo`?o00001?ooool2o`0000Go
oooo00?o0000ooooooooool0COooool00ol00?ooooooooooo`0Booooo`03o`000?oooooooooo017o
oooo0_l00?m?ooooo`03o`000?oooooooooo01_ooooo1Ol00003ooooo`;o00001Oooool00ol0003o
ooooooooo`18ooooo`03ool00?oooooooooo02_ooooo00?oo`00ooooooooool0Boooool00ol0003o
ooooooooo`0Mooooo`?o00001?ooool2o`0000Cooooo00?o0000ooooooooool0C_ooool00ol00?oo
ooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo0_l00?m?ooooo`03o`000?oooooooooo01Ko
oooo000Fooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00004oooo
o`03o`000?oooooooooo04gooooo00?o003oooooooooool04_ooool00ol0003oooooooooo`0Boooo
o`03o`00oooooooooooo04gooooo00?o0000ooooooooool07?ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0B?ooool2ool002_ooooo0_oo
001=ooooo`03o`000?oooooooooo01cooooo00Go0000ooooooooooooooooo`000002ooooo`04o`00
0?ooooooooooo`0000?ooooo00?o0000ooooooooool0COooool00ol00?ooooooooooo`0Booooo`03
o`000?oooooooooo01;ooooo0_l00?m?ooooo`03o`000?oooooooooo01Kooooo000Jooooo`04o`00
0?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1=ooooo`03
o`00oooooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol00?ooooooooooo`1=ooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00004oooo
o`;o0000<?ooool00ol0003oooooooooo`0Fooooo`;oo`005Oooool00ol0003oooooooooo`0Coooo
o`;oo`006?ooool00ol0003oooooooooo`0^ooooo`05o`000?ooooooooooooooool000008_ooool0
1?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool00000Coooool2o`00oa?ooooo
00?o0000ooooooooool04_ooool2o`00odoooooo00?o0000ooooooooool05_ooool001Sooooo0_l0
0003ooooo`04o`000?ooooooooooo`0000Cooooo0_l0001>ooooo`03o`00oooooooooooo01;ooooo
00?o0000ooooooooool0HOooool2o`00023ooooo00Go0000ooooooooooooooooo`000002ooooo`03
o`000?oooooooooo00;ooooo0_l00009ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool00_l0000Pooooo`;o00000oooool01?l0003oooooooooool00003ooooo`;o0000C_ooool2o`00
oa?ooooo00?o0000ooooooooool0HOooool3o`0001Sooooo000Jooooo`04o`000?ooooooooooo`00
00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
02gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo
02gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Kooooo`05o`000?oooooooooo
ooooool000000_ooool01?l0003oooooooooool00004ooooolSo00008_ooool01?l0003ooooooooo
ool00002ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0]ooooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0]ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool05_ooool001Kooooo00Go0000oooooooooooo
ooooo`000002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0Kooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0
003Zooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00003ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool05_ooool001Oooooo0ol00004ooooo`;o0000
1Oooooo;o`0001kooooo0ol00004ooooo`;o0000k?ooool3o`0000Cooooo0_l00004ooooolco0000
6?ooool00?ooooooooooooofooooo`00ooooooooooooooKooooo003ooooooooooooom_ooool00?oo
ooooooooooofooooo`00\
\>"],
  ImageRangeCache->{{{0, 755}, {145, 0}} -> {-0.0839304, -0.0144882, \
0.00419585, 0.00419585}, {{20, 243.438}, {141.5, 3.4375}} -> {-14.3597, \
-4.53701, 0.10376, 0.25198}, {{265.75, 489.188}, {141.5, 3.4375}} -> \
{-39.6066, -3.00968, 0.103552, 0.167878}, {{511.562, 734.938}, {141.5, \
3.4375}} -> {-65.3609, -4.53794, 0.10376, 0.251986}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .19314 
%%ImageSize: 756 146.011 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.00459847 0.31746 [
[ 0 0 0 0 ]
[ 1 .19314 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .19314 L
0 .19314 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00459847 0.321429 0.188537 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.047619 0.0147142 0.0363327 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01471 -6 -4.5 ]
[-0.0125 .01471 0 4.5 ]
[-0.0125 .10555 -18 -4.5 ]
[-0.0125 .10555 0 4.5 ]
[-0.0125 .19638 -6 -4.5 ]
[-0.0125 .19638 0 4.5 ]
[-0.0125 .28721 -18 -4.5 ]
[-0.0125 .28721 0 4.5 ]
[-0.0125 .37804 -12 -4.5 ]
[-0.0125 .37804 0 4.5 ]
[-0.0125 .46887 -24 -4.5 ]
[-0.0125 .46887 0 4.5 ]
[-0.0125 .5597 -12 -4.5 ]
[-0.0125 .5597 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01471 m
.00625 .01471 L
s
[(0)] -0.0125 .01471 1 0 Mshowa
0 .10555 m
.00625 .10555 L
s
[(2.5)] -0.0125 .10555 1 0 Mshowa
0 .19638 m
.00625 .19638 L
s
[(5)] -0.0125 .19638 1 0 Mshowa
0 .28721 m
.00625 .28721 L
s
[(7.5)] -0.0125 .28721 1 0 Mshowa
0 .37804 m
.00625 .37804 L
s
[(10)] -0.0125 .37804 1 0 Mshowa
0 .46887 m
.00625 .46887 L
s
[(12.5)] -0.0125 .46887 1 0 Mshowa
0 .5597 m
.00625 .5597 L
s
[(15)] -0.0125 .5597 1 0 Mshowa
.125 Mabswid
0 .03288 m
.00375 .03288 L
s
0 .05105 m
.00375 .05105 L
s
0 .06921 m
.00375 .06921 L
s
0 .08738 m
.00375 .08738 L
s
0 .12371 m
.00375 .12371 L
s
0 .14188 m
.00375 .14188 L
s
0 .16005 m
.00375 .16005 L
s
0 .17821 m
.00375 .17821 L
s
0 .21454 m
.00375 .21454 L
s
0 .23271 m
.00375 .23271 L
s
0 .25088 m
.00375 .25088 L
s
0 .26904 m
.00375 .26904 L
s
0 .30538 m
.00375 .30538 L
s
0 .32354 m
.00375 .32354 L
s
0 .34171 m
.00375 .34171 L
s
0 .35987 m
.00375 .35987 L
s
0 .39621 m
.00375 .39621 L
s
0 .41437 m
.00375 .41437 L
s
0 .43254 m
.00375 .43254 L
s
0 .45071 m
.00375 .45071 L
s
0 .48704 m
.00375 .48704 L
s
0 .50521 m
.00375 .50521 L
s
0 .52337 m
.00375 .52337 L
s
0 .54154 m
.00375 .54154 L
s
0 .57787 m
.00375 .57787 L
s
0 .59604 m
.00375 .59604 L
s
0 .6142 m
.00375 .6142 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01471 m
1 .01471 L
s
.99375 .10555 m
1 .10555 L
s
.99375 .19638 m
1 .19638 L
s
.99375 .28721 m
1 .28721 L
s
.99375 .37804 m
1 .37804 L
s
.99375 .46887 m
1 .46887 L
s
.99375 .5597 m
1 .5597 L
s
.125 Mabswid
.99625 .03288 m
1 .03288 L
s
.99625 .05105 m
1 .05105 L
s
.99625 .06921 m
1 .06921 L
s
.99625 .08738 m
1 .08738 L
s
.99625 .12371 m
1 .12371 L
s
.99625 .14188 m
1 .14188 L
s
.99625 .16005 m
1 .16005 L
s
.99625 .17821 m
1 .17821 L
s
.99625 .21454 m
1 .21454 L
s
.99625 .23271 m
1 .23271 L
s
.99625 .25088 m
1 .25088 L
s
.99625 .26904 m
1 .26904 L
s
.99625 .30538 m
1 .30538 L
s
.99625 .32354 m
1 .32354 L
s
.99625 .34171 m
1 .34171 L
s
.99625 .35987 m
1 .35987 L
s
.99625 .39621 m
1 .39621 L
s
.99625 .41437 m
1 .41437 L
s
.99625 .43254 m
1 .43254 L
s
.99625 .45071 m
1 .45071 L
s
.99625 .48704 m
1 .48704 L
s
.99625 .50521 m
1 .50521 L
s
.99625 .52337 m
1 .52337 L
s
.99625 .54154 m
1 .54154 L
s
.99625 .57787 m
1 .57787 L
s
.99625 .59604 m
1 .59604 L
s
.99625 .6142 m
1 .6142 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
0 0 1 r
.5 Mabswid
[ .01 ] 0 setdash
.02381 .01762 m
.02395 .01762 L
.02408 .01762 L
.02423 .01761 L
.02437 .0176 L
.02462 .01758 L
.02489 .01755 L
.02519 .01751 L
.02551 .01746 L
.02608 .01733 L
.02722 .01699 L
.02847 .01647 L
.02973 .01584 L
.03043 .01546 L
.03109 .01509 L
.03139 .01492 L
.03155 .01483 L
.03171 .01474 L
.03179 .01474 L
.03189 .0148 L
.03205 .01489 L
.03238 .01508 L
.03355 .01573 L
.03596 .01687 L
.03717 .01727 L
.03785 .01744 L
.03819 .0175 L
.0385 .01755 L
.03879 .01758 L
.03894 .01759 L
.0391 .01761 L
.03918 .01761 L
.03926 .01762 L
.03941 .01762 L
.03949 .01762 L
.03958 .01762 L
.03967 .01763 L
.03976 .01763 L
.03991 .01762 L
.04006 .01762 L
.04019 .01761 L
.04033 .0176 L
.04065 .01757 L
.04095 .01754 L
.04147 .01745 L
.04204 .01732 L
.04319 .01695 L
.04573 .01578 L
.04631 .01546 L
.04694 .01511 L
Mistroke
.04724 .01493 L
.04739 .01485 L
.04752 .01477 L
.04765 .01473 L
.04778 .01481 L
.04805 .01496 L
.0492 .01561 L
.05046 .01627 L
.05165 .01681 L
.05274 .01719 L
.05332 .01736 L
.05388 .01748 L
.05417 .01753 L
.05447 .01757 L
.05463 .01759 L
.0548 .01761 L
.05495 .01762 L
.05511 .01763 L
.05525 .01763 L
.0554 .01764 L
.05553 .01764 L
.05566 .01764 L
.05581 .01764 L
.05595 .01763 L
.0561 .01762 L
.05625 .01761 L
.05652 .01759 L
.05676 .01756 L
.05732 .01747 L
.05789 .01734 L
.05849 .01716 L
.05959 .01676 L
.06208 .01552 L
.06267 .01519 L
.063 .015 L
.0633 .01482 L
.06346 .01473 L
.06355 .01475 L
.06363 .0148 L
.064 .01501 L
.06464 .01538 L
.06589 .01606 L
.06706 .01663 L
.06826 .0171 L
.06878 .01726 L
.06934 .01741 L
.06967 .01748 L
.06996 .01754 L
.07027 .01759 L
.07055 .01762 L
Mistroke
.07071 .01763 L
.07085 .01764 L
.07101 .01765 L
.07109 .01766 L
.07118 .01766 L
.07126 .01766 L
.07134 .01766 L
.07149 .01766 L
.07159 .01766 L
.07167 .01766 L
.07175 .01766 L
.07184 .01766 L
.07199 .01765 L
.07213 .01764 L
.07243 .01761 L
.07272 .01757 L
.07299 .01753 L
.07359 .0174 L
.07425 .01722 L
.07557 .01674 L
.07679 .01616 L
.07787 .01558 L
.07844 .01525 L
.07904 .01491 L
.07919 .01481 L
.07928 .01476 L
.07936 .01472 L
.07945 .01477 L
.07954 .01482 L
.07971 .01492 L
.08032 .01527 L
.08152 .01595 L
.0827 .01654 L
.08394 .01706 L
.085 .01739 L
.0856 .01753 L
.08588 .01758 L
.08617 .01762 L
.08633 .01764 L
.08648 .01766 L
.08663 .01767 L
.08677 .01768 L
.08693 .01769 L
.08702 .01769 L
.08711 .0177 L
.08726 .0177 L
.08734 .0177 L
.08742 .0177 L
.08758 .0177 L
.08772 .01769 L
Mistroke
.08786 .01768 L
.088 .01767 L
.08832 .01764 L
.08861 .0176 L
.08913 .01751 L
.0897 .01738 L
.09085 .017 L
.09339 .01579 L
.09397 .01546 L
.09459 .0151 L
.09489 .01492 L
.09504 .01483 L
.09518 .01475 L
.0953 .01475 L
.09543 .01483 L
.09571 .01499 L
.09685 .01566 L
.0981 .01633 L
.0993 .01689 L
.10038 .01729 L
.10097 .01746 L
.10153 .01758 L
.10181 .01763 L
.10211 .01768 L
.10227 .01769 L
.10244 .01771 L
.10259 .01772 L
.10275 .01773 L
.10289 .01774 L
.10304 .01774 L
.10317 .01775 L
.1033 .01775 L
.10345 .01774 L
.10358 .01774 L
.10374 .01773 L
.10389 .01772 L
.10416 .01769 L
.1044 .01766 L
.10496 .01756 L
.10552 .01743 L
.10613 .01725 L
.10722 .01683 L
.10971 .01555 L
.1103 .0152 L
.11063 .01501 L
.11093 .01482 L
.11102 .01477 L
.11111 .01472 L
.1112 .01477 L
.1113 .01483 L
Mistroke
.11162 .01502 L
.11226 .01541 L
.11343 .01608 L
.11469 .01671 L
.11593 .01722 L
.11652 .01742 L
.11706 .01756 L
.1176 .01767 L
.11789 .01772 L
.1182 .01776 L
.11832 .01777 L
.11846 .01778 L
.11858 .01779 L
.11871 .0178 L
.11885 .0178 L
.119 .0178 L
.11914 .0178 L
.11927 .0178 L
.11943 .0178 L
.1195 .01779 L
.11959 .01779 L
.11988 .01777 L
.12005 .01775 L
.12022 .01773 L
.12054 .01768 L
.12117 .01754 L
.12174 .01738 L
.12289 .01696 L
.12399 .01645 L
.12515 .01582 L
.12578 .01545 L
.12638 .01508 L
.12663 .01493 L
.12676 .01485 L
.12689 .01477 L
.12703 .01474 L
.12718 .01483 L
.12744 .01499 L
.1286 .0157 L
.13086 .01689 L
.13148 .01716 L
.13213 .0174 L
.1327 .01757 L
.13331 .01771 L
.13364 .01777 L
.13394 .01781 L
.13408 .01783 L
.13424 .01784 L
.13439 .01786 L
.13453 .01786 L
Mistroke
.13462 .01787 L
.13471 .01787 L
.13479 .01787 L
.13487 .01788 L
.13495 .01788 L
.13504 .01788 L
.13514 .01787 L
.13523 .01787 L
.13531 .01787 L
.13539 .01786 L
.13554 .01786 L
.1357 .01784 L
.13588 .01782 L
.13617 .01779 L
.13649 .01773 L
.13714 .01759 L
.13774 .01741 L
.13831 .01721 L
.14074 .01601 L
.14182 .01537 L
.14211 .01519 L
.14241 .01499 L
.14255 .01491 L
.1427 .01481 L
.14283 .01473 L
.14297 .01479 L
.14313 .01489 L
.14329 .01499 L
.14359 .01518 L
.14416 .01553 L
.14526 .01618 L
.14655 .01687 L
.14775 .01738 L
.14839 .01759 L
.14898 .01774 L
.14929 .01781 L
.14962 .01787 L
.1498 .01789 L
.14997 .01792 L
.15014 .01793 L
.15031 .01794 L
.15046 .01795 L
.1506 .01796 L
.15074 .01796 L
.15087 .01796 L
.15102 .01796 L
.15117 .01796 L
.15132 .01795 L
.15149 .01794 L
.15179 .01791 L
Mistroke
.15208 .01787 L
.15273 .01774 L
.15333 .01758 L
.15398 .01735 L
.15517 .01683 L
.1574 .01557 L
.15804 .01516 L
.15836 .01496 L
.1585 .01487 L
.15865 .01477 L
.15878 .01475 L
.15891 .01483 L
.15919 .01501 L
.15978 .01539 L
.16107 .0162 L
.1623 .01687 L
.16348 .0174 L
.1641 .01763 L
.16476 .01782 L
.16531 .01794 L
.16562 .01799 L
.16592 .01802 L
.16605 .01804 L
.16619 .01805 L
.16631 .01805 L
.16644 .01806 L
.16657 .01806 L
.16672 .01807 L
.16687 .01806 L
.16699 .01806 L
.16714 .01805 L
.16727 .01805 L
.16742 .01803 L
.16758 .01802 L
.1679 .01797 L
.1682 .01792 L
.16876 .01779 L
.1693 .01764 L
.1705 .01716 L
.17181 .01649 L
.17304 .01575 L
.17364 .01536 L
.17419 .01499 L
.17435 .01489 L
.1745 .01479 L
.17465 .01475 L
.17474 .0148 L
.17483 .01486 L
.17551 .01533 L
.17672 .01611 L
Mistroke
.17795 .01683 L
.17928 .01747 L
.17989 .0177 L
.18054 .01791 L
.1811 .01804 L
.18141 .01809 L
.18171 .01813 L
.18185 .01815 L
.182 .01816 L
.18215 .01817 L
.18228 .01818 L
.18243 .01819 L
.18252 .01819 L
.1826 .01819 L
.18274 .01819 L
.1829 .01818 L
.18304 .01818 L
.1832 .01816 L
.18335 .01815 L
.18349 .01813 L
.18383 .01809 L
.18415 .01803 L
.1847 .01789 L
.18521 .01773 L
.18638 .01726 L
.18865 .01596 L
.18928 .01555 L
.18993 .01509 L
.1902 .01491 L
.19035 .0148 L
.19049 .01473 L
.19057 .01478 L
.19066 .01484 L
.19081 .01495 L
.19111 .01516 L
.19245 .01607 L
.1937 .01684 L
.19495 .01749 L
.19557 .01775 L
.19613 .01795 L
.19669 .01811 L
.19722 .01822 L
.19751 .01827 L
.19778 .0183 L
.19793 .01831 L
.19807 .01832 L
.19815 .01833 L
.19824 .01833 L
.19839 .01833 L
.19854 .01833 L
Mistroke
.19869 .01833 L
.19885 .01832 L
.19894 .01832 L
.19902 .01831 L
.19918 .0183 L
.19936 .01828 L
.19969 .01823 L
.19999 .01817 L
.2003 .0181 L
.20088 .01793 L
.20201 .01748 L
.20322 .01684 L
.20437 .01612 L
.20543 .01538 L
.20599 .01498 L
.20615 .01486 L
.2063 .01475 L
.20644 .01478 L
.20658 .01489 L
.20785 .0158 L
.20906 .01662 L
.21039 .0174 L
.21099 .01769 L
.21163 .01797 L
.21218 .01816 L
.21279 .01832 L
.21314 .01839 L
.21331 .01842 L
.21347 .01845 L
.21362 .01846 L
.21378 .01848 L
.21387 .01849 L
.21395 .01849 L
.21403 .0185 L
.21411 .0185 L
.21426 .0185 L
.21439 .01851 L
.21448 .0185 L
.21456 .0185 L
.2147 .0185 L
.21486 .01849 L
.215 .01848 L
.21532 .01844 L
.21562 .01839 L
.21589 .01833 L
.21649 .01817 L
.21702 .01799 L
.21758 .01776 L
.22007 .01631 L
.22122 .01548 L
Mistroke
.22155 .01523 L
.22187 .01499 L
.222 .01488 L
.22215 .01477 L
.22231 .01478 L
.22245 .01489 L
.22467 .01654 L
.22581 .01728 L
.22703 .01793 L
.22763 .01819 L
.22819 .01838 L
.22869 .01852 L
.22898 .01858 L
.22924 .01863 L
.22952 .01867 L
.22967 .01868 L
.22983 .01869 L
.22996 .0187 L
.23009 .01871 L
.23023 .01871 L
.23037 .01871 L
.23046 .01871 L
.23054 .0187 L
.23062 .0187 L
.23071 .01869 L
.23086 .01868 L
.23103 .01866 L
.23134 .01862 L
.23162 .01856 L
.23226 .01839 L
.23284 .01819 L
.23416 .01756 L
.23536 .01681 L
.23664 .01587 L
.23726 .01538 L
.23757 .01514 L
.23785 .01491 L
.23798 .0148 L
.23811 .01472 L
.23824 .01483 L
.23838 .01494 L
.23895 .01541 L
.24131 .01719 L
.24248 .0179 L
.24356 .01842 L
.24413 .01862 L
.24473 .01879 L
.24505 .01885 L
.24534 .0189 L
.24551 .01892 L
Mistroke
.24566 .01893 L
.24574 .01894 L
.24583 .01894 L
.24593 .01895 L
.24601 .01895 L
.24615 .01895 L
.2463 .01895 L
.24645 .01894 L
.24658 .01893 L
.2467 .01892 L
.24683 .01891 L
.24709 .01887 L
.24738 .01882 L
.24769 .01875 L
.24825 .01858 L
.24888 .01833 L
.24947 .01805 L
.25081 .01724 L
.25197 .01638 L
.25323 .01535 L
.25355 .01507 L
.25373 .01492 L
.25382 .01484 L
.2539 .01478 L
.25404 .01477 L
.25419 .0149 L
.25451 .01518 L
.25571 .0162 L
.25796 .01787 L
.25854 .01822 L
.25916 .01854 L
.25969 .01877 L
.26026 .01897 L
.26059 .01906 L
.26088 .01912 L
.26118 .01917 L
.26132 .01919 L
.26146 .01921 L
.26161 .01922 L
.2617 .01923 L
.26178 .01923 L
.26193 .01924 L
.26208 .01924 L
.26217 .01924 L
.26226 .01923 L
.26235 .01923 L
.26244 .01922 L
.2626 .01921 L
.26277 .01919 L
.26308 .01914 L
Mistroke
.26341 .01907 L
.264 .01889 L
.26463 .01864 L
.26533 .01829 L
.26776 .01657 L
.26889 .01558 L
.26946 .01506 L
.26962 .01492 L
.26971 .01484 L
.26979 .01476 L
.26995 .01481 L
.27009 .01494 L
.2714 .01615 L
.2726 .01718 L
.27377 .01806 L
.27502 .01881 L
.27553 .01905 L
.27607 .01927 L
.27639 .01936 L
.27668 .01944 L
.27697 .01949 L
.27724 .01954 L
.27739 .01955 L
.27747 .01956 L
.27755 .01957 L
.27771 .01957 L
.27785 .01958 L
.27798 .01958 L
.27811 .01957 L
.27825 .01957 L
.2784 .01955 L
.27856 .01954 L
.27873 .01951 L
.27904 .01945 L
.27935 .01938 L
.27963 .01929 L
.28071 .01884 L
.28125 .01853 L
.28185 .01815 L
.28309 .01719 L
.28438 .01602 L
.28492 .0155 L
.28521 .01521 L
.28549 .01494 L
.28565 .01478 L
.28574 .01474 L
.28582 .01482 L
.28612 .01512 L
.2867 .0157 L
.28912 .01792 L
Mistroke
.2903 .01879 L
.29137 .01939 L
.29193 .01963 L
.29247 .0198 L
.29276 .01987 L
.29303 .01992 L
.29317 .01993 L
.29332 .01995 L
.2934 .01996 L
.29349 .01996 L
.29364 .01997 L
.2938 .01997 L
.29394 .01997 L
.29403 .01997 L
.2941 .01996 L
.29419 .01996 L
.29427 .01995 L
.29444 .01993 L
.29459 .01991 L
.29494 .01983 L
.29521 .01976 L
.29552 .01966 L
.29613 .01941 L
.29735 .0187 L
.29847 .01783 L
.29978 .01662 L
.30041 .01597 L
.30099 .01536 L
.30126 .01506 L
.30141 .01491 L
.30156 .01474 L
.30169 .01483 L
.30184 .01499 L
.3021 .01527 L
.30328 .01653 L
.30459 .01782 L
.30578 .01884 L
.30636 .01925 L
.30699 .01964 L
.30753 .01992 L
.30813 .02015 L
.30846 .02025 L
.30877 .02032 L
.30894 .02035 L
.30909 .02037 L
.30926 .02039 L
.30935 .02039 L
.30944 .0204 L
.3096 .0204 L
.30975 .0204 L
Mistroke
.30983 .0204 L
.30991 .0204 L
.31007 .02038 L
.31022 .02037 L
.31037 .02035 L
.31065 .02029 L
.31096 .02021 L
.31125 .02012 L
.31179 .01989 L
.31238 .01958 L
.31302 .01917 L
.31522 .01721 L
.31645 .01588 L
.31674 .01555 L
.31705 .01519 L
.31731 .01489 L
.31746 .01472 L
.3176 .01488 L
.31824 .01562 L
.31893 .01641 L
.32013 .01772 L
.3214 .01891 L
.32259 .01981 L
.32311 .02012 L
.32367 .02038 L
.32395 .02049 L
.32427 .02059 L
.32456 .02066 L
.32483 .02071 L
.32497 .02073 L
.32513 .02075 L
.32527 .02075 L
.3254 .02076 L
.32555 .02076 L
.32564 .02075 L
.32572 .02075 L
.32587 .02074 L
.32602 .02072 L
.32617 .0207 L
.32633 .02067 L
.32662 .0206 L
.32696 .02049 L
.32727 .02037 L
.32842 .01973 L
.3295 .01889 L
.3317 .01665 L
.3323 .01595 L
.33262 .01557 L
.33295 .01518 L
.33309 .01501 L
Mistroke
.33324 .01482 L
.33333 .01472 L
.33341 .0148 L
.33356 .01499 L
.33412 .01566 L
.33651 .01824 L
.33781 .01933 L
.33839 .01972 L
.33904 .02006 L
.33933 .02018 L
.33964 .02029 L
.33991 .02037 L
.34021 .02043 L
.34038 .02046 L
.34047 .02047 L
.34054 .02048 L
.34069 .02049 L
.34078 .0205 L
.34086 .0205 L
.34101 .0205 L
.34114 .0205 L
.34129 .02049 L
.34145 .02048 L
.34159 .02046 L
.34171 .02044 L
.342 .02038 L
.34226 .02031 L
.34251 .02023 L
.34307 .02 L
.34367 .01967 L
.34481 .01889 L
.34606 .01781 L
.34738 .01652 L
.34796 .01594 L
.3486 .01531 L
.34888 .01503 L
.34904 .01488 L
.34918 .01473 L
.34932 .01482 L
.34947 .01496 L
.34973 .0152 L
.35093 .01619 L
.35157 .01663 L
.35224 .01702 L
.35281 .01728 L
.35312 .0174 L
.35345 .0175 L
.35377 .01759 L
.35408 .01765 L
.35437 .01769 L
Mistroke
.35453 .01771 L
.35467 .01772 L
.35482 .01773 L
.35495 .01773 L
.3551 .01774 L
.35525 .01774 L
.35539 .01774 L
.35551 .01773 L
.35565 .01773 L
.35579 .01772 L
.35831 .01763 L
.35948 .0178 L
.36011 .01794 L
.36071 .01805 L
.36087 .01807 L
.36102 .01809 L
.3611 .0181 L
.36119 .01811 L
.36135 .01812 L
.36145 .01812 L
.36153 .01812 L
.36163 .01812 L
.36172 .01811 L
.36181 .0181 L
.36189 .01809 L
.36206 .01806 L
.36221 .01803 L
.36235 .01799 L
.36267 .01786 L
.36298 .01768 L
.36331 .01743 L
.36363 .01712 L
.36393 .01677 L
.3646 .01571 L
.36475 .01542 L
.36491 .01509 L
.36506 .01476 L
.3652 .015 L
.36534 .01537 L
.3655 .01578 L
.36583 .01675 L
.36693 .02093 L
.36813 .02739 L
.36936 .03646 L
.37049 .04706 L
.37302 .07997 L
.37533 .12181 L
.37784 .17943 L
.38277 .32022 L
.38752 .46162 L
Mistroke
.38991 .52167 L
.39209 .56432 L
.39329 .58165 L
.39385 .58799 L
.39444 .59357 L
.39476 .59614 L
.39506 .59814 L
.39536 .59984 L
.39564 .6011 L
.39597 .60223 L
.39614 .60266 L
.39622 .60284 L
.39632 .603 L
.39647 .6032 L
.39662 .6033 L
.39671 .60332 L
.3968 .60331 L
.39695 .60323 L
.39709 .60308 L
.39724 .60284 L
.39738 .60254 L
.39751 .6022 L
.39781 .60118 L
.39812 .59976 L
.39871 .5961 L
.39936 .59066 L
.40051 .5774 L
.40158 .56117 L
.40405 .51111 L
.4063 .45369 L
.41112 .31169 L
.41577 .18256 L
.41812 .12899 L
.42071 .0823 L
.42189 .0653 L
.42317 .05005 L
.42436 .03842 L
.42547 .02978 L
.42669 .02235 L
.42732 .01931 L
.42766 .0179 L
.42802 .01652 L
.42818 .01598 L
.42834 .01544 L
.42848 .015 L
.42863 .01489 L
.42877 .01529 L
.42892 .01571 L
.4292 .0164 L
.42985 .01778 L
Mistroke
.43045 .01874 L
.43105 .01945 L
.43135 .01972 L
.43168 .01995 L
.43201 .02013 L
.4322 .02021 L
.43237 .02026 L
.43253 .0203 L
.43261 .02032 L
.4327 .02034 L
.43279 .02035 L
.43287 .02036 L
.43302 .02037 L
.43317 .02037 L
.43325 .02037 L
.43333 .02037 L
.43348 .02035 L
.43362 .02034 L
.43378 .02031 L
.43393 .02028 L
.43427 .02019 L
.43488 .01997 L
.43545 .01971 L
.44007 .01713 L
.44241 .01586 L
.44305 .01551 L
.44374 .01512 L
.44406 .01494 L
.44423 .01484 L
.44432 .01479 L
.44439 .01474 L
.44453 .01476 L
.44468 .01485 L
.44499 .01503 L
.44746 .0164 L
.44854 .01692 L
.44973 .01739 L
.45027 .01756 L
.45085 .01771 L
.45117 .01777 L
.45147 .01782 L
.45176 .01786 L
.45191 .01787 L
.45204 .01788 L
.4522 .01789 L
.45235 .0179 L
.4525 .0179 L
.45259 .0179 L
.45267 .0179 L
.4528 .0179 L
Mistroke
.45295 .01789 L
.4531 .01789 L
.45324 .01787 L
.45357 .01784 L
.45388 .0178 L
.45422 .01773 L
.45455 .01766 L
.45572 .01729 L
.45696 .01673 L
.45918 .01545 L
.45976 .01507 L
.46005 .01489 L
.46019 .0148 L
.46032 .01472 L
.46046 .01481 L
.46062 .01491 L
.46095 .01513 L
.46154 .0155 L
.46374 .01677 L
.46495 .01731 L
.46553 .01752 L
.46606 .01767 L
.46664 .01781 L
.46695 .01786 L
.46728 .0179 L
.46745 .01792 L
.46763 .01794 L
.46771 .01794 L
.4678 .01794 L
.46796 .01795 L
.46811 .01795 L
.46825 .01795 L
.4684 .01795 L
.46849 .01795 L
.46857 .01794 L
.46873 .01793 L
.46887 .01792 L
.46914 .01789 L
.46944 .01785 L
.46975 .01779 L
.47033 .01766 L
.47085 .0175 L
.47206 .01704 L
.47335 .0164 L
.47449 .01576 L
.47511 .01538 L
.47571 .01501 L
.47597 .01485 L
.47612 .01476 L
.47626 .01476 L
Mistroke
.47634 .0148 L
.47642 .01486 L
.47657 .01495 L
.47686 .01513 L
.47792 .01575 L
.47916 .01642 L
.48032 .01695 L
.48153 .01737 L
.48218 .01753 L
.48254 .0176 L
.48286 .01765 L
.48314 .01768 L
.4833 .0177 L
.48344 .01771 L
.4836 .01772 L
.48368 .01772 L
.48376 .01772 L
.48391 .01773 L
.48406 .01773 L
.48421 .01773 L
.48434 .01772 L
.48449 .01771 L
.48463 .0177 L
.48489 .01768 L
.48517 .01765 L
.48547 .0176 L
.4858 .01754 L
.48647 .01738 L
.48767 .01698 L
.48898 .01641 L
.49022 .01577 L
.49133 .01514 L
.49164 .01496 L
.4918 .01487 L
.49196 .01477 L
.49211 .01474 L
.49227 .01483 L
.49254 .01499 L
.49478 .01621 L
.49605 .01678 L
.49666 .01701 L
.49723 .0172 L
.49779 .01735 L
.49839 .01748 L
.49873 .01753 L
.49903 .01757 L
.49933 .0176 L
.49948 .01761 L
.49964 .01761 L
.49972 .01762 L
Mistroke
.49981 .01762 L
.49989 .01762 L
.49997 .01762 L
.50012 .01762 L
.50027 .01762 L
.50036 .01761 L
.50046 .01761 L
.50063 .0176 L
.5008 .01758 L
.50095 .01757 L
.50155 .01749 L
.50185 .01743 L
.50218 .01736 L
.50341 .01699 L
.50454 .01653 L
.50585 .01589 L
.50642 .01558 L
.50706 .01522 L
.50733 .01506 L
.50763 .01489 L
.50777 .01481 L
.50792 .01473 L
.50804 .01477 L
.50817 .01485 L
.50936 .01553 L
.51067 .01624 L
.51186 .0168 L
.51245 .01703 L
.51308 .01725 L
.51363 .01741 L
.51423 .01755 L
.51454 .01761 L
.51487 .01765 L
.51505 .01768 L
.51522 .01769 L
.51539 .01771 L
.51554 .01772 L
.51569 .01772 L
.51584 .01773 L
.51593 .01773 L
.51601 .01773 L
.51616 .01773 L
.51631 .01772 L
.51645 .01771 L
.5166 .0177 L
.51675 .01769 L
.51706 .01766 L
.51735 .01762 L
.5179 .01751 L
.51849 .01736 L
Mistroke
.51913 .01716 L
.52134 .01616 L
.52257 .01547 L
.52318 .0151 L
.52344 .01494 L
.52359 .01485 L
.52373 .01476 L
.52387 .01475 L
.52401 .01484 L
.52431 .01502 L
.52494 .01541 L
.52626 .01619 L
.5275 .01684 L
.52815 .01713 L
.52884 .0174 L
.52945 .0176 L
.53011 .01776 L
.5304 .01782 L
.53071 .01787 L
.53101 .01791 L
.53128 .01793 L
.53142 .01794 L
.53155 .01795 L
.5317 .01795 L
.53185 .01795 L
.53201 .01795 L
.53209 .01795 L
.53217 .01795 L
.53233 .01794 L
.53247 .01793 L
.53275 .0179 L
.533 .01787 L
.53357 .01776 L
.53419 .0176 L
.53486 .01738 L
.53608 .01686 L
.53847 .0155 L
.53905 .01512 L
.53937 .01492 L
.53953 .01481 L
.53968 .01472 L
.53976 .01477 L
.53985 .01482 L
.54004 .01495 L
.54037 .01516 L
.54101 .01557 L
.54225 .01631 L
.54359 .017 L
.54421 .01726 L
.54486 .01749 L
Mistroke
.54542 .01765 L
.54603 .01778 L
.54633 .01783 L
.54649 .01785 L
.54666 .01787 L
.54681 .01788 L
.54688 .01788 L
.54697 .01789 L
.54712 .0179 L
.54726 .0179 L
.54739 .0179 L
.54754 .0179 L
.5477 .0179 L
.54784 .01789 L
.54798 .01788 L
.5481 .01787 L
.54838 .01784 L
.5487 .01779 L
.549 .01774 L
.54968 .01758 L
.5509 .01716 L
.55317 .01607 L
.55447 .01534 L
.55477 .01517 L
.55509 .01499 L
.55524 .0149 L
.55539 .01481 L
.55552 .01474 L
.55566 .01477 L
.5558 .01486 L
.55596 .01495 L
.55623 .0151 L
.55686 .01546 L
.558 .01609 L
.56052 .01746 L
.56293 .01883 L
.56397 .01942 L
.56511 .01996 L
.56542 .02008 L
.56574 .02019 L
.56602 .02027 L
.56618 .0203 L
.56632 .02033 L
.56647 .02035 L
.56661 .02036 L
.56676 .02037 L
.56684 .02037 L
.56692 .02037 L
.56706 .02036 L
.56718 .02035 L
Mistroke
.56733 .02033 L
.56747 .0203 L
.56762 .02027 L
.56778 .02022 L
.5681 .02007 L
.5684 .0199 L
.56868 .01969 L
.56932 .01905 L
.56967 .01857 L
.57 .01805 L
.57058 .01692 L
.57089 .01618 L
.57119 .0154 L
.57131 .01505 L
.57144 .01476 L
.57159 .0152 L
.57172 .01562 L
.5723 .01772 L
.57349 .02332 L
.5748 .03167 L
.57604 .04203 L
.57716 .05372 L
.57969 .08862 L
.582 .13156 L
.58451 .18951 L
.58944 .32867 L
.59419 .46699 L
.59658 .52545 L
.59876 .56677 L
.59996 .58341 L
.60052 .58945 L
.60111 .59472 L
.60143 .59712 L
.60173 .59896 L
.60203 .6005 L
.60231 .60163 L
.60247 .60213 L
.60264 .60258 L
.60281 .60293 L
.6029 .60307 L
.60299 .60318 L
.60307 .60325 L
.60315 .60329 L
.6033 .60332 L
.60345 .60326 L
.60354 .60318 L
.60362 .60308 L
.60377 .60285 L
.60392 .60253 L
.60418 .60176 L
Mistroke
.60447 .60062 L
.60479 .59903 L
.60535 .59527 L
.60588 .59075 L
.60708 .57676 L
.60836 .55655 L
.61094 .50161 L
.61337 .43642 L
.61802 .29619 L
.62037 .22729 L
.62296 .15987 L
.62544 .10655 L
.62771 .06909 L
.63006 .04155 L
.63136 .03086 L
.63258 .02331 L
.63375 .01819 L
.63433 .01626 L
.63449 .0158 L
.63467 .01534 L
.63475 .01513 L
.63483 .01493 L
.63498 .01485 L
.63512 .01516 L
.63525 .01542 L
.63553 .01595 L
.63604 .01673 L
.63633 .01708 L
.63664 .01739 L
.63693 .01762 L
.6372 .01779 L
.63748 .01793 L
.63764 .01798 L
.63779 .01803 L
.63792 .01806 L
.63805 .01808 L
.6382 .0181 L
.63834 .01811 L
.63842 .01812 L
.6385 .01812 L
.63859 .01812 L
.63868 .01812 L
.63883 .01811 L
.63892 .0181 L
.639 .01809 L
.63929 .01805 L
.63959 .018 L
.64023 .01786 L
.64058 .01779 L
.64091 .01773 L
Mistroke
.64121 .01768 L
.64149 .01765 L
.64164 .01764 L
.6418 .01762 L
.64196 .01762 L
.64205 .01761 L
.64213 .01761 L
.64221 .01761 L
.64229 .01761 L
.64244 .01761 L
.64259 .01762 L
.64272 .01762 L
.64303 .01764 L
.64336 .01766 L
.64369 .01769 L
.64405 .01771 L
.64422 .01772 L
.64438 .01773 L
.64453 .01774 L
.64462 .01774 L
.64469 .01774 L
.64484 .01774 L
.64499 .01774 L
.64511 .01773 L
.64525 .01772 L
.6454 .01771 L
.64556 .0177 L
.64585 .01766 L
.64616 .0176 L
.64645 .01753 L
.64712 .01731 L
.64821 .01677 L
.64937 .01596 L
.64998 .01546 L
.6503 .01517 L
.65047 .01502 L
.65064 .01486 L
.6508 .01472 L
.65088 .0148 L
.65096 .01487 L
.65125 .01515 L
.65182 .01572 L
.65439 .01821 L
.65555 .01916 L
.65617 .01958 L
.65681 .01994 L
.65713 .02009 L
.65748 .02022 L
.6578 .02033 L
.65809 .0204 L
Mistroke
.65839 .02046 L
.65855 .02048 L
.65871 .02049 L
.65885 .0205 L
.65898 .0205 L
.65913 .0205 L
.65929 .0205 L
.65942 .02048 L
.65955 .02047 L
.65969 .02045 L
.65984 .02042 L
.66008 .02037 L
.66035 .02029 L
.66096 .02006 L
.66153 .01976 L
.6628 .01886 L
.66399 .01775 L
.66506 .0166 L
.66567 .0159 L
.66596 .01555 L
.66624 .01523 L
.66637 .01506 L
.66653 .01488 L
.66667 .01472 L
.6668 .01487 L
.66741 .0156 L
.66865 .01704 L
.66972 .01817 L
.67087 .01921 L
.67154 .0197 L
.67215 .02008 L
.67273 .02037 L
.67303 .02048 L
.67335 .02059 L
.67364 .02066 L
.6739 .02071 L
.67403 .02073 L
.67417 .02074 L
.6743 .02075 L
.67442 .02076 L
.67456 .02076 L
.67469 .02076 L
.67483 .02075 L
.67499 .02073 L
.67514 .02072 L
.6753 .02069 L
.67559 .02063 L
.6759 .02054 L
.6762 .02044 L
.67675 .02019 L
Mistroke
.67798 .01942 L
.67904 .01852 L
.68019 .01738 L
.68143 .016 L
.68204 .0153 L
.6823 .01499 L
.68245 .01481 L
.68259 .01478 L
.68274 .01494 L
.68289 .01512 L
.68318 .01545 L
.6838 .01616 L
.68513 .01757 L
.68638 .01871 L
.68703 .0192 L
.68772 .01964 L
.68833 .01995 L
.68865 .02008 L
.68899 .0202 L
.68931 .02028 L
.68959 .02034 L
.68973 .02036 L
.68988 .02038 L
.69002 .02039 L
.69016 .0204 L
.69031 .0204 L
.69045 .0204 L
.69058 .0204 L
.69072 .02039 L
.69087 .02038 L
.69103 .02035 L
.69132 .0203 L
.69162 .02023 L
.69189 .02014 L
.69241 .01994 L
.69304 .01963 L
.69361 .01928 L
.6949 .01828 L
.69717 .01605 L
.69779 .01539 L
.69813 .01502 L
.69822 .01493 L
.6983 .01483 L
.69846 .01476 L
.6986 .01492 L
.69876 .01509 L
.69909 .01544 L
.69966 .01604 L
.70089 .01726 L
.70219 .01836 L
Mistroke
.7033 .01911 L
.70393 .01944 L
.70451 .01967 L
.7048 .01977 L
.70512 .01985 L
.70526 .01988 L
.70542 .01991 L
.70555 .01993 L
.70569 .01994 L
.70583 .01996 L
.70596 .01997 L
.70608 .01997 L
.7062 .01997 L
.70634 .01997 L
.70647 .01997 L
.70661 .01996 L
.70677 .01994 L
.70693 .01992 L
.70708 .0199 L
.70742 .01983 L
.70771 .01975 L
.70803 .01964 L
.70917 .01911 L
.71032 .01836 L
.71155 .01736 L
.7127 .01629 L
.71376 .01524 L
.71391 .01509 L
.71407 .01493 L
.71422 .01478 L
.71436 .01478 L
.7145 .01493 L
.71466 .01509 L
.71499 .01541 L
.71633 .01668 L
.7175 .01767 L
.71875 .01854 L
.7194 .01889 L
.72 .01916 L
.72055 .01935 L
.72086 .01943 L
.72114 .01949 L
.72127 .01951 L
.7214 .01953 L
.72152 .01955 L
.72165 .01956 L
.7218 .01957 L
.72195 .01957 L
.72209 .01958 L
.72222 .01958 L
Mistroke
.72235 .01957 L
.72248 .01956 L
.72262 .01955 L
.72277 .01953 L
.72307 .01949 L
.72336 .01943 L
.72393 .01927 L
.72454 .01903 L
.72563 .01845 L
.72694 .01754 L
.72813 .01656 L
.72925 .01555 L
.72982 .01503 L
.72997 .01489 L
.73006 .01481 L
.73014 .01473 L
.7303 .01484 L
.73044 .01497 L
.73174 .01615 L
.73295 .01714 L
.7341 .01795 L
.73474 .01833 L
.73534 .01863 L
.7359 .01885 L
.73619 .01895 L
.7365 .01904 L
.73676 .0191 L
.73705 .01916 L
.73718 .01918 L
.73731 .0192 L
.73744 .01921 L
.73755 .01922 L
.7377 .01923 L
.73778 .01923 L
.73786 .01924 L
.73795 .01924 L
.73804 .01924 L
.73819 .01923 L
.73834 .01923 L
.73847 .01922 L
.73862 .0192 L
.73878 .01918 L
.73914 .01912 L
.73948 .01904 L
.74012 .01884 L
.74072 .01859 L
.74128 .01832 L
.74254 .01754 L
.74481 .01577 L
.74543 .01524 L
Mistroke
.74559 .01509 L
.74577 .01494 L
.74585 .01487 L
.74594 .01479 L
.74609 .01477 L
.74618 .01484 L
.74626 .01492 L
.74642 .01505 L
.74672 .01531 L
.7473 .01579 L
.74966 .01755 L
.75031 .01793 L
.751 .01828 L
.75165 .01855 L
.75225 .01873 L
.75255 .01881 L
.75287 .01887 L
.75318 .01891 L
.75336 .01893 L
.75345 .01894 L
.75353 .01894 L
.75369 .01895 L
.75384 .01895 L
.75398 .01895 L
.75412 .01894 L
.7542 .01894 L
.75428 .01894 L
.75442 .01892 L
.75458 .01891 L
.75475 .01889 L
.75502 .01884 L
.75532 .01878 L
.75593 .0186 L
.7565 .01839 L
.75702 .01816 L
.75947 .01663 L
.76056 .0158 L
.76115 .01532 L
.76144 .01509 L
.76171 .01487 L
.76184 .01476 L
.76198 .01478 L
.76213 .01489 L
.76228 .01502 L
.76291 .01552 L
.76401 .01637 L
.76532 .01725 L
.76651 .01791 L
.7671 .01817 L
.76773 .01839 L
Mistroke
.76802 .01848 L
.76833 .01855 L
.76861 .01861 L
.76888 .01865 L
.76902 .01867 L
.76918 .01868 L
.76926 .01869 L
.76934 .0187 L
.7695 .0187 L
.76965 .01871 L
.76978 .01871 L
.76994 .01871 L
.77008 .0187 L
.77016 .0187 L
.77024 .01869 L
.77041 .01867 L
.77072 .01864 L
.77107 .01857 L
.7714 .0185 L
.77201 .01832 L
.77267 .01807 L
.77386 .01747 L
.7761 .01599 L
.77665 .01558 L
.77724 .01513 L
.7774 .015 L
.77757 .01487 L
.77772 .01476 L
.7778 .01473 L
.77788 .01479 L
.77849 .01526 L
.77979 .01621 L
.78102 .01702 L
.78221 .01766 L
.78283 .01793 L
.78349 .01817 L
.78405 .01832 L
.78437 .01839 L
.78466 .01843 L
.7848 .01845 L
.78493 .01847 L
.78505 .01848 L
.78518 .01849 L
.78532 .0185 L
.78545 .0185 L
.78558 .0185 L
.78574 .0185 L
.78588 .0185 L
.78602 .01849 L
.78617 .01848 L
Mistroke
.78633 .01847 L
.78665 .01843 L
.78695 .01838 L
.78752 .01824 L
.78806 .01808 L
.78927 .01757 L
.79058 .01685 L
.79181 .01604 L
.79297 .01521 L
.79327 .01499 L
.79342 .01489 L
.79355 .01479 L
.79371 .01476 L
.79379 .01482 L
.79388 .01488 L
.79418 .0151 L
.79551 .01604 L
.79675 .01682 L
.79809 .01753 L
.79871 .01778 L
.79936 .01801 L
.79991 .01815 L
.80023 .01822 L
.80052 .01826 L
.80067 .01828 L
.80084 .0183 L
.80098 .01831 L
.80113 .01832 L
.80121 .01833 L
.80129 .01833 L
.80144 .01833 L
.80152 .01833 L
.80161 .01833 L
.8017 .01833 L
.80178 .01833 L
.80194 .01832 L
.80209 .01831 L
.80222 .0183 L
.80236 .01828 L
.80268 .01824 L
.80298 .01818 L
.80349 .01806 L
.80406 .01789 L
.80522 .01741 L
.80652 .01671 L
.80776 .01593 L
.80887 .01517 L
.80917 .01496 L
.80934 .01484 L
.8095 .01473 L
Mistroke
.80964 .0148 L
.8098 .01491 L
.81008 .0151 L
.81231 .01656 L
.81358 .01724 L
.8142 .01751 L
.81476 .01772 L
.81532 .0179 L
.81593 .01804 L
.81626 .0181 L
.81641 .01812 L
.81657 .01814 L
.81671 .01816 L
.81686 .01817 L
.81694 .01817 L
.81702 .01818 L
.81717 .01818 L
.81732 .01819 L
.81748 .01819 L
.81763 .01818 L
.81776 .01818 L
.81785 .01817 L
.81792 .01817 L
.8181 .01816 L
.81841 .01812 L
.81871 .01807 L
.81904 .01801 L
.81971 .01783 L
.82035 .01762 L
.82094 .01737 L
.82206 .01682 L
.82329 .0161 L
.82396 .01568 L
.82459 .01526 L
.82513 .01489 L
.82528 .01479 L
.82544 .01474 L
.82558 .01484 L
.82573 .01494 L
.82698 .01576 L
.8292 .01703 L
.82984 .01732 L
.83044 .01755 L
.83099 .01773 L
.83157 .01787 L
.83187 .01794 L
.8322 .01799 L
.83234 .01801 L
.8325 .01803 L
.83264 .01804 L
Mistroke
.83278 .01805 L
.83287 .01805 L
.83295 .01806 L
.83304 .01806 L
.83313 .01806 L
.83321 .01807 L
.8333 .01807 L
.83339 .01807 L
.83346 .01806 L
.83361 .01806 L
.83369 .01805 L
.83377 .01805 L
.83393 .01804 L
.83409 .01802 L
.8344 .01798 L
.83473 .01793 L
.83532 .0178 L
.83596 .01761 L
.83666 .01735 L
.83908 .0161 L
.84022 .0154 L
.84052 .0152 L
.84084 .01499 L
.841 .01489 L
.84114 .0148 L
.84128 .01472 L
.84142 .01481 L
.84205 .01522 L
.84273 .01565 L
.84393 .01637 L
.84517 .017 L
.84633 .01747 L
.84692 .01765 L
.84754 .0178 L
.8479 .01786 L
.84824 .01791 L
.84838 .01792 L
.84854 .01794 L
.84863 .01794 L
.84871 .01795 L
.84887 .01796 L
.84902 .01796 L
.84915 .01796 L
.8493 .01796 L
.84939 .01796 L
.84946 .01796 L
.84962 .01795 L
.84978 .01794 L
.84994 .01792 L
.85009 .01791 L
Mistroke
.85063 .01783 L
.8509 .01777 L
.8512 .0177 L
.8525 .01728 L
.85371 .01674 L
.85496 .01606 L
.85615 .01534 L
.85667 .01501 L
.85681 .01493 L
.85695 .01483 L
.85709 .01475 L
.85722 .01476 L
.85738 .01486 L
.85754 .01496 L
.85783 .01515 L
.85839 .01549 L
.85962 .01621 L
.86078 .01681 L
.86192 .01729 L
.86297 .01761 L
.86351 .01773 L
.86379 .01778 L
.86409 .01782 L
.86424 .01784 L
.8644 .01785 L
.86457 .01786 L
.86472 .01787 L
.86487 .01787 L
.86501 .01788 L
.86516 .01788 L
.86524 .01787 L
.86532 .01787 L
.86548 .01786 L
.86555 .01786 L
.86564 .01785 L
.86594 .01783 L
.86611 .01781 L
.86629 .01778 L
.86661 .01772 L
.86725 .01758 L
.86784 .0174 L
.86903 .01694 L
.87013 .01641 L
.87142 .01569 L
.87205 .01531 L
.87233 .01514 L
.87263 .01495 L
.87278 .01486 L
.87293 .01476 L
.87308 .01475 L
Mistroke
.87321 .01484 L
.87383 .01521 L
.87511 .01597 L
.8762 .01655 L
.87736 .01707 L
.87793 .01728 L
.87856 .01747 L
.87913 .01761 L
.87966 .01771 L
.87997 .01775 L
.88014 .01777 L
.88029 .01778 L
.88043 .01779 L
.88057 .0178 L
.88073 .0178 L
.88087 .0178 L
.88095 .0178 L
.88104 .0178 L
.88119 .0178 L
.88128 .0178 L
.88136 .01779 L
.88154 .01778 L
.8817 .01777 L
.88184 .01775 L
.88217 .01771 L
.88275 .0176 L
.88336 .01745 L
.88447 .01708 L
.88565 .01655 L
.88697 .01585 L
.8881 .01519 L
.88838 .01502 L
.88867 .01484 L
.88876 .01479 L
.88884 .01474 L
.889 .01478 L
.88914 .01487 L
.8893 .01496 L
.89061 .01573 L
.89181 .01638 L
.89305 .01695 L
.89421 .01736 L
.89479 .01751 L
.89541 .01763 L
.89577 .01768 L
.89594 .0177 L
.89611 .01772 L
.89625 .01773 L
.89641 .01774 L
.8965 .01774 L
Mistroke
.89658 .01774 L
.89674 .01775 L
.89688 .01775 L
.89703 .01774 L
.89717 .01774 L
.8973 .01773 L
.89745 .01772 L
.89762 .01771 L
.89792 .01767 L
.89823 .01762 L
.89857 .01756 L
.89916 .01742 L
.90022 .01708 L
.90139 .01658 L
.90253 .016 L
.90373 .01533 L
.90435 .01496 L
.90452 .01486 L
.90462 .0148 L
.90471 .01475 L
.90479 .01473 L
.90488 .01479 L
.90504 .01488 L
.90624 .01558 L
.90864 .01679 L
.90985 .01724 L
.91054 .01744 L
.91087 .01751 L
.91118 .01757 L
.91149 .01762 L
.91178 .01765 L
.91193 .01767 L
.9121 .01768 L
.91219 .01769 L
.91227 .01769 L
.91235 .01769 L
.91243 .0177 L
.91258 .0177 L
.91271 .0177 L
.91287 .0177 L
.91301 .01769 L
.91316 .01769 L
.91333 .01768 L
.91363 .01765 L
.91389 .01761 L
.91419 .01757 L
.91479 .01744 L
.91534 .01729 L
.91586 .01713 L
.9183 .01604 L
Mistroke
.91938 .01544 L
.91997 .0151 L
.92027 .01493 L
.92039 .01486 L
.92053 .01477 L
.92068 .01474 L
.92083 .01483 L
.92116 .01502 L
.92172 .01535 L
.92282 .01596 L
.92413 .0166 L
.92532 .01708 L
.9259 .01727 L
.92653 .01743 L
.92682 .01749 L
.92712 .01755 L
.92741 .01759 L
.92767 .01762 L
.92781 .01763 L
.92797 .01764 L
.92812 .01765 L
.92821 .01766 L
.92829 .01766 L
.92844 .01766 L
.92857 .01766 L
.92872 .01766 L
.92887 .01766 L
.92895 .01766 L
.92903 .01765 L
.9292 .01764 L
.9295 .01761 L
.92986 .01757 L
.93019 .01751 L
.93079 .01738 L
.93145 .0172 L
.93264 .01675 L
.93487 .01565 L
.93551 .01529 L
.93583 .01511 L
.93612 .01494 L
.93638 .01479 L
.93652 .01472 L
.93666 .0148 L
.93725 .01514 L
.93857 .01588 L
.93978 .01648 L
.94091 .01696 L
.9415 .01716 L
.94213 .01734 L
.94245 .01742 L
Mistroke
.94281 .01749 L
.94313 .01754 L
.94343 .01758 L
.94373 .01761 L
.94389 .01762 L
.94398 .01763 L
.94406 .01763 L
.94421 .01764 L
.94435 .01764 L
.94443 .01764 L
.94451 .01764 L
.94466 .01764 L
.9448 .01763 L
.94495 .01763 L
.94509 .01762 L
.94522 .01761 L
.94553 .01757 L
.94583 .01753 L
.94643 .01742 L
.94707 .01725 L
.94823 .01685 L
.9493 .01639 L
.95058 .01573 L
.95121 .01539 L
.95178 .01506 L
.95205 .0149 L
.95219 .01483 L
.95231 .01476 L
.95244 .01475 L
.95257 .01482 L
.95286 .01499 L
.95403 .01565 L
.95634 .01677 L
.95697 .01701 L
.95764 .01723 L
.95827 .01739 L
.95884 .0175 L
.95912 .01755 L
.95942 .01758 L
.95956 .01759 L
.95971 .01761 L
.95985 .01761 L
.95998 .01762 L
.96014 .01762 L
.96028 .01763 L
.96044 .01762 L
.96052 .01762 L
.96061 .01762 L
.96075 .01761 L
.96091 .01761 L
Mistroke
.96106 .01759 L
.9612 .01758 L
.96174 .01751 L
.96205 .01746 L
.96233 .0174 L
.96341 .0171 L
.96457 .01665 L
.96566 .01614 L
.96687 .0155 L
.96753 .01513 L
.96785 .01495 L
.96799 .01487 L
.96814 .01478 L
.96829 .01474 L
.96843 .01482 L
.9687 .01497 L
.9693 .01531 L
.97057 .016 L
.97173 .01656 L
.97281 .01699 L
.97358 .01724 L
.97442 .01744 L
.97465 .01749 L
.97489 .01753 L
.97511 .01755 L
.97534 .01758 L
.97546 .01759 L
.97557 .0176 L
.97568 .01761 L
.97578 .01761 L
.97588 .01762 L
.97598 .01762 L
.97608 .01762 L
.97619 .01762 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.00459847 0.64881 0.188537 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.491929 0.0484262 0.0147151 0.0443004 [
[.00767 -0.0125 -9 -9 ]
[.00767 -0.0125 9 0 ]
[.2498 -0.0125 -6 -9 ]
[.2498 -0.0125 6 0 ]
[.49193 -0.0125 -3 -9 ]
[.49193 -0.0125 3 0 ]
[.73406 -0.0125 -3 -9 ]
[.73406 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .10332 -6 -4.5 ]
[-0.0125 .10332 0 4.5 ]
[-0.0125 .19192 -6 -4.5 ]
[-0.0125 .19192 0 4.5 ]
[-0.0125 .28052 -6 -4.5 ]
[-0.0125 .28052 0 4.5 ]
[-0.0125 .36912 -6 -4.5 ]
[-0.0125 .36912 0 4.5 ]
[-0.0125 .45772 -12 -4.5 ]
[-0.0125 .45772 0 4.5 ]
[-0.0125 .54632 -12 -4.5 ]
[-0.0125 .54632 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.00767 0 m
.00767 .00625 L
s
[(-10)] .00767 -0.0125 0 1 Mshowa
.2498 0 m
.2498 .00625 L
s
[(-5)] .2498 -0.0125 0 1 Mshowa
.49193 0 m
.49193 .00625 L
s
[(0)] .49193 -0.0125 0 1 Mshowa
.73406 0 m
.73406 .00625 L
s
[(5)] .73406 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05609 0 m
.05609 .00375 L
s
.10452 0 m
.10452 .00375 L
s
.15295 0 m
.15295 .00375 L
s
.20137 0 m
.20137 .00375 L
s
.29822 0 m
.29822 .00375 L
s
.34665 0 m
.34665 .00375 L
s
.39508 0 m
.39508 .00375 L
s
.4435 0 m
.4435 .00375 L
s
.54036 0 m
.54036 .00375 L
s
.58878 0 m
.58878 .00375 L
s
.63721 0 m
.63721 .00375 L
s
.68563 0 m
.68563 .00375 L
s
.78249 0 m
.78249 .00375 L
s
.83091 0 m
.83091 .00375 L
s
.87934 0 m
.87934 .00375 L
s
.92776 0 m
.92776 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .10332 m
.00625 .10332 L
s
[(2)] -0.0125 .10332 1 0 Mshowa
0 .19192 m
.00625 .19192 L
s
[(4)] -0.0125 .19192 1 0 Mshowa
0 .28052 m
.00625 .28052 L
s
[(6)] -0.0125 .28052 1 0 Mshowa
0 .36912 m
.00625 .36912 L
s
[(8)] -0.0125 .36912 1 0 Mshowa
0 .45772 m
.00625 .45772 L
s
[(10)] -0.0125 .45772 1 0 Mshowa
0 .54632 m
.00625 .54632 L
s
[(12)] -0.0125 .54632 1 0 Mshowa
.125 Mabswid
0 .03687 m
.00375 .03687 L
s
0 .05902 m
.00375 .05902 L
s
0 .08117 m
.00375 .08117 L
s
0 .12547 m
.00375 .12547 L
s
0 .14762 m
.00375 .14762 L
s
0 .16977 m
.00375 .16977 L
s
0 .21407 m
.00375 .21407 L
s
0 .23622 m
.00375 .23622 L
s
0 .25837 m
.00375 .25837 L
s
0 .30267 m
.00375 .30267 L
s
0 .32482 m
.00375 .32482 L
s
0 .34697 m
.00375 .34697 L
s
0 .39127 m
.00375 .39127 L
s
0 .41342 m
.00375 .41342 L
s
0 .43557 m
.00375 .43557 L
s
0 .47987 m
.00375 .47987 L
s
0 .50202 m
.00375 .50202 L
s
0 .52417 m
.00375 .52417 L
s
0 .56847 m
.00375 .56847 L
s
0 .59062 m
.00375 .59062 L
s
0 .61277 m
.00375 .61277 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.00767 .61178 m
.00767 .61803 L
s
.2498 .61178 m
.2498 .61803 L
s
.49193 .61178 m
.49193 .61803 L
s
.73406 .61178 m
.73406 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.05609 .61428 m
.05609 .61803 L
s
.10452 .61428 m
.10452 .61803 L
s
.15295 .61428 m
.15295 .61803 L
s
.20137 .61428 m
.20137 .61803 L
s
.29822 .61428 m
.29822 .61803 L
s
.34665 .61428 m
.34665 .61803 L
s
.39508 .61428 m
.39508 .61803 L
s
.4435 .61428 m
.4435 .61803 L
s
.54036 .61428 m
.54036 .61803 L
s
.58878 .61428 m
.58878 .61803 L
s
.63721 .61428 m
.63721 .61803 L
s
.68563 .61428 m
.68563 .61803 L
s
.78249 .61428 m
.78249 .61803 L
s
.83091 .61428 m
.83091 .61803 L
s
.87934 .61428 m
.87934 .61803 L
s
.92776 .61428 m
.92776 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .10332 m
1 .10332 L
s
.99375 .19192 m
1 .19192 L
s
.99375 .28052 m
1 .28052 L
s
.99375 .36912 m
1 .36912 L
s
.99375 .45772 m
1 .45772 L
s
.99375 .54632 m
1 .54632 L
s
.125 Mabswid
.99625 .03687 m
1 .03687 L
s
.99625 .05902 m
1 .05902 L
s
.99625 .08117 m
1 .08117 L
s
.99625 .12547 m
1 .12547 L
s
.99625 .14762 m
1 .14762 L
s
.99625 .16977 m
1 .16977 L
s
.99625 .21407 m
1 .21407 L
s
.99625 .23622 m
1 .23622 L
s
.99625 .25837 m
1 .25837 L
s
.99625 .30267 m
1 .30267 L
s
.99625 .32482 m
1 .32482 L
s
.99625 .34697 m
1 .34697 L
s
.99625 .39127 m
1 .39127 L
s
.99625 .41342 m
1 .41342 L
s
.99625 .43557 m
1 .43557 L
s
.99625 .47987 m
1 .47987 L
s
.99625 .50202 m
1 .50202 L
s
.99625 .52417 m
1 .52417 L
s
.99625 .56847 m
1 .56847 L
s
.99625 .59062 m
1 .59062 L
s
.99625 .61277 m
1 .61277 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .01472 m
.02381 .01827 L
s
.03995 .01472 m
.03995 .01828 L
s
.05609 .01472 m
.05609 .01831 L
s
.07224 .01472 m
.07224 .01836 L
s
.08838 .01472 m
.08838 .01841 L
s
.10452 .01472 m
.10452 .01848 L
s
.12066 .01472 m
.12066 .01857 L
s
.1368 .01472 m
.1368 .01868 L
s
.15295 .01472 m
.15295 .0188 L
s
.16909 .01472 m
.16909 .01895 L
s
.18523 .01472 m
.18523 .01913 L
s
.20137 .01472 m
.20137 .01934 L
s
.21751 .01472 m
.21751 .01958 L
s
.23366 .01472 m
.23366 .01988 L
s
.2498 .01472 m
.2498 .02023 L
s
.26594 .01472 m
.26594 .02064 L
s
.28208 .01472 m
.28208 .02113 L
s
.29822 .01472 m
.29822 .02165 L
s
.31437 .01472 m
.31437 .02208 L
s
.33051 .01472 m
.33051 .02176 L
s
.34665 .01472 m
.34665 .01827 L
s
.36279 .01472 m
.36279 .09426 L
s
.37893 .01472 m
.37893 .60332 L
s
.39508 .01472 m
.39508 .59911 L
s
.41122 .01472 m
.41122 .09851 L
s
.42736 .01472 m
.42736 .02013 L
s
.4435 .01472 m
.4435 .0186 L
s
.45964 .01472 m
.45964 .01866 L
s
.47579 .01472 m
.47579 .01839 L
s
.49193 .01472 m
.49193 .01826 L
s
.50807 .01472 m
.50807 .01839 L
s
.52421 .01472 m
.52421 .01866 L
s
.54036 .01472 m
.54036 .0186 L
s
.5565 .01472 m
.5565 .02013 L
s
.57264 .01472 m
.57264 .09851 L
s
.58878 .01472 m
.58878 .59911 L
s
.60492 .01472 m
.60492 .60332 L
s
.62107 .01472 m
.62107 .09426 L
s
.63721 .01472 m
.63721 .01827 L
s
.65335 .01472 m
.65335 .02176 L
s
.66949 .01472 m
.66949 .02208 L
s
.68563 .01472 m
.68563 .02165 L
s
.70178 .01472 m
.70178 .02113 L
s
.71792 .01472 m
.71792 .02064 L
s
.73406 .01472 m
.73406 .02023 L
s
.7502 .01472 m
.7502 .01988 L
s
.76634 .01472 m
.76634 .01958 L
s
.78249 .01472 m
.78249 .01934 L
s
.79863 .01472 m
.79863 .01913 L
s
.81477 .01472 m
.81477 .01895 L
s
.83091 .01472 m
.83091 .0188 L
s
.84705 .01472 m
.84705 .01868 L
s
.8632 .01472 m
.8632 .01857 L
s
.87934 .01472 m
.87934 .01848 L
s
.89548 .01472 m
.89548 .01841 L
s
.91162 .01472 m
.91162 .01836 L
s
.92776 .01472 m
.92776 .01831 L
s
.94391 .01472 m
.94391 .01828 L
s
.96005 .01472 m
.96005 .01827 L
s
.97619 .01472 m
.97619 .01826 L
s
.015 w
.02381 .01827 Mdot
.03995 .01828 Mdot
.05609 .01831 Mdot
.07224 .01836 Mdot
.08838 .01841 Mdot
.10452 .01848 Mdot
.12066 .01857 Mdot
.1368 .01868 Mdot
.15295 .0188 Mdot
.16909 .01895 Mdot
.18523 .01913 Mdot
.20137 .01934 Mdot
.21751 .01958 Mdot
.23366 .01988 Mdot
.2498 .02023 Mdot
.26594 .02064 Mdot
.28208 .02113 Mdot
.29822 .02165 Mdot
.31437 .02208 Mdot
.33051 .02176 Mdot
.34665 .01827 Mdot
.36279 .09426 Mdot
.37893 .60332 Mdot
.39508 .59911 Mdot
.41122 .09851 Mdot
.42736 .02013 Mdot
.4435 .0186 Mdot
.45964 .01866 Mdot
.47579 .01839 Mdot
.49193 .01826 Mdot
.50807 .01839 Mdot
.52421 .01866 Mdot
.54036 .0186 Mdot
.5565 .02013 Mdot
.57264 .09851 Mdot
.58878 .59911 Mdot
.60492 .60332 Mdot
.62107 .09426 Mdot
.63721 .01827 Mdot
.65335 .02176 Mdot
.66949 .02208 Mdot
.68563 .02165 Mdot
.70178 .02113 Mdot
.71792 .02064 Mdot
.73406 .02023 Mdot
.7502 .01988 Mdot
.76634 .01958 Mdot
.78249 .01934 Mdot
.79863 .01913 Mdot
.81477 .01895 Mdot
.83091 .0188 Mdot
.84705 .01868 Mdot
.8632 .01857 Mdot
.87934 .01848 Mdot
.89548 .01841 Mdot
.91162 .01836 Mdot
.92776 .01831 Mdot
.94391 .01828 Mdot
.96005 .01827 Mdot
.97619 .01826 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.00459847 0.97619 0.188537 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.047619 0.0147151 0.0363327 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .10555 -18 -4.5 ]
[-0.0125 .10555 0 4.5 ]
[-0.0125 .19638 -6 -4.5 ]
[-0.0125 .19638 0 4.5 ]
[-0.0125 .28721 -18 -4.5 ]
[-0.0125 .28721 0 4.5 ]
[-0.0125 .37804 -12 -4.5 ]
[-0.0125 .37804 0 4.5 ]
[-0.0125 .46887 -24 -4.5 ]
[-0.0125 .46887 0 4.5 ]
[-0.0125 .5597 -12 -4.5 ]
[-0.0125 .5597 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .10555 m
.00625 .10555 L
s
[(2.5)] -0.0125 .10555 1 0 Mshowa
0 .19638 m
.00625 .19638 L
s
[(5)] -0.0125 .19638 1 0 Mshowa
0 .28721 m
.00625 .28721 L
s
[(7.5)] -0.0125 .28721 1 0 Mshowa
0 .37804 m
.00625 .37804 L
s
[(10)] -0.0125 .37804 1 0 Mshowa
0 .46887 m
.00625 .46887 L
s
[(12.5)] -0.0125 .46887 1 0 Mshowa
0 .5597 m
.00625 .5597 L
s
[(15)] -0.0125 .5597 1 0 Mshowa
.125 Mabswid
0 .03288 m
.00375 .03288 L
s
0 .05105 m
.00375 .05105 L
s
0 .06921 m
.00375 .06921 L
s
0 .08738 m
.00375 .08738 L
s
0 .12371 m
.00375 .12371 L
s
0 .14188 m
.00375 .14188 L
s
0 .16005 m
.00375 .16005 L
s
0 .17821 m
.00375 .17821 L
s
0 .21454 m
.00375 .21454 L
s
0 .23271 m
.00375 .23271 L
s
0 .25088 m
.00375 .25088 L
s
0 .26904 m
.00375 .26904 L
s
0 .30538 m
.00375 .30538 L
s
0 .32354 m
.00375 .32354 L
s
0 .34171 m
.00375 .34171 L
s
0 .35988 m
.00375 .35988 L
s
0 .39621 m
.00375 .39621 L
s
0 .41437 m
.00375 .41437 L
s
0 .43254 m
.00375 .43254 L
s
0 .45071 m
.00375 .45071 L
s
0 .48704 m
.00375 .48704 L
s
0 .50521 m
.00375 .50521 L
s
0 .52337 m
.00375 .52337 L
s
0 .54154 m
.00375 .54154 L
s
0 .57787 m
.00375 .57787 L
s
0 .59604 m
.00375 .59604 L
s
0 .6142 m
.00375 .6142 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .10555 m
1 .10555 L
s
.99375 .19638 m
1 .19638 L
s
.99375 .28721 m
1 .28721 L
s
.99375 .37804 m
1 .37804 L
s
.99375 .46887 m
1 .46887 L
s
.99375 .5597 m
1 .5597 L
s
.125 Mabswid
.99625 .03288 m
1 .03288 L
s
.99625 .05105 m
1 .05105 L
s
.99625 .06921 m
1 .06921 L
s
.99625 .08738 m
1 .08738 L
s
.99625 .12371 m
1 .12371 L
s
.99625 .14188 m
1 .14188 L
s
.99625 .16005 m
1 .16005 L
s
.99625 .17821 m
1 .17821 L
s
.99625 .21454 m
1 .21454 L
s
.99625 .23271 m
1 .23271 L
s
.99625 .25088 m
1 .25088 L
s
.99625 .26904 m
1 .26904 L
s
.99625 .30538 m
1 .30538 L
s
.99625 .32354 m
1 .32354 L
s
.99625 .34171 m
1 .34171 L
s
.99625 .35988 m
1 .35988 L
s
.99625 .39621 m
1 .39621 L
s
.99625 .41437 m
1 .41437 L
s
.99625 .43254 m
1 .43254 L
s
.99625 .45071 m
1 .45071 L
s
.99625 .48704 m
1 .48704 L
s
.99625 .50521 m
1 .50521 L
s
.99625 .52337 m
1 .52337 L
s
.99625 .54154 m
1 .54154 L
s
.99625 .57787 m
1 .57787 L
s
.99625 .59604 m
1 .59604 L
s
.99625 .6142 m
1 .6142 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
0 0 1 r
.5 Mabswid
[ .01 ] 0 setdash
.02381 .01762 m
.02395 .01762 L
.02408 .01762 L
.02423 .01761 L
.02437 .0176 L
.02462 .01758 L
.02489 .01756 L
.02519 .01751 L
.02551 .01746 L
.02608 .01733 L
.02722 .01699 L
.02847 .01647 L
.02973 .01584 L
.03043 .01546 L
.03109 .01509 L
.03139 .01492 L
.03155 .01483 L
.03171 .01474 L
.03179 .01474 L
.03189 .0148 L
.03205 .01489 L
.03238 .01508 L
.03355 .01573 L
.03596 .01687 L
.03717 .01727 L
.03785 .01744 L
.03819 .0175 L
.0385 .01755 L
.03879 .01758 L
.03894 .01759 L
.0391 .01761 L
.03918 .01761 L
.03926 .01762 L
.03941 .01762 L
.03949 .01762 L
.03958 .01763 L
.03967 .01763 L
.03976 .01763 L
.03991 .01762 L
.04006 .01762 L
.04019 .01761 L
.04033 .0176 L
.04065 .01757 L
.04095 .01754 L
.04147 .01745 L
.04204 .01732 L
.04319 .01696 L
.04573 .01578 L
.04631 .01546 L
.04694 .01511 L
Mistroke
.04724 .01493 L
.04739 .01485 L
.04752 .01477 L
.04765 .01473 L
.04778 .01481 L
.04805 .01497 L
.0492 .01562 L
.05046 .01627 L
.05165 .01681 L
.05274 .01719 L
.05332 .01736 L
.05388 .01748 L
.05417 .01753 L
.05447 .01757 L
.05463 .01759 L
.0548 .01761 L
.05495 .01762 L
.05511 .01763 L
.05525 .01764 L
.0554 .01764 L
.05553 .01764 L
.05566 .01764 L
.05581 .01764 L
.05595 .01763 L
.0561 .01762 L
.05625 .01761 L
.05652 .01759 L
.05676 .01756 L
.05732 .01747 L
.05789 .01734 L
.05849 .01716 L
.05959 .01676 L
.06208 .01552 L
.06267 .01519 L
.063 .015 L
.0633 .01482 L
.06346 .01473 L
.06355 .01475 L
.06363 .0148 L
.064 .01501 L
.06464 .01538 L
.06589 .01606 L
.06706 .01663 L
.06826 .0171 L
.06878 .01727 L
.06934 .01741 L
.06967 .01749 L
.06996 .01754 L
.07027 .01759 L
.07055 .01762 L
Mistroke
.07071 .01763 L
.07085 .01765 L
.07101 .01765 L
.07109 .01766 L
.07118 .01766 L
.07126 .01766 L
.07134 .01767 L
.07149 .01767 L
.07159 .01766 L
.07167 .01766 L
.07175 .01766 L
.07184 .01766 L
.07199 .01765 L
.07213 .01764 L
.07243 .01761 L
.07272 .01757 L
.07299 .01753 L
.07359 .0174 L
.07425 .01722 L
.07557 .01674 L
.07679 .01616 L
.07787 .01558 L
.07844 .01525 L
.07904 .01491 L
.07919 .01482 L
.07928 .01477 L
.07936 .01472 L
.07945 .01477 L
.07954 .01482 L
.07971 .01492 L
.08032 .01527 L
.08152 .01595 L
.0827 .01654 L
.08394 .01706 L
.085 .01739 L
.0856 .01753 L
.08588 .01758 L
.08617 .01762 L
.08633 .01764 L
.08648 .01766 L
.08663 .01767 L
.08677 .01768 L
.08693 .01769 L
.08702 .0177 L
.08711 .0177 L
.08726 .0177 L
.08734 .0177 L
.08742 .0177 L
.08758 .0177 L
.08772 .01769 L
Mistroke
.08786 .01768 L
.088 .01767 L
.08832 .01764 L
.08861 .0176 L
.08913 .01751 L
.0897 .01738 L
.09085 .017 L
.09339 .01579 L
.09397 .01546 L
.09459 .0151 L
.09489 .01492 L
.09504 .01483 L
.09518 .01475 L
.0953 .01475 L
.09543 .01483 L
.09571 .01499 L
.09685 .01566 L
.0981 .01634 L
.0993 .01689 L
.10038 .01729 L
.10097 .01746 L
.10153 .01758 L
.10181 .01763 L
.10211 .01768 L
.10227 .0177 L
.10244 .01771 L
.10259 .01773 L
.10275 .01774 L
.10289 .01774 L
.10304 .01775 L
.10317 .01775 L
.1033 .01775 L
.10345 .01774 L
.10358 .01774 L
.10374 .01773 L
.10389 .01772 L
.10416 .01769 L
.1044 .01766 L
.10496 .01757 L
.10552 .01743 L
.10613 .01725 L
.10722 .01683 L
.10971 .01555 L
.1103 .0152 L
.11063 .01501 L
.11093 .01482 L
.11102 .01477 L
.11111 .01472 L
.1112 .01477 L
.1113 .01483 L
Mistroke
.11162 .01502 L
.11226 .01541 L
.11343 .01608 L
.11469 .01671 L
.11593 .01723 L
.11652 .01742 L
.11706 .01756 L
.1176 .01767 L
.11789 .01772 L
.1182 .01776 L
.11832 .01777 L
.11846 .01778 L
.11858 .01779 L
.11871 .0178 L
.11885 .0178 L
.119 .01781 L
.11914 .01781 L
.11927 .0178 L
.11943 .0178 L
.1195 .01779 L
.11959 .01779 L
.11988 .01777 L
.12005 .01775 L
.12022 .01773 L
.12054 .01768 L
.12117 .01754 L
.12174 .01739 L
.12289 .01696 L
.12399 .01645 L
.12515 .01582 L
.12578 .01545 L
.12638 .01509 L
.12663 .01493 L
.12676 .01485 L
.12689 .01477 L
.12703 .01474 L
.12718 .01483 L
.12744 .015 L
.1286 .0157 L
.13086 .0169 L
.13148 .01716 L
.13213 .0174 L
.1327 .01757 L
.13331 .01771 L
.13364 .01777 L
.13394 .01781 L
.13408 .01783 L
.13424 .01785 L
.13439 .01786 L
.13453 .01787 L
Mistroke
.13462 .01787 L
.13471 .01787 L
.13479 .01788 L
.13487 .01788 L
.13495 .01788 L
.13504 .01788 L
.13514 .01788 L
.13523 .01787 L
.13531 .01787 L
.13539 .01787 L
.13554 .01786 L
.1357 .01784 L
.13588 .01783 L
.13617 .01779 L
.13649 .01773 L
.13714 .01759 L
.13774 .01741 L
.13831 .01721 L
.14074 .01601 L
.14182 .01537 L
.14211 .01519 L
.14241 .015 L
.14255 .01491 L
.1427 .01481 L
.14283 .01473 L
.14297 .01479 L
.14313 .01489 L
.14329 .01499 L
.14359 .01518 L
.14416 .01553 L
.14526 .01619 L
.14655 .01687 L
.14775 .01738 L
.14839 .01759 L
.14898 .01775 L
.14929 .01781 L
.14962 .01787 L
.1498 .0179 L
.14997 .01792 L
.15014 .01793 L
.15031 .01795 L
.15046 .01795 L
.1506 .01796 L
.15074 .01796 L
.15087 .01796 L
.15102 .01796 L
.15117 .01796 L
.15132 .01795 L
.15149 .01794 L
.15179 .01791 L
Mistroke
.15208 .01787 L
.15273 .01774 L
.15333 .01758 L
.15398 .01735 L
.15517 .01684 L
.1574 .01557 L
.15804 .01516 L
.15836 .01496 L
.1585 .01487 L
.15865 .01477 L
.15878 .01475 L
.15891 .01483 L
.15919 .01501 L
.15978 .01539 L
.16107 .0162 L
.1623 .01687 L
.16348 .0174 L
.1641 .01763 L
.16476 .01782 L
.16531 .01794 L
.16562 .01799 L
.16592 .01802 L
.16605 .01804 L
.16619 .01805 L
.16631 .01806 L
.16644 .01806 L
.16657 .01807 L
.16672 .01807 L
.16687 .01807 L
.16699 .01806 L
.16714 .01806 L
.16727 .01805 L
.16742 .01803 L
.16758 .01802 L
.1679 .01798 L
.1682 .01792 L
.16876 .0178 L
.1693 .01764 L
.1705 .01717 L
.17181 .01649 L
.17304 .01575 L
.17364 .01536 L
.17419 .015 L
.17435 .01489 L
.1745 .01479 L
.17465 .01475 L
.17474 .01481 L
.17483 .01487 L
.17551 .01533 L
.17672 .01611 L
Mistroke
.17795 .01683 L
.17928 .01747 L
.17989 .0177 L
.18054 .01791 L
.1811 .01804 L
.18141 .01809 L
.18171 .01814 L
.18185 .01815 L
.182 .01817 L
.18215 .01818 L
.18228 .01818 L
.18243 .01819 L
.18252 .01819 L
.1826 .01819 L
.18274 .01819 L
.1829 .01818 L
.18304 .01818 L
.1832 .01816 L
.18335 .01815 L
.18349 .01814 L
.18383 .01809 L
.18415 .01803 L
.1847 .01789 L
.18521 .01773 L
.18638 .01726 L
.18865 .01596 L
.18928 .01555 L
.18993 .0151 L
.1902 .01491 L
.19035 .0148 L
.19049 .01473 L
.19057 .01478 L
.19066 .01484 L
.19081 .01495 L
.19111 .01516 L
.19245 .01607 L
.1937 .01684 L
.19495 .01749 L
.19557 .01775 L
.19613 .01795 L
.19669 .01811 L
.19722 .01822 L
.19751 .01827 L
.19778 .0183 L
.19793 .01831 L
.19807 .01832 L
.19815 .01833 L
.19824 .01833 L
.19839 .01833 L
.19854 .01833 L
Mistroke
.19869 .01833 L
.19885 .01832 L
.19894 .01832 L
.19902 .01831 L
.19918 .0183 L
.19936 .01828 L
.19969 .01823 L
.19999 .01818 L
.2003 .0181 L
.20088 .01793 L
.20201 .01748 L
.20322 .01684 L
.20437 .01612 L
.20543 .01538 L
.20599 .01498 L
.20615 .01486 L
.2063 .01475 L
.20644 .01478 L
.20658 .01489 L
.20785 .0158 L
.20906 .01662 L
.21039 .0174 L
.21099 .0177 L
.21163 .01797 L
.21218 .01816 L
.21279 .01832 L
.21314 .0184 L
.21331 .01842 L
.21347 .01845 L
.21362 .01846 L
.21378 .01848 L
.21387 .01849 L
.21395 .01849 L
.21403 .0185 L
.21411 .0185 L
.21426 .01851 L
.21439 .01851 L
.21448 .01851 L
.21456 .0185 L
.2147 .0185 L
.21486 .01849 L
.215 .01848 L
.21532 .01844 L
.21562 .01839 L
.21589 .01834 L
.21649 .01817 L
.21702 .01799 L
.21758 .01776 L
.22007 .01631 L
.22122 .01548 L
Mistroke
.22155 .01523 L
.22187 .01499 L
.222 .01488 L
.22215 .01477 L
.22231 .01478 L
.22245 .01489 L
.22467 .01654 L
.22581 .01728 L
.22703 .01793 L
.22763 .01819 L
.22819 .01838 L
.22869 .01852 L
.22898 .01858 L
.22924 .01863 L
.22952 .01867 L
.22967 .01868 L
.22983 .0187 L
.22996 .0187 L
.23009 .01871 L
.23023 .01871 L
.23037 .01871 L
.23046 .01871 L
.23054 .0187 L
.23062 .0187 L
.23071 .01869 L
.23086 .01868 L
.23103 .01866 L
.23134 .01862 L
.23162 .01856 L
.23226 .01839 L
.23284 .01819 L
.23416 .01756 L
.23536 .01681 L
.23664 .01587 L
.23726 .01539 L
.23757 .01514 L
.23785 .01491 L
.23798 .01481 L
.23811 .01473 L
.23824 .01483 L
.23838 .01495 L
.23895 .01541 L
.24131 .01719 L
.24248 .0179 L
.24356 .01842 L
.24413 .01862 L
.24473 .01879 L
.24505 .01885 L
.24534 .0189 L
.24551 .01892 L
Mistroke
.24566 .01893 L
.24574 .01894 L
.24583 .01894 L
.24593 .01895 L
.24601 .01895 L
.24615 .01895 L
.2463 .01895 L
.24645 .01894 L
.24658 .01893 L
.2467 .01892 L
.24683 .01891 L
.24709 .01887 L
.24738 .01882 L
.24769 .01875 L
.24825 .01858 L
.24888 .01833 L
.24947 .01805 L
.25081 .01724 L
.25197 .01639 L
.25323 .01535 L
.25355 .01507 L
.25373 .01492 L
.25382 .01485 L
.2539 .01478 L
.25404 .01478 L
.25419 .01491 L
.25451 .01518 L
.25571 .0162 L
.25796 .01787 L
.25854 .01822 L
.25916 .01854 L
.25969 .01877 L
.26026 .01897 L
.26059 .01906 L
.26088 .01912 L
.26118 .01918 L
.26132 .0192 L
.26146 .01921 L
.26161 .01922 L
.2617 .01923 L
.26178 .01923 L
.26193 .01924 L
.26208 .01924 L
.26217 .01924 L
.26226 .01923 L
.26235 .01923 L
.26244 .01922 L
.2626 .01921 L
.26277 .01919 L
.26308 .01914 L
Mistroke
.26341 .01907 L
.264 .01889 L
.26463 .01864 L
.26533 .01829 L
.26776 .01658 L
.26889 .01559 L
.26946 .01506 L
.26962 .01492 L
.26971 .01484 L
.26979 .01476 L
.26995 .01481 L
.27009 .01494 L
.2714 .01615 L
.2726 .01718 L
.27377 .01807 L
.27502 .01881 L
.27553 .01906 L
.27607 .01927 L
.27639 .01936 L
.27668 .01944 L
.27697 .0195 L
.27724 .01954 L
.27739 .01955 L
.27747 .01956 L
.27755 .01957 L
.27771 .01957 L
.27785 .01958 L
.27798 .01958 L
.27811 .01957 L
.27825 .01957 L
.2784 .01955 L
.27856 .01954 L
.27873 .01951 L
.27904 .01945 L
.27935 .01938 L
.27963 .01929 L
.28071 .01884 L
.28125 .01854 L
.28185 .01815 L
.28309 .01719 L
.28438 .01602 L
.28492 .0155 L
.28521 .01521 L
.28549 .01494 L
.28565 .01478 L
.28574 .01474 L
.28582 .01482 L
.28612 .01512 L
.2867 .0157 L
.28912 .01792 L
Mistroke
.2903 .01879 L
.29137 .01939 L
.29193 .01963 L
.29247 .0198 L
.29276 .01987 L
.29303 .01992 L
.29317 .01994 L
.29332 .01995 L
.2934 .01996 L
.29349 .01997 L
.29364 .01997 L
.2938 .01997 L
.29394 .01997 L
.29403 .01997 L
.2941 .01996 L
.29419 .01996 L
.29427 .01995 L
.29444 .01993 L
.29459 .01991 L
.29494 .01984 L
.29521 .01976 L
.29552 .01966 L
.29613 .01941 L
.29735 .0187 L
.29847 .01783 L
.29978 .01662 L
.30041 .01597 L
.30099 .01536 L
.30126 .01506 L
.30141 .01491 L
.30156 .01474 L
.30169 .01483 L
.30184 .01499 L
.3021 .01527 L
.30328 .01653 L
.30459 .01782 L
.30578 .01884 L
.30636 .01925 L
.30699 .01964 L
.30753 .01992 L
.30813 .02015 L
.30846 .02025 L
.30877 .02032 L
.30894 .02035 L
.30909 .02037 L
.30926 .02039 L
.30935 .0204 L
.30944 .0204 L
.3096 .02041 L
.30975 .0204 L
Mistroke
.30983 .0204 L
.30991 .0204 L
.31007 .02039 L
.31022 .02037 L
.31037 .02035 L
.31065 .02029 L
.31096 .02021 L
.31125 .02012 L
.31179 .01989 L
.31238 .01958 L
.31302 .01917 L
.31522 .01722 L
.31645 .01588 L
.31674 .01555 L
.31705 .01519 L
.31731 .01489 L
.31746 .01472 L
.3176 .01488 L
.31824 .01562 L
.31893 .01641 L
.32013 .01772 L
.3214 .01891 L
.32259 .01981 L
.32311 .02012 L
.32367 .02038 L
.32395 .02049 L
.32427 .02059 L
.32456 .02066 L
.32483 .02071 L
.32497 .02073 L
.32513 .02075 L
.32527 .02075 L
.3254 .02076 L
.32555 .02076 L
.32564 .02075 L
.32572 .02075 L
.32587 .02074 L
.32602 .02072 L
.32617 .0207 L
.32633 .02067 L
.32662 .0206 L
.32696 .02049 L
.32727 .02037 L
.32842 .01974 L
.3295 .01889 L
.3317 .01665 L
.3323 .01595 L
.33262 .01557 L
.33295 .01518 L
.33309 .01501 L
Mistroke
.33324 .01483 L
.33333 .01472 L
.33341 .0148 L
.33356 .01499 L
.33412 .01566 L
.33651 .01824 L
.33781 .01933 L
.33839 .01972 L
.33904 .02006 L
.33933 .02018 L
.33964 .02029 L
.33991 .02037 L
.34021 .02043 L
.34038 .02046 L
.34047 .02047 L
.34054 .02048 L
.34069 .02049 L
.34078 .0205 L
.34086 .0205 L
.34101 .0205 L
.34114 .0205 L
.34129 .02049 L
.34145 .02048 L
.34159 .02046 L
.34171 .02044 L
.342 .02038 L
.34226 .02031 L
.34251 .02023 L
.34307 .02 L
.34367 .01968 L
.34481 .01889 L
.34606 .01781 L
.34738 .01652 L
.34796 .01594 L
.3486 .01531 L
.34888 .01503 L
.34904 .01488 L
.34918 .01474 L
.34932 .01482 L
.34947 .01496 L
.34973 .0152 L
.35093 .01619 L
.35157 .01663 L
.35224 .01702 L
.35281 .01728 L
.35312 .0174 L
.35345 .0175 L
.35377 .01759 L
.35408 .01765 L
.35437 .01769 L
Mistroke
.35453 .01771 L
.35467 .01772 L
.35482 .01773 L
.35495 .01774 L
.3551 .01774 L
.35525 .01774 L
.35539 .01774 L
.35551 .01774 L
.35565 .01773 L
.35579 .01772 L
.35831 .01763 L
.35948 .0178 L
.36011 .01794 L
.36071 .01805 L
.36087 .01808 L
.36102 .01809 L
.3611 .0181 L
.36119 .01811 L
.36135 .01812 L
.36145 .01812 L
.36153 .01812 L
.36163 .01812 L
.36172 .01811 L
.36181 .0181 L
.36189 .01809 L
.36206 .01806 L
.36221 .01803 L
.36235 .01799 L
.36267 .01786 L
.36298 .01768 L
.36331 .01743 L
.36363 .01712 L
.36393 .01677 L
.3646 .01571 L
.36475 .01542 L
.36491 .01509 L
.36506 .01476 L
.3652 .015 L
.36534 .01537 L
.3655 .01578 L
.36583 .01675 L
.36693 .02093 L
.36813 .02739 L
.36936 .03646 L
.37049 .04706 L
.37302 .07997 L
.37533 .12181 L
.37784 .17943 L
.38277 .32022 L
.38752 .46162 L
Mistroke
.38991 .52167 L
.39209 .56432 L
.39329 .58165 L
.39385 .58799 L
.39444 .59357 L
.39476 .59614 L
.39506 .59814 L
.39536 .59984 L
.39564 .6011 L
.39597 .60223 L
.39614 .60266 L
.39622 .60284 L
.39632 .603 L
.39647 .6032 L
.39662 .6033 L
.39671 .60332 L
.3968 .60331 L
.39695 .60323 L
.39709 .60308 L
.39724 .60284 L
.39738 .60254 L
.39751 .6022 L
.39781 .60118 L
.39812 .59976 L
.39871 .5961 L
.39936 .59066 L
.40051 .5774 L
.40158 .56117 L
.40405 .51111 L
.4063 .45369 L
.41112 .31169 L
.41577 .18256 L
.41812 .12899 L
.42071 .0823 L
.42189 .0653 L
.42317 .05005 L
.42436 .03842 L
.42547 .02978 L
.42669 .02235 L
.42732 .01931 L
.42766 .0179 L
.42802 .01652 L
.42818 .01598 L
.42834 .01544 L
.42848 .015 L
.42863 .01489 L
.42877 .0153 L
.42892 .01571 L
.4292 .0164 L
.42985 .01778 L
Mistroke
.43045 .01874 L
.43105 .01945 L
.43135 .01972 L
.43168 .01995 L
.43201 .02013 L
.4322 .02021 L
.43237 .02026 L
.43253 .02031 L
.43261 .02032 L
.4327 .02034 L
.43279 .02035 L
.43287 .02036 L
.43302 .02037 L
.43317 .02037 L
.43325 .02037 L
.43333 .02037 L
.43348 .02035 L
.43362 .02034 L
.43378 .02031 L
.43393 .02028 L
.43427 .02019 L
.43488 .01997 L
.43545 .01971 L
.44007 .01714 L
.44241 .01586 L
.44305 .01551 L
.44374 .01512 L
.44406 .01494 L
.44423 .01484 L
.44432 .01479 L
.44439 .01474 L
.44453 .01477 L
.44468 .01485 L
.44499 .01503 L
.44746 .0164 L
.44854 .01692 L
.44973 .01739 L
.45027 .01756 L
.45085 .01771 L
.45117 .01777 L
.45147 .01782 L
.45176 .01786 L
.45191 .01787 L
.45204 .01788 L
.4522 .01789 L
.45235 .0179 L
.4525 .0179 L
.45259 .0179 L
.45267 .0179 L
.4528 .0179 L
Mistroke
.45295 .01789 L
.4531 .01789 L
.45324 .01788 L
.45357 .01784 L
.45388 .0178 L
.45422 .01773 L
.45455 .01766 L
.45572 .01729 L
.45696 .01673 L
.45918 .01545 L
.45976 .01508 L
.46005 .01489 L
.46019 .0148 L
.46032 .01472 L
.46046 .01481 L
.46062 .01491 L
.46095 .01513 L
.46154 .0155 L
.46374 .01677 L
.46495 .01731 L
.46553 .01752 L
.46606 .01768 L
.46664 .01781 L
.46695 .01786 L
.46728 .0179 L
.46745 .01792 L
.46763 .01794 L
.46771 .01794 L
.4678 .01795 L
.46796 .01795 L
.46811 .01795 L
.46825 .01795 L
.4684 .01795 L
.46849 .01795 L
.46857 .01794 L
.46873 .01793 L
.46887 .01792 L
.46914 .01789 L
.46944 .01785 L
.46975 .01779 L
.47033 .01766 L
.47085 .0175 L
.47206 .01704 L
.47335 .0164 L
.47449 .01576 L
.47511 .01538 L
.47571 .01501 L
.47597 .01485 L
.47612 .01476 L
.47626 .01476 L
Mistroke
.47634 .01481 L
.47642 .01486 L
.47657 .01495 L
.47686 .01513 L
.47792 .01575 L
.47916 .01642 L
.48032 .01695 L
.48153 .01737 L
.48218 .01753 L
.48254 .0176 L
.48286 .01765 L
.48314 .01768 L
.4833 .0177 L
.48344 .01771 L
.4836 .01772 L
.48368 .01772 L
.48376 .01772 L
.48391 .01773 L
.48406 .01773 L
.48421 .01773 L
.48434 .01772 L
.48449 .01772 L
.48463 .01771 L
.48489 .01768 L
.48517 .01765 L
.48547 .01761 L
.4858 .01754 L
.48647 .01738 L
.48767 .01698 L
.48898 .01641 L
.49022 .01577 L
.49133 .01514 L
.49164 .01496 L
.4918 .01487 L
.49196 .01478 L
.49211 .01474 L
.49227 .01483 L
.49254 .01499 L
.49478 .01621 L
.49605 .01678 L
.49666 .01702 L
.49723 .0172 L
.49779 .01735 L
.49839 .01748 L
.49873 .01753 L
.49903 .01757 L
.49933 .0176 L
.49948 .01761 L
.49964 .01761 L
.49972 .01762 L
Mistroke
.49981 .01762 L
.49989 .01762 L
.49997 .01762 L
.50012 .01762 L
.50027 .01762 L
.50036 .01761 L
.50046 .01761 L
.50063 .0176 L
.5008 .01759 L
.50095 .01757 L
.50155 .01749 L
.50185 .01743 L
.50218 .01736 L
.50341 .01699 L
.50454 .01653 L
.50585 .01589 L
.50642 .01558 L
.50706 .01522 L
.50733 .01506 L
.50763 .01489 L
.50777 .01481 L
.50792 .01473 L
.50804 .01477 L
.50817 .01485 L
.50936 .01553 L
.51067 .01624 L
.51186 .0168 L
.51245 .01703 L
.51308 .01725 L
.51363 .01741 L
.51423 .01755 L
.51454 .01761 L
.51487 .01766 L
.51505 .01768 L
.51522 .01769 L
.51539 .01771 L
.51554 .01772 L
.51569 .01772 L
.51584 .01773 L
.51593 .01773 L
.51601 .01773 L
.51616 .01773 L
.51631 .01772 L
.51645 .01772 L
.5166 .01771 L
.51675 .01769 L
.51706 .01766 L
.51735 .01762 L
.5179 .01751 L
.51849 .01736 L
Mistroke
.51913 .01716 L
.52134 .01616 L
.52257 .01547 L
.52318 .0151 L
.52344 .01494 L
.52359 .01485 L
.52373 .01476 L
.52387 .01475 L
.52401 .01484 L
.52431 .01503 L
.52494 .01541 L
.52626 .01619 L
.5275 .01684 L
.52815 .01713 L
.52884 .0174 L
.52945 .0176 L
.53011 .01776 L
.5304 .01782 L
.53071 .01787 L
.53101 .01791 L
.53128 .01793 L
.53142 .01794 L
.53155 .01795 L
.5317 .01795 L
.53185 .01795 L
.53201 .01795 L
.53209 .01795 L
.53217 .01795 L
.53233 .01794 L
.53247 .01793 L
.53275 .0179 L
.533 .01787 L
.53357 .01776 L
.53419 .01761 L
.53486 .01738 L
.53608 .01686 L
.53847 .0155 L
.53905 .01512 L
.53937 .01492 L
.53953 .01481 L
.53968 .01472 L
.53976 .01477 L
.53985 .01482 L
.54004 .01495 L
.54037 .01516 L
.54101 .01557 L
.54225 .01631 L
.54359 .017 L
.54421 .01726 L
.54486 .01749 L
Mistroke
.54542 .01765 L
.54603 .01778 L
.54633 .01783 L
.54649 .01785 L
.54666 .01787 L
.54681 .01788 L
.54688 .01788 L
.54697 .01789 L
.54712 .0179 L
.54726 .0179 L
.54739 .0179 L
.54754 .0179 L
.5477 .0179 L
.54784 .01789 L
.54798 .01788 L
.5481 .01787 L
.54838 .01784 L
.5487 .01779 L
.549 .01774 L
.54968 .01758 L
.5509 .01716 L
.55317 .01607 L
.55447 .01534 L
.55477 .01517 L
.55509 .01499 L
.55524 .0149 L
.55539 .01481 L
.55552 .01474 L
.55566 .01477 L
.5558 .01486 L
.55596 .01495 L
.55623 .0151 L
.55686 .01546 L
.558 .01609 L
.56052 .01746 L
.56293 .01883 L
.56397 .01942 L
.56511 .01996 L
.56542 .02008 L
.56574 .02019 L
.56602 .02027 L
.56618 .0203 L
.56632 .02033 L
.56647 .02035 L
.56661 .02036 L
.56676 .02037 L
.56684 .02037 L
.56692 .02037 L
.56706 .02037 L
.56718 .02035 L
Mistroke
.56733 .02033 L
.56747 .02031 L
.56762 .02027 L
.56778 .02022 L
.5681 .02008 L
.5684 .0199 L
.56868 .01969 L
.56932 .01905 L
.56967 .01857 L
.57 .01805 L
.57058 .01692 L
.57089 .01618 L
.57119 .0154 L
.57131 .01505 L
.57144 .01476 L
.57159 .0152 L
.57172 .01562 L
.5723 .01772 L
.57349 .02332 L
.5748 .03167 L
.57604 .04203 L
.57716 .05372 L
.57969 .08862 L
.582 .13156 L
.58451 .18952 L
.58944 .32867 L
.59419 .46699 L
.59658 .52545 L
.59876 .56677 L
.59996 .58341 L
.60052 .58945 L
.60111 .59472 L
.60143 .59712 L
.60173 .59896 L
.60203 .6005 L
.60231 .60163 L
.60247 .60213 L
.60264 .60258 L
.60281 .60293 L
.6029 .60307 L
.60299 .60318 L
.60307 .60325 L
.60315 .60329 L
.6033 .60332 L
.60345 .60326 L
.60354 .60318 L
.60362 .60308 L
.60377 .60285 L
.60392 .60254 L
.60418 .60176 L
Mistroke
.60447 .60062 L
.60479 .59903 L
.60535 .59527 L
.60588 .59075 L
.60708 .57676 L
.60836 .55655 L
.61094 .50161 L
.61337 .43642 L
.61802 .2962 L
.62037 .22729 L
.62296 .15987 L
.62544 .10655 L
.62771 .0691 L
.63006 .04155 L
.63136 .03086 L
.63258 .02331 L
.63375 .01819 L
.63433 .01626 L
.63449 .0158 L
.63467 .01534 L
.63475 .01514 L
.63483 .01493 L
.63498 .01485 L
.63512 .01516 L
.63525 .01542 L
.63553 .01595 L
.63604 .01673 L
.63633 .01708 L
.63664 .01739 L
.63693 .01762 L
.6372 .01779 L
.63748 .01793 L
.63764 .01798 L
.63779 .01803 L
.63792 .01806 L
.63805 .01808 L
.6382 .0181 L
.63834 .01811 L
.63842 .01812 L
.6385 .01812 L
.63859 .01812 L
.63868 .01812 L
.63883 .01811 L
.63892 .0181 L
.639 .01809 L
.63929 .01805 L
.63959 .018 L
.64023 .01786 L
.64058 .01779 L
.64091 .01773 L
Mistroke
.64121 .01768 L
.64149 .01765 L
.64164 .01764 L
.6418 .01763 L
.64196 .01762 L
.64205 .01761 L
.64213 .01761 L
.64221 .01761 L
.64229 .01761 L
.64244 .01761 L
.64259 .01762 L
.64272 .01762 L
.64303 .01764 L
.64336 .01766 L
.64369 .01769 L
.64405 .01771 L
.64422 .01772 L
.64438 .01773 L
.64453 .01774 L
.64462 .01774 L
.64469 .01774 L
.64484 .01774 L
.64499 .01774 L
.64511 .01773 L
.64525 .01773 L
.6454 .01771 L
.64556 .0177 L
.64585 .01766 L
.64616 .0176 L
.64645 .01753 L
.64712 .01731 L
.64821 .01677 L
.64937 .01596 L
.64998 .01546 L
.6503 .01517 L
.65047 .01502 L
.65064 .01486 L
.6508 .01472 L
.65088 .0148 L
.65096 .01487 L
.65125 .01515 L
.65182 .01572 L
.65439 .01821 L
.65555 .01916 L
.65617 .01958 L
.65681 .01994 L
.65713 .02009 L
.65748 .02023 L
.6578 .02033 L
.65809 .0204 L
Mistroke
.65839 .02046 L
.65855 .02048 L
.65871 .02049 L
.65885 .0205 L
.65898 .0205 L
.65913 .0205 L
.65929 .0205 L
.65942 .02049 L
.65955 .02047 L
.65969 .02045 L
.65984 .02042 L
.66008 .02037 L
.66035 .02029 L
.66096 .02006 L
.66153 .01976 L
.6628 .01886 L
.66399 .01775 L
.66506 .0166 L
.66567 .0159 L
.66596 .01555 L
.66624 .01523 L
.66637 .01507 L
.66653 .01488 L
.66667 .01472 L
.6668 .01488 L
.66741 .0156 L
.66865 .01704 L
.66972 .01817 L
.67087 .01921 L
.67154 .0197 L
.67215 .02008 L
.67273 .02037 L
.67303 .02049 L
.67335 .02059 L
.67364 .02066 L
.6739 .02071 L
.67403 .02073 L
.67417 .02074 L
.6743 .02075 L
.67442 .02076 L
.67456 .02076 L
.67469 .02076 L
.67483 .02075 L
.67499 .02074 L
.67514 .02072 L
.6753 .02069 L
.67559 .02063 L
.6759 .02054 L
.6762 .02044 L
.67675 .02019 L
Mistroke
.67798 .01942 L
.67904 .01853 L
.68019 .01738 L
.68143 .016 L
.68204 .0153 L
.6823 .01499 L
.68245 .01482 L
.68259 .01478 L
.68274 .01495 L
.68289 .01512 L
.68318 .01545 L
.6838 .01616 L
.68513 .01758 L
.68638 .01871 L
.68703 .0192 L
.68772 .01964 L
.68833 .01995 L
.68865 .02008 L
.68899 .0202 L
.68931 .02028 L
.68959 .02034 L
.68973 .02036 L
.68988 .02038 L
.69002 .02039 L
.69016 .0204 L
.69031 .02041 L
.69045 .0204 L
.69058 .0204 L
.69072 .02039 L
.69087 .02038 L
.69103 .02035 L
.69132 .0203 L
.69162 .02023 L
.69189 .02014 L
.69241 .01994 L
.69304 .01963 L
.69361 .01928 L
.6949 .01828 L
.69717 .01606 L
.69779 .01539 L
.69813 .01502 L
.69822 .01493 L
.6983 .01483 L
.69846 .01476 L
.6986 .01492 L
.69876 .01509 L
.69909 .01544 L
.69966 .01605 L
.70089 .01726 L
.70219 .01837 L
Mistroke
.7033 .01911 L
.70393 .01944 L
.70451 .01967 L
.7048 .01977 L
.70512 .01985 L
.70526 .01988 L
.70542 .01991 L
.70555 .01993 L
.70569 .01995 L
.70583 .01996 L
.70596 .01997 L
.70608 .01997 L
.7062 .01997 L
.70634 .01997 L
.70647 .01997 L
.70661 .01996 L
.70677 .01994 L
.70693 .01992 L
.70708 .0199 L
.70742 .01983 L
.70771 .01975 L
.70803 .01964 L
.70917 .01911 L
.71032 .01836 L
.71155 .01736 L
.7127 .01629 L
.71376 .01524 L
.71391 .01509 L
.71407 .01493 L
.71422 .01478 L
.71436 .01479 L
.7145 .01493 L
.71466 .01509 L
.71499 .01541 L
.71633 .01668 L
.7175 .01767 L
.71875 .01854 L
.7194 .01889 L
.72 .01916 L
.72055 .01935 L
.72086 .01943 L
.72114 .01949 L
.72127 .01951 L
.7214 .01953 L
.72152 .01955 L
.72165 .01956 L
.7218 .01957 L
.72195 .01958 L
.72209 .01958 L
.72222 .01958 L
Mistroke
.72235 .01957 L
.72248 .01956 L
.72262 .01955 L
.72277 .01954 L
.72307 .01949 L
.72336 .01943 L
.72393 .01927 L
.72454 .01903 L
.72563 .01845 L
.72694 .01754 L
.72813 .01656 L
.72925 .01556 L
.72982 .01503 L
.72997 .01489 L
.73006 .01481 L
.73014 .01473 L
.7303 .01484 L
.73044 .01498 L
.73174 .01615 L
.73295 .01714 L
.7341 .01795 L
.73474 .01833 L
.73534 .01863 L
.7359 .01885 L
.73619 .01895 L
.7365 .01904 L
.73676 .01911 L
.73705 .01916 L
.73718 .01918 L
.73731 .0192 L
.73744 .01921 L
.73755 .01922 L
.7377 .01923 L
.73778 .01923 L
.73786 .01924 L
.73795 .01924 L
.73804 .01924 L
.73819 .01923 L
.73834 .01923 L
.73847 .01922 L
.73862 .0192 L
.73878 .01918 L
.73914 .01912 L
.73948 .01904 L
.74012 .01884 L
.74072 .01859 L
.74128 .01832 L
.74254 .01754 L
.74481 .01577 L
.74543 .01524 L
Mistroke
.74559 .0151 L
.74577 .01494 L
.74585 .01487 L
.74594 .0148 L
.74609 .01477 L
.74618 .01484 L
.74626 .01492 L
.74642 .01505 L
.74672 .01531 L
.7473 .01579 L
.74966 .01755 L
.75031 .01793 L
.751 .01828 L
.75165 .01855 L
.75225 .01873 L
.75255 .01881 L
.75287 .01887 L
.75318 .01891 L
.75336 .01893 L
.75345 .01894 L
.75353 .01894 L
.75369 .01895 L
.75384 .01895 L
.75398 .01895 L
.75412 .01895 L
.7542 .01894 L
.75428 .01894 L
.75442 .01893 L
.75458 .01891 L
.75475 .01889 L
.75502 .01884 L
.75532 .01878 L
.75593 .0186 L
.7565 .0184 L
.75702 .01816 L
.75947 .01663 L
.76056 .0158 L
.76115 .01533 L
.76144 .01509 L
.76171 .01487 L
.76184 .01476 L
.76198 .01478 L
.76213 .01489 L
.76228 .01502 L
.76291 .01552 L
.76401 .01637 L
.76532 .01726 L
.76651 .01791 L
.7671 .01817 L
.76773 .01839 L
Mistroke
.76802 .01848 L
.76833 .01855 L
.76861 .01861 L
.76888 .01865 L
.76902 .01867 L
.76918 .01868 L
.76926 .01869 L
.76934 .0187 L
.7695 .0187 L
.76965 .01871 L
.76978 .01871 L
.76994 .01871 L
.77008 .0187 L
.77016 .0187 L
.77024 .01869 L
.77041 .01868 L
.77072 .01864 L
.77107 .01857 L
.7714 .0185 L
.77201 .01832 L
.77267 .01807 L
.77386 .01747 L
.7761 .01599 L
.77665 .01558 L
.77724 .01513 L
.7774 .01501 L
.77757 .01487 L
.77772 .01476 L
.7778 .01474 L
.77788 .0148 L
.77849 .01526 L
.77979 .01621 L
.78102 .01702 L
.78221 .01766 L
.78283 .01793 L
.78349 .01817 L
.78405 .01832 L
.78437 .01839 L
.78466 .01844 L
.7848 .01845 L
.78493 .01847 L
.78505 .01848 L
.78518 .01849 L
.78532 .0185 L
.78545 .0185 L
.78558 .01851 L
.78574 .01851 L
.78588 .0185 L
.78602 .0185 L
.78617 .01849 L
Mistroke
.78633 .01847 L
.78665 .01843 L
.78695 .01838 L
.78752 .01825 L
.78806 .01808 L
.78927 .01757 L
.79058 .01685 L
.79181 .01604 L
.79297 .01521 L
.79327 .01499 L
.79342 .01489 L
.79355 .01479 L
.79371 .01476 L
.79379 .01482 L
.79388 .01488 L
.79418 .0151 L
.79551 .01604 L
.79675 .01683 L
.79809 .01753 L
.79871 .01779 L
.79936 .01801 L
.79991 .01815 L
.80023 .01822 L
.80052 .01826 L
.80067 .01828 L
.80084 .0183 L
.80098 .01831 L
.80113 .01832 L
.80121 .01833 L
.80129 .01833 L
.80144 .01833 L
.80152 .01833 L
.80161 .01833 L
.8017 .01833 L
.80178 .01833 L
.80194 .01832 L
.80209 .01831 L
.80222 .0183 L
.80236 .01828 L
.80268 .01824 L
.80298 .01818 L
.80349 .01806 L
.80406 .01789 L
.80522 .01741 L
.80652 .01672 L
.80776 .01593 L
.80887 .01517 L
.80917 .01496 L
.80934 .01484 L
.8095 .01473 L
Mistroke
.80964 .0148 L
.8098 .01491 L
.81008 .0151 L
.81231 .01656 L
.81358 .01724 L
.8142 .01751 L
.81476 .01773 L
.81532 .0179 L
.81593 .01804 L
.81626 .0181 L
.81641 .01812 L
.81657 .01814 L
.81671 .01816 L
.81686 .01817 L
.81694 .01818 L
.81702 .01818 L
.81717 .01819 L
.81732 .01819 L
.81748 .01819 L
.81763 .01819 L
.81776 .01818 L
.81785 .01818 L
.81792 .01817 L
.8181 .01816 L
.81841 .01812 L
.81871 .01807 L
.81904 .01801 L
.81971 .01783 L
.82035 .01762 L
.82094 .01737 L
.82206 .01682 L
.82329 .01611 L
.82396 .01568 L
.82459 .01526 L
.82513 .01489 L
.82528 .01479 L
.82544 .01475 L
.82558 .01484 L
.82573 .01494 L
.82698 .01577 L
.8292 .01703 L
.82984 .01732 L
.83044 .01755 L
.83099 .01773 L
.83157 .01788 L
.83187 .01794 L
.8322 .01799 L
.83234 .01801 L
.8325 .01803 L
.83264 .01804 L
Mistroke
.83278 .01805 L
.83287 .01806 L
.83295 .01806 L
.83304 .01806 L
.83313 .01807 L
.83321 .01807 L
.8333 .01807 L
.83339 .01807 L
.83346 .01806 L
.83361 .01806 L
.83369 .01806 L
.83377 .01805 L
.83393 .01804 L
.83409 .01802 L
.8344 .01798 L
.83473 .01793 L
.83532 .0178 L
.83596 .01761 L
.83666 .01735 L
.83908 .0161 L
.84022 .0154 L
.84052 .0152 L
.84084 .01499 L
.841 .01489 L
.84114 .0148 L
.84128 .01472 L
.84142 .01481 L
.84205 .01522 L
.84273 .01565 L
.84393 .01637 L
.84517 .017 L
.84633 .01747 L
.84692 .01765 L
.84754 .0178 L
.8479 .01786 L
.84824 .01791 L
.84838 .01793 L
.84854 .01794 L
.84863 .01795 L
.84871 .01795 L
.84887 .01796 L
.84902 .01796 L
.84915 .01796 L
.8493 .01796 L
.84939 .01796 L
.84946 .01796 L
.84962 .01795 L
.84978 .01794 L
.84994 .01792 L
.85009 .01791 L
Mistroke
.85063 .01783 L
.8509 .01777 L
.8512 .0177 L
.8525 .01728 L
.85371 .01674 L
.85496 .01606 L
.85615 .01534 L
.85667 .01501 L
.85681 .01493 L
.85695 .01483 L
.85709 .01475 L
.85722 .01477 L
.85738 .01486 L
.85754 .01497 L
.85783 .01515 L
.85839 .01549 L
.85962 .01622 L
.86078 .01682 L
.86192 .01729 L
.86297 .01761 L
.86351 .01773 L
.86379 .01778 L
.86409 .01782 L
.86424 .01784 L
.8644 .01785 L
.86457 .01786 L
.86472 .01787 L
.86487 .01788 L
.86501 .01788 L
.86516 .01788 L
.86524 .01787 L
.86532 .01787 L
.86548 .01787 L
.86555 .01786 L
.86564 .01785 L
.86594 .01783 L
.86611 .01781 L
.86629 .01778 L
.86661 .01772 L
.86725 .01758 L
.86784 .01741 L
.86903 .01695 L
.87013 .01641 L
.87142 .01569 L
.87205 .01531 L
.87233 .01514 L
.87263 .01495 L
.87278 .01486 L
.87293 .01477 L
.87308 .01475 L
Mistroke
.87321 .01484 L
.87383 .01521 L
.87511 .01597 L
.8762 .01655 L
.87736 .01707 L
.87793 .01728 L
.87856 .01747 L
.87913 .01761 L
.87966 .01771 L
.87997 .01775 L
.88014 .01777 L
.88029 .01778 L
.88043 .01779 L
.88057 .0178 L
.88073 .0178 L
.88087 .01781 L
.88095 .01781 L
.88104 .0178 L
.88119 .0178 L
.88128 .0178 L
.88136 .01779 L
.88154 .01778 L
.8817 .01777 L
.88184 .01775 L
.88217 .01771 L
.88275 .01761 L
.88336 .01745 L
.88447 .01708 L
.88565 .01655 L
.88697 .01585 L
.8881 .01519 L
.88838 .01502 L
.88867 .01485 L
.88876 .01479 L
.88884 .01474 L
.889 .01478 L
.88914 .01487 L
.8893 .01496 L
.89061 .01573 L
.89181 .01638 L
.89305 .01695 L
.89421 .01736 L
.89479 .01751 L
.89541 .01763 L
.89577 .01768 L
.89594 .0177 L
.89611 .01772 L
.89625 .01773 L
.89641 .01774 L
.8965 .01774 L
Mistroke
.89658 .01774 L
.89674 .01775 L
.89688 .01775 L
.89703 .01774 L
.89717 .01774 L
.8973 .01773 L
.89745 .01772 L
.89762 .01771 L
.89792 .01767 L
.89823 .01763 L
.89857 .01756 L
.89916 .01742 L
.90022 .01708 L
.90139 .01658 L
.90253 .016 L
.90373 .01533 L
.90435 .01496 L
.90452 .01486 L
.90462 .0148 L
.90471 .01475 L
.90479 .01473 L
.90488 .01479 L
.90504 .01488 L
.90624 .01558 L
.90864 .0168 L
.90985 .01724 L
.91054 .01744 L
.91087 .01751 L
.91118 .01757 L
.91149 .01762 L
.91178 .01765 L
.91193 .01767 L
.9121 .01768 L
.91219 .01769 L
.91227 .01769 L
.91235 .01769 L
.91243 .0177 L
.91258 .0177 L
.91271 .0177 L
.91287 .0177 L
.91301 .01769 L
.91316 .01769 L
.91333 .01768 L
.91363 .01765 L
.91389 .01761 L
.91419 .01757 L
.91479 .01744 L
.91534 .0173 L
.91586 .01713 L
.9183 .01604 L
Mistroke
.91938 .01544 L
.91997 .0151 L
.92027 .01493 L
.92039 .01486 L
.92053 .01477 L
.92068 .01474 L
.92083 .01483 L
.92116 .01502 L
.92172 .01535 L
.92282 .01596 L
.92413 .0166 L
.92532 .01708 L
.9259 .01727 L
.92653 .01743 L
.92682 .01749 L
.92712 .01755 L
.92741 .01759 L
.92767 .01762 L
.92781 .01763 L
.92797 .01765 L
.92812 .01766 L
.92821 .01766 L
.92829 .01766 L
.92844 .01766 L
.92857 .01767 L
.92872 .01766 L
.92887 .01766 L
.92895 .01766 L
.92903 .01765 L
.9292 .01764 L
.9295 .01761 L
.92986 .01757 L
.93019 .01751 L
.93079 .01738 L
.93145 .0172 L
.93264 .01676 L
.93487 .01565 L
.93551 .01529 L
.93583 .01511 L
.93612 .01494 L
.93638 .01479 L
.93652 .01472 L
.93666 .0148 L
.93725 .01514 L
.93857 .01588 L
.93978 .01648 L
.94091 .01696 L
.9415 .01716 L
.94213 .01734 L
.94245 .01742 L
Mistroke
.94281 .01749 L
.94313 .01754 L
.94343 .01758 L
.94373 .01761 L
.94389 .01762 L
.94398 .01763 L
.94406 .01763 L
.94421 .01764 L
.94435 .01764 L
.94443 .01764 L
.94451 .01764 L
.94466 .01764 L
.9448 .01763 L
.94495 .01763 L
.94509 .01762 L
.94522 .01761 L
.94553 .01757 L
.94583 .01753 L
.94643 .01742 L
.94707 .01725 L
.94823 .01686 L
.9493 .01639 L
.95058 .01573 L
.95121 .01539 L
.95178 .01506 L
.95205 .0149 L
.95219 .01483 L
.95231 .01476 L
.95244 .01475 L
.95257 .01483 L
.95286 .01499 L
.95403 .01565 L
.95634 .01677 L
.95697 .01701 L
.95764 .01723 L
.95827 .01739 L
.95884 .0175 L
.95912 .01755 L
.95942 .01758 L
.95956 .01759 L
.95971 .01761 L
.95985 .01761 L
.95998 .01762 L
.96014 .01762 L
.96028 .01763 L
.96044 .01763 L
.96052 .01762 L
.96061 .01762 L
.96075 .01762 L
.96091 .01761 L
Mistroke
.96106 .01759 L
.9612 .01758 L
.96174 .01751 L
.96205 .01746 L
.96233 .0174 L
.96341 .0171 L
.96457 .01665 L
.96566 .01615 L
.96687 .0155 L
.96753 .01513 L
.96785 .01495 L
.96799 .01487 L
.96814 .01478 L
.96829 .01474 L
.96843 .01482 L
.9687 .01497 L
.9693 .01531 L
.97057 .016 L
.97173 .01656 L
.97281 .01699 L
.97358 .01724 L
.97442 .01744 L
.97465 .01749 L
.97489 .01753 L
.97511 .01756 L
.97534 .01758 L
.97546 .01759 L
.97557 .0176 L
.97568 .01761 L
.97578 .01761 L
.97588 .01762 L
.97598 .01762 L
.97608 .01762 L
.97619 .01762 L
Mfstroke
1 0 0 r
[ ] 0 setdash
.03968 .01472 m
.03968 .01763 L
s
.05556 .01472 m
.05556 .01764 L
s
.07143 .01472 m
.07143 .01767 L
s
.0873 .01472 m
.0873 .0177 L
s
.10317 .01472 m
.10317 .01775 L
s
.11905 .01472 m
.11905 .01781 L
s
.13492 .01472 m
.13492 .01788 L
s
.15079 .01472 m
.15079 .01796 L
s
.16667 .01472 m
.16667 .01807 L
s
.18254 .01472 m
.18254 .01819 L
s
.19841 .01472 m
.19841 .01833 L
s
.21429 .01472 m
.21429 .01851 L
s
.23016 .01472 m
.23016 .01871 L
s
.24603 .01472 m
.24603 .01895 L
s
.2619 .01472 m
.2619 .01924 L
s
.27778 .01472 m
.27778 .01958 L
s
.29365 .01472 m
.29365 .01997 L
s
.30952 .01472 m
.30952 .0204 L
s
.3254 .01472 m
.3254 .02076 L
s
.34127 .01472 m
.34127 .02049 L
s
.35714 .01472 m
.35714 .01763 L
s
.37302 .01472 m
.37302 .07995 L
s
.38889 .01472 m
.38889 .49745 L
s
.40476 .01472 m
.40476 .494 L
s
.42063 .01472 m
.42063 .08344 L
s
.43651 .01472 m
.43651 .01915 L
s
.45238 .01472 m
.45238 .0179 L
s
.46825 .01472 m
.46825 .01795 L
s
.48413 .01472 m
.48413 .01773 L
s
.5 .01472 m
.5 .01762 L
s
.51587 .01472 m
.51587 .01773 L
s
.53175 .01472 m
.53175 .01795 L
s
.54762 .01472 m
.54762 .0179 L
s
.56349 .01472 m
.56349 .01915 L
s
.57937 .01472 m
.57937 .08344 L
s
.59524 .01472 m
.59524 .494 L
s
.61111 .01472 m
.61111 .49745 L
s
.62698 .01472 m
.62698 .07995 L
s
.64286 .01472 m
.64286 .01763 L
s
.65873 .01472 m
.65873 .02049 L
s
.6746 .01472 m
.6746 .02076 L
s
.69048 .01472 m
.69048 .0204 L
s
.70635 .01472 m
.70635 .01997 L
s
.72222 .01472 m
.72222 .01958 L
s
.7381 .01472 m
.7381 .01924 L
s
.75397 .01472 m
.75397 .01895 L
s
.76984 .01472 m
.76984 .01871 L
s
.78571 .01472 m
.78571 .01851 L
s
.80159 .01472 m
.80159 .01833 L
s
.81746 .01472 m
.81746 .01819 L
s
.83333 .01472 m
.83333 .01807 L
s
.84921 .01472 m
.84921 .01796 L
s
.86508 .01472 m
.86508 .01788 L
s
.88095 .01472 m
.88095 .01781 L
s
.89683 .01472 m
.89683 .01775 L
s
.9127 .01472 m
.9127 .0177 L
s
.92857 .01472 m
.92857 .01767 L
s
.94444 .01472 m
.94444 .01764 L
s
.96032 .01472 m
.96032 .01763 L
s
.97619 .01472 m
.97619 .01762 L
s
.015 w
.03968 .01763 Mdot
.05556 .01764 Mdot
.07143 .01767 Mdot
.0873 .0177 Mdot
.10317 .01775 Mdot
.11905 .01781 Mdot
.13492 .01788 Mdot
.15079 .01796 Mdot
.16667 .01807 Mdot
.18254 .01819 Mdot
.19841 .01833 Mdot
.21429 .01851 Mdot
.23016 .01871 Mdot
.24603 .01895 Mdot
.2619 .01924 Mdot
.27778 .01958 Mdot
.29365 .01997 Mdot
.30952 .0204 Mdot
.3254 .02076 Mdot
.34127 .02049 Mdot
.35714 .01763 Mdot
.37302 .07995 Mdot
.38889 .49745 Mdot
.40476 .494 Mdot
.42063 .08344 Mdot
.43651 .01915 Mdot
.45238 .0179 Mdot
.46825 .01795 Mdot
.48413 .01773 Mdot
.5 .01762 Mdot
.51587 .01773 Mdot
.53175 .01795 Mdot
.54762 .0179 Mdot
.56349 .01915 Mdot
.57937 .08344 Mdot
.59524 .494 Mdot
.61111 .49745 Mdot
.62698 .07995 Mdot
.64286 .01763 Mdot
.65873 .02049 Mdot
.6746 .02076 Mdot
.69048 .0204 Mdot
.70635 .01997 Mdot
.72222 .01958 Mdot
.7381 .01924 Mdot
.75397 .01895 Mdot
.76984 .01871 Mdot
.78571 .01851 Mdot
.80159 .01833 Mdot
.81746 .01819 Mdot
.83333 .01807 Mdot
.84921 .01796 Mdot
.86508 .01788 Mdot
.88095 .01781 Mdot
.89683 .01775 Mdot
.9127 .0177 Mdot
.92857 .01767 Mdot
.94444 .01764 Mdot
.96032 .01763 Mdot
.97619 .01762 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{756, 146},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000;d0000TR000`400?l00000o`00003ooooooooo
ooooooKooooo003ooooooooooooom_ooool00?ooooooooooooofooooo`00ooooooooooooooKooooo
003ooooooooooooom_ooool00?oooooo6_ooool3o`0000Cooooo0_l0000[ooooo`?o0000;Oooool2
o`0002oooooo0ol0000[ooooo`?o00001?ooool2o`000?oooooo4?ooool00?oooooo6oooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0002Wooooo00Go0000ooooooooooooooooo`00
000[ooooo`04o`000?ooooooooooo`0002gooooo00Go0000ooooooooooooooooo`00000[ooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000ooooool?ooooo`00oooooolCooooo`Go
00000oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0002?ooooo1Ol00005oooo
o`03o`000?oooooooooo02Wooooo00Co0000oooooooooooo0000<Oooool00ol0003oooooooooo`0Y
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000ooooool?ooooo`00<Oooool3
o`0000Cooooo0_l0000Xooooo`?o0000:_ooool2o`0002_ooooo0ol0000Yooooo`?o00001?ooool2
o`0002Wooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000]ooooo`03o`000?oo
oooooooo02Wooooo00Co0000oooooooooooo0000<Oooool00ol0003oooooooooo`0Yooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo0000=_ooool3o`0000Cooooo0_l0000Yooooo`?o
0000:Oooool2o`0002cooooo0ol0000Xooooo`?o00001?ooool2o`0001Sooooo000booooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00009_ooool01Ol0003ooooooooooooooooo0000
02Sooooo00Co0000oooooooooooo0000:Oooool01Ol0003ooooooooooooooooo000002Wooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool0000Xooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo0000:Oooool4o`0002cooooo00Co0000oooooooooooo0000;Oooool4o`00
02cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000gooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00009oooool01Ol0003ooooooooooooooooo000002Oooooo
00Co0000oooooooooooo0000:_ooool01Ol0003ooooooooooooooooo000002Sooooo00?o0000oooo
ooooool00_ooool01?l0003oooooooooool0000Gooooo`00:_ooool5o`0000?ooooo00?o0000oooo
ooooool00_ooool01?l0003oooooooooool0000Pooooo`Go00001Oooool00ol0003oooooooooo`0V
ooooo`04o`000?ooooooooooo`0002gooooo00?o0000ooooooooool09oooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0002Oooooo0_l00004ooooo`04o`000?ooooooooooo`0002Wo
oooo00?o0000ooooooooool0;Oooool01?l0003oooooooooool0000]ooooo`03o`000?oooooooooo
02cooooo0_l00004ooooo`04o`000?ooooooooooo`0002oooooo1Ol00003ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00008Oooool5o`0000Gooooo00?o0000ooooooooool09Ooo
ool01?l0003oooooooooool0000^ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool0000Gooooo`00<_ooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0002[ooooo00?o0000ooooooooool09_ooool01?l0003oooooooooool0000]oooo
o`03o`000?oooooooooo02Oooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000X
ooooo`03o`000?oooooooooo00?ooooo0_l0000Zooooo`Go0000;?ooool2o`0002kooooo1Ol0000[
ooooo`03o`000?oooooooooo00?ooooo0_l0000hooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo0000:oooool00ol0003oooooooooo`0Uooooo`04o`000?ooooooooooo`0002kooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001Oo
oooo000booooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00009_ooool4o`0002Wo
oooo00Co0000oooooooooooo0000:Oooool4o`0002[ooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool0003oooooobcooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
000Wooooo`Co0000:?ooool01?l0003oooooooooool0000Zooooo`Co0000:Oooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0001Oooooo000aooooo`;o00001?ooool01?l0003ooooo
ooooool0000Vooooo`03o`000?oooooooooo02[ooooo00Co0000oooooooooooo0000:Oooool00ol0
003oooooooooo`0Zooooo`;o00001?ooool01?l0003oooooooooool0003oooooob_ooooo0_l00004
ooooo`04o`000?ooooooooooo`0002Oooooo00?o0000ooooooooool0:Oooool01?l0003ooooooooo
ool0000Zooooo`03o`000?oooooooooo02Wooooo0_l00004ooooo`04o`000?ooooooooooo`0001Oo
oooo000booooo`03o`000?oooooooooo00?ooooo0_l0000Wooooo`Go0000:Oooool2o`0002[ooooo
1Ol0000Yooooo`03o`000?oooooooooo00?ooooo0_l0003oooooobgooooo00?o0000ooooooooool0
0oooool2o`0002Sooooo1Ol0000Xooooo`;o0000:oooool5o`0002Sooooo00?o0000ooooooooool0
0oooool2o`0001Sooooo003ooooooooooooom_ooool00?oooooo5?ooool2o`0000Coooooc_l0003o
ooooo`kooooo003ooooooa?ooooo00Co0000oooooooooooo00000oooool00ol0003oooooo`00000`
ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0^
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0ooooool<ooooo`00;_ooooo5o`00
01oooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooooooool3ool00003oooooooo
003oo`0000[oo`0000?oooooool00?oo00001ooo00000oooooooo`00ool00007ool001kooooo0ooo
000Aooooo`Koo`0000?oooooool00?oo00001ooo00000oooooooo`00ool00004ool0017ooooo0ooo
000Nooooo`Woo`0000?oooooool00?oo00001ooo00000oooooooo`00ool00007ool00003oooooooo
003oo`0000Ooo`000oooool00ol0003oooooooooo`0aooooolCo00005_ooool002Sooooo0_l00004
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07Oooool01?l0003oooooooooool0
0003ooooo`?o000000Goooooool00?oo003oo`00ooooo`0<ool00003oooooooo003oo`0000Ooo`00
00?oooooool00?oo00001ooo00000oooooooo`00ool0000:ool00003oooooooo003oo`0000Ooo`00
00?oooooool00?oo00001ooo0002ooooo`04ool00?ooooooooooool000;ooooo00Koo`00oooooooo
ooooooooool00?ooool9ool00003oooooooo003oo`0000Ooo`0000?oooooool00?oo00001ooo0002
ooooo`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000_ooool9ool00003oooo
oooo003oo`0000Ooo`0000?oooooool00?oo00001ooo00000oooooooo`00ool0000:ool00003oooo
oooo003oo`0000Ooo`0000?oooooool00?oo00001ooo00000oooooooo`00ool00007ool000;ooooo
0_l0000/ooooo`;o00001Oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Cooooo000Wooooo`04o`00
0?ooooooooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo02cooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0/ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool07Oooool01?l0003oooooooooool00003oooo
o`04o`000?ooooooooooooooo`?oo`0000?oooooool00?oo00002_oo00000oooooooo`00ool00007
ool00003oooooooo003oo`0000Ooo`0000?oooooool00?oo00002_oo00000oooooooo`00ool00007
ool00003oooooooo003oo`0000Ooo`000_ooool01?oo003ooooooooooooo0002ooooo`06ool00?oo
oooooooooooooooo003ooooo2Ooo00000oooooooo`00ool00007ool00003oooooooo003oo`0000Oo
o`000_ooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000;ooooo2Ooo0000
0oooooooo`00ool00007ool00003oooooooo003oo`0000Ooo`0000?oooooool00?oo00002_oo0000
0oooooooo`00ool00007ool00003oooooooo003oo`0000Ooo`0000?oooooool00?oo00001ooo0003
ooooo`03o`000?oooooooooo02Wooooo00Co0000oooooooooooo00001?ooool01Ol0003ooooooooo
oooooooo000002kooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0/ooooo`03o`00
0?oooooooooo02_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Dooooo`009ooo
ool01?l0003oooooooooool00003ooooo`;o00001oooool01?l00?ooooooooooool00?l2ooooo`;o
003o00Coooooo`00ool00?oooooo0_l00?l2ooooo`04o`00oooooooo003oo`00o`;ooooo00?o003o
ooooooooool00_l00?l01Ooooooo003ooooooooooooo003o00;ooooo00?o003oooooooooool00ooo
ool2o`00o`Sooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooo
oooo003o00?ooooo00Co003ooooooooooooo003o0_ooool3o`00o`03ooooool00?oooooo00;o003o
00?oooooo`00ool00?l04Oooool00ol00?ooooooooooo`06ooooo`;o003o00?oooooo`00ool00?l0
0_ooool01?l00?ooooooooooool00?l2ooooo`04o`00ooooooooooooo`00o`;ooooo00?o003ooooo
ooooool00_l00?l2ooooo`03o`00oooooooooooo00;ooooo0_l00?l01?oooooo003oo`00ooooool2
o`00o`04ooooool00?oo003oooooo`?o003o00Coooooo`00ool00?oooooo0_l00?l01?oooooo003o
ooooooooool2o`00o`?ooooo0ol0000Oooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooo
ooooool09_ooool<ool00003oooooooo003oo`0000Ooo`0000?oooooool00?oo00001?oo0005oooo
o`04ool00?ooooooooooool000;ooooo00Koo`00ooooooooooooooooool00?ooool3ool001Oooooo
0ooo0002ooooo`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`001Oooool6ool0
0003oooooooo003oo`0000Ooo`0000?oooooool00?oo00001ooo00001?ooooooo`00ool00?oo000Z
ooooo`03o`000?oooooooooo02Wooooo00Co0000oooooooooooo00001?ooool2o`0000Gooooo00ko
o`00o`00ool00?ooo`00ooooool00?ooo`00ooooool00?ooooooool00?l00?ooooooool000;o003o
00Coo`00o`00ool00?ooo`000_l00?l01ooo003ooooooooooooo003o003ooooooooo00000_l00?l0
2ooo003o003oo`00oooo003oooooo`00ooooooooo`00o`00ooooooooo`0000;o003o00Coo`00o`00
ooooooooo`000_l00?l01?oo003o003oo`00oooo0002o`00o`07ool00?oooooo003oool00?oooooo
003oool00002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo0002
ooooo`04ool00?l00?oo003oool000;o003o00Ooo`00ooooool00?ooo`00o`00ooooooooo`0000;o
003o00Goo`00o`00ooooooooooooool00002ooooo`07ool00?l00?oo003oool00?l00?ooooooool0
0002ooooo`04ool00?ooooooooooool000;ooooo00[oo`00ooooool00?ooo`00ooooool00?ooo`00
ooooool00?ooo`000oooool02_oo003ooooooooooooo003o003ooooooooo003o003ooooooooo0002
o`00o`04ool00?l00?oo003oool000;o003o00Coo`00o`00ool00?ooo`000_l00?l02?oo003ooooo
o`00oooo003oooooo`00ooooooooo`000_ooool01?oo003o003ooooooooo0002o`00o`04ool00?l0
0?oo003oool000;o003o00Coo`00o`00ool00?ooo`000_ooool01?oo003o003oo`00oooo0003oooo
o`;o00005_ooool002Oooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`02oooo
o`05o`00oooooooo003oo`00ooooool00ol00?l3ooooo`?o003o0_ooool3o`00o`;ooooo0_l00?l0
1?oooooo003oo`00ooooool2o`00o`04ooooool00?oo003oooooo`Wo003o00?oooooo`00ool00?l0
1_l00?l2ooooo`;o003o00?oooooo`00ool00?l01_l00?l2ooooo`;o003o2oooool3o`00o`03oooo
ool00?oo003o00;ooooo0_l00?l00ooooooo003oo`00o`02o`00o`03ooooool00?oo003o00;o003o
00?oooooo`00ool00?l01_l00?l;ooooo`Ko003o00Goooooo`00ool00?oo003oooooo`04o`00o`03
ooooool00?oo003o00Co003o00Coooooo`00oooooooooooo0_l00?l01?oooooo003oo`00ooooool2
o`00o`03ooooool00?oo003o00Oo003o00?oooooo`00ool00?l00_ooool00ol00?ooooooooooo`02
ooooo`04o`00ooooooooooooo`00o`;ooooo0ol00?l00ooooooo003oo`00o`06ooooo`03o`000?oo
oooooooo01kooooo0_l00004ooooo`03o`000?oooooooooo04Sooooo00Coo`00ooooooooooooo`00
0_ooool01Ooo003oooooooooooooooooo`00023ooooo00Coo`00ooooooooooooo`000_ooool01?oo
003ooooooooooooo001=ooooo`03o`000?oooooooooo02Wooooo00Co0000oooooooooooo00001?oo
ool01?l0003oooooooooooooool2o`00o`;oo`0000Go003oool00?oo003o003oooooo`02ool00004
oooooooo003oo`00ooooo`;oo`0000Coooooool00?oo003ooooo0_oo00001?l00?ooo`00ool00?oo
ool2ool00004o`00oooo003oo`00o`00o`;oo`0000?o003oool00?oo00000_l00?l2ool00004o`00
oooo003oo`00ooooo`;oo`0000Co003oool00?oo003o003o0_oo00001?ooooooo`00ool00?l00?l2
ool00004o`00oooo003oo`00o`00o`;oo`000_l00?l01Ooo003oooooooooooooooooo`0000;ooooo
00Goo`00ooooooooooooo`00o`00o`02ool00004o`00oooo003oo`00ooooo`;oo`0000Coooooool0
0?oo003o003o0_oo00001Ol00?ooo`00ool00?l00?oooooo00;oo`0000Coooooool00?oo003ooooo
0_oo00000ol00?ooooooool00002ooooo`04ool00?ooooooooooool000;ooooo00Goo`00oooooooo
003oo`00o`00o`02ool000;o003o0_oo00001?l00?ooo`00ool00?l00?l2ool00004o`00oooo003o
o`00o`00o`;oo`0000Co003oool00?oo003o003o0_oo00001?ooooooo`00ool00?l00?l2ool00003
o`00oooo003oo`0000;ooooo0_oo00001?ooooooo`00ool00?ooool2ool00004o`00oooo003oo`00
o`00o`;oo`0000Co003oool00?oo003o003o0_oo00001?l00?ooo`00ool00?l00?l2ool00004o`00
ooooooooo`00ool000?ooooo00?o0000ooooooooool05?ooool002Oooooo00Co0000oooooooooooo
00000oooool00ol0003oooooooooo`1@ooooo`03o`00oooooooooooo00cooooo00?o0000oooooooo
ool02oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo04Gooooo00?o0000oooooooo
ool09?ooool2o`0004Wooooo00Coo`00ooooooooooooo`000_ooool01Ooo003ooooooooooooooooo
o`00023ooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo001<ooooo`;o0000
:oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00?ooooo0_oo00000ooooooo
o`00ool00002ooooo`;oo`0000Coooooool00?oo003ooooo0_oo00001?ooooooo`00ool00?ooool2
ool00004oooooooo003oo`00ooooo`;oo`0000Coooooool00?oo003ooooo0_oo00000oooooooo`00
ool00002ooooo`;oo`0000Coooooool00?oo003ooooo0_oo00001?ooooooo`00ool00?ooool2ool0
0004oooooooo003oo`00ooooo`;oo`0000Coooooool00?oo003ooooo0_oo00000ooooooo003oool0
0003ooooo`04ool00?ooooooooooool000;ooooo00Goo`00o`00oooo003oo`00ooooo`02ool00004
oooooooo003oo`00ooooo`;oo`0000Coooooool00?oo003ooooo0_oo0002ooooo`;oo`0000Cooooo
ool00?oo003ooooo0_oo00000ooooooo003oool00002ooooo`04ool00?ooooooooooool000;ooooo
00Goo`00o`00oooo003oo`00ooooo`02ool000;ooooo0_oo00001?ooooooo`00ool00?ooool2ool0
0004oooooooo003oo`00ooooo`;oo`0000Coooooool00?oo003ooooo0_oo00001?ooooooo`00ool0
0?ooool2ool00003oooooooo003oo`0000;ooooo0_oo00001?ooooooo`00ool00?ooool2ool00004
oooooooo003oo`00ooooo`;oo`0000Coooooool00?oo003ooooo0_oo00001?ooooooo`00ool00?oo
ool2ool000;ooooo0_oo0003ooooo`03o`000?oooooooooo01Cooooo000Wooooo`04o`000?oooooo
ooooo`0000?ooooo00?o0000ooooooooool0AOooool00ol00?ooooooooooo`08ooooo`03o`00oooo
oooooooo00cooooo00?o0000ooooooooool02oooool00ol00?ooooooooooo`1Aooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool0B?ooool01?oo003ooooooooooooo0002ooooo`05ool0
0?oooooooooooooooooo00008?ooool01?oo003ooooooooooooo0002ooooo`04ool00?oooooooooo
ool004gooooo00?o0000ooooooooool0:Oooool01?l0003oooooooooool00004ooooo`03o`000?oo
oooooooo04Gooooo00Goo`00ooooooooooooooooool00002ooooo`05ool00?ooooooooooool00?l0
0?l03Oooool00ol0003oooooooooo`0=ooooo`04ool00?ooooooooooool000;ooooo00Goo`00oooo
ooooooooo`00o`00o`17ooooo`03o`000?oooooooooo01Cooooo000Xooooo`;o00001?ooool2o`00
04Kooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0<ooooo`03o`000?oooooooooo
01Kooooo00?o003oooooooooool0AOooool2o`0002Kooooo00?o0000ooooooooool0B?ooool01?oo
003ooooooooooooo0002ooooo`05ool00?oooooooooooooooooo00008?ooool01?oo003ooooooooo
oooo0002ooooo`04ool00?ooooooooooool004gooooo00?o0000ooooooooool0:_ooool2o`0000Go
oooo00?o0000ooooooooool0AOooool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00oooo
ooooooooo`003_ooool00ol0003oooooooooo`0<ooooo`05o`00oooo003ooooooooooooo00000_oo
ool01Ooo003ooooooooooooo003o003o04Kooooo0_l0000Fooooo`00;_ooool00ol0003ooooooooo
o`15ooooo`03o`00oooooooooooo01Oooooo00?o0000ooooooooool03?ooool00ol00?oooooooooo
o`07ooooo`03o`00oooooooooooo04Kooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`18ooooo`04ool00?ooooooooooool000;ooooo00Goo`00ooooooooooooooooool0000Pooooo`04
ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`00COooool00ol0003oooooooooo`0a
ooooo`03o`000?oooooooooo04Gooooo00Goo`00ooooooooooooooooool00002ooooo`05ool00?oo
ooooooooool00?l00?l03Oooool00ol0003oooooooooo`0<ooooo`05o`00oooo003ooooooooooooo
00000_ooool01?oo003ooooooooooooo0018ooooo`03o`000?oooooooooo01Cooooo000^ooooo`03
o`000?oooooooooo053ooooo00?o003oooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03
o`00oooooooooooo00Oooooo00?o003oooooooooool0A_ooool00ol0003oooooooooo`0Tooooo`03
o`000?oooooooooo04Sooooo00Coo`00ooooooooooooo`000_ooool01Ooo003ooooooooooooooooo
o`00023ooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo001=ooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool0AOooool01Ooo003oooooooooooooooooo`0000;o
oooo00Goo`00ooooooooooooo`00o`00o`0=ooooo`03o`000?oooooooooo00cooooo00Go003oool0
0?ooooooooooool00002ooooo`05ool00?ooooooooooool00?l00?l0Aoooool00ol0003ooooooooo
o`0Dooooo`00;_ooool2o`0004Kooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o003oooooooooool0Coooool2o`0002Kooooo0_l00019
ooooo`04ool00?ooooooooooool000;ooooo00Goo`00ooooooooooooooooool0000Pooooo`04ool0
0?ooooooooooool000;ooooo00Coo`00ooooooooooooo`00C?ooool2o`0003?ooooo00?o0000oooo
ooooool0AOooool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`003_oo
ool00ol0003oooooooooo`0=ooooo`04ool00?ooooooooooool000;ooooo00Goo`00oooooooooooo
o`00o`00o`16ooooo`;o00005_ooool002kooooo00?o0000ooooooooool0AOooool00ol00?oooooo
ooooo`08ooooo`03o`00oooooooooooo00cooooo00?o0000ooooooooool05_ooool00ol00?oooooo
ooooo`16ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0B?ooool01?oo003ooooo
oooooooo0002ooooo`05ool00?oooooooooooooooooo00008?ooool01?oo003ooooooooooooo0002
ooooo`04ool00?ooooooooooool004gooooo00?o0000ooooooooool0<Oooool00ol0003ooooooooo
o`15ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo000>ooooo`03
o`000?oooooooooo00cooooo00Go003oool00?ooooooooooool00002ooooo`04ool00?oooooooooo
ool004Sooooo00?o0000ooooooooool05?ooool002kooooo00?o0000ooooooooool0A_ooool00ol0
0?ooooooooooo`0Fooooo`03o`000?oooooooooo00cooooo00?o003oooooooooool01oooool00ol0
0?ooooooooooo`16ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0B?ooool01?oo
003ooooooooooooo0002ooooo`05ool00?oooooooooooooooooo00008?ooool01?oo003ooooooooo
oooo0002ooooo`04ool00?ooooooooooool004gooooo00?o0000ooooooooool0<Oooool00ol0003o
ooooooooo`15ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo000>
ooooo`03o`000?oooooooooo00cooooo00Go003oool00?ooooooooooool00002ooooo`04ool00?oo
ooooooooool004Sooooo00?o0000ooooooooool05?ooool002kooooo00?o0000ooooooooool0Cooo
ool00ol00?ooooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o003oooooooooool01ooo
ool00ol00?ooooooooooo`16ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0B?oo
ool01?oo003ooooooooooooo0002ooooo`05ool00?oooooooooooooooooo00008?ooool01?oo003o
oooooooooooo0002ooooo`04ool00?ooooooooooool004gooooo00?o0000ooooooooool0<Oooool0
0ol0003oooooooooo`15ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooo
oooo000>ooooo`03o`000?oooooooooo00cooooo00Go003oool00?ooooooooooool00002ooooo`04
ool00?ooooooooooool004Sooooo00?o0000ooooooooool05?ooool002kooooo0_l00017ooooo`03
o`00oooooooooooo00Kooooo00?o003oooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03
o`00oooooooooooo04oooooo0_l0000Vooooo`;o0000BOooool01?oo003ooooooooooooo0002oooo
o`05ool00?oooooooooooooooooo00008?ooool01?oo003ooooooooooooo0002ooooo`04ool00?oo
ooooooooool004cooooo0_l0000cooooo`03o`000?oooooooooo04Gooooo00Goo`00oooooooooooo
ooooool00002ooooo`04ool00?ooooooooooool000kooooo00?o0000ooooooooool03Oooool01?oo
003ooooooooooooo0002ooooo`04ool00?ooooooooooool004Oooooo0_l0000Fooooo`00;_ooool0
0ol0003oooooooooo`16ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03Oooool0
0ol0003oooooooooo`0Fooooo`03o`00oooooooooooo04Kooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`18ooooo`04ool00?ooooooooooool000;ooooo00Goo`00oooooooooooooooo
ool0000Pooooo`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`00COooool00ol0
003oooooooooo`0aooooo`03o`000?oooooooooo04Gooooo00Goo`00ooooooooooooooooool00002
ooooo`04ool00?ooooooooooool000kooooo00?o0000ooooooooool03Oooool01?oo003ooooooooo
oooo0002ooooo`04ool00?ooooooooooool004Sooooo00?o0000ooooooooool05?ooool002kooooo
00?o0000ooooooooool0A_ooool00ol00?ooooooooooo`0Fooooo`03o`000?oooooooooo00cooooo
00?o003oooooooooool01oooool00ol00?ooooooooooo`16ooooo`03o`000?oooooooooo01cooooo
1Ol00003ooooo`03o`000?oooooooooo04Oooooo0ooo00001Oooooooo`00ooooooooooooo`0000?o
oooo00?oo`00ooooooooool07_ooool01?oo003ooooooooooooo0002ooooo`03ool00?ooooooo`00
00;oo`00C?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo04Gooooo0_oo0002oooo
o`04ool00?ooooooooooool000;ooooo00?oo`00ooooooooool03?ooool00ol0003oooooooooo`0=
ooooo`04ool00?ooooooooooool000;ooooo00Coo`00oooooooo003oo`00B?ooool00ol0003ooooo
ooooo`0Dooooo`00;_ooool2o`00053ooooo00?o003oooooooooool03Oooool00ol0003ooooooooo
o`0<ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool0AOooool2o`0001oooooo00Co
0000oooooooooooo00000oooool00ol0003oooooooooo`17ooooo`?oo`0000Goooooool00?oooooo
ooooool00002ooooo`?oo`007_ooool3ool00006oooooooo003ooooooooooooo003ooooo0ooo001<
ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0AOooool2ool000;ooooo00Goo`00
ooooooooooooo`00ooooo`02ool000kooooo00?o0000ooooooooool03?ooool2ool000;ooooo00Go
o`00ooooooooooooo`00ooooo`02ool004Oooooo0_l0000Fooooo`006_ooool5o`0000?ooooo00?o
0000ooooooooool00_ooool3o`0000Cooooo00?o0000ooooooooool0A_ooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo00gooooo00?o0000ooooooooool03?ooool00ol00?oooooooooo
o`1@ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`17ooooo`?oo`0000Goooooool00?ooooooooooool00002ooooo`?oo`007_ooool3ool00006oooo
oooo003ooooooooooooo003ooooo0ooo001<ooooo`03o`000?oooooooooo01cooooo1Ol00003oooo
o`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo04Wooooo00Goo`00oooo
ooooooooo`00ooooo`02ool000kooooo00?o0000ooooooooool03?ooool2ool000;ooooo00Coo`00
ooooooooooooo`000_ooool00ol00?ooooooooooo`16ooooo`03o`000?oooooooooo01Cooooo000K
ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000003ooooo`03o`00
0?oooooooooo04Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00
0?oooooooooo01Gooooo00?o003oooooooooool0Aoooool00ol0003oooooooooo`0Oooooo`03o`00
0?oooooooooo00;ooooo0ol0001;ooooo`04ool00?ooooooooooool000;ooooo0ooo000Nooooo`?o
o`0000Goooooool00?ooooooooooool0001?ooooo`;o00007oooool01?l0003oooooooooool00007
ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`16ooooo`04o`00oooo
ooooooooool000;ooooo00?oo`00ooooooooool03oooool00ol0003oooooooooo`0=ooooo`04o`00
ooooooooooooool000;ooooo00Coo`00oooooooooooo003oB?ooool00ol0003oooooooooo`0Doooo
o`007?ooool00ol0003oooooooooo`0;ooooo`05o`000?ooooooooooooooool00000B?ooool00ol0
0?ooooooooooo`0Fooooo`03o`000?oooooooooo00cooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`17ooooo`03o`000?oooooooooo01cooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooooooo04_ooooo00Coo`00ooooooooooooo`009oooool01?oo003ooooooooo
oooo001@ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo04Kooooo00Co003oooooooooooooo`000_ooool01?oo003o
ooooooooool00?l>ooooo`03o`000?oooooooooo00gooooo00Co003oooooooooooooo`000_ooool0
0ooo003oooooooooo`19ooooo`03o`000?oooooooooo01Cooooo000Mooooo`03o`000?oooooooooo
00[ooooo00Co0000oooooooooooooooo0_l0001@ooooo`03o`00oooooooooooo00gooooo00?o0000
ooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo04Gooooo0ol0000N
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`1;ooooo`04ool00?oo
ooooooooool002Oooooo00Coo`00ooooooooooooo`00D?ooool00ol0003oooooooooo`0Oooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool2o`0004Oooooo00Co003ooooooooo
ooooo`000_ooool00ooo003oooooo`00o`0?ooooo`03o`000?oooooooooo013ooooo00Coo`00oooo
ooooooooo`000_ooool00ol00?ooooooooooo`15ooooo`;o00005_ooool001[ooooo00Go0000oooo
ooooooooooooo`000007ooooo`Co00001?ooool00ol0003oooooooooo`16ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`00oooooooo
oooo04oooooo00?o0000ooooooooool07Oooool3o`0000Cooooo00?o0000ooooooooool0Boooool0
1?oo003ooooooooooooo000Wooooo`04ool00?ooooooooooool0053ooooo00?o0000ooooooooool0
7?ooool01Ol0003ooooooooooooooooo000000Oooooo1?l00005ooooo`03o`000?oooooooooo04Wo
oooo00Coo`00ooooooooooooo`004Oooool00ol0003oooooooooo`0=ooooo`04o`00oooooooooooo
ool000;ooooo00Coo`00oooooooooooo003oB?ooool00ol0003oooooooooo`0Dooooo`006_ooool0
1Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`16ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03Oooool00ol0003ooooooooo
o`0Eooooo`03o`00oooooooooooo04Oooooo00?o0000ooooooooool09?ooool2o`0004cooooo00Co
o`00ooooooooooooo`009oooool01?oo003ooooooooooooo001?ooooo`;o00007_ooool01Ol0003o
oooooooooooooooo000000Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`16oooo
o`04o`00ooooooooooooool000;ooooo00?oo`00ooooool00?l03oooool00ol0003oooooooooo`0=
ooooo`04o`00ooooooooooooool000;ooooo00Coo`00oooooooooooo003oB?ooool00ol0003ooooo
ooooo`0Dooooo`006oooool3o`0000Sooooo1Ol00003ooooo`;o0000Aoooool00ol00?oooooooooo
o`0Fooooo`03o`000?oooooooooo00gooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`16ooooo`;o00009_ooool00ol0003oooooooooo`1;ooooo`04ool00?ooooooooooool002Oooooo
00Coo`00ooooooooooooo`00D?ooool00ol0003oooooooooo`0Mooooo`?o00002?ooool5o`0000Co
oooo00?o0000ooooooooool0A_ooool01?l00?oooooooooooooo0002ooooo`03ool00?oooooo003o
00oooooo00?o0000ooooooooool03Oooool01?l00?oooooooooooooo0002ooooo`03ool00?oooooo
oooo04Wooooo00?o0000ooooooooool05?ooool002kooooo00?o0000ooooooooool0Coooool00ol0
0?ooooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`17ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0Boooool01?oo
003ooooooooooooo000Wooooo`04ool00?ooooooooooool0053ooooo00?o0000ooooooooool0<Ooo
ool00ol0003oooooooooo`16ooooo`04o`00ooooooooooooool000;ooooo00?oo`00ooooool00?l0
3oooool00ol0003oooooooooo`0@ooooo`04ool00?ooooooooooool000;ooooo00?o003ooooooooo
ool0AOooool2o`0001Kooooo000^ooooo`03o`000?oooooooooo04Kooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o003oooooooooool0
Coooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo04_ooooo00Coo`00oooooooooooo
o`009oooool01?oo003ooooooooooooo001@ooooo`03o`000?oooooooooo037ooooo00?o0000oooo
ooooool0BOooool01?oo003ooooooooooooo000Aooooo`03o`000?oooooooooo00gooooo00Co003o
ooooooooooooo`000_ooool01?oo003oooooooooool00?m8ooooo`03o`000?oooooooooo01Cooooo
000^ooooo`03o`000?oooooooooo04Kooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`0=ooooo`03o`000?oooooooooo01Gooooo00?o003oooooooooool0Aoooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo04_ooooo00Coo`00ooooooooooooo`009oooool01?oo003ooooo
oooooooo001@ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0A_ooool01?l00?oo
oooooooooooo0002ooooo`03ool00?oooooo003o00oooooo00?o0000ooooooooool03Oooool01?l0
0?oooooooooooooo0002ooooo`03ool00?oooooooooo04Wooooo00?o0000ooooooooool05?ooool0
02kooooo0_l00018ooooo`03o`00oooooooooooo01Gooooo00?o0000ooooooooool03Oooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo04Kooooo0_l0000Vooooo`;o0000C?ooool01?oo
003ooooooooooooo000Wooooo`04ool00?ooooooooooool004oooooo0_l0000cooooo`03o`000?oo
oooooooo04Kooooo00Co003oooooooooooooo`000_ooool00ooo003oooooo`00o`0?ooooo`03o`00
0?oooooooooo00gooooo00Co003oooooooooooooo`000_ooool00ooo003oooooo`00o`18ooooo`;o
00005_ooool002kooooo00?o0000ooooooooool0Aoooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00gooooo00?o0000ooooooooool03Oooool00ol00?ooooooooooo`1?ooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool0Boooool01?oo003ooooooooooooo000Wooooo`04
ool00?ooooooooooool0053ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`16oooo
o`04o`00ooooooooooooool000;ooooo00?oo`00ooooool00?l03oooool00ol0003oooooooooo`0@
ooooo`06ool00?ooooooooooool00?oooooo003oBOooool00ol0003oooooooooo`0Dooooo`00;_oo
ool00ol0003oooooooooo`17ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03Ooo
ool00ol0003oooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0Aooo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo04_ooooo00Coo`00ooooooooooooo`00
9oooool01?oo003ooooooooooooo001@ooooo`03o`000?oooooooooo037ooooo00?o0000oooooooo
ool0BOooool01?oo003ooooooooooooo000Aooooo`03o`000?oooooooooo00gooooo00Co003ooooo
ooooooooo`000_ooool00ooo003oooooo`00o`19ooooo`03o`000?oooooooooo01Cooooo000^oooo
o`03o`000?oooooooooo04Oooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0=oooo
o`03o`000?oooooooooo01Gooooo00?o003oooooooooool0Aoooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo04_ooooo00Coo`00ooooooooooooo`009oooool01?oo003ooooooooooooo
001@ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0A_ooool01?l00?oooooooooo
oooo0002ooooo`03ool00?oooooo003o00oooooo00?o0000ooooooooool03Oooool01?l00?oooooo
oooooooo0002ooooo`03ool00?oooooooooo04Wooooo00?o0000ooooooooool05?ooool002kooooo
0_l0001Pooooo`03o`000?oooooooooo00gooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`16ooooo`;o00009_ooool2o`0004cooooo00Coo`00ooooooooooooo`009oooool01?oo003o
oooooooooooo001?ooooo`;o0000<oooool00ol0003oooooooooo`16ooooo`04o`00oooooooooooo
ool000;ooooo00?oo`00ooooool00?l03oooool00ol0003oooooooooo`0>ooooo`03o`00oooooooo
o`0000;ooooo00?oo`00ooooool00?l0B?ooool2o`0001Kooooo000^ooooo`03o`000?oooooooooo
04Oooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`000?oooooooooo
00gooooo00?o003oooooooooool0Coooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
04_ooooo00Coo`00ooooooooooooo`009oooool01?oo003ooooooooooooo001@ooooo`03o`000?oo
oooooooo037ooooo00?o0000ooooooooool0A_ooool01?l00?oooooooooooooo0002ooooo`03ool0
0?oooooo003o00oooooo00?o0000ooooooooool04?ooool01_oo003ooooooooooooo003oooooo`00
odWooooo00?o0000ooooooooool05?ooool002kooooo00?o0000ooooooooool0Aoooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o0000ooooooooool03Oooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo04Oooooo00?o0000ooooooooool07_ooool3o`0000?o
oooo00?o0000ooooooooool0Boooool01?oo003ooooooooooooo000Wooooo`04ool00?oooooooooo
ool0053ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`19ooooo`04ool00?oooooo
ooooool0017ooooo00?o0000ooooooooool03_ooool00ol00?ooooooool00002ooooo`03ool00?oo
oooo003o04Wooooo00?o0000ooooooooool05?ooool002kooooo0_l00018ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool03_ooool00ol0003oooooooooo`0Eooooo`03o`00oooooooo
oooo04Kooooo0_l0000Qooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Boooool0
1?oo003ooooooooooooo000Wooooo`04ool00?ooooooooooool0053ooooo00?o0000ooooooooool0
<Oooool00ol0003oooooooooo`16ooooo`04o`00ooooooooooooool000;ooooo00?oo`00ooooool0
0?l03oooool00ol0003oooooooooo`0>ooooo`03o`00ooooooooo`0000;ooooo00?oo`00oooooooo
ool0B?ooool2o`0001Kooooo000Wooooo`?o00001?ooool00ol0003oooooooooo`1Oooooo`03o`00
0?oooooooooo00gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`17ooooo`03o`00
0?oooooooooo01cooooo1Ol00003ooooo`03o`000?oooooooooo04_ooooo00Coo`00oooooooooooo
o`009oooool01?oo003ooooooooooooo001@ooooo`03o`000?oooooooooo02Wooooo0ol00005oooo
o`03o`000?oooooooooo04Kooooo00Co003oooooooooooooo`000_ooool00ooo003oooooo`00o`0?
ooooo`03o`000?oooooooooo00kooooo00?o003ooooooooo00000_ooool00ooo003oooooo`00o`19
ooooo`03o`000?oooooooooo01Cooooo000Vooooo`05o`000?ooooooooooooooool000000oooool0
0ol0003oooooooooo`17ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03_ooool0
0ol0003oooooooooo`0=ooooo`03o`00oooooooooooo04oooooo00?o0000ooooooooool07?ooool0
1?l0003oooooooooool00004ooooo`?o0000Boooool01?oo003ooooooooooooo000Wooooo`04ool0
0?ooooooooooool004oooooo0_l0000Zooooo`05o`000?ooooooooooooooool000001?ooool00ol0
003oooooooooo`16ooooo`04o`00ooooooooooooool000;ooooo00?oo`00ooooool00?l03oooool0
0ol0003oooooooooo`0@ooooo`06ool00?ooooooooooool00?oooooo003oBOooool00ol0003ooooo
ooooo`0Dooooo`00:_ooool01Ol0003ooooooooooooooooo000004Wooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`17ooooo`03o`000?oooooooooo01gooooo00?o0000ooooool00000
1?ooool00ol0003oooooooooo`1;ooooo`04ool00?ooooooooooool002Oooooo00Coo`00oooooooo
ooooo`00D?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0BOooool01?oo003ooooooooooooo000Aooooo`03o`000?oooooooooo00kooooo00?o003o
oooooooo00000_ooool00ooo003oooooo`00o`19ooooo`03o`000?oooooooooo01Cooooo000Zoooo
o`04o`000?ooooooooooooooo`;o0000B?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo00kooooo00?o0000ooooooooool05Oooool00ol00?ooooooooooo`15ooooo`?o00008?ooool2
o`0000Cooooo00?o0000ooooooooool0Boooool01?oo003ooooooooooooo000Wooooo`04ool00?oo
ooooooooool0053ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`02ooooo`;o0000
Aoooool01?l00?oooooooooooooo0002ooooo`03ool00?oooooo003o00oooooo00?o0000oooooooo
ool03_ooool00ol00?ooooooool00002ooooo`03ool00?oooooooooo04Sooooo0_l0000Fooooo`00
9_ooool4o`0000Cooooo00?o0000ooooooooool0C_ooool00ol00?ooooooooooo`0>ooooo`03o`00
0?oooooooooo00gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`18ooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1;ooooo`04ool0
0?ooooooooooool002Oooooo00Coo`00ooooooooooooo`00D?ooool00ol0003oooooooooo`0Xoooo
o`Co00001Oooool00ol0003oooooooooo`16ooooo`04o`00ooooooooooooool000;ooooo00?oo`00
ooooool00?l03oooool00ol0003oooooooooo`0>ooooo`03o`00ooooooooo`0000;ooooo00?oo`00
ooooool00?l0BOooool00ol0003oooooooooo`0Dooooo`009_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo04Oooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0>oooo
o`03o`000?oooooooooo00gooooo00?o003oooooooooool0Coooool00ol0003oooooooooo`0Toooo
o`;o0000C?ooool01?oo003ooooooooooooo000Wooooo`04ool00?ooooooooooool004oooooo0_l0
000Zooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Aoooool00ol00?ooooooool0
0002ooooo`03ool00?oooooo003o00oooooo00?o0000ooooooooool04?ooool01_oo003ooooooooo
oooo003oooooo`00odWooooo00?o0000ooooooooool05?ooool002Kooooo1Ol00003ooooo`;o0000
B?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o0000ooooooooool0
3Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo04Oooooo0_l0000Vooooo`03o`00
0?oooooooooo04_ooooo00Coo`00ooooooooooooo`009oooool01?oo003ooooooooooooo001@oooo
o`03o`000?oooooooooo02Sooooo1Ol00004ooooo`03o`000?oooooooooo04Wooooo00Coo`00oooo
ooooooooo`004Oooool00ol0003oooooooooo`0>ooooo`03o`00ooooooooo`0000;ooooo00?oo`00
ooooool00?l0B?ooool2o`0001Kooooo000^ooooo`03o`000?oooooooooo04Oooooo00?o003ooooo
ooooool05Oooool00ol0003oooooooooo`0Dooooo`03o`00oooooooooooo04Sooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`1;ooooo`04ool00?ooooooooooool002Oooooo00Coo`00
ooooooooooooo`00D?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo04Oooooo00?o
003ooooooooo00000_ooool00ooo003oooooo`00o`0?ooooo`03o`000?oooooooooo00kooooo00?o
003ooooooooo00000_ooool00ooo003oooooooooo`19ooooo`03o`000?oooooooooo01Cooooo000^
ooooo`03o`000?oooooooooo04kooooo00?o003oooooooooool03_ooool00ol0003oooooooooo`0=
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0B?ooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo04_ooooo00Coo`00ooooooooooooo`009oooool01?oo003ooooooooo
oooo001@ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0Aoooool00ol00?oooooo
ool00002ooooo`03ool00?oooooo003o00oooooo00?o0000ooooooooool03_ooool00ol00?oooooo
ool00002ooooo`03ool00?oooooo003o04Wooooo00?o0000ooooooooool05?ooool002kooooo00?o
0000ooooooooool0Aoooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o
0000ooooooooool03_ooool00ol00?ooooooooooo`1>ooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool0Boooool01?oo003ooooooooooooo000Wooooo`04ool00?ooooooooooool0053o
oooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`17ooooo`03o`00ooooooooo`0000;o
oooo00?oo`00o`00ooooool03oooool00ol0003oooooooooo`0@ooooo`06ool00?ooooooooooool0
0?oooooo003oBOooool00ol0003oooooooooo`0Dooooo`00;_ooool2o`0004Sooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`000?oooooooooo01Cooooo00?o003ooooo
ooooool0Aoooool2o`0002Kooooo0_l0001<ooooo`04ool00?ooooooooooool002Oooooo00Coo`00
ooooooooooooo`00Coooool2o`0003?ooooo00?o0000ooooooooool0BOooool01?oo003ooooooooo
oooo000Aooooo`03o`000?oooooooooo00kooooo00?o003ooooooooo00000_ooool00ooo003ooooo
o`00o`18ooooo`;o00005_ooool002kooooo00?o0000ooooooooool0Aoooool00ol00?oooooooooo
o`0Eooooo`03o`000?oooooooooo00kooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`18ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0Boooool01?oo003ooooooooo
oooo000Wooooo`04ool00?ooooooooooool0053ooooo00?o0000ooooooooool0<Oooool00ol0003o
ooooooooo`17ooooo`03o`00ooooooooo`0000;ooooo00?oo`00o`00ooooool03oooool00ol0003o
ooooooooo`0>ooooo`03o`00ooooooooo`0000;ooooo00?oo`00ooooooooool0BOooool00ol0003o
ooooooooo`0Dooooo`00;_ooool00ol0003oooooooooo`1>ooooo`03o`00oooooooooooo00kooooo
00?o0000ooooooooool03_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo04Sooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`1;ooooo`04ool00?ooooooooooool002Oo
oooo00Coo`00ooooooooooooo`00D?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo
04Oooooo00?o003ooooooooo00000_ooool00ooo003o003oooooo`0?ooooo`03o`000?oooooooooo
00kooooo00?o003ooooooooo00000_ooool00ooo003oooooo`00o`19ooooo`03o`000?oooooooooo
01Cooooo000^ooooo`;o0000B?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00ko
oooo00?o0000ooooooooool03_ooool00ol00?ooooooooooo`1=ooooo`;o00009_ooool00ol0003o
ooooooooo`1;ooooo`04ool00?ooooooooooool002Oooooo00Coo`00ooooooooooooo`00D?ooool0
0ol0003oooooooooo`0aooooo`03o`000?oooooooooo04Oooooo00?o003ooooooooo00000_ooool0
0ooo003o003oooooo`0?ooooo`03o`000?oooooooooo013ooooo00Koo`00ooooooooooooo`00oooo
ool00?m8ooooo`;o00005_ooool002kooooo00?o0000ooooooooool0Aoooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00kooooo00?o0000ooooooooool05?ooool00ol00?oooooooooo
o`18ooooo`03o`000?oooooooooo02Cooooo0_l0001<ooooo`04ool00?ooooooooooool002Oooooo
00Coo`00ooooooooooooo`00Coooool2o`0003?ooooo00?o0000ooooooooool0BOooool01?oo003o
oooooooooooo000Aooooo`03o`000?oooooooooo00kooooo00?o003ooooooooo00000_ooool00ooo
003oooooo`00o`19ooooo`03o`000?oooooooooo01Cooooo000^ooooo`03o`000?oooooooooo04Oo
oooo00?o003oooooooooool05Oooool00ol0003oooooooooo`0>ooooo`03o`00oooooooooooo00?o
oooo00?o003oooooooooool0B?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo04_o
oooo00Coo`00ooooooooooooo`009oooool01?oo003ooooooooooooo001@ooooo`03o`000?oooooo
oooo037ooooo00?o0000ooooooooool0Aoooool00ol00?ooooooool00002ooooo`03ool00?l00?oo
oooo00oooooo00?o0000ooooooooool03_ooool00ol00?ooooooool00002ooooo`03ool00?oooooo
oooo04Wooooo00?o0000ooooooooool05?ooool002kooooo00?o0000ooooooooool0C_ooool00ol0
0?ooooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o003oooooooooool00oooool00ol0
0?ooooooooooo`18ooooo`03o`000?oooooooooo01gooooo0ol00004ooooo`03o`000?oooooooooo
04_ooooo00Coo`00ooooooooooooo`009oooool01?oo003ooooooooooooo001@ooooo`03o`000?oo
oooooooo037ooooo00?o0000ooooooooool0Aoooool00ol00?ooooooool00002ooooo`03ool00?l0
0?oooooo00oooooo00?o0000ooooooooool03_ooool00ol00?ooooooool00002ooooo`03ool00?oo
oooo003o04Wooooo00?o0000ooooooooool05?ooool002kooooo0_l00018ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`00oooooooo
oooo04gooooo0_l0000Nooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`1;ooooo`04ool00?ooooooooooool002Oooooo00Coo`00ooooooooooooo`00D?ooool00ol0003o
ooooooooo`0aooooo`03o`000?oooooooooo04Oooooo00?o003ooooooooo00000_ooool00ooo003o
003oooooo`0?ooooo`03o`000?oooooooooo013ooooo00Koo`00ooooooooooooo`00ooooool00?m8
ooooo`;o00005_ooool001cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`?o00001?ooool00ol0003oooooooooo`17ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool03_ooool00ol0003oooooooooo`0Dooooo`03o`00oooooooooooo04Sooooo00?o0000oooo
ooooool07?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0Boooool0
1?oo003ooooooooooooo000Wooooo`04ool00?ooooooooooool0053ooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`00
0?oooooooooo04Wooooo00Coo`00ooooooooooooo`004Oooool00ol0003oooooooooo`0>ooooo`03
o`00ooooooooo`0000;ooooo00?oo`00ooooool00?l0BOooool00ol0003oooooooooo`0Dooooo`00
7?ooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool000000oooool00ol0003o
ooooooooo`18ooooo`03o`00oooooooooooo01Cooooo00?o0000ooooooooool03_ooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooooooo04Sooooo00?o0000ooooooooool07?ooool4o`0000Co
oooo0ol0001;ooooo`04ool00?ooooooooooool002Oooooo00Coo`00ooooooooooooo`00Coooool2
o`00023ooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo000000Cooooo00?o
0000ooooooooool0Aoooool00ol00?ooooooool00002ooooo`03ool00?l00?oooooo00oooooo00?o
0000ooooooooool03_ooool00ol00?ooooooool00002ooooo`03ool00?oooooooooo04Wooooo00?o
0000ooooooooool05?ooool001gooooo00?o0000ooooooooool02_ooool01?l0003ooooooooooooo
ool2o`0004oooooo00?o003oooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`00oooo
oooooooo00?ooooo00?o003oooooooooool0A_ooool3o`0001kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`1;ooooo`04ool00?ooooooooooool002Oooooo00Coo`00oooooooooooo
o`00D?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool00_ooool2o`0004Sooooo00?o003ooooooooo00000_ooool00ooo003o003oooooo`0?ooooo`03
o`000?oooooooooo013ooooo00Goo`00ooooooooooooo`00o`00o`19ooooo`;o00005_ooool001go
oooo00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo000004[ooooo00?o003ooooo
ooooool00oooool00ol00?ooooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o003ooooo
ooooool0C_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0Boooool01?oo003ooooooooooooo000Wooooo`04ool00?ooooooooooool0053ooooo00?o
0000ooooooooool07oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0BOooool01Ooo003ooooooooooooo003o003o013ooooo00?o0000ooooooooool0
3oooool01_l00?ooo`00ooooooooooooo`00o`00od[ooooo00?o0000ooooooooool05?ooool001ko
oooo00?o0000ooooooooool01Oooool4o`0000Cooooo00?o0000ooooooooool0B?ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00oooooo00?o0000ooooooooool05?ooool00ol00?oo
ooooooooo`18ooooo`03o`000?oooooooooo01kooooo0_l00004ooooo`03o`000?oooooooooo04_o
oooo00Coo`00ooooooooooooo`009oooool01?oo003ooooooooooooo001@ooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool01Oooool4o`0000Gooooo00?o0000ooooooooool0Aoooool0
0ol00?ooooooool00002ooooo`03ool00?oooooooooo00oooooo00?o0000ooooooooool03oooool0
1_l00?ooo`00ooooooooooooo`00o`00od[ooooo00?o0000ooooooooool05?ooool001[ooooo00Go
0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
B?ooool00ol00?ooooooooooo`0Dooooo`03o`000?oooooooooo00kooooo00?o003oooooooooool0
0oooool00ol00?ooooooooooo`18ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
Boooool01?oo003ooooooooooooo000Wooooo`04ool00?ooooooooooool0053ooooo00?o0000oooo
ooooool07?ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`17ooooo`03o`00ooooooooo`0000;ooooo00?oo`00o`00ooooool03oooool0
0ol0003oooooooooo`0?ooooo`05o`00oooo003ooooooooooooo0000Boooool00ol0003ooooooooo
o`0Dooooo`006_ooool5o`0000Oooooo1Ol00003ooooo`;o0000C_ooool00ol00?ooooooooooo`0?
ooooo`03o`000?oooooooooo00kooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`17
ooooo`;o00009_ooool2o`0004cooooo00Coo`00ooooooooooooo`009oooool01?oo003ooooooooo
oooo001?ooooo`;o00007_ooool5o`0000Oooooo1Ol00004ooooo`03o`000?oooooooooo04Oooooo
00?o003ooooooooo00000_ooool00ooo003o003oooooo`0?ooooo`03o`000?oooooooooo013ooooo
00Goo`00ooooooooooooo`00o`00o`19ooooo`;o00005_ooool002kooooo00?o0000ooooooooool0
B?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00oooooo00?o0000ooooooooool0
3_ooool00ol00?ooooooooooo`1>ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
Boooool01?oo003ooooooooooooo000Wooooo`04ool00?ooooooooooool0053ooooo00?o0000oooo
ooooool0<Oooool00ol0003oooooooooo`19ooooo`05ool00?ooooooooooool00?l00?l04?ooool0
0ol0003oooooooooo`0?ooooo`06o`00oooo003ooooooooooooo003o003oB_ooool00ol0003ooooo
ooooo`0Dooooo`00;_ooool00ol0003oooooooooo`18ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool03oooool00ol0003oooooooooo`0Dooooo`03o`00oooooooooooo04Sooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`1;ooooo`04ool00?ooooooooooool002Oooooo
00Coo`00ooooooooooooo`00D?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo04Oo
oooo00?o003ooooooooo00000_ooool00ooo003oooooooooo`0?ooooo`03o`000?oooooooooo00oo
oooo00Ko003oool00?ooooooooooool00?l00?m:ooooo`03o`000?oooooooooo01Cooooo000^oooo
o`03o`000?oooooooooo04Sooooo00?o003oooooooooool05?ooool00ol0003oooooooooo`0>oooo
o`03o`00oooooooooooo00?ooooo00?o003oooooooooool0B?ooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo04_ooooo00Coo`00ooooooooooooo`009oooool01?oo003ooooooooooooo
001@ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0Aoooool00ol00?ooooooool0
0002ooooo`03ool00?l00?oooooo00oooooo00?o0000ooooooooool03oooool01Ol00?ooo`00oooo
ooooooooo`0004_ooooo00?o0000ooooooooool05?ooool002kooooo0_l0001>ooooo`03o`00oooo
oooooooo00oooooo00?o0000ooooooooool03_ooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooooooo04Oooooo0_l0000Vooooo`;o0000C?ooool01?oo003ooooooooooooo000Wooooo`04ool0
0?ooooooooooool004oooooo0_l0000cooooo`03o`000?oooooooooo04Oooooo00?o003ooooooooo
00000_ooool00ooo003o003oooooo`0?ooooo`03o`000?oooooooooo013ooooo00Goo`00oooooooo
ooooo`00o`00o`19ooooo`;o00005_ooool002kooooo00?o0000ooooooooool0B?ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00oooooo00?o0000ooooooooool03_ooool00ol00?oo
ooooooooo`1>ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0Boooool01?oo003o
oooooooooooo000Wooooo`04ool00?ooooooooooool0053ooooo00?o0000ooooooooool0<Oooool0
0ol0003oooooooooo`19ooooo`04ool00?ooooooooooool0017ooooo00?o0000ooooooooool03ooo
ool01_l00?ooo`00ooooooooooooo`00o`00od[ooooo00?o0000ooooooooool05?ooool002kooooo
00?o0000ooooooooool0B?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00oooooo
00?o0000ooooooooool05?ooool00ol00?ooooooooooo`18ooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool0Boooool01?oo003ooooooooooooo000Wooooo`04ool00?ooooooooooool0
053ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`17ooooo`03o`00ooooooooo`00
00;ooooo00?oo`00o`00ooooool03oooool00ol0003oooooooooo`0?ooooo`06o`00oooo003ooooo
oooooooo003o003oB_ooool00ol0003oooooooooo`0Dooooo`00;_ooool2o`0004Wooooo00?o003o
ooooooooool05?ooool00ol0003oooooooooo`0>ooooo`03o`00oooooooooooo00?ooooo00?o003o
ooooooooool0Aoooool2o`0002Kooooo00?o0000ooooooooool0Boooool01?oo003ooooooooooooo
000Wooooo`04ool00?ooooooooooool0053ooooo00?o0000ooooooooool0<Oooool00ol0003ooooo
ooooo`17ooooo`03o`00ooooooooo`0000;ooooo00?oo`00o`00ooooool03oooool00ol0003ooooo
ooooo`0?ooooo`05o`00oooo003ooooooooooooo0000B_ooool2o`0001Kooooo000^ooooo`03o`00
0?oooooooooo04gooooo00?o003oooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`00
oooooooooooo00?ooooo00?o003oooooooooool0B?ooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo04_ooooo00Coo`00ooooooooooooo`009oooool01?oo003ooooooooooooo001@oooo
o`03o`000?oooooooooo037ooooo00?o0000ooooooooool0Aoooool00ol00?ooooooool00002oooo
o`03ool00?l00?oooooo00oooooo00?o0000ooooooooool04?ooool01Ooo003ooooooooooooo003o
003o04[ooooo00?o0000ooooooooool05?ooool002kooooo00?o0000ooooooooool0B?ooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0
0?ooooooooooo`1>ooooo`03o`000?oooooooooo02Cooooo0_l0001<ooooo`04ool00?oooooooooo
ool002Oooooo00Coo`00ooooooooooooo`00Coooool2o`0003?ooooo00?o0000ooooooooool0BOoo
ool01?oo003ooooooooooooo000Aooooo`03o`000?oooooooooo00oooooo00Ko003oool00?oooooo
ooooool00?l00?m:ooooo`03o`000?oooooooooo01Cooooo000^ooooo`03o`000?oooooooooo04So
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0?ooooo`03o`000?oooooooooo01?o
oooo00?o003oooooooooool0BOooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo04_o
oooo00Coo`00ooooooooooooo`009oooool01?oo003ooooooooooooo001@ooooo`03o`000?oooooo
oooo037ooooo00?o0000ooooooooool0B?ooool01_l00?ooo`00ooooooooooooo`00o`00oa3ooooo
00?o0000ooooooooool03oooool01Ol00?ooo`00ooooooooooooo`0004_ooooo00?o0000oooooooo
ool05?ooool002kooooo0_l00019ooooo`03o`00oooooooooooo01Cooooo00?o0000ooooooooool0
3_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo04Sooooo0_l0000Oooooo`?o0000
1?ooool00ol0003oooooooooo`1;ooooo`04ool00?ooooooooooool002Oooooo00Coo`00oooooooo
ooooo`00D?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo04Sooooo00Ko003oool0
0?ooooooooooool00?l00?l@ooooo`03o`000?oooooooooo00oooooo00Ko003oool00?oooooooooo
ool00?l00?m9ooooo`;o00005_ooool0027ooooo0ol00004ooooo`;o00001?ooool00ol0003ooooo
ooooo`18ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool03oooool00ol0003ooooo
ooooo`0>ooooo`03o`00oooooooooooo04kooooo00?o0000ooooooooool07?ooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooooooool0Boooool01?oo003ooooooooooooo000Woooo
o`04ool00?ooooooooooool0053ooooo00?o0000ooooooooool08oooool3o`0000Cooooo0_l00005
ooooo`03o`000?oooooooooo04Sooooo00Ko003oool00?ooooooooooool00?l00?l@ooooo`03o`00
0?oooooooooo013ooooo00Goo`00ooooooooooooo`00o`00o`1:ooooo`03o`000?oooooooooo01Co
oooo000Rooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000oooool00ol0003o
ooooooooo`18ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool03oooool00ol0003o
ooooooooo`0?ooooo`05o`00ooooooooooooooooool00?l0Boooool00ol0003oooooooooo`0Loooo
o`05o`000?ooooooooooooooool000000oooool3o`0004_ooooo00Coo`00ooooooooooooo`009ooo
ool01?oo003ooooooooooooo001?ooooo`;o00009_ooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool0BOooool01?oo003ooooooooooooo000Aoooo
o`03o`000?oooooooooo00oooooo00Ko003oool00?ooooooooooool00?l00?m:ooooo`03o`000?oo
oooooooo01Cooooo000Rooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000ooo
ool2o`0004Wooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0?ooooo`03o`000?oo
oooooooo01?ooooo00?o003oooooooooool0Aoooool3o`0001oooooo0ol00004ooooo`03o`000?oo
oooooooo04_ooooo00Coo`00ooooooooooooo`009oooool01?oo003ooooooooooooo001@ooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00004oooo
o`;o0000BOooool01Ol00?ooo`00ooooooooooooo`00017ooooo00?o0000ooooooooool03oooool0
1Ol00?ooo`00ooooooooooooo`0004[ooooo0_l0000Fooooo`008_ooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0Goooool00ol0003ooooooooo
o`0?ooooo`05o`00ooooooooooooooooool00?l0Boooool00ol0003oooooooooo`0Looooo`05o`00
0?ooooooooooooooool000000oooool00ol0003oooooooooo`1;ooooo`04ool00?ooooooooooool0
02Oooooo00Coo`00ooooooooooooo`00D?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`18ooooo`05o`00oooo
003ooooooooooooo00004Oooool00ol0003oooooooooo`0?ooooo`06o`00oooo003ooooooooooooo
003o003oB_ooool00ol0003oooooooooo`0Dooooo`008_ooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0B?ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo00oooooo00?o0000ooooooooool03oooool00ol00?ooooooooooo`1=oooo
o`03o`000?oooooooooo01cooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo
oooo04_ooooo00Coo`00ooooooooooooo`009oooool01?oo003ooooooooooooo001@ooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo04Sooooo00Go003oool00?ooooooooooool0000Aooooo`03o`000?oooooooooo
013ooooo00Goo`00ooooooooooooo`00o`00o`1:ooooo`03o`000?oooooooooo01Cooooo000Qoooo
o`;o00001?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo04Sooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`0?ooooo`03o`000?oooooooooo00oooooo00Go003o
ooooooooooooooooo`00o`1;ooooo`03o`000?oooooooooo01gooooo0ol00004ooooo`03o`000?oo
oooooooo04_ooooo00Coo`00ooooooooooooo`009oooool01?oo003ooooooooooooo001@ooooo`03
o`000?oooooooooo02?ooooo0_l00004ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooo
ooooool0BOooool01?oo003ooooooooooooo000Aooooo`03o`000?oooooooooo00oooooo00Ko003o
ool00?ooooooooooool00?l00?m:ooooo`03o`000?oooooooooo01Cooooo000Rooooo`03o`000?oo
oooooooo00?ooooo0_l00004ooooo`;o0000BOooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo00oooooo00?o0000ooooooooool04oooool00ol00?ooooooooooo`18ooooo`;o00009_oo
ool2o`0004cooooo00Coo`00ooooooooooooo`009oooool01?oo003ooooooooooooo001?ooooo`;o
00009_ooool00ol0003oooooooooo`03ooooo`;o00001Oooool00ol0003oooooooooo`18ooooo`05
o`00oooo003ooooooooooooo00004Oooool00ol0003oooooooooo`0?ooooo`05o`00oooo003ooooo
oooooooo0000B_ooool2o`0001Kooooo000^ooooo`03o`000?oooooooooo05oooooo00?o0000oooo
ooooool03oooool01Ol00?oooooooooooooooooo003o04_ooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`1;ooooo`04ool00?ooooooooooool002Oooooo00Coo`00ooooooooooooo`00
D?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo04Sooooo00Go003oool00?oooooo
ooooool0000Aooooo`03o`000?oooooooooo00oooooo00Ko003oool00?ooooooooooool00?l00?m:
ooooo`03o`000?oooooooooo01Cooooo000^ooooo`03o`000?oooooooooo04Sooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`0?ooooo`03o`000?oooooooooo00oooooo00?o003ooooo
ooooool0COooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo04_ooooo00Coo`00oooo
ooooooooo`009oooool01?oo003ooooooooooooo001@ooooo`03o`000?oooooooooo037ooooo00?o
0000ooooooooool0B?ooool01Ol00?ooo`00ooooooooooooo`00017ooooo00?o0000ooooooooool0
4?ooool01Ooo003ooooooooooooo003o003o04[ooooo00?o0000ooooooooool05?ooool002kooooo
0_l00019ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool03oooool00ol0003ooooo
ooooo`0?ooooo`05o`00ooooooooooooooooool00?l0B_ooool2o`0002Kooooo00?o0000oooooooo
ool0Boooool01?oo003ooooooooooooo000Wooooo`04ool00?ooooooooooool0053ooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`19ooooo`04ool00?ooooooooooool0017ooooo00?o
0000ooooooooool03oooool01_l00?ooo`00ooooooooooooo`00o`00odWooooo0_l0000Fooooo`00
;_ooool00ol0003oooooooooo`18ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
3oooool00ol0003oooooooooo`0Cooooo`03o`00oooooooooooo04Wooooo00?o0000ooooooooool0
9?ooool2o`0004cooooo00Coo`00ooooooooooooo`009oooool01?oo003ooooooooooooo001?oooo
o`;o0000<oooool00ol0003oooooooooo`18ooooo`05o`00oooo003ooooooooooooo00004Oooool0
0ol0003oooooooooo`0?ooooo`05o`00oooo003ooooooooooooo0000Boooool00ol0003ooooooooo
o`0Dooooo`00;_ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo00oooooo00Go003o
ooooooooooooooooo`00o`1;ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0Booo
ool01?oo003ooooooooooooo000Wooooo`04ool00?ooooooooooool0053ooooo00?o0000oooooooo
ool0<Oooool00ol0003oooooooooo`18ooooo`05o`00oooo003ooooooooooooo00004Oooool00ol0
003oooooooooo`0?ooooo`06o`00oooo003ooooooooooooo003o003oB_ooool00ol0003ooooooooo
o`0Dooooo`00;_ooool00ol0003oooooooooo`19ooooo`05o`00ooooooooooooooooool00?l04Ooo
ool00ol0003oooooooooo`0?ooooo`03o`00oooooooooooo04gooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`1;ooooo`04ool00?ooooooooooool002Oooooo00Coo`00oooooooooooo
o`00D?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo04Sooooo00Go003oool00?oo
ooooooooool0000Aooooo`03o`000?oooooooooo013ooooo00Goo`00ooooooooooooo`00o`00o`1:
ooooo`03o`000?oooooooooo01Cooooo000^ooooo`;o0000B_ooool01Ol00?oooooooooooooooooo
003o017ooooo00?o0000ooooooooool03oooool01Ol00?oooooooooooooooooo003o04[ooooo0_l0
000Vooooo`03o`000?oooooooooo04_ooooo00Coo`00ooooooooooooo`009oooool01?oo003ooooo
oooooooo001@ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0BOooool01?oo003o
oooooooooooo000Aooooo`03o`000?oooooooooo00oooooo00Go003oool00?ooooooooooool0001:
ooooo`;o00005_ooool002kooooo00?o0000ooooooooool0BOooool00ol00?ooooooooooo`0Coooo
o`03o`000?oooooooooo01?ooooo00?o003oooooooooool0BOooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo04_ooooo00Coo`00ooooooooooooo`009oooool01?oo003ooooooooooooo
001@ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0B?ooool01Ol00?ooo`00oooo
ooooooooo`00017ooooo00?o0000ooooooooool03oooool01Ol00?ooo`00ooooooooooooo`0004_o
oooo00?o0000ooooooooool05?ooool002kooooo00?o0000ooooooooool0C?ooool00ol00?oooooo
ooooo`0@ooooo`03o`000?oooooooooo00oooooo00Go003oooooooooooooooooo`00o`1;ooooo`03
o`000?oooooooooo02Cooooo0_l0001<ooooo`04ool00?ooooooooooool002Oooooo00Coo`00oooo
ooooooooo`00Coooool2o`0003?ooooo00?o0000ooooooooool0B?ooool01Ol00?ooo`00oooooooo
ooooo`00017ooooo00?o0000ooooooooool04?ooool01?oo003ooooooooooooo001;ooooo`03o`00
0?oooooooooo01Cooooo000^ooooo`;o0000B_ooool01?l00?ooooooooooool00?lBooooo`03o`00
0?oooooooooo00oooooo00?o003oooooooooool0C?ooool2o`0002Kooooo00?o0000ooooooooool0
Boooool01?oo003ooooooooooooo000Wooooo`04ool00?ooooooooooool0053ooooo00?o0000oooo
ooooool0<Oooool00ol0003oooooooooo`18ooooo`05o`00oooo003ooooooooooooo00004Oooool0
0ol0003oooooooooo`0@ooooo`04ool00?ooooooooooool004[ooooo0_l0000Fooooo`00;_ooool0
0ol0003oooooooooo`19ooooo`04o`00ooooooooooooo`00oa;ooooo00?o0000ooooooooool03ooo
ool01Ol00?oooooooooooooooooo003o04_ooooo00?o0000ooooooooool05oooool3o`0000Cooooo
0_l00004ooooo`03o`000?oooooooooo04_ooooo00Coo`00ooooooooooooo`009oooool01?oo003o
oooooooooooo001@ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0BOooool01?oo
003ooooooooooooo000Aooooo`03o`000?oooooooooo013ooooo00Coo`00ooooooooooooo`00Booo
ool00ol0003oooooooooo`0Dooooo`005Oooool3o`0000;ooooo1Ol00003ooooo`03o`000?oooooo
oooo00;ooooo0ol00004ooooo`03o`000?oooooooooo04Wooooo00?o003oooooooooool04oooool0
0ol0003oooooooooo`0?ooooo`05o`00ooooooooooooooooool00?l0Boooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000oooool00ol0003ooooo
ooooo`1;ooooo`04ool00?ooooooooooool002Oooooo00Coo`00ooooooooooooo`00D?ooool00ol0
003oooooooooo`0Gooooo`?o00000_ooool5o`0000?ooooo00?o0000ooooooooool00_ooool3o`00
00Gooooo00?o0000ooooooooool0B?ooool01Ol00?ooo`00ooooooooooooo`00017ooooo00?o0000
ooooooooool04?ooool01?oo003ooooooooooooo001;ooooo`03o`000?oooooooooo01Cooooo000F
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooo
oooooooo000000?ooooo00?o0000ooooooooool0BOooool01?l00?ooooooooooool00?lBooooo`03
o`000?oooooooooo00oooooo00Go003oooooooooooooooooo`00o`1;ooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003ooooo`?o0000Boooool0
1?oo003ooooooooooooo000Wooooo`04ool00?ooooooooooool004oooooo0_l0000Jooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000
00Cooooo00?o0000ooooooooool0B?ooool01Ol00?ooo`00ooooooooooooo`00017ooooo00?o0000
ooooooooool04?ooool01?oo003ooooooooooooo001;ooooo`03o`000?oooooooooo01Cooooo000F
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02oooool01?l0003ooooooooooooo
ool2o`0004gooooo00?o003oooooooooool04?ooool00ol0003oooooooooo`0?ooooo`03o`00oooo
oooooooo04_ooooo0ol0000Jooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000
0oooool00ol0003oooooooooo`1;ooooo`04ool00?ooooooooooool002Oooooo00Coo`00oooooooo
ooooo`00D?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`02ooooo`;o0000BOooool01Ol00?ooo`00oooooooooooo
o`00017ooooo00?o0000ooooooooool04?ooool01?oo003ooooooooooooo001:ooooo`;o00005_oo
ool001Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`05o`000?oooooo
ooooooooool00000Boooool01?l00?ooooooooooool00?lBooooo`03o`000?oooooooooo01?ooooo
00?o003oooooooooool0BOooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00000oooool00ol0003oooooooooo`1;ooooo`04ool00?ooooooooooool0
02Oooooo00Coo`00ooooooooooooo`00D?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo04Wooooo00Coo`00ooooooooooooo`004Oooool00ol0003oooooooooo`0@ooooo`04ool00?oo
ooooooooool004_ooooo00?o0000ooooooooool05?ooool001Kooooo00Go0000oooooooooooooooo
o`000003ooooo`03o`000?oooooooooo00Gooooo1?l00004ooooo`03o`000?oooooooooo04Wooooo
00?o003oooooooooool04oooool00ol0003oooooooooo`0?ooooo`05o`00ooooooooooooooooool0
0?l0Boooool00ol0003oooooooooo`0Gooooo`;o00001?ooool01?l0003oooooooooool00003oooo
o`03o`000?oooooooooo04_ooooo00Coo`00ooooooooooooo`009oooool01?oo003ooooooooooooo
001@ooooo`03o`000?oooooooooo01Sooooo00Go0000ooooooooooooooooo`000003ooooo`03o`00
0?oooooooooo00Gooooo1?l00005ooooo`03o`000?oooooooooo04Sooooo00Go003oool00?oooooo
ooooool0000Aooooo`03o`000?oooooooooo013ooooo00Coo`00ooooooooooooo`00Boooool00ol0
003oooooooooo`0Dooooo`005Oooool2o`0000?ooooo00Go0000ooooooooooooooooo`000007oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0BOooool01?l00?ooooooooooool00?lB
ooooo`03o`000?oooooooooo00oooooo00Go003oooooooooooooooooo`00o`1;ooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool00oooool2o`0000Cooooo00?o0000ooooooooool0Booo
ool01?oo003ooooooooooooo000Wooooo`04ool00?ooooooooooool0053ooooo00?o0000oooooooo
ool05oooool2o`0000?ooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0B?ooool01Ol00?ooo`00ooooooooooooo`00017ooooo00?o0000
ooooooooool04?ooool01?oo003ooooooooooooo001;ooooo`03o`000?oooooooooo01Cooooo000F
ooooo`03o`000?oooooooooo00;ooooo0ol00008ooooo`Go00000oooool2o`0004gooooo00?o003o
ooooooooool04?ooool00ol0003oooooooooo`0?ooooo`03o`00oooooooooooo04cooooo0_l0000V
ooooo`;o0000C?ooool01?oo003ooooooooooooo000Wooooo`04ool00?ooooooooooool004oooooo
0_l0000Jooooo`03o`000?oooooooooo00;ooooo0ol00008ooooo`Go00001?ooool00ol0003ooooo
ooooo`18ooooo`05o`00oooo003ooooooooooooo00004Oooool00ol0003oooooooooo`0@ooooo`04
ool00?ooooooooooool004[ooooo0_l0000Fooooo`00;_ooool00ol0003oooooooooo`19ooooo`04
o`00ooooooooooooo`00oa;ooooo00?o0000ooooooooool04_ooool00ol00?ooooooooooo`1:oooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0Boooool01?oo003ooooooooooooo000W
ooooo`04ool00?ooooooooooool0053ooooo00?o0000ooooooooool0<Oooool00ol0003ooooooooo
o`19ooooo`04ool00?ooooooo`00ool0017ooooo00?o0000ooooooooool03oooool2ool000;ooooo
00?oo`00ooooooooool0BOooool00ol0003oooooooooo`0Dooooo`00;_ooool00ol0003ooooooooo
o`19ooooo`03o`00oooooooooooo01?ooooo00?o0000ooooooooool03oooool01?l00?oooooooooo
ool00?m<ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0Boooool01?oo003ooooo
oooooooo000Wooooo`04ool00?ooooooooooool0053ooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`18ooooo`;oo`0000?oooooool00?oo00004Oooool00ol0003oooooooooo`0?oooo
o`;oo`0000?oooooool00?oo0000Boooool00ol0003oooooooooo`0Dooooo`00;_ooool2o`0004[o
oooo00Co003ooooooooooooo003o4_ooool00ol0003oooooooooo`0?ooooo`04o`00oooooooooooo
o`00od_ooooo0_l0000Vooooo`03o`000?oooooooooo04_ooooo00Coo`00ooooooooooooo`009ooo
ool01?oo003ooooooooooooo001@ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
B?ooool2ool000;ooooo00?o003oooooooooool03oooool00ol0003oooooooooo`0Booooo`;oo`00
B_ooool2o`0001Kooooo000^ooooo`03o`000?oooooooooo04cooooo00?o003oooooooooool04?oo
ool00ol0003oooooooooo`0@ooooo`03o`00oooooooooooo04cooooo00?o0000ooooooooool09?oo
ool2o`0004cooooo00Coo`00ooooooooooooo`009oooool01?oo003ooooooooooooo001?ooooo`;o
0000<oooool00ol0003oooooooooo`19ooooo`04o`00ooooooooooooo`00oa7ooooo00?o0000oooo
ooooool04?ooool01?l00?ooooooooooool00?m;ooooo`03o`000?oooooooooo01Cooooo000^oooo
o`03o`000?oooooooooo04Wooooo00Co003ooooooooooooo003o4_ooool00ol0003oooooooooo`0B
ooooo`03o`00oooooooooooo04[ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1;
ooooo`04ool00?ooooooooooool002Oooooo00Coo`00ooooooooooooo`00D?ooool00ol0003ooooo
ooooo`0aooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool04?ooool01?l00?oooooo
ooooool00?m;ooooo`03o`000?oooooooooo01Cooooo000^ooooo`03o`000?oooooooooo04Wooooo
00?o003oooooooooool04oooool00ol0003oooooooooo`0@ooooo`03o`00oooooooo003o04cooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`1;ooooo`04ool00?ooooooooooool002Oo
oooo00Coo`00ooooooooooooo`00D?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo
04Wooooo00?o003oooooool00?l04_ooool00ol0003oooooooooo`0@ooooo`03o`00oooooooooooo
04cooooo00?o0000ooooooooool05?ooool002kooooo0_l0001:ooooo`04o`00ooooooooooooo`00
oa;ooooo00?o0000ooooooooool04?ooool00ol00?ooooooo`00o`1;ooooo`;o00009_ooool00ol0
003oooooooooo`1;ooooo`04ool00?ooooooooooool002Oooooo00Coo`00ooooooooooooo`00D?oo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo04Wooooo00?o003oooooool00?l04_oo
ool00ol0003oooooooooo`0Cooooo`03o`00oooooooooooo04Sooooo0_l0000Fooooo`00;_ooool0
0ol0003oooooooooo`1<ooooo`03o`00oooooooooooo013ooooo00?o0000ooooooooool04?ooool0
0ol00?ooooooooooo`1<ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0Boooool0
1?oo003ooooooooooooo000Wooooo`04ool00?ooooooooooool0053ooooo00?o0000ooooooooool0
<Oooool00ol0003oooooooooo`19ooooo`03o`00oooooooo003o01;ooooo00?o0000ooooooooool0
4?ooool01?l00?ooooooooooool00?m;ooooo`03o`000?oooooooooo01Cooooo000^ooooo`03o`00
0?oooooooooo04Wooooo00Co003ooooooooooooo003o4_ooool00ol0003oooooooooo`0Booooo`03
o`00oooooooooooo04[ooooo00?o0000ooooooooool09?ooool2o`0004cooooo00Coo`00oooooooo
ooooo`009oooool01?oo003ooooooooooooo001?ooooo`;o0000<oooool00ol0003oooooooooo`1N
ooooo`03o`000?oooooooooo013ooooo00Co003ooooooooooooo003oBoooool00ol0003ooooooooo
o`0Dooooo`00;_ooool2o`0004[ooooo00?o003oooooooooool04oooool00ol0003oooooooooo`0@
ooooo`03o`00oooooooo003o04_ooooo0_l0000Vooooo`03o`000?oooooooooo04_ooooo00Coo`00
ooooooooooooo`009oooool01?oo003ooooooooooooo001@ooooo`03o`000?oooooooooo037ooooo
00?o0000ooooooooool0BOooool00ol00?ooooooo`00o`0Booooo`03o`000?oooooooooo013ooooo
00?o003oooooooooool0Boooool2o`0001Kooooo000Qooooo`?o00000oooool3o`0000Cooooo00?o
0000ooooooooool0BOooool01?l00?ooooooooooool00?lBooooo`03o`000?oooooooooo013ooooo
00?o003oooooool00?l0C?ooool00ol0003oooooooooo`0Gooooo`?o00000_ooool5o`0000?ooooo
00?o0000ooooooooool0Boooool01?oo003ooooooooooooo000Wooooo`04ool00?ooooooooooool0
053ooooo00?o0000ooooooooool08oooool3o`0000?ooooo0ol00005ooooo`03o`000?oooooooooo
04Wooooo00?o003oooooool00?l04_ooool00ol0003oooooooooo`0Cooooo`03o`00oooooooooooo
04Wooooo00?o0000ooooooooool05?ooool002;ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool00000C_ooool00ol00?ooooooooooo`0@ooooo`03o`000?oooooo
oooo013ooooo00?o003oooooooooool0C?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`1;ooooo`04ool00?oo
ooooooooool002Oooooo00Coo`00ooooooooooooo`00D?ooool00ol0003oooooooooo`0Tooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
04Wooooo00?o003oooooooooool04_ooool00ol0003oooooooooo`0@ooooo`04o`00oooooooooooo
o`00od_ooooo00?o0000ooooooooool05?ooool002;ooooo00?o0000ooooooooool01Oooool01Ol0
003ooooooooooooooooo000004cooooo00?o003oooooool00?l04_ooool00ol0003oooooooooo`0B
ooooo`03o`00oooooooooooo04[ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo0ol0001;ooooo`04ool00?ooooooooooool002Oooooo00Co
o`00ooooooooooooo`00Coooool2o`0002Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo04_ooooo00?o003oooooooooool04?ooool00ol0003ooooo
ooooo`0@ooooo`03o`00oooooooo003o04cooooo00?o0000ooooooooool05?ooool002;ooooo00?o
0000ooooooooool01Oooool01?l0003oooooooooooooool2o`0004_ooooo00?o003oooooooooool0
4_ooool00ol0003oooooooooo`0@ooooo`03o`00oooooooo003o04[ooooo0ol0000Jooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1;ooooo`04ool0
0?ooooooooooool002Oooooo00Coo`00ooooooooooooo`00D?ooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool2o`0004[ooooo00?o003ooooo
ool00?l04_ooool00ol0003oooooooooo`0Aooooo`03o`00oooooooooooo04[ooooo0_l0000Foooo
o`008_ooool01?l0003oooooooooooooool4o`0000Cooooo00?o0000ooooooooool0B_ooool2o`00
oa?ooooo00?o0000ooooooooool04?ooool00ol00?ooooooo`00o`1<ooooo`03o`000?oooooooooo
01Sooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000COoo
ool01?oo003ooooooooooooo000Wooooo`04ool00?ooooooooooool0053ooooo00?o0000oooooooo
ool09?ooool01?l0003oooooooooooooool4o`0000Gooooo00?o0000ooooooooool0BOooool00ol0
0?ooooooo`00o`0Booooo`03o`000?oooooooooo01;ooooo00?o003oooooooooool0B_ooool00ol0
003oooooooooo`0Dooooo`008Oooool2o`0000?ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`1:ooooo`;o003o4oooool00ol0003oooooooooo`0@ooooo`03o`00oooooooooooo04co
oooo00?o0000ooooooooool05oooool2o`0000?ooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooooooo04_ooooo00Coo`00ooooooooooooo`009oooool01?oo003ooooooooooooo
001@ooooo`03o`000?oooooooooo02?ooooo0_l00003ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0BOooool00ol00?ooooooooooo`0Booooo`03o`000?oooooooooo017ooooo0_l0
0?m<ooooo`03o`000?oooooooooo01Cooooo000Rooooo`04o`000?ooooooooooooooo`Go00000ooo
ool2o`0004_ooooo0_l00?lCooooo`03o`000?oooooooooo01;ooooo00?o003oooooooooool0BOoo
ool2o`0001[ooooo00?o0000ooooooooool00_ooool3o`0000Cooooo00?o0000ooooooooool0Booo
ool01?oo003ooooooooooooo000Wooooo`04ool00?ooooooooooool0053ooooo00?o0000oooooooo
ool09?ooool01?l0003oooooooooooooool5o`0000Cooooo00?o0000ooooooooool0Boooool00ol0
0?ooooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o003oooooooooool0B_ooool2o`00
01Kooooo000^ooooo`03o`000?oooooooooo04[ooooo00?o003oooooooooool04_ooool00ol0003o
ooooooooo`0@ooooo`03o`00oooooooo003o04cooooo00?o0000ooooooooool09?ooool2o`0004co
oooo00Coo`00ooooooooooooo`009oooool01?oo003ooooooooooooo001?ooooo`;o0000<oooool0
0ol0003oooooooooo`19ooooo`03o`00oooooooo003o01;ooooo00?o0000ooooooooool04Oooool2
o`00odcooooo00?o0000ooooooooool05?ooool002kooooo00?o0000ooooooooool0Boooool00ol0
0?ooooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o003oooooooooool0C?ooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo04_ooooo00Coo`00ooooooooooooo`009oooool0
1?oo003ooooooooooooo001@ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0B_oo
ool2o`00oa;ooooo00?o0000ooooooooool04_ooool00ol00?ooooooooooo`1:ooooo`03o`000?oo
oooooooo01Cooooo000^ooooo`03o`000?oooooooooo04[ooooo0_l00?lCooooo`03o`000?oooooo
oooo013ooooo0_l00?m=ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0Boooool0
1?oo003ooooooooooooo000Wooooo`04ool00?ooooooooooool0053ooooo00?o0000ooooooooool0
<Oooool00ol0003oooooooooo`1:ooooo`03o`00oooooooooooo017ooooo00?o0000ooooooooool0
4Oooool2o`00odcooooo00?o0000ooooooooool05?ooool002kooooo0_l0001;ooooo`;o003o4ooo
ool00ol0003oooooooooo`0Aooooo`03o`00oooooooooooo04[ooooo0_l0000Vooooo`03o`000?oo
oooooooo04_ooooo00Coo`00ooooooooooooo`009oooool01?oo003ooooooooooooo001@ooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool0B_ooool00ol00?ooooooooooo`0Aooooo`03
o`000?oooooooooo017ooooo00?o003oooooooooool0B_ooool2o`0001Kooooo000^ooooo`03o`00
0?oooooooooo04[ooooo00?o003oooooooooool04_ooool00ol0003oooooooooo`0Aooooo`03o`00
oooooooooooo04_ooooo00?o0000ooooooooool09?ooool2o`0004cooooo00Coo`00oooooooooooo
o`009oooool01?oo003ooooooooooooo001?ooooo`;o0000<oooool00ol0003oooooooooo`1:oooo
o`03o`00oooooooooooo017ooooo00?o0000ooooooooool04Oooool00ol00?ooooooooooo`1;oooo
o`03o`000?oooooooooo01Cooooo000^ooooo`03o`000?oooooooooo05oooooo00?o0000oooooooo
ool0Goooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo04_ooooo00?oo`00oooooooo
00000_oo000Uooooo`?oo`0000?oooooool00?ooool0Coooool00ol0003oooooooooo`0aooooo`03
o`000?oooooooooo05kooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0Dooooo`00
;_ooool2o`0000?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`04o`00
0?ooooooooooooooo`;o00009_ooool00ol0003oooooooooo`1:ooooo`Koo`009Oooool6ool004oo
oooo00?o0000ooooooooool0<Oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01_ooool01?l0003oooooooooooooool2o`0001Kooooo000^ooooolGo00009_ooool00ol0
003oooooooooo`1:ooooo`Koo`009Oooool6ool004oooooo00?o0000ooooooooool0<Oooooo4o`00
01Kooooo003ooooooa[ooooo00?o0000ooooooooool0B_ooool3ool002_ooooo0ooo001?ooooo`03
o`000?oooooooooo0?oooooo3?ooool00?oooooo6_ooool3o`0000Wooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool01?l0003oooooooooooooool2o`000?oooooo3_ooool00?oooooo6_ooooo>o`000?oooooo
3_ooool00?ooooooooooooofooooo`00ooooooooooooooKooooo003ooooooooooooom_ooool00001
\
\>"],
  ImageRangeCache->{{{0, 755}, {145, 0}} -> {-0.0839304, -0.0144882, \
0.00419585, 0.00419585}, {{20, 243.438}, {141.5, 3.4375}} -> {-15.4854, \
-2.90846, 0.107336, 0.140678}, {{265.75, 489.188}, {141.5, 3.4375}} -> \
{-38.5921, -1.99292, 0.100886, 0.110281}, {{511.562, 734.938}, {141.5, \
3.4375}} -> {-68.2661, -2.91199, 0.10737, 0.140723}}]
}, Closed]]
}, Closed]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Windowing example #2 (example #6 waveform, DC, (1+1/6) Hz, \
(2+1/6)Hz)\
\>", "Section"],

Cell[CellGroupData[{

Cell["Unwindowed example w/zero padding", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(x[
          t_] := \((1\  + \ 2\ Cos[2 \((1 + 1/6)\) \[Pi]\ t]\  + \ 
            4\ Cos[\((4  \[Pi]\  + \ 2  \[Pi]\ \((1/6)\))\) 
                  t])\);\)\), "\n", 
    \(\(xda = \ sampler[x, fs = 20, {0, 3}];\)\), "\[IndentingNewLine]", 
    \(\(xd2 = \ 
        Table[{n, 0}, {n, \(-fs\), \(-1\)}]~Join~xda~Join~\ 
          Table[{n, 0}, {n, 3*fs + 1, 4*fs}];\)\), "\[IndentingNewLine]", 
    \(\ \(If[OddQ[Length[xda]], \ xda\  = \ Drop[xda, \(-1\)]];\)\), "\n", 
    \(\(gwa\  = \ 
        DiscreteListPlot2[xd2, \ Blue, \ Frame \[Rule] True, 
          Axes \[Rule] {True, False}, \ AspectRatio \[Rule] 1/3, \ 
          ImageSize \[Rule] 504, \ PlotRange \[Rule] All];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .33333 
%%ImageSize: 504 168 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.214286 0.00952381 0.140212 0.026455 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.21429 -0.0125 -3 -9 ]
[.21429 -0.0125 3 0 ]
[.40476 -0.0125 -6 -9 ]
[.40476 -0.0125 6 0 ]
[.59524 -0.0125 -6 -9 ]
[.59524 -0.0125 6 0 ]
[.78571 -0.0125 -6 -9 ]
[.78571 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .03439 -12 -4.5 ]
[-0.0125 .03439 0 4.5 ]
[-0.0125 .0873 -12 -4.5 ]
[-0.0125 .0873 0 4.5 ]
[-0.0125 .14021 -6 -4.5 ]
[-0.0125 .14021 0 4.5 ]
[-0.0125 .19312 -6 -4.5 ]
[-0.0125 .19312 0 4.5 ]
[-0.0125 .24603 -6 -4.5 ]
[-0.0125 .24603 0 4.5 ]
[-0.0125 .29894 -6 -4.5 ]
[-0.0125 .29894 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .33333 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-20)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(0)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(20)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(40)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(60)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(80)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .03439 m
.00625 .03439 L
s
[(-4)] -0.0125 .03439 1 0 Mshowa
0 .0873 m
.00625 .0873 L
s
[(-2)] -0.0125 .0873 1 0 Mshowa
0 .14021 m
.00625 .14021 L
s
[(0)] -0.0125 .14021 1 0 Mshowa
0 .19312 m
.00625 .19312 L
s
[(2)] -0.0125 .19312 1 0 Mshowa
0 .24603 m
.00625 .24603 L
s
[(4)] -0.0125 .24603 1 0 Mshowa
0 .29894 m
.00625 .29894 L
s
[(6)] -0.0125 .29894 1 0 Mshowa
.125 Mabswid
0 .04762 m
.00375 .04762 L
s
0 .06085 m
.00375 .06085 L
s
0 .07407 m
.00375 .07407 L
s
0 .10053 m
.00375 .10053 L
s
0 .11376 m
.00375 .11376 L
s
0 .12698 m
.00375 .12698 L
s
0 .15344 m
.00375 .15344 L
s
0 .16667 m
.00375 .16667 L
s
0 .17989 m
.00375 .17989 L
s
0 .20635 m
.00375 .20635 L
s
0 .21958 m
.00375 .21958 L
s
0 .2328 m
.00375 .2328 L
s
0 .25926 m
.00375 .25926 L
s
0 .27249 m
.00375 .27249 L
s
0 .28571 m
.00375 .28571 L
s
0 .02116 m
.00375 .02116 L
s
0 .00794 m
.00375 .00794 L
s
0 .31217 m
.00375 .31217 L
s
0 .3254 m
.00375 .3254 L
s
.25 Mabswid
0 0 m
0 .33333 L
s
.02381 .32708 m
.02381 .33333 L
s
.21429 .32708 m
.21429 .33333 L
s
.40476 .32708 m
.40476 .33333 L
s
.59524 .32708 m
.59524 .33333 L
s
.78571 .32708 m
.78571 .33333 L
s
.97619 .32708 m
.97619 .33333 L
s
.125 Mabswid
.07143 .32958 m
.07143 .33333 L
s
.11905 .32958 m
.11905 .33333 L
s
.16667 .32958 m
.16667 .33333 L
s
.2619 .32958 m
.2619 .33333 L
s
.30952 .32958 m
.30952 .33333 L
s
.35714 .32958 m
.35714 .33333 L
s
.45238 .32958 m
.45238 .33333 L
s
.5 .32958 m
.5 .33333 L
s
.54762 .32958 m
.54762 .33333 L
s
.64286 .32958 m
.64286 .33333 L
s
.69048 .32958 m
.69048 .33333 L
s
.7381 .32958 m
.7381 .33333 L
s
.83333 .32958 m
.83333 .33333 L
s
.88095 .32958 m
.88095 .33333 L
s
.92857 .32958 m
.92857 .33333 L
s
.25 Mabswid
0 .33333 m
1 .33333 L
s
.99375 .03439 m
1 .03439 L
s
.99375 .0873 m
1 .0873 L
s
.99375 .14021 m
1 .14021 L
s
.99375 .19312 m
1 .19312 L
s
.99375 .24603 m
1 .24603 L
s
.99375 .29894 m
1 .29894 L
s
.125 Mabswid
.99625 .04762 m
1 .04762 L
s
.99625 .06085 m
1 .06085 L
s
.99625 .07407 m
1 .07407 L
s
.99625 .10053 m
1 .10053 L
s
.99625 .11376 m
1 .11376 L
s
.99625 .12698 m
1 .12698 L
s
.99625 .15344 m
1 .15344 L
s
.99625 .16667 m
1 .16667 L
s
.99625 .17989 m
1 .17989 L
s
.99625 .20635 m
1 .20635 L
s
.99625 .21958 m
1 .21958 L
s
.99625 .2328 m
1 .2328 L
s
.99625 .25926 m
1 .25926 L
s
.99625 .27249 m
1 .27249 L
s
.99625 .28571 m
1 .28571 L
s
.99625 .02116 m
1 .02116 L
s
.99625 .00794 m
1 .00794 L
s
.99625 .31217 m
1 .31217 L
s
.99625 .3254 m
1 .3254 L
s
.25 Mabswid
1 0 m
1 .33333 L
s
0 .14021 m
1 .14021 L
s
0 0 1 r
.5 Mabswid
.02381 .14021 m
.02381 .14021 L
s
.03333 .14021 m
.03333 .14021 L
s
.04286 .14021 m
.04286 .14021 L
s
.05238 .14021 m
.05238 .14021 L
s
.0619 .14021 m
.0619 .14021 L
s
.07143 .14021 m
.07143 .14021 L
s
.08095 .14021 m
.08095 .14021 L
s
.09048 .14021 m
.09048 .14021 L
s
.1 .14021 m
.1 .14021 L
s
.10952 .14021 m
.10952 .14021 L
s
.11905 .14021 m
.11905 .14021 L
s
.12857 .14021 m
.12857 .14021 L
s
.1381 .14021 m
.1381 .14021 L
s
.14762 .14021 m
.14762 .14021 L
s
.15714 .14021 m
.15714 .14021 L
s
.16667 .14021 m
.16667 .14021 L
s
.17619 .14021 m
.17619 .14021 L
s
.18571 .14021 m
.18571 .14021 L
s
.19524 .14021 m
.19524 .14021 L
s
.20476 .14021 m
.20476 .14021 L
s
.21429 .14021 m
.21429 .3254 L
s
.22381 .14021 m
.22381 .2983 L
s
.23333 .14021 m
.23333 .22799 L
s
.24286 .14021 m
.24286 .14265 L
s
.25238 .14021 m
.25238 .07553 L
s
.2619 .14021 m
.2619 .05076 L
s
.27143 .14021 m
.27143 .07337 L
s
.28095 .14021 m
.28095 .12783 L
s
.29048 .14021 m
.29048 .18572 L
s
.3 .14021 m
.3 .21893 L
s
.30952 .14021 m
.30952 .21249 L
s
.31905 .14021 m
.31905 .17129 L
s
.32857 .14021 m
.32857 .11762 L
s
.3381 .14021 m
.3381 .08069 L
s
.34762 .14021 m
.34762 .08295 L
s
.35714 .14021 m
.35714 .12925 L
s
.36667 .14021 m
.36667 .20394 L
s
.37619 .14021 m
.37619 .27714 L
s
.38571 .14021 m
.38571 .31763 L
s
.39524 .14021 m
.39524 .30658 L
s
.40476 .14021 m
.40476 .24603 L
s
.41429 .14021 m
.41429 .15839 L
s
.42381 .14021 m
.42381 .07703 L
s
.43333 .14021 m
.43333 .03217 L
s
.44286 .14021 m
.44286 .03825 L
s
.45238 .14021 m
.45238 .08817 L
s
.4619 .14021 m
.4619 .15709 L
s
.47143 .14021 m
.47143 .21381 L
s
.48095 .14021 m
.48095 .23477 L
s
.49048 .14021 m
.49048 .2143 L
s
.5 .14021 m
.5 .16667 L
s
.50952 .14021 m
.50952 .11903 L
s
.51905 .14021 m
.51905 .09856 L
s
.52857 .14021 m
.52857 .11952 L
s
.5381 .14021 m
.5381 .17625 L
s
.54762 .14021 m
.54762 .24516 L
s
.55714 .14021 m
.55714 .29508 L
s
.56667 .14021 m
.56667 .30116 L
s
.57619 .14021 m
.57619 .25631 L
s
.58571 .14021 m
.58571 .17494 L
s
.59524 .14021 m
.59524 .0873 L
s
.60476 .14021 m
.60476 .02676 L
s
.61429 .14021 m
.61429 .01571 L
s
.62381 .14021 m
.62381 .0562 L
s
.63333 .14021 m
.63333 .12939 L
s
.64286 .14021 m
.64286 .20408 L
s
.65238 .14021 m
.65238 .25039 L
s
.6619 .14021 m
.6619 .25265 L
s
.67143 .14021 m
.67143 .21572 L
s
.68095 .14021 m
.68095 .16204 L
s
.69048 .14021 m
.69048 .12085 L
s
.7 .14021 m
.7 .11441 L
s
.70952 .14021 m
.70952 .14761 L
s
.71905 .14021 m
.71905 .2055 L
s
.72857 .14021 m
.72857 .25997 L
s
.7381 .14021 m
.7381 .28258 L
s
.74762 .14021 m
.74762 .25781 L
s
.75714 .14021 m
.75714 .19069 L
s
.76667 .14021 m
.76667 .10535 L
s
.77619 .14021 m
.77619 .03503 L
s
.78571 .14021 m
.78571 .00794 L
s
.79524 .14021 m
.79524 .14021 L
s
.80476 .14021 m
.80476 .14021 L
s
.81429 .14021 m
.81429 .14021 L
s
.82381 .14021 m
.82381 .14021 L
s
.83333 .14021 m
.83333 .14021 L
s
.84286 .14021 m
.84286 .14021 L
s
.85238 .14021 m
.85238 .14021 L
s
.8619 .14021 m
.8619 .14021 L
s
.87143 .14021 m
.87143 .14021 L
s
.88095 .14021 m
.88095 .14021 L
s
.89048 .14021 m
.89048 .14021 L
s
.9 .14021 m
.9 .14021 L
s
.90952 .14021 m
.90952 .14021 L
s
.91905 .14021 m
.91905 .14021 L
s
.92857 .14021 m
.92857 .14021 L
s
.9381 .14021 m
.9381 .14021 L
s
.94762 .14021 m
.94762 .14021 L
s
.95714 .14021 m
.95714 .14021 L
s
.96667 .14021 m
.96667 .14021 L
s
.97619 .14021 m
.97619 .14021 L
s
.005 w
.02381 .14021 Mdot
.03333 .14021 Mdot
.04286 .14021 Mdot
.05238 .14021 Mdot
.0619 .14021 Mdot
.07143 .14021 Mdot
.08095 .14021 Mdot
.09048 .14021 Mdot
.1 .14021 Mdot
.10952 .14021 Mdot
.11905 .14021 Mdot
.12857 .14021 Mdot
.1381 .14021 Mdot
.14762 .14021 Mdot
.15714 .14021 Mdot
.16667 .14021 Mdot
.17619 .14021 Mdot
.18571 .14021 Mdot
.19524 .14021 Mdot
.20476 .14021 Mdot
.21429 .3254 Mdot
.22381 .2983 Mdot
.23333 .22799 Mdot
.24286 .14265 Mdot
.25238 .07553 Mdot
.2619 .05076 Mdot
.27143 .07337 Mdot
.28095 .12783 Mdot
.29048 .18572 Mdot
.3 .21893 Mdot
.30952 .21249 Mdot
.31905 .17129 Mdot
.32857 .11762 Mdot
.3381 .08069 Mdot
.34762 .08295 Mdot
.35714 .12925 Mdot
.36667 .20394 Mdot
.37619 .27714 Mdot
.38571 .31763 Mdot
.39524 .30658 Mdot
.40476 .24603 Mdot
.41429 .15839 Mdot
.42381 .07703 Mdot
.43333 .03217 Mdot
.44286 .03825 Mdot
.45238 .08817 Mdot
.4619 .15709 Mdot
.47143 .21381 Mdot
.48095 .23477 Mdot
.49048 .2143 Mdot
.5 .16667 Mdot
.50952 .11903 Mdot
.51905 .09856 Mdot
.52857 .11952 Mdot
.5381 .17625 Mdot
.54762 .24516 Mdot
.55714 .29508 Mdot
.56667 .30116 Mdot
.57619 .25631 Mdot
.58571 .17494 Mdot
.59524 .0873 Mdot
.60476 .02676 Mdot
.61429 .01571 Mdot
.62381 .0562 Mdot
.63333 .12939 Mdot
.64286 .20408 Mdot
.65238 .25039 Mdot
.6619 .25265 Mdot
.67143 .21572 Mdot
.68095 .16204 Mdot
.69048 .12085 Mdot
.7 .11441 Mdot
.70952 .14761 Mdot
.71905 .2055 Mdot
.72857 .25997 Mdot
.7381 .28258 Mdot
.74762 .25781 Mdot
.75714 .19069 Mdot
.76667 .10535 Mdot
.77619 .03503 Mdot
.78571 .00794 Mdot
.79524 .14021 Mdot
.80476 .14021 Mdot
.81429 .14021 Mdot
.82381 .14021 Mdot
.83333 .14021 Mdot
.84286 .14021 Mdot
.85238 .14021 Mdot
.8619 .14021 Mdot
.87143 .14021 Mdot
.88095 .14021 Mdot
.89048 .14021 Mdot
.9 .14021 Mdot
.90952 .14021 Mdot
.91905 .14021 Mdot
.92857 .14021 Mdot
.9381 .14021 Mdot
.94762 .14021 Mdot
.95714 .14021 Mdot
.96667 .14021 Mdot
.97619 .14021 Mdot
0 0 m
1 0 L
1 .33333 L
0 .33333 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{504, 168},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007h0000Z2000`400?l00000o`00003ooooooooi
ooooo`009oooool5o`0000?ooooo0_l0001?ooooo`;o0000D?ooool5o`0000?ooooo0_l0001?oooo
o`?o00000oooool2o`0004kooooo0ol00004ooooo`;o0000C_ooool3o`0000Cooooo0_l0000Goooo
o`00:?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0004gooooo00Co0000
oooooooooooo0000D?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0004oo
oooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo04[ooooo00Go0000oooo
ooooooooooooo`000002ooooo`04o`000?ooooooooooo`0004cooooo00Go0000oooooooooooooooo
o`000002ooooo`04o`000?ooooooooooo`0001Kooooo000Qooooo`Go00000oooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0004gooooo00Co0000oooooooooooo0000DOooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0004cooooo1Ol00002ooooo`04o`000?oooooo
ooooo`0004cooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0004co
oooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0001Kooooo000Zoooo
o`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`1;ooooo`04o`000?oooooo
ooooo`0005;ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo04[ooooo
00Co0000oooooooooooo00000oooool01?l0003oooooooooool0001<ooooo`Co00000oooool01?l0
003oooooooooool0001=ooooo`?o00000oooool01?l0003oooooooooool0000Fooooo`009oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000COooool01?l0003ooooo
ooooool0001?ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0001=
ooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooo0000C?ooool00ol0003ooooooooo
o`04ooooo`04o`000?ooooooooooo`0004cooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0001Kooooo000Wooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0001=ooooo`04o`000?ooooooooooo`0004oooooo00Go0000oooooooooooooooo
o`000002ooooo`04o`000?ooooooooooo`0004kooooo0_l00003ooooo`04o`000?ooooooooooo`00
04gooooo00?o0000ooooooooool00oooool01?l0003oooooooooool0001<ooooo`05o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool0000Fooooo`00:?ooool3o`0000Cooooo0_l0
001?ooooo`;o0000DOooool3o`0000Cooooo0_l0001@ooooo`03o`000?oooooooooo00;ooooo0_l0
001?ooooo`;o00001?ooool2o`0004kooooo0ol00004ooooo`;o00005oooool00?oooooonOooool0
0?oooooonOooool00?oooooonOooool00?oooooonOooool00?oooooonOooool00?oooooonOooool0
0?oooooonOooool001ooooooool0003;o`0000oooooo000Oooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool04_ooool00`00003oooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool03Oooool001oooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0Booooo`0300000?oooooooooo01?ooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0=ooooo`007oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo05Cooooo00<00000
ooooooooool0E?ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo05Cooooo0_l00?mE
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03Oooool001oooooo0ol0003ooooo
ofGooooo0_l00?mOooooo`;o00003oooool001oooooo00?o0000ooooooooool0oooooomUooooo`03
0000oooooooooooo05oooooo00?o0000ooooooooool03Oooool001oooooo00?o0000ooooooooool0
oooooomUooooo`030000oooooooooooo05oooooo00?o0000ooooooooool03Oooool001oooooo00?o
0000ooooooooool0oooooolFooooo`;o003oCOooool00`000?ooooooooooo`1Oooooo`03o`000?oo
oooooooo00gooooo000Oooooo`03o`000?oooooooooo0?oooooo5_ooool2o`00odgooooo00<0003o
ooooooooool0Goooool00ol0003oooooooooo`0=ooooo`007oooool00ol0003oooooooooo`3ooooo
oaOooooo00<0003oooooooooool0Boooool00`000?ooooooooooo`1Oooooo`03o`000?oooooooooo
00gooooo000Oooooo`?o0000oooooolGooooo`030000oooooooooooo04_ooooo00<0003ooooooooo
ool0G_ooool2o`0000oooooo000Oooooo`03o`000?oooooooooo0?oooooo5oooool00`000?oooooo
ooooo`1;ooooo`030000oooooooooooo05oooooo00?o0000ooooooooool03Oooool001oooooo00?o
0000ooooooooool0oooooolBooooo`;o003o0oooool00`000?ooooooooooo`1;ooooo`030000oooo
oooooooo05oooooo00?o0000ooooooooool03Oooool001Kooooo0ol00006ooooo`03o`000?oooooo
oooo0?oooooo4_ooool2o`00o`?ooooo00<0003oooooooooool0Boooool00`000?ooooooooooo`1O
ooooo`03o`000?oooooooooo00gooooo000Gooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0oooooolCooooo`050000ooooooooooooooooo`000?l0COooool00`000?ooooooooooo`1O
ooooo`03o`000?oooooooooo00gooooo000>ooooo`Go000000?oooooo`000?l000000ol00006oooo
o`03o`000?oooooooooo0<?ooooo0_l00?m=ooooo`050000ooooooooooooooooo`000?l0COooool0
0`000?ooooooooooo`1Oooooo`03o`000?oooooooooo00gooooo000Dooooo`04o`000?oooooooooo
o`0000Oooooo1?l00032ooooo`;o003oCOooool01@000?ooooooooooooooool0003o04Sooooo0_l0
0?l3ooooo`030000oooooooooooo05cooooo1?l0000?ooooo`005Oooool00ol0003oooooo`000007
ooooo`03o`000?oooooooooo0<?ooooo00@0003ooooooooooooooooo0_l00?m9ooooo`050000oooo
ooooooooooooo`000?l0B?ooool2o`00o`?ooooo00<0003oooooooooool0Goooool00ol0003ooooo
ooooo`0=ooooo`005_ooool2o`0000Oooooo00?o0000ooooooooool0`oooool010000?oooooooooo
ooooool2o`00odWooooo00D0003ooooooooooooooooo0000o`19ooooo`050000oooooooooooooooo
o`000?l0HOooool00ol0003oooooooooo`0=ooooo`005oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0<?ooooo00<0003oooooooooool00_ooool00`000?ooooooooooo`17ooooo`05
0000ooooooooooooooooo`000?l0BOooool01@000?ooooooooooooooool0003o067ooooo00?o0000
ooooooooool03Oooool001oooooo00?o0000ooooooooool0`oooool00`000?ooooooooooo`02oooo
o`030000oooooooooooo04Oooooo00D0003ooooooooooooooooo0000o`19ooooo`050000oooooooo
ooooooooo`000?l0HOooool00ol0003oooooooooo`0=ooooo`007oooool00ol0003oooooooooo`33
ooooo`030000oooooooooooo00;ooooo00<0003oooooooooool0Aoooool01@000?oooooooooooooo
ool0003o04Wooooo00D0003ooooooooooooooooo0000o`1Qooooo`03o`000?oooooooooo00gooooo
000Oooooo`?o0000`oooool00`000?ooooooooooo`02ooooo`030000oooooooooooo04Oooooo00D0
003ooooooooooooooooo0000o`19ooooo`050000ooooooooooooooooo`000?l0H?ooool2o`0000oo
oooo000Oooooo`03o`000?oooooooooo07Cooooo0_l00?m=ooooo`030000oooooooooooo00;ooooo
00<0003oooooooooool0Aoooool01@000?ooooooooooooooool0003o04Wooooo00D0003ooooooooo
oooooooo0000o`1Qooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo07Co
oooo0_l00?m=ooooo`030000oooooooooooo00;ooooo00<0003oooooooooool0Aoooool01@000?oo
ooooooooooooool0003o04Wooooo00D0003ooooooooooooooooo0000o`1Qooooo`03o`000?oooooo
oooo00gooooo000Oooooo`03o`000?oooooooooo07Gooooo00<0003oooooooooool0Boooool00`00
0?ooooooooooo`02ooooo`030000oooooooooooo04Oooooo00D0003ooooooooooooooooo0000o`19
ooooo`050000ooooooooooooooooo`000?l0HOooool00ol0003oooooooooo`0=ooooo`007oooool0
0ol0003oooooooooo`1eooooo`030000oooooooooooo04_ooooo00<0003oooooooooool00_ooool0
0`000?ooooooooooo`17ooooo`050000ooooooooooooooooo`000?l00oooool2o`00odCooooo00D0
003ooooooooooooooooo0000o`1Qooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oo
oooooooo07Gooooo00<0003oooooooooool0Boooool00`000?ooooooooooo`02ooooo`030000oooo
oooooooo04Oooooo00D0003ooooooooooooooooo0000o`03ooooo`;o003oA?ooool01@000?oooooo
ooooooooool0003o067ooooo00?o0000ooooooooool03Oooool001oooooo0ol0001eooooo`030000
oooooooooooo04_ooooo00<0003oooooooooool00_ooool00`000?ooooooooooo`17ooooo`050000
ooooooooooooooooo`000?l00oooool00`000?ooooooooooo`13ooooo`050000oooooooooooooooo
o`000?l0H?ooool2o`0000oooooo000Oooooo`03o`000?oooooooooo07Gooooo00<0003ooooooooo
ool0Boooool00`000?ooooooooooo`02ooooo`030000oooooooooooo04Oooooo00D0003ooooooooo
oooooooo0000o`03ooooo`030000oooooooooooo04?ooooo00D0003ooooooooooooooooo0000o`1Q
ooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo07Gooooo00<0003ooooo
ooooool0Boooool00`000?ooooooooooo`02ooooo`030000oooooooooooo04Oooooo00D0003ooooo
oooooooooooo0000o`03ooooo`030000oooooooooooo04?ooooo00D0003ooooooooooooooooo0000
o`1Qooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo07Gooooo00<0003o
ooooooooool0Boooool00`000?ooooooooooo`02ooooo`030000oooooooooooo04Oooooo00D0003o
oooooooooooooooo0000o`03ooooo`030000oooooooooooo04?ooooo00D0003ooooooooooooooooo
0000o`1Qooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo07Gooooo00<0
003oooooooooool0Boooool00`000?ooooooooooo`02ooooo`030000oooooooooooo04Oooooo00D0
003ooooooooooooooooo0000o`03ooooo`030000oooooooooooo04?ooooo00D0003ooooooooooooo
oooo0000o`1Qooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo07Gooooo
00@0003ooooooooooooooooo0_l00?m8ooooo`030000oooooooooooo00;ooooo00<0003ooooooooo
ool0Aoooool01@000?ooooooooooooooool0003o00?ooooo00<0003oooooooooool0@oooool01@00
0?ooooooooooooooool0003o067ooooo00?o0000ooooooooool03Oooool001oooooo0ol0001`oooo
o`;o003o0oooool010000?ooooooooooooooool2o`00odSooooo00<0003oooooooooool00_ooool0
0`000?ooooooooooo`17ooooo`050000ooooooooooooooooo`000?l00oooool00`000?oooooooooo
o`13ooooo`050000ooooooooooooooooo`000?l0H?ooool2o`0000oooooo000Oooooo`03o`000?oo
oooooooo073ooooo0_l00?l3ooooo`050000ooooooooooooooooo`000?l0A?ooool2o`00o`?ooooo
00<0003oooooooooool00_ooool00`000?ooooooooooo`17ooooo`050000ooooooooooooooooo`00
0?l00oooool00`000?ooooooooooo`13ooooo`050000ooooooooooooooooo`000?l0HOooool00ol0
003oooooooooo`0=ooooo`007oooool00ol0003oooooooooo`1aooooo`050000oooooooooooooooo
o`000?l00oooool00`000?ooooooooooo`12ooooo`;o003o0oooool00`000?ooooooooooo`02oooo
o`030000oooooooooooo04Oooooo00D0003ooooooooooooooooo0000o`03ooooo`030000oooooooo
oooo04?ooooo00D0003ooooooooooooooooo0000o`1Qooooo`03o`000?oooooooooo00gooooo000O
ooooo`03o`000?oooooooooo077ooooo00D0003ooooooooooooooooo0000o`03ooooo`030000oooo
oooooooo01_ooooo0_l00?lVooooo`050000ooooooooooooooooo`000?l01?ooool00`000?oooooo
ooooo`17ooooo`050000ooooooooooooooooo`000?l00oooool00`000?ooooooooooo`13ooooo`05
0000ooooooooooooooooo`000?l0HOooool00ol0003oooooooooo`0=ooooo`005?ooool5o`0000Ko
oooo00?o0000ooooooooool0LOooool01@000?ooooooooooooooool0003o00?ooooo00<0003ooooo
ooooool06oooool2o`00o`?ooooo0_l00?lQooooo`050000ooooooooooooooooo`000?l01?ooool0
0`000?ooooooooooo`17ooooo`050000ooooooooooooooooo`000?l00oooool00`000?oooooooooo
o`13ooooo`050000ooooooooooooooooo`000?l0HOooool00ol0003oooooooooo`0=ooooo`005Ooo
ool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo077ooooo00D0003ooooooooooooo
oooo0000o`03ooooo`030000oooooooooooo01cooooo00@0003ooooooooooooooooo0_l00?lQoooo
o`050000ooooooooooooooooo`000?l01?ooool00`000?ooooooooooo`17ooooo`050000oooooooo
ooooooooo`000?l00oooool00`000?ooooooooooo`13ooooo`050000ooooooooooooooooo`000?l0
HOooool00ol0003oooooooooo`0=ooooo`003_ooool5o`0000?ooooo00?o0000ooooooooool01_oo
ool4o`00073ooooo00D0003ooooooooooooooooo0000o`03ooooo`030000oooooooooooo01cooooo
00D0003ooooooooooooooooo0000o`0Rooooo`050000ooooooooooooooooo`000?l01?ooool00`00
0?ooooooooooo`02o`00od3ooooo0_l00?l3ooooo`050000ooooooooooooooooo`000?l00oooool0
0`000?ooooooooooo`13ooooo`050000ooooooooooooooooo`000?l0G_ooool4o`0000oooooo000G
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0LOooool01@000?oooooooooooooo
ool0003o00?ooooo00<0003oooooooooool07?ooool01@000?ooooooooooooooool0003o02;ooooo
00D0003ooooooooooooooooo0000o`04ooooo`030000oooooooooooo00;o003o@?ooool2o`00o`?o
oooo00D0003ooooooooooooooooo0000o`03ooooo`030000oooooooooooo04?ooooo00D0003ooooo
oooooooooooo0000o`1Qooooo`03o`000?oooooooooo00gooooo000Dooooo`05o`000?oooooooooo
ooooool000001_ooool00ol0003oooooooooo`1aooooo`050000ooooooooooooooooo`000?l00ooo
ool00`000?ooooooooooo`0Looooo`050000ooooooooooooooooo`000?l08_ooool01@000?oooooo
ooooooooool0003o00Cooooo00D0003ooooooooooooooooo0000o`10ooooo`030000oooooooooooo
00;ooooo00D0003ooooooooooooooooo0000o`03ooooo`030000oooooooooooo04?ooooo00D0003o
oooooooooooooooo0000o`1Qooooo`03o`000?oooooooooo00gooooo000Dooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`1aooooo`050000ooooooooooooooooo`000?l0
0oooool00`000?ooooooooooo`0Looooo`050000ooooooooooooooooo`000?l08_ooool01@000?oo
ooooooooooooool0003o00Cooooo00D0003ooooooooooooooooo0000o`10ooooo`030000oooooooo
oooo00;ooooo00D0003ooooooooooooooooo0000o`03ooooo`030000oooooooooooo04?ooooo00D0
003ooooooooooooooooo0000o`1Qooooo`03o`000?oooooooooo00gooooo000Eooooo`?o00001ooo
ool00ol0003oooooooooo`1aooooo`050000ooooooooooooooooo`000?l00oooool00`000?oooooo
ooooo`0Looooo`050000ooooooooooooooooo`000?l08_ooool01@000?ooooooooooooooool0003o
00Cooooo00D0003ooooooooooooooooo0000o`10ooooo`030000oooooooooooo00;ooooo00D0003o
oooooooooooooooo0000o`03ooooo`030000oooooooooooo04?ooooo00D0003ooooooooooooooooo
0000o`1Qooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo077ooooo00D0
003ooooooooooooooooo0000o`03ooooo`030000oooooooooooo01cooooo00D0003ooooooooooooo
oooo0000o`0Rooooo`050000ooooooooooooooooo`000?l01?ooool01@000?ooooooooooooooool0
003o01gooooo0_l00?lQooooo`030000oooooooooooo00;ooooo00D0003ooooooooooooooooo0000
o`03ooooo`030000oooooooooooo04?ooooo00D0003ooooooooooooooooo0000o`1Qooooo`03o`00
0?oooooooooo00gooooo000Oooooo`?o0000LOooool01@000?ooooooooooooooool0003o00?ooooo
00<0003oooooooooool07?ooool01@000?ooooooooooooooool0003o02;ooooo00D0003ooooooooo
oooooooo0000o`04ooooo`050000ooooooooooooooooo`000?l07Oooool2o`00ob7ooooo00<0003o
ooooooooool00_ooool01@000?ooooooooooooooool0003o00?ooooo00<0003oooooooooool0@ooo
ool01@000?ooooooooooooooool0003o063ooooo0_l0000?ooooo`007oooool00ol0003ooooooooo
o`1aooooo`050000ooooooooooooooooo`000?l00oooool00`000?ooooooooooo`0Looooo`050000
ooooooooooooooooo`000?l08_ooool01@000?ooooooooooooooool0003o00Cooooo00D0003ooooo
oooooooooooo0000o`0Mooooo`030000oooooooooooo023ooooo00<0003oooooooooool00_ooool0
1@000?ooooooooooooooool0003o00?ooooo00<0003oooooooooool0@oooool01@000?oooooooooo
ooooool0003o067ooooo00?o0000ooooooooool03Oooool001oooooo00?o0000ooooooooool0LOoo
ool01@000?ooooooooooooooool0003o00?ooooo00<0003oooooooooool07?ooool01@000?oooooo
ooooooooool0003o02;ooooo00D0003ooooooooooooooooo0000o`04ooooo`050000oooooooooooo
ooooo`000?l07Oooool00`000?ooooooooooo`0Pooooo`030000oooooooooooo00;ooooo00D0003o
oooooooooooooooo0000o`03ooooo`030000oooooooooooo03kooooo0_l00?l3ooooo`050000oooo
ooooooooooooo`000?l0HOooool00ol0003oooooooooo`0=ooooo`007oooool00ol0003ooooooooo
o`1aooooo`050000ooooooooooooooooo`000?l00oooool00`000?ooooooooooo`0Looooo`050000
ooooooooooooooooo`000?l08_ooool01@000?ooooooooooooooool0003o00Cooooo00D0003ooooo
oooooooooooo0000o`0Mooooo`030000oooooooooooo023ooooo00<0003oooooooooool00_ooool0
1@000?ooooooooooooooool0003o00?ooooo00<0003oooooooooool0?_ooool2o`00o`?ooooo00D0
003ooooooooooooooooo0000o`1Qooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oo
oooooooo077ooooo00D0003ooooooooooooooooo0000o`03ooooo`030000oooooooooooo01cooooo
00D0003ooooooooooooooooo0000o`0Rooooo`050000ooooooooooooooooo`000?l01?ooool01@00
0?ooooooooooooooool0003o01gooooo00<0003oooooooooool08?ooool00`000?ooooooooooo`02
ooooo`050000ooooooooooooooooo`000?l00oooool00`000?ooooooooooo`0oooooo`050000oooo
ooooooooooooo`000?l00oooool00`000?ooooooooooo`1Oooooo`03o`000?oooooooooo00gooooo
000Oooooo`03o`000?oooooooooo077ooooo00D0003ooooooooooooooooo0000o`03ooooo`030000
oooooooooooo01cooooo00D0003ooooooooooooooooo0000o`0Rooooo`050000oooooooooooooooo
o`000?l01?ooool01@000?ooooooooooooooool0003o01gooooo00<0003oooooooooool08?ooool0
0`000?ooooooooooo`02ooooo`050000ooooooooooooooooo`000?l00oooool00`000?oooooooooo
o`0oooooo`050000ooooooooooooooooo`000?l00oooool00`000?ooooooooooo`1Oooooo`03o`00
0?oooooooooo00gooooo000Oooooo`?o0000LOooool01@000?ooooooooooooooool0003o00?ooooo
00<0003oooooooooool07?ooool01@000?ooooooooooooooool0003o02;ooooo00D0003ooooooooo
oooooooo0000o`04ooooo`050000ooooooooooooooooo`000?l07Oooool00`000?ooooooooooo`0P
ooooo`030000oooooooooooo00;ooooo00D0003ooooooooooooooooo0000o`03ooooo`030000oooo
oooooooo023ooooo0_l00?lMooooo`050000ooooooooooooooooo`000?l00oooool00`000?oooooo
ooooo`1Nooooo`;o00003oooool001oooooo00?o0000ooooooooool0LOooool01@000?oooooooooo
ooooool0003o00?ooooo00<0003oooooooooool07?ooool01@000?ooooooooooooooool0003o02;o
oooo00D0003ooooooooooooooooo0000o`04ooooo`050000ooooooooooooooooo`000?l07Oooool0
0`000?ooooooooooo`0Pooooo`030000oooooooooooo00;ooooo00D0003ooooooooooooooooo0000
o`03ooooo`030000oooooooooooo023ooooo0_l00?lMooooo`050000ooooooooooooooooo`000?l0
0oooool00`000?ooooooooooo`1Oooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oo
oooooooo077ooooo00D0003ooooooooooooooooo0000o`03ooooo`030000oooooooooooo01Oooooo
0_l00?l3ooooo`050000ooooooooooooooooo`000?l08_ooool01@000?ooooooooooooooool0003o
00Cooooo00D0003ooooooooooooooooo0000o`0Iooooo`;o003o0_ooool010000?oooooooooooooo
ool2o`00oagooooo00<0003oooooooooool00_ooool01@000?ooooooooooooooool0003o00?ooooo
00<0003oooooooooool08?ooool00`000?ooooooooooo`0Looooo`050000ooooooooooooooooo`00
0?l00oooool00`000?ooooooooooo`1Oooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`00
0?oooooooooo077ooooo00D0003ooooooooooooooooo0000o`03ooooo`030000oooooooooooo01Oo
oooo0_l00?l3ooooo`050000ooooooooooooooooo`000?l08_ooool01@000?ooooooooooooooool0
003o00Cooooo00D0003ooooooooooooooooo0000o`0Iooooo`;o003o0_ooool010000?oooooooooo
ooooool2o`00oagooooo00<0003oooooooooool00_ooool01@000?ooooooooooooooool0003o00?o
oooo00<0003oooooooooool06oooool2o`00o`?ooooo00<0003oooooooooool07?ooool01@000?oo
ooooooooooooool0003o00?ooooo00<0003oooooooooool0Goooool00ol0003oooooooooo`0=oooo
o`007oooool00ol0003oooooooooo`1aooooo`050000ooooooooooooooooo`000?l00oooool00`00
0?ooooooooooo`0Gooooo`030000oooooooooooo00;ooooo00D0003ooooooooooooooooo0000o`0R
ooooo`050000ooooooooooooooooo`000?l01?ooool01@000?ooooooooooooooool0003o01Wooooo
00D0003ooooooooooooooooo0000o`04ooooo`030000oooooooooooo01_ooooo00<0003ooooooooo
ool00_ooool01@000?ooooooooooooooool0003o00?ooooo00<0003oooooooooool06oooool2o`00
o`?ooooo00<0003oooooooooool07?ooool01@000?ooooooooooooooool0003o00?ooooo00<0003o
ooooooooool0Goooool00ol0003oooooooooo`0=ooooo`007oooool00ol0003oooooooooo`1aoooo
o`050000ooooooooooooooooo`000?l00oooool00`000?ooooooooooo`0Gooooo`030000oooooooo
oooo00;ooooo00D0003ooooooooooooooooo0000o`0Rooooo`050000ooooooooooooooooo`000?l0
1?ooool01@000?ooooooooooooooool0003o01Wooooo00D0003ooooooooooooooooo0000o`04oooo
o`030000oooooooooooo01_ooooo00<0003oooooooooool00_ooool01@000?ooooooooooooooool0
003o00?ooooo00<0003oooooooooool07?ooool01@000?ooooooooooooooool0003o01kooooo00D0
003ooooooooooooooooo0000o`03ooooo`030000oooooooooooo05oooooo00?o0000ooooooooool0
3Oooool001oooooo0ol0001aooooo`050000ooooooooooooooooo`000?l00oooool010000?oooooo
ooooooooool2o`00oaCooooo00<0003oooooooooool00_ooool01@000?ooooooooooooooool0003o
02;ooooo00D0003ooooooooooooooooo0000o`04ooooo`050000ooooooooooooooooo`000?l06Ooo
ool01@000?ooooooooooooooool0003o00Cooooo00<0003oooooooooool06oooool00`000?oooooo
ooooo`02ooooo`050000ooooooooooooooooo`000?l00oooool00`000?ooooooooooo`0Looooo`05
0000ooooooooooooooooo`000?l07_ooool01@000?ooooooooooooooool0003o00?ooooo00<0003o
ooooooooool0G_ooool2o`0000oooooo000Oooooo`03o`000?oooooooooo077ooooo00D0003ooooo
oooooooooooo0000o`03ooooo`040000ooooooooooooooooo`;o003o5?ooool00`000?oooooooooo
o`02ooooo`050000ooooooooooooooooo`000?l00oooool2o`00oagooooo00D0003ooooooooooooo
oooo0000o`04ooooo`050000ooooooooooooooooo`000?l06Oooool01@000?ooooooooooooooool0
003o00Cooooo00<0003oooooooooool06oooool00`000?ooooooooooo`02ooooo`050000oooooooo
ooooooooo`000?l00oooool010000?ooooooooooooooool2o`00oaWooooo00D0003ooooooooooooo
oooo0000o`0Nooooo`050000ooooooooooooooooo`000?l00oooool00`000?ooooooooooo`1Ooooo
o`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo077ooooo00D0003ooooooooo
oooooooo0000o`03ooooo`030000oooooooooooo00;ooooo00<0003oooooooooool04_ooool00`00
0?ooooooooooo`02ooooo`050000ooooooooooooooooo`000?l00oooool2o`00oagooooo00D0003o
oooooooooooooooo0000o`04ooooo`050000ooooooooooooooooo`000?l06Oooool01@000?oooooo
ooooooooool0003o00Cooooo00<0003oooooooooool06oooool00`000?ooooooooooo`02ooooo`05
0000ooooooooooooooooo`000?l00oooool010000?ooooooooooooooool2o`00oaWooooo00D0003o
oooooooooooooooo0000o`0Nooooo`050000ooooooooooooooooo`000?l00oooool00`000?oooooo
ooooo`1Oooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo077ooooo00D0
003ooooooooooooooooo0000o`03ooooo`030000oooooooooooo00;ooooo00<0003oooooooooool0
4_ooool00`000?ooooooooooo`02ooooo`050000ooooooooooooooooo`000?l01?ooool00`000?oo
ooooooooo`0Kooooo`050000ooooooooooooooooo`000?l01?ooool01@000?ooooooooooooooool0
003o01Wooooo00D0003ooooooooooooooooo0000o`04ooooo`030000oooooooooooo01_ooooo00<0
003oooooooooool00_ooool01@000?ooooooooooooooool0003o00?ooooo00<0003oooooooooool0
0_ooool00`000?ooooooooooo`0Gooooo`050000ooooooooooooooooo`000?l07_ooool01@000?oo
ooooooooooooool0003o00?ooooo00<0003oooooooooool0Goooool00ol0003oooooooooo`0=oooo
o`005_ooool2o`0000Oooooo00?o0000ooooooooool0LOooool01@000?ooooooooooooooool0003o
00?ooooo00<0003oooooooooool00_ooool00`000?ooooooooooo`0Booooo`030000oooooooooooo
00;ooooo00D0003ooooooooooooooooo0000o`04ooooo`030000oooooooooooo01_ooooo00D0003o
oooooooooooooooo0000o`04ooooo`050000ooooooooooooooooo`000?l06Oooool01@000?oooooo
ooooooooool0003o00Cooooo00<0003oooooooooool06oooool00`000?ooooooooooo`02ooooo`05
0000ooooooooooooooooo`000?l00oooool00`000?ooooooooooo`02ooooo`030000oooooooooooo
01Oooooo00D0003ooooooooooooooooo0000o`0Nooooo`050000ooooooooooooooooo`000?l00ooo
ool00`000?ooooooooooo`1Oooooo`03o`000?oooooooooo00gooooo000Eooooo`04o`000?oooooo
ooooo`0000Kooooo00?o0000ooooooooool0LOooool01@000?ooooooooooooooool0003o00?ooooo
00<0003oooooooooool00_ooool00`000?ooooooooooo`0Booooo`030000oooooooooooo00;ooooo
00D0003ooooooooooooooooo0000o`04ooooo`030000oooooooooooo01_ooooo00D0003ooooooooo
oooooooo0000o`04ooooo`050000ooooooooooooooooo`000?l06Oooool01@000?oooooooooooooo
ool0003o00Cooooo00<0003oooooooooool06oooool00`000?ooooooooooo`02ooooo`050000oooo
ooooooooooooo`000?l00oooool00`000?ooooooooooo`02ooooo`030000oooooooooooo01Oooooo
00D0003ooooooooooooooooo0000o`0Nooooo`050000ooooooooooooooooo`000?l00oooool00`00
0?ooooooooooo`1Oooooo`03o`000?oooooooooo00gooooo000Eooooo`04o`000?ooooooooooo`00
00Kooooo2ol00002o`00o`;o00000_l00?l2o`0000;o003o0ol00002o`00o`;o00000_l00?l2o`00
00;o003o0ol00002o`00o`;o00000_l00?l2o`0000;o003o0ol00002o`00o`;o00000_l00?l2o`00
00;o003o0ol00002o`00o`;o00000_l00?l3o`0000;o003o0_l00002o`00o`;o00000_l00?l3o`00
00;o003o0_l00002o`00o`;o00000_l00?l3o`0000030000ool0003o000000;o000000D0003oo`00
0?l0003o00000000o`03o`000003o`00ool0003o000000;o000000D0003oo`000?l0003o00000000
o`03o`0000030000ool0003o000000;o000000D0003oo`000?l0003o00000000o`03o`0000030000
ool0003o000000;o000000D0003oo`000?l0003o00000000o`03o`0000030000ool0003o000000;o
000000D0003oo`000?l0003o00000000o`04o`0000050000ool0003o0000o`0000000?l00ol00000
0`000?oo0000o`000002o`0000050000ool0003o0000o`0000000?l00ol000000`000?oo0000o`00
0002o`0000050000ool0003o0000o`0000000?l00ol000000`000?oo0000o`000002o`0000050000
ool0003o0000o`0000000?l00ol000000`000?oo0000o`000002o`0000050000ool0003o0000o`00
00000?l00ol000000`000?oo0000o`000002o`0000050000ool0003o0000o`0000000?l00ol00000
0`000?oo0000o`000002o`0000050000ool0003o0000o`0000000?l01?l000001@000?oo0000o`00
0?l00000003o00?o000000<0003oo`000?l000000_l000001@000?oo0000o`000?l00000003o00?o
000000<0003oo`000?l000000_l000001@000?oo0000o`000?l00000003o00?o000000<0003oo`00
0?l000000_l000001@000?oo0000o`000?l00000003o00?o000000<0003oo`000?l000000_l00000
1@000?oo0000o`000?l00000003o00?o000000<0003oo`000?l000000_l000001@000?oo0000o`00
0?l00000003o00Co000000D0003oo`000?l0003o00000000o`03o`0000030000ool0003o000000;o
000000D0003oo`000?l0003o00000000o`03o`0000030000ool0003o000000;o000000D0003oo`00
0?l0003o00000000o`03o`0000040000ool0003o0000o`0000;o003o0_l00002o`00o`?o00000_l0
0?l2o`0000;o003o0_l00002o`00o`?o00000_l00?l2o`0000;o003o0ol00002o`00o`;o00000_l0
0?l2o`0000;o003o0ol00002o`00o`;o00000_l00?l2o`0000;o003o0ol00002o`00o`;o00000_l0
0?l2o`0000;o003o0ol00002o`00o`;o00000_l00?l2o`0000;o003o0ol00002o`00o`[o00003ooo
ool001Gooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`08ooooo`;o003o0_oo
ool2o`00o`;ooooo0_l00?l3ooooo`;o003o0_ooool2o`00o`;ooooo0_l00?l3ooooo`;o003o0_oo
ool2o`00o`;ooooo0_l00?l3ooooo`;o003o0_ooool2o`00o`;ooooo0_l00?l3ooooo`;o003o0_oo
ool2o`00o`?ooooo0_l00?l2ooooo`;o003o0_ooool2o`00o`?ooooo0_l00?l2ooooo`;o003o0_oo
ool2o`00o`?ooooo00<0003oooooooooool00_ooool01@000?ooooooooooooooool0003o00?ooooo
0_l00?lDooooo`050000ooooooooooooooooo`000?l01?ooool01@000?ooooooooooooooool0003o
01Gooooo00D0003ooooooooooooooooo0000o`04ooooo`050000ooooooooooooooooo`000?l00ooo
ool00`000?ooooooooooo`02ooooo`030000oooooooooooo01;ooooo00<0003oooooooooool00_oo
ool01@000?ooooooooooooooool0003o00?ooooo00<0003oooooooooool00_ooool00`000?oooooo
ooooo`0>ooooo`030000oooooooooooo00;ooooo00D0003ooooooooooooooooo0000o`03ooooo`03
0000oooooooooooo00;ooooo00D0003ooooooooooooooooo0000o`0Iooooo`050000oooooooooooo
ooooo`000?l01?ooool01@000?ooooooooooooooool0003o00?ooooo00<0003oooooooooool02ooo
ool01@000?ooooooooooooooool0003o00?ooooo00<0003oooooooooool00_ooool01@000?oooooo
ooooooooool0003o00?ooooo00<0003oooooooooool03_ooool2o`00o`;ooooo0_l00?l3ooooo`;o
003o0_ooool2o`00o`;ooooo0_l00?l3ooooo`;o003o0_ooool2o`00o`?ooooo0_l00?l2ooooo`;o
003o0_ooool2o`00o`?ooooo0_l00?l2ooooo`;o003o0_ooool2o`00o`?ooooo0_l00?l2ooooo`;o
003o0_ooool2o`00o`?ooooo0_l00?l2ooooo`;o003o0_ooool2o`00o`?ooooo0_l00?l9ooooo`03
o`000?oooooooooo00gooooo000Eooooo`04o`000?ooooooooooo`0000Kooooo00?o0000oooooooo
ool0Goooool00`000?ooooooooooo`02ooooo`050000ooooooooooooooooo`000?l00oooool2o`00
oaCooooo00D0003ooooooooooooooooo0000o`04ooooo`050000ooooooooooooooooo`000?l05Ooo
ool01@000?ooooooooooooooool0003o00Cooooo00D0003ooooooooooooooooo0000o`03ooooo`03
0000oooooooooooo00;ooooo00<0003oooooooooool04_ooool00`000?ooooooooooo`02ooooo`05
0000ooooooooooooooooo`000?l00oooool00`000?ooooooooooo`02ooooo`030000oooooooooooo
00kooooo00<0003oooooooooool00_ooool01@000?ooooooooooooooool0003o00?ooooo00<0003o
ooooooooool00_ooool01@000?ooooooooooooooool0003o01Wooooo00D0003ooooooooooooooooo
0000o`04ooooo`050000ooooooooooooooooo`000?l00oooool00`000?ooooooooooo`0;ooooo`05
0000ooooooooooooooooo`000?l00oooool00`000?ooooooooooo`02ooooo`050000oooooooooooo
ooooo`000?l00oooool00`000?ooooooooooo`1/ooooo`03o`000?oooooooooo00gooooo000Eoooo
o`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool0Goooool00`000?ooooooooooo`02
ooooo`050000ooooooooooooooooo`000?l06Oooool01@000?ooooooooooooooool0003o00Cooooo
00D0003ooooooooooooooooo0000o`0Eooooo`050000ooooooooooooooooo`000?l01?ooool01@00
0?ooooooooooooooool0003o00?ooooo00<0003oooooooooool00_ooool00`000?ooooooooooo`0B
ooooo`030000oooooooooooo00;ooooo00D0003ooooooooooooooooo0000o`03ooooo`030000oooo
oooooooo00;ooooo00<0003oooooooooool03_ooool00`000?ooooooooooo`02ooooo`050000oooo
ooooooooooooo`000?l00oooool00`000?ooooooooooo`02ooooo`050000ooooooooooooooooo`00
0?l06Oooool01@000?ooooooooooooooool0003o00Cooooo00D0003ooooooooooooooooo0000o`03
ooooo`030000oooooooooooo00[ooooo0_l00?l3ooooo`050000ooooooooooooooooo`000?l01?oo
ool01@000?ooooooooooooooool0003o00?ooooo00<0003oooooooooool0K?ooool00ol0003ooooo
ooooo`0=ooooo`005_ooool2o`0000Oooooo00?o0000ooooooooool0Goooool00`000?oooooooooo
o`02ooooo`050000ooooooooooooooooo`000?l06Oooool01@000?ooooooooooooooool0003o00Co
oooo00D0003ooooooooooooooooo0000o`0Eooooo`050000ooooooooooooooooo`000?l01?ooool0
1@000?ooooooooooooooool0003o00?ooooo00<0003oooooooooool00_ooool00`000?oooooooooo
o`0Booooo`030000oooooooooooo00;ooooo00D0003ooooooooooooooooo0000o`03ooooo`030000
oooooooooooo00;ooooo00<0003oooooooooool03_ooool00`000?ooooooooooo`02ooooo`050000
ooooooooooooooooo`000?l00oooool00`000?ooooooooooo`02ooooo`050000oooooooooooooooo
o`000?l06Oooool01@000?ooooooooooooooool0003o00Cooooo00D0003ooooooooooooooooo0000
o`03ooooo`030000oooooooooooo00[ooooo0_l00?l3ooooo`050000ooooooooooooooooo`000?l0
1?ooool01@000?ooooooooooooooool0003o00?ooooo00<0003oooooooooool0K?ooool00ol0003o
ooooooooo`0=ooooo`007oooool00ol0003oooooooooo`1Oooooo`030000oooooooooooo00;ooooo
00D0003ooooooooooooooooo0000o`0Iooooo`050000ooooooooooooooooo`000?l01?ooool01@00
0?ooooooooooooooool0003o01Gooooo00D0003ooooooooooooooooo0000o`04ooooo`050000oooo
ooooooooooooo`000?l00oooool00`000?ooooooooooo`02ooooo`030000oooooooooooo01;ooooo
00<0003oooooooooool00_ooool01@000?ooooooooooooooool0003o00?ooooo00<0003ooooooooo
ool00_ooool00`000?ooooooooooo`0>ooooo`030000oooooooooooo00;ooooo00D0003ooooooooo
oooooooo0000o`03ooooo`030000oooooooooooo00;ooooo00D0003ooooooooooooooooo0000o`0I
ooooo`050000ooooooooooooooooo`000?l01?ooool01@000?ooooooooooooooool0003o00?ooooo
00<0003oooooooooool03oooool01@000?ooooooooooooooool0003o00Cooooo00D0003ooooooooo
oooooooo0000o`03ooooo`030000oooooooooooo06cooooo00?o0000ooooooooool03Oooool001oo
oooo0ol0001Oooooo`030000oooooooooooo00;ooooo00D0003ooooooooooooooooo0000o`0Ioooo
o`050000ooooooooooooooooo`000?l01?ooool01@000?ooooooooooooooool0003o01Gooooo00D0
003ooooooooooooooooo0000o`04ooooo`050000ooooooooooooooooo`000?l00oooool00`000?oo
ooooooooo`02ooooo`030000oooooooooooo01;ooooo00<0003oooooooooool00_ooool01@000?oo
ooooooooooooool0003o00?ooooo00<0003oooooooooool00_ooool00`000?ooooooooooo`0>oooo
o`030000oooooooooooo00;ooooo00D0003ooooooooooooooooo0000o`03ooooo`030000oooooooo
oooo00;ooooo00D0003ooooooooooooooooo0000o`0Iooooo`050000ooooooooooooooooo`000?l0
1?ooool01@000?ooooooooooooooool0003o00?ooooo00<0003oooooooooool03oooool01@000?oo
ooooooooooooool0003o00Cooooo00D0003ooooooooooooooooo0000o`03ooooo`030000oooooooo
oooo06_ooooo0_l0000?ooooo`007oooool00ol0003oooooooooo`1Oooooo`030000oooooooooooo
00;ooooo00D0003ooooooooooooooooo0000o`0Iooooo`050000ooooooooooooooooo`000?l01?oo
ool01@000?ooooooooooooooool0003o01Gooooo00D0003ooooooooooooooooo0000o`04ooooo`05
0000ooooooooooooooooo`000?l00oooool00`000?ooooooooooo`02ooooo`030000oooooooooooo
01;ooooo00<0003oooooooooool00_ooool01@000?ooooooooooooooool0003o00?ooooo00<0003o
ooooooooool00_ooool00`000?ooooooooooo`0>ooooo`030000oooooooooooo00;ooooo00D0003o
oooooooooooooooo0000o`03ooooo`030000oooooooooooo00;ooooo00D0003ooooooooooooooooo
0000o`0Iooooo`050000ooooooooooooooooo`000?l01?ooool01@000?ooooooooooooooool0003o
00?ooooo00<0003oooooooooool03oooool01@000?ooooooooooooooool0003o00Cooooo00D0003o
oooooooooooooooo0000o`03ooooo`030000oooooooooooo06cooooo00?o0000ooooooooool03Ooo
ool001oooooo00?o0000ooooooooool0Goooool00`000?ooooooooooo`02ooooo`050000oooooooo
ooooooooo`000?l06Oooool01@000?ooooooooooooooool0003o00Cooooo00D0003ooooooooooooo
oooo0000o`0Eooooo`050000ooooooooooooooooo`000?l01?ooool01@000?ooooooooooooooool0
003o00?ooooo00@0003ooooooooooooooooo0_l00?lDooooo`;o003o0oooool01@000?oooooooooo
ooooool0003o00?ooooo00<0003oooooooooool00_ooool00`000?ooooooooooo`0>ooooo`030000
oooooooooooo00;ooooo00D0003ooooooooooooooooo0000o`03ooooo`030000oooooooooooo00;o
oooo00D0003ooooooooooooooooo0000o`0Iooooo`050000ooooooooooooooooo`000?l01?ooool0
1@000?ooooooooooooooool0003o00?ooooo00<0003oooooooooool03oooool01@000?oooooooooo
ooooool0003o00Cooooo00D0003ooooooooooooooooo0000o`03ooooo`030000oooooooooooo06co
oooo00?o0000ooooooooool03Oooool001oooooo00?o0000ooooooooool0Goooool00`000?oooooo
ooooo`02ooooo`050000ooooooooooooooooo`000?l06Oooool01@000?ooooooooooooooool0003o
00Cooooo00D0003ooooooooooooooooo0000o`0Eooooo`050000ooooooooooooooooo`000?l01?oo
ool01@000?ooooooooooooooool0003o00?ooooo00@0003ooooooooooooooooo0_l00?lDooooo`;o
003o0oooool01@000?ooooooooooooooool0003o00?ooooo00<0003oooooooooool00_ooool00`00
0?ooooooooooo`0>ooooo`030000oooooooooooo00;ooooo00D0003ooooooooooooooooo0000o`03
ooooo`030000oooooooooooo00;ooooo00D0003ooooooooooooooooo0000o`0Iooooo`050000oooo
ooooooooooooo`000?l01?ooool01@000?ooooooooooooooool0003o00?ooooo00<0003ooooooooo
ool03oooool01@000?ooooooooooooooool0003o00Cooooo00D0003ooooooooooooooooo0000o`03
ooooo`030000oooooooooooo06cooooo00?o0000ooooooooool03Oooool001oooooo00?o0000oooo
ooooool0Goooool00`000?ooooooooooo`02ooooo`050000ooooooooooooooooo`000?l06Oooool0
1@000?ooooooooooooooool0003o00Cooooo00D0003ooooooooooooooooo0000o`0Eooooo`050000
ooooooooooooooooo`000?l01?ooool01@000?ooooooooooooooool0003o00?ooooo00<0003ooooo
ooooool07?ooool01@000?ooooooooooooooool0003o00?ooooo00<0003oooooooooool00_ooool0
0`000?ooooooooooo`0>ooooo`030000oooooooooooo00;ooooo00D0003ooooooooooooooooo0000
o`03ooooo`030000oooooooooooo00;ooooo00D0003ooooooooooooooooo0000o`0Iooooo`050000
ooooooooooooooooo`000?l01?ooool01@000?ooooooooooooooool0003o00?ooooo0_l00?l@oooo
o`050000ooooooooooooooooo`000?l01?ooool01@000?ooooooooooooooool0003o00?ooooo00<0
003oooooooooool0K?ooool00ol0003oooooooooo`0=ooooo`007oooool00ol0003oooooooooo`1O
ooooo`030000oooooooooooo00;ooooo00D0003ooooooooooooooooo0000o`0Iooooo`050000oooo
ooooooooooooo`000?l01?ooool01@000?ooooooooooooooool0003o01Gooooo00D0003ooooooooo
oooooooo0000o`04ooooo`050000ooooooooooooooooo`000?l00oooool00`000?ooooooooooo`0L
ooooo`050000ooooooooooooooooo`000?l00oooool00`000?ooooooooooo`02ooooo`030000oooo
oooooooo00kooooo00<0003oooooooooool00_ooool01@000?ooooooooooooooool0003o00?ooooo
00<0003oooooooooool00_ooool01@000?ooooooooooooooool0003o01Wooooo00D0003ooooooooo
oooooooo0000o`04ooooo`050000ooooooooooooooooo`000?l00oooool2o`00oa3ooooo00D0003o
oooooooooooooooo0000o`04ooooo`050000ooooooooooooooooo`000?l00oooool00`000?oooooo
ooooo`1/ooooo`03o`000?oooooooooo00gooooo000Oooooo`?o0000Goooool00`000?oooooooooo
o`02ooooo`050000ooooooooooooooooo`000?l06Oooool01@000?ooooooooooooooool0003o00Co
oooo00D0003ooooooooooooooooo0000o`0Eooooo`050000ooooooooooooooooo`000?l01?ooool0
1@000?ooooooooooooooool0003o00?ooooo00<0003oooooooooool07?ooool01@000?oooooooooo
ooooool0003o00?ooooo00@0003ooooooooooooooooo0_l00?l@ooooo`030000oooooooooooo00;o
oooo00D0003ooooooooooooooooo0000o`03ooooo`030000oooooooooooo00;ooooo00D0003ooooo
oooooooooooo0000o`0Iooooo`050000ooooooooooooooooo`000?l01?ooool01@000?oooooooooo
ooooool0003o01Gooooo00D0003ooooooooooooooooo0000o`04ooooo`050000oooooooooooooooo
o`000?l00oooool00`000?ooooooooooo`1[ooooo`;o00003oooool001oooooo00?o0000oooooooo
ool0Goooool00`000?ooooooooooo`02ooooo`050000ooooooooooooooooo`000?l06Oooool01@00
0?ooooooooooooooool0003o00Cooooo00D0003ooooooooooooooooo0000o`0Eooooo`050000oooo
ooooooooooooo`000?l01?ooool01@000?ooooooooooooooool0003o00?ooooo00<0003ooooooooo
ool07?ooool01@000?ooooooooooooooool0003o00?ooooo00@0003ooooooooooooooooo0_l00?l@
ooooo`030000oooooooooooo00;ooooo00D0003ooooooooooooooooo0000o`03ooooo`030000oooo
oooooooo00;ooooo00D0003ooooooooooooooooo0000o`0Iooooo`050000ooooooooooooooooo`00
0?l01?ooool01@000?ooooooooooooooool0003o01Gooooo00D0003ooooooooooooooooo0000o`04
ooooo`050000ooooooooooooooooo`000?l00oooool00`000?ooooooooooo`1/ooooo`03o`000?oo
oooooooo00gooooo000Oooooo`03o`000?oooooooooo05oooooo00<0003oooooooooool00_ooool0
1@000?ooooooooooooooool0003o01Wooooo00D0003ooooooooooooooooo0000o`04ooooo`030000
oooooooooooo00;o003o5Oooool01@000?ooooooooooooooool0003o00Cooooo00D0003ooooooooo
oooooooo0000o`03ooooo`030000oooooooooooo01cooooo00D0003ooooooooooooooooo0000o`03
ooooo`030000oooooooooooo01?ooooo00<0003oooooooooool00_ooool01@000?oooooooooooooo
ool0003o00?ooooo00<0003oooooooooool00_ooool01@000?ooooooooooooooool0003o01Wooooo
00D0003ooooooooooooooooo0000o`04ooooo`050000ooooooooooooooooo`000?l05Oooool01@00
0?ooooooooooooooool0003o00Cooooo00D0003ooooooooooooooooo0000o`03ooooo`030000oooo
oooooooo06cooooo00?o0000ooooooooool03Oooool001oooooo00?o0000ooooooooool0Goooool0
0`000?ooooooooooo`02ooooo`050000ooooooooooooooooo`000?l06Oooool01@000?oooooooooo
ooooool0003o00Cooooo00<0003oooooooooool00_l00?lEooooo`050000ooooooooooooooooo`00
0?l01?ooool01@000?ooooooooooooooool0003o00?ooooo00<0003oooooooooool07?ooool01@00
0?ooooooooooooooool0003o00?ooooo00<0003oooooooooool04oooool00`000?ooooooooooo`02
ooooo`050000ooooooooooooooooo`000?l00oooool00`000?ooooooooooo`02ooooo`050000oooo
ooooooooooooo`000?l06Oooool01@000?ooooooooooooooool0003o00Cooooo00D0003ooooooooo
oooooooo0000o`0Eooooo`050000ooooooooooooooooo`000?l01?ooool01@000?oooooooooooooo
ool0003o00?ooooo00<0003oooooooooool0K?ooool00ol0003oooooooooo`0=ooooo`007oooool0
0ol0003oooooooooo`1Oooooo`030000oooooooooooo00;ooooo00D0003ooooooooooooooooo0000
o`0Iooooo`050000ooooooooooooooooo`000?l01?ooool00`000?ooooooooooo`0Gooooo`050000
ooooooooooooooooo`000?l01?ooool01@000?ooooooooooooooool0003o00?ooooo00<0003ooooo
ooooool07?ooool01@000?ooooooooooooooool0003o00?ooooo00<0003oooooooooool04oooool2
o`00o`?ooooo00D0003ooooooooooooooooo0000o`03ooooo`030000oooooooooooo00;ooooo00<0
003oooooooooool00_l00?lIooooo`050000ooooooooooooooooo`000?l01?ooool01@000?oooooo
ooooooooool0003o01Gooooo00D0003ooooooooooooooooo0000o`04ooooo`050000oooooooooooo
ooooo`000?l00oooool00`000?ooooooooooo`1/ooooo`03o`000?oooooooooo00gooooo000Ooooo
o`03o`000?oooooooooo05oooooo00<0003oooooooooool00_ooool01@000?ooooooooooooooool0
003o01Wooooo00D0003ooooooooooooooooo0000o`04ooooo`030000oooooooooooo01Oooooo00D0
003ooooooooooooooooo0000o`04ooooo`050000ooooooooooooooooo`000?l00oooool00`000?oo
ooooooooo`0Looooo`050000ooooooooooooooooo`000?l00oooool00`000?ooooooooooo`0Coooo
o`;o003o0oooool01@000?ooooooooooooooool0003o00?ooooo00<0003oooooooooool00_ooool0
0`000?ooooooooooo`02o`00oaWooooo00D0003ooooooooooooooooo0000o`04ooooo`050000oooo
ooooooooooooo`000?l05Oooool01@000?ooooooooooooooool0003o00Cooooo00D0003ooooooooo
oooooooo0000o`03ooooo`030000oooooooooooo06cooooo00?o0000ooooooooool03Oooool001oo
oooo0ol0001Oooooo`030000oooooooooooo00;ooooo00D0003ooooooooooooooooo0000o`0Ioooo
o`050000ooooooooooooooooo`000?l01?ooool00`000?ooooooooooo`0Gooooo`050000oooooooo
ooooooooo`000?l01?ooool01@000?ooooooooooooooool0003o00?ooooo00<0003oooooooooool0
7?ooool01@000?ooooooooooooooool0003o00?ooooo00<0003oooooooooool06?ooool01@000?oo
ooooooooooooool0003o00?ooooo00<0003oooooooooool00_ooool00`000?ooooooooooo`0Koooo
o`050000ooooooooooooooooo`000?l01?ooool01@000?ooooooooooooooool0003o01Gooooo00D0
003ooooooooooooooooo0000o`04ooooo`050000ooooooooooooooooo`000?l00oooool00`000?oo
ooooooooo`1[ooooo`;o00003oooool001oooooo00?o0000ooooooooool0Goooool00`000?oooooo
ooooo`02ooooo`050000ooooooooooooooooo`000?l06Oooool01@000?ooooooooooooooool0003o
00Cooooo00<0003oooooooooool05oooool01@000?ooooooooooooooool0003o00Cooooo00D0003o
oooooooooooooooo0000o`03ooooo`030000oooooooooooo01cooooo00D0003ooooooooooooooooo
0000o`03ooooo`030000oooooooooooo01Sooooo00D0003ooooooooooooooooo0000o`03ooooo`03
0000oooooooooooo00;ooooo00<0003oooooooooool06oooool01@000?ooooooooooooooool0003o
00Cooooo00D0003ooooooooooooooooo0000o`0Eooooo`050000ooooooooooooooooo`000?l01?oo
ool01@000?ooooooooooooooool0003o00?ooooo00<0003oooooooooool0K?ooool00ol0003ooooo
ooooo`0=ooooo`007oooool00ol0003oooooooooo`1Oooooo`030000oooooooooooo00;ooooo00D0
003ooooooooooooooooo0000o`0Iooooo`050000ooooooooooooooooo`000?l01?ooool00`000?oo
ooooooooo`0Gooooo`050000ooooooooooooooooo`000?l01?ooool01@000?ooooooooooooooool0
003o00?ooooo00<0003oooooooooool07?ooool01@000?ooooooooooooooool0003o00?ooooo00<0
003oooooooooool06?ooool01@000?ooooooooooooooool0003o00?ooooo00<0003oooooooooool0
0_ooool00`000?ooooooooooo`0Kooooo`050000ooooooooooooooooo`000?l01?ooool01@000?oo
ooooooooooooool0003o01Gooooo00D0003ooooooooooooooooo0000o`04ooooo`050000oooooooo
ooooooooo`000?l00oooool00`000?ooooooooooo`1/ooooo`03o`000?oooooooooo00gooooo000O
ooooo`03o`000?oooooooooo05oooooo00<0003oooooooooool00_ooool01@000?oooooooooooooo
ool0003o01Sooooo0_l00?l3ooooo`030000oooooooooooo00;ooooo00<0003oooooooooool05ooo
ool01@000?ooooooooooooooool0003o00Cooooo00D0003ooooooooooooooooo0000o`03ooooo`03
0000oooooooooooo01cooooo00D0003ooooooooooooooooo0000o`03ooooo`030000oooooooooooo
01Sooooo00D0003ooooooooooooooooo0000o`03ooooo`030000oooooooooooo00;ooooo00<0003o
ooooooooool06oooool01@000?ooooooooooooooool0003o00Cooooo00D0003ooooooooooooooooo
0000o`0Eooooo`050000ooooooooooooooooo`000?l01?ooool01@000?ooooooooooooooool0003o
00?ooooo00<0003oooooooooool0K?ooool00ol0003oooooooooo`0=ooooo`005?ooool5o`0000Ko
oooo00?o0000ooooooooool0Goooool00`000?ooooooooooo`02ooooo`050000oooooooooooooooo
o`000?l06?ooool2o`00o`?ooooo00<0003oooooooooool00_ooool00`000?ooooooooooo`0Goooo
o`050000ooooooooooooooooo`000?l01?ooool01@000?ooooooooooooooool0003o00?ooooo00<0
003oooooooooool07?ooool01@000?ooooooooooooooool0003o00?ooooo00<0003oooooooooool0
6?ooool01@000?ooooooooooooooool0003o00?ooooo00<0003oooooooooool00_ooool00`000?oo
ooooooooo`0Kooooo`050000ooooooooooooooooo`000?l01?ooool01@000?ooooooooooooooool0
003o01Gooooo00D0003ooooooooooooooooo0000o`04ooooo`050000ooooooooooooooooo`000?l0
0oooool00`000?ooooooooooo`1/ooooo`03o`000?oooooooooo00gooooo000Eooooo`04o`000?oo
ooooooooo`0000Kooooo00?o0000ooooooooool0Goooool00`000?ooooooooooo`02ooooo`050000
ooooooooooooooooo`000?l07Oooool00`000?ooooooooooo`02ooooo`030000oooooooooooo01Oo
oooo00D0003ooooooooooooooooo0000o`04ooooo`050000ooooooooooooooooo`000?l00oooool0
0`000?ooooooooooo`0Looooo`050000ooooooooooooooooo`000?l00oooool00`000?oooooooooo
o`0Hooooo`050000ooooooooooooooooo`000?l00oooool00`000?ooooooooooo`02ooooo`030000
oooooooooooo01_ooooo00D0003ooooooooooooooooo0000o`04ooooo`050000oooooooooooooooo
o`000?l05Oooool01@000?ooooooooooooooool0003o00Cooooo00D0003ooooooooooooooooo0000
o`03ooooo`;o003oKOooool00ol0003oooooooooo`0=ooooo`005_ooool00ol0003oooooooooo`06
ooooo`Co0000G_ooool00`000?ooooooooooo`02ooooo`050000ooooooooooooooooo`000?l07Ooo
ool00`000?ooooooooooo`02ooooo`030000oooooooooooo01Oooooo00D0003ooooooooooooooooo
0000o`04ooooo`050000ooooooooooooooooo`000?l00oooool00`000?ooooooooooo`0Looooo`05
0000ooooooooooooooooo`000?l00oooool00`000?ooooooooooo`0Hooooo`050000oooooooooooo
ooooo`000?l00oooool00`000?ooooooooooo`02ooooo`030000oooooooooooo01_ooooo00D0003o
oooooooooooooooo0000o`04ooooo`050000ooooooooooooooooo`000?l05Oooool01@000?oooooo
ooooooooool0003o00Cooooo00D0003ooooooooooooooooo0000o`03ooooo`;o003oJ_ooool4o`00
00oooooo000Gooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Goooool00`000?oo
ooooooooo`02ooooo`050000ooooooooooooooooo`000?l07Oooool00`000?ooooooooooo`02oooo
o`030000oooooooooooo01Oooooo00D0003ooooooooooooooooo0000o`04ooooo`050000oooooooo
ooooooooo`000?l00oooool00`000?ooooooooooo`0Looooo`050000ooooooooooooooooo`000?l0
0oooool00`000?ooooooooooo`0Hooooo`050000ooooooooooooooooo`000?l00oooool00`000?oo
ooooooooo`02ooooo`030000oooooooooooo01_ooooo00D0003ooooooooooooooooo0000o`04oooo
o`050000ooooooooooooooooo`000?l05Oooool01@000?ooooooooooooooool0003o00Cooooo00D0
003ooooooooooooooooo0000o`1booooo`03o`000?oooooooooo00gooooo000Dooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`1Oooooo`030000oooooooooooo00;ooooo
00D0003ooooooooooooooooo0000o`0Mooooo`030000oooooooooooo00;ooooo00<0003ooooooooo
ool05oooool01@000?ooooooooooooooool0003o00Cooooo00D0003ooooooooooooooooo0000o`03
ooooo`030000oooooooooooo01cooooo00D0003ooooooooooooooooo0000o`03ooooo`030000oooo
oooooooo01Sooooo00D0003ooooooooooooooooo0000o`03ooooo`030000oooooooooooo00;ooooo
00<0003oooooooooool06oooool01@000?ooooooooooooooool0003o00Cooooo00D0003ooooooooo
oooooooo0000o`0Eooooo`050000ooooooooooooooooo`000?l01?ooool01@000?oooooooooooooo
ool0003o07;ooooo00?o0000ooooooooool03Oooool001Cooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo05oooooo00<0003oooooooooool00_ooool01@000?oooooooooo
ooooool0003o01gooooo00<0003oooooooooool00_ooool00`000?ooooooooooo`0Gooooo`050000
ooooooooooooooooo`000?l01?ooool01@000?ooooooooooooooool0003o00?ooooo00<0003ooooo
ooooool07?ooool01@000?ooooooooooooooool0003o00?ooooo00<0003oooooooooool06?ooool0
1@000?ooooooooooooooool0003o00?ooooo00<0003oooooooooool00_ooool00`000?oooooooooo
o`0Kooooo`050000ooooooooooooooooo`000?l01?ooool01@000?ooooooooooooooool0003o01Go
oooo00D0003ooooooooooooooooo0000o`04ooooo`050000ooooooooooooooooo`000?l0L_ooool0
0ol0003oooooooooo`0=ooooo`005Oooool3o`0000Oooooo00?o0000ooooooooool0Goooool00`00
0?ooooooooooo`02ooooo`050000ooooooooooooooooo`000?l07Oooool00`000?ooooooooooo`02
ooooo`030000oooooooooooo01Oooooo00D0003ooooooooooooooooo0000o`04ooooo`050000oooo
ooooooooooooo`000?l00oooool00`000?ooooooooooo`0Looooo`050000ooooooooooooooooo`00
0?l00oooool00`000?ooooooooooo`0Hooooo`050000ooooooooooooooooo`000?l00oooool00`00
0?ooooooooooo`02ooooo`030000oooooooooooo01_ooooo00D0003ooooooooooooooooo0000o`04
ooooo`050000ooooooooooooooooo`000?l05Oooool01@000?ooooooooooooooool0003o00Cooooo
00D0003ooooooooooooooooo0000o`1booooo`03o`000?oooooooooo00gooooo000Oooooo`03o`00
0?oooooooooo05oooooo00<0003oooooooooool00_ooool01@000?ooooooooooooooool0003o01go
oooo00<0003oooooooooool00_ooool00`000?ooooooooooo`0Fooooo`;o003o0oooool00`000?oo
ooooooooo`02ooooo`050000ooooooooooooooooo`000?l00oooool00`000?ooooooooooo`0Loooo
o`050000ooooooooooooooooo`000?l00oooool00`000?ooooooooooo`0Hooooo`050000oooooooo
ooooooooo`000?l00oooool00`000?ooooooooooo`02ooooo`030000oooooooooooo01[ooooo0_l0
0?l3ooooo`030000oooooooooooo00;ooooo00D0003ooooooooooooooooo0000o`0Eooooo`050000
ooooooooooooooooo`000?l01?ooool01@000?ooooooooooooooool0003o07;ooooo00?o0000oooo
ooooool03Oooool001oooooo0ol0001Oooooo`030000oooooooooooo00;ooooo00D0003ooooooooo
oooooooo0000o`0Mooooo`030000oooooooooooo00;ooooo00<0003oooooooooool05_ooool2o`00
o`?ooooo00<0003oooooooooool00_ooool01@000?ooooooooooooooool0003o00?ooooo00<0003o
ooooooooool07?ooool01@000?ooooooooooooooool0003o00?ooooo00<0003oooooooooool06?oo
ool01@000?ooooooooooooooool0003o00?ooooo00<0003oooooooooool00_ooool00`000?oooooo
ooooo`0Jooooo`;o003o0oooool00`000?ooooooooooo`02ooooo`050000ooooooooooooooooo`00
0?l05?ooool2o`00o`?ooooo00<0003oooooooooool00_ooool01@000?ooooooooooooooool0003o
077ooooo0_l0000?ooooo`007oooool00ol0003oooooooooo`1Oooooo`030000oooooooooooo00;o
oooo00D0003ooooooooooooooooo0000o`0Mooooo`030000oooooooooooo00;ooooo00<0003ooooo
ooooool06oooool00`000?ooooooooooo`02ooooo`050000ooooooooooooooooo`000?l00oooool0
0`000?ooooooooooo`0Looooo`050000ooooooooooooooooo`000?l00oooool00`000?oooooooooo
o`0Hooooo`050000ooooooooooooooooo`000?l00oooool00`000?ooooooooooo`02ooooo`030000
oooooooooooo01oooooo00<0003oooooooooool00_ooool01@000?ooooooooooooooool0003o01Co
oooo0_l00?l3ooooo`030000oooooooooooo00;ooooo00D0003ooooooooooooooooo0000o`1boooo
o`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo05oooooo00<0003ooooooooo
ool00_ooool01@000?ooooooooooooooool0003o01gooooo00<0003oooooooooool00_ooool00`00
0?ooooooooooo`0Kooooo`030000oooooooooooo00;ooooo00D0003ooooooooooooooooo0000o`03
ooooo`030000oooooooooooo01cooooo00D0003ooooooooooooooooo0000o`03ooooo`030000oooo
oooooooo01Sooooo00D0003ooooooooooooooooo0000o`03ooooo`030000oooooooooooo00;ooooo
00<0003oooooooooool07oooool00`000?ooooooooooo`02ooooo`050000ooooooooooooooooo`00
0?l06Oooool00`000?ooooooooooo`02ooooo`050000ooooooooooooooooo`000?l0L_ooool00ol0
003oooooooooo`0=ooooo`007oooool00ol0003oooooooooo`1Oooooo`030000oooooooooooo00;o
oooo00D0003ooooooooooooooooo0000o`0Mooooo`040000ooooooooooooooooo`;o003o7Oooool0
0`000?ooooooooooo`02ooooo`050000ooooooooooooooooo`000?l00oooool00`000?oooooooooo
o`0Looooo`050000ooooooooooooooooo`000?l00oooool00`000?ooooooooooo`0Hooooo`050000
ooooooooooooooooo`000?l00oooool00`000?ooooooooooo`02ooooo`030000oooooooooooo01oo
oooo00<0003oooooooooool00_ooool01@000?ooooooooooooooool0003o01Wooooo00<0003ooooo
ooooool00_ooool01@000?ooooooooooooooool0003o07;ooooo00?o0000ooooooooool03Oooool0
01oooooo00?o0000ooooooooool0Goooool00`000?ooooooooooo`02ooooo`050000oooooooooooo
ooooo`000?l07Oooool010000?ooooooooooooooool2o`00oagooooo00<0003oooooooooool00_oo
ool01@000?ooooooooooooooool0003o00?ooooo00<0003oooooooooool06oooool2o`00o`?ooooo
00@0003ooooooooooooooooo0_l00?lIooooo`050000ooooooooooooooooo`000?l00oooool00`00
0?ooooooooooo`02ooooo`030000oooooooooooo01oooooo00<0003oooooooooool00_ooool00`00
0?ooooooooooo`02o`00oaWooooo00<0003oooooooooool00_ooool01@000?ooooooooooooooool0
003o07;ooooo00?o0000ooooooooool03Oooool001oooooo00?o0000ooooooooool0Goooool00`00
0?ooooooooooo`02ooooo`050000ooooooooooooooooo`000?l07Oooool00`000?ooooooooooo`0P
ooooo`030000oooooooooooo00;ooooo00D0003ooooooooooooooooo0000o`03ooooo`030000oooo
oooooooo01_ooooo0_l00?l3ooooo`040000ooooooooooooooooo`;o003o6Oooool01@000?oooooo
ooooooooool0003o00?ooooo00<0003oooooooooool00_ooool00`000?ooooooooooo`0Oooooo`03
0000oooooooooooo00;ooooo00<0003oooooooooool00_l00?lIooooo`030000oooooooooooo00;o
oooo00D0003ooooooooooooooooo0000o`1booooo`03o`000?oooooooooo00gooooo000Oooooo`03
o`000?oooooooooo05oooooo00<0003oooooooooool00_ooool01@000?ooooooooooooooool0003o
01gooooo0_l00?lQooooo`030000oooooooooooo00;ooooo00D0003ooooooooooooooooo0000o`03
ooooo`030000oooooooooooo023ooooo00<0003oooooooooool07?ooool01@000?oooooooooooooo
ool0003o00?ooooo00<0003oooooooooool00_ooool00`000?ooooooooooo`0Oooooo`030000oooo
oooooooo00;ooooo00<0003oooooooooool06oooool00`000?ooooooooooo`02ooooo`050000oooo
ooooooooooooo`000?l0L_ooool00ol0003oooooooooo`0=ooooo`007oooool3o`0005oooooo00<0
003oooooooooool00_ooool01@000?ooooooooooooooool0003o01gooooo0_l00?lQooooo`030000
oooooooooooo00;ooooo00D0003ooooooooooooooooo0000o`03ooooo`030000oooooooooooo023o
oooo00<0003oooooooooool07?ooool01@000?ooooooooooooooool0003o00?ooooo00<0003ooooo
ooooool00_ooool00`000?ooooooooooo`0Oooooo`030000oooooooooooo00;ooooo00<0003ooooo
ooooool06oooool00`000?ooooooooooo`02ooooo`050000ooooooooooooooooo`000?l0LOooool2
o`0000oooooo000Oooooo`03o`000?oooooooooo05oooooo00<0003oooooooooool00_ooool01@00
0?ooooooooooooooool0003o043ooooo00<0003oooooooooool00_ooool01@000?oooooooooooooo
ool0003o00?ooooo00<0003oooooooooool08?ooool00`000?ooooooooooo`0Looooo`050000oooo
ooooooooooooo`000?l00oooool00`000?ooooooooooo`02ooooo`030000oooooooooooo01oooooo
00<0003oooooooooool00_ooool00`000?ooooooooooo`0Kooooo`030000oooooooooooo00;ooooo
00D0003ooooooooooooooooo0000o`1booooo`03o`000?oooooooooo00gooooo000Oooooo`03o`00
0?oooooooooo05oooooo00<0003oooooooooool00_ooool01@000?ooooooooooooooool0003o043o
oooo00<0003oooooooooool00_ooool01@000?ooooooooooooooool0003o00?ooooo00<0003ooooo
ooooool08?ooool00`000?ooooooooooo`0Looooo`050000ooooooooooooooooo`000?l00oooool0
0`000?ooooooooooo`02ooooo`030000oooooooooooo01oooooo00<0003oooooooooool00_ooool0
0`000?ooooooooooo`0Kooooo`030000oooooooooooo00;ooooo00D0003ooooooooooooooooo0000
o`1booooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo05oooooo00<0003o
ooooooooool00_ooool00`000?ooooooooooo`02o`00od3ooooo00<0003oooooooooool00_ooool0
1@000?ooooooooooooooool0003o00?ooooo00<0003oooooooooool08?ooool00`000?oooooooooo
o`0Looooo`050000ooooooooooooooooo`000?l00oooool00`000?ooooooooooo`02ooooo`030000
oooooooooooo01oooooo00<0003oooooooooool00_ooool00`000?ooooooooooo`0Kooooo`030000
oooooooooooo00;ooooo00D0003ooooooooooooooooo0000o`1booooo`03o`000?oooooooooo00go
oooo000Oooooo`03o`000?oooooooooo05oooooo00<0003oooooooooool00_ooool00`000?oooooo
ooooo`02o`00od3ooooo00<0003oooooooooool00_ooool01@000?ooooooooooooooool0003o00?o
oooo00<0003oooooooooool08?ooool00`000?ooooooooooo`0Looooo`050000oooooooooooooooo
o`000?l00oooool00`000?ooooooooooo`02ooooo`030000oooooooooooo01oooooo00<0003ooooo
ooooool00_ooool00`000?ooooooooooo`0Kooooo`030000oooooooooooo00;ooooo00D0003ooooo
oooooooooooo0000o`1booooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo
05oooooo00<0003oooooooooool00_ooool00`000?ooooooooooo`12ooooo`030000oooooooooooo
00;ooooo00D0003ooooooooooooooooo0000o`03ooooo`030000oooooooooooo023ooooo00<0003o
ooooooooool07?ooool01@000?ooooooooooooooool0003o00?ooooo00<0003oooooooooool00_oo
ool00`000?ooooooooooo`0Oooooo`030000oooooooooooo00;ooooo00<0003oooooooooool06ooo
ool00`000?ooooooooooo`02ooooo`050000ooooooooooooooooo`000?l0L_ooool00ol0003ooooo
ooooo`0=ooooo`007oooool3o`0005oooooo00<0003oooooooooool00_ooool00`000?oooooooooo
o`12ooooo`030000oooooooooooo00;ooooo00D0003ooooooooooooooooo0000o`03ooooo`030000
oooooooooooo01oooooo0_l00?lNooooo`050000ooooooooooooooooo`000?l00oooool00`000?oo
ooooooooo`02ooooo`030000oooooooooooo01oooooo00<0003oooooooooool00_ooool00`000?oo
ooooooooo`0Kooooo`030000oooooooooooo00;ooooo00D0003ooooooooooooooooo0000o`1aoooo
o`;o00003oooool001oooooo00?o0000ooooooooool0Goooool00`000?ooooooooooo`02ooooo`03
0000oooooooooooo04;ooooo00<0003oooooooooool00_ooool01@000?ooooooooooooooool0003o
00?ooooo00<0003oooooooooool07oooool2o`00oakooooo00D0003ooooooooooooooooo0000o`03
ooooo`030000oooooooooooo00;ooooo00<0003oooooooooool07oooool00`000?ooooooooooo`02
ooooo`030000oooooooooooo01_ooooo00<0003oooooooooool00_ooool01@000?oooooooooooooo
ool0003o07;ooooo00?o0000ooooooooool03Oooool001oooooo00?o0000ooooooooool0Goooool0
0`000?ooooooooooo`02ooooo`030000oooooooooooo04;ooooo00<0003oooooooooool00_ooool0
1@000?ooooooooooooooool0003o00?ooooo00<0003oooooooooool0?oooool01@000?oooooooooo
ooooool0003o00?ooooo00<0003oooooooooool00_ooool00`000?ooooooooooo`0Oooooo`030000
oooooooooooo00;ooooo00<0003oooooooooool06oooool00`000?ooooooooooo`02ooooo`050000
ooooooooooooooooo`000?l0L_ooool00ol0003oooooooooo`0=ooooo`005_ooool3o`0000Kooooo
00?o0000ooooooooool0Goooool00`000?ooooooooooo`02ooooo`030000oooooooooooo04;ooooo
00<0003oooooooooool00_ooool01@000?ooooooooooooooool0003o00?ooooo00<0003ooooooooo
ool0?oooool01@000?ooooooooooooooool0003o00?ooooo00<0003oooooooooool00_ooool00`00
0?ooooooooooo`0Oooooo`030000oooooooooooo00;ooooo00<0003oooooooooool06oooool00`00
0?ooooooooooo`02ooooo`050000ooooooooooooooooo`000?l0L_ooool00ol0003oooooooooo`0=
ooooo`005oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05oooooo00<0003ooooo
ooooool00_ooool00`000?ooooooooooo`12ooooo`030000oooooooooooo00;ooooo00D0003ooooo
oooooooooooo0000o`03ooooo`030000oooooooooooo03oooooo00D0003ooooooooooooooooo0000
o`03ooooo`030000oooooooooooo00;ooooo00<0003oooooooooool07oooool00`000?oooooooooo
o`02ooooo`030000oooooooooooo01_ooooo00<0003oooooooooool00_ooool01@000?oooooooooo
ooooool0003o07;ooooo00?o0000ooooooooool03Oooool001Cooooo1Ol00006ooooo`03o`000?oo
oooooooo05oooooo00<0003oooooooooool00_ooool00`000?ooooooooooo`12ooooo`030000oooo
oooooooo00;ooooo00D0003ooooooooooooooooo0000o`03ooooo`;o003o?oooool2o`00o`?ooooo
00D0003ooooooooooooooooo0000o`04ooooo`030000oooooooooooo01oooooo00<0003ooooooooo
ool00_ooool00`000?ooooooooooo`0Kooooo`030000oooooooooooo00;ooooo00D0003ooooooooo
oooooooo0000o`1booooo`03o`000?oooooooooo00gooooo000Dooooo`04o`000?ooooooooooo`00
00Oooooo1?l0001Nooooo`030000oooooooooooo00;ooooo00<0003oooooooooool0@_ooool00`00
0?ooooooooooo`02ooooo`050000ooooooooooooooooo`000?l00oooool2o`00ocoooooo0_l00?l3
ooooo`050000ooooooooooooooooo`000?l01?ooool00`000?ooooooooooo`0Oooooo`030000oooo
oooooooo00;ooooo00<0003oooooooooool06oooool00`000?ooooooooooo`02ooooo`050000oooo
ooooooooooooo`000?l0Koooool4o`0000oooooo000Eooooo`03o`000?oooooo000000Oooooo00?o
0000ooooooooool0Goooool00`000?ooooooooooo`02ooooo`030000oooooooooooo04;ooooo00<0
003oooooooooool00_ooool01@000?ooooooooooooooool0003o04Wooooo00D0003ooooooooooooo
oooo0000o`04ooooo`030000oooooooooooo01oooooo0_l00?l3ooooo`030000oooooooooooo01_o
oooo00<0003oooooooooool00_ooool01@000?ooooooooooooooool0003o07;ooooo00?o0000oooo
ooooool03Oooool001Kooooo0_l00007ooooo`03o`000?oooooooooo05oooooo00<0003ooooooooo
ool00_ooool00`000?ooooooooooo`12ooooo`030000oooooooooooo00;ooooo00D0003ooooooooo
oooooooo0000o`19ooooo`050000ooooooooooooooooo`000?l01?ooool00`000?ooooooooooo`0O
ooooo`;o003o0_ooool2o`00oagooooo00<0003oooooooooool00_ooool01@000?oooooooooooooo
ool0003o07;ooooo00?o0000ooooooooool03Oooool001Oooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`1Oooooo`030000oooooooooooo00;ooooo00<0003oooooooooool0@_ooool0
0`000?ooooooooooo`02ooooo`050000ooooooooooooooooo`000?l0BOooool01@000?oooooooooo
ooooool0003o00Cooooo00<0003oooooooooool08oooool2o`00oagooooo00<0003oooooooooool0
0_ooool01@000?ooooooooooooooool0003o07;ooooo00?o0000ooooooooool03Oooool001oooooo
00?o0000ooooooooool0Goooool00`000?ooooooooooo`02ooooo`030000oooooooooooo04;ooooo
00<0003oooooooooool00_ooool01@000?ooooooooooooooool0003o04Wooooo00D0003ooooooooo
oooooooo0000o`03ooooo`;o003oA?ooool00`000?ooooooooooo`02ooooo`050000oooooooooooo
ooooo`000?l0L_ooool00ol0003oooooooooo`0=ooooo`007oooool00ol0003oooooooooo`1Ooooo
o`030000oooooooooooo00;ooooo00<0003oooooooooool0@_ooool00`000?ooooooooooo`02oooo
o`050000ooooooooooooooooo`000?l0BOooool01@000?ooooooooooooooool0003o00?ooooo0_l0
0?m4ooooo`030000oooooooooooo00;ooooo00<0003oooooooooool00_l00?mbooooo`03o`000?oo
oooooooo00gooooo000Oooooo`?o0000Goooool00`000?ooooooooooo`02ooooo`030000oooooooo
oooo04;ooooo00<0003oooooooooool00_ooool01@000?ooooooooooooooool0003o04Wooooo00D0
003ooooooooooooooooo0000o`19ooooo`;o003o0oooool00`000?ooooooooooo`02o`00og7ooooo
0_l0000?ooooo`007oooool00ol0003oooooooooo`1Oooooo`030000oooooooooooo00;ooooo00<0
003oooooooooool0@_ooool00`000?ooooooooooo`02ooooo`050000ooooooooooooooooo`000?l0
BOooool01@000?ooooooooooooooool0003o04Wooooo0_l00?l3ooooo`030000oooooooooooo07Co
oooo00?o0000ooooooooool03Oooool001oooooo00?o0000ooooooooool0Goooool00`000?oooooo
ooooo`02ooooo`030000oooooooooooo04;ooooo00<0003oooooooooool00_ooool01@000?oooooo
ooooooooool0003o04Wooooo00D0003ooooooooooooooooo0000o`1>ooooo`030000oooooooooooo
07Cooooo00?o0000ooooooooool03Oooool001oooooo00?o0000ooooooooool0Goooool00`000?oo
ooooooooo`02ooooo`030000oooooooooooo04;ooooo00<0003oooooooooool00_ooool01@000?oo
ooooooooooooool0003o04Wooooo00D0003ooooooooooooooooo0000o`1>ooooo`030000oooooooo
oooo07Cooooo00?o0000ooooooooool03Oooool001oooooo00?o0000ooooooooool0Goooool00`00
0?ooooooooooo`02ooooo`030000oooooooooooo04;ooooo00<0003oooooooooool00_ooool01@00
0?ooooooooooooooool0003o04Wooooo00D0003ooooooooooooooooo0000o`1>ooooo`030000oooo
oooooooo07Cooooo00?o0000ooooooooool03Oooool001oooooo00?o0000ooooooooool0Goooool0
0`000?ooooooooooo`02ooooo`030000oooooooooooo04;ooooo00<0003oooooooooool00_ooool0
1@000?ooooooooooooooool0003o04Wooooo00D0003ooooooooooooooooo0000o`1>ooooo`030000
oooooooooooo07Cooooo00?o0000ooooooooool03Oooool001oooooo0ol0001Oooooo`030000oooo
oooooooo00;ooooo00<0003oooooooooool0@_ooool00`000?ooooooooooo`02ooooo`050000oooo
ooooooooooooo`000?l0BOooool01@000?ooooooooooooooool0003o04kooooo00<0003ooooooooo
ool0Loooool2o`0000oooooo000Oooooo`03o`000?oooooooooo05oooooo00<0003oooooooooool0
0_ooool00`000?ooooooooooo`12ooooo`;o003o0oooool01@000?ooooooooooooooool0003o04Wo
oooo00D0003ooooooooooooooooo0000o`1>ooooo`030000oooooooooooo07Cooooo00?o0000oooo
ooooool03Oooool001oooooo00?o0000ooooooooool0Goooool00`000?ooooooooooo`02ooooo`03
0000oooooooooooo04;ooooo0_l00?l3ooooo`050000ooooooooooooooooo`000?l0BOooool01@00
0?ooooooooooooooool0003o04kooooo00<0003oooooooooool0M?ooool00ol0003oooooooooo`0=
ooooo`007oooool00ol0003oooooooooo`1Oooooo`030000oooooooooooo00;ooooo00<0003ooooo
ooooool0Aoooool01@000?ooooooooooooooool0003o04Wooooo00D0003ooooooooooooooooo0000
o`1>ooooo`030000oooooooooooo07Cooooo00?o0000ooooooooool03Oooool001oooooo00?o0000
ooooooooool0Goooool00`000?ooooooooooo`02ooooo`030000oooooooooooo04Oooooo00D0003o
oooooooooooooooo0000o`19ooooo`050000ooooooooooooooooo`000?l0COooool2o`00ogKooooo
00?o0000ooooooooool03Oooool001oooooo00?o0000ooooooooool0Goooool00`000?oooooooooo
o`02ooooo`030000oooooooooooo04Oooooo00D0003ooooooooooooooooo0000o`19ooooo`050000
ooooooooooooooooo`000?l0COooool2o`00ogKooooo00?o0000ooooooooool03Oooool001oooooo
0ol0001Oooooo`030000oooooooooooo00;ooooo00<0003oooooooooool0Aoooool01@000?oooooo
ooooooooool0003o04Wooooo00D0003ooooooooooooooooo0000o`34ooooo`;o00003oooool001oo
oooo00?o0000ooooooooool0Goooool00`000?ooooooooooo`02ooooo`030000oooooooooooo04Oo
oooo00D0003ooooooooooooooooo0000o`19ooooo`050000ooooooooooooooooo`000?l0aOooool0
0ol0003oooooooooo`0=ooooo`007oooool00ol0003oooooooooo`1Oooooo`030000oooooooooooo
00;ooooo00<0003oooooooooool0Aoooool01@000?ooooooooooooooool0003o04Wooooo00D0003o
oooooooooooooooo0000o`35ooooo`03o`000?oooooooooo00gooooo000Eooooo`?o00001oooool0
0ol0003oooooooooo`1Oooooo`030000oooooooooooo00;ooooo00<0003oooooooooool0Aoooool0
1@000?ooooooooooooooool0003o04Wooooo00D0003ooooooooooooooooo0000o`35ooooo`03o`00
0?oooooooooo00gooooo000Dooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooo
ooooo`1Oooooo`030000oooooooooooo00;ooooo00<0003oooooooooool0Aoooool01@000?oooooo
ooooooooool0003o04Sooooo0_l00?l3ooooo`030000oooooooooooo0<?ooooo00?o0000oooooooo
ool03Oooool001Cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo05oo
oooo00@0003ooooooooooooooooo0_l00?m9ooooo`050000ooooooooooooooooo`000?l0B?ooool2
o`00o`?ooooo00<0003oooooooooool0`oooool00ol0003oooooooooo`0=ooooo`005?ooool4o`00
00Oooooo1?l0001Nooooo`040000ooooooooooooooooo`;o003oBOooool01@000?oooooooooooooo
ool0003o04gooooo0_l00?o1ooooo`Co00003oooool001Cooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`1Oooooo`030000oooooooooooo04cooooo00D0003ooooooooooooooooo0000
o`1=ooooo`;o003oa?ooool00ol0003oooooooooo`0=ooooo`005Oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo05oooooo00<0003oooooooooool0C?ooool01@000?oooooooooooooo
ool0003o0?oooooo5?ooool00ol0003oooooooooo`0=ooooo`005_ooool2o`0000Oooooo00?o0000
ooooooooool0Goooool00`000?ooooooooooo`1<ooooo`030000oooooooooooo00;o003ooooooolD
ooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo05oooooo00<0003ooooo
ooooool0C?ooool00`000?ooooooooooo`02o`00oooooooo5?ooool00ol0003oooooooooo`0=oooo
o`007oooool00ol0003oooooooooo`1Oooooo`030000oooooooooooo04cooooo00<0003ooooooooo
ool0oooooolFooooo`03o`000?oooooooooo00gooooo000Oooooo`?o0000Goooool00`000?oooooo
ooooo`1<ooooo`030000oooooooooooo0?oooooo5Oooool2o`0000oooooo000Oooooo`03o`000?oo
oooooooo05oooooo00<0003oooooooooool0C?ooool00`000?ooooooooooo`3ooooooaKooooo00?o
0000ooooooooool03Oooool001oooooo00?o0000ooooooooool0Goooool00`000?ooooooooooo`1;
ooooo`;o003ooooooolHooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo
05oooooo00<0003oooooooooool0Boooool2o`00oooooooo6?ooool00ol0003oooooooooo`0=oooo
o`007oooool00ol0003oooooooooo`1Oooooo`030000oooooooooooo0?ooooooIOooool00ol0003o
ooooooooo`0=ooooo`007oooool00ol0003oooooooooo`1Oooooo`;o003ooooooomVooooo`03o`00
0?oooooooooo00gooooo000Oooooo`?o0000Goooool2o`00ooooooooIOooool2o`0000oooooo000O
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`1D
ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`1D
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03Oooool001oooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0=ooooo`007oooooooo`000<_o00003oooool00001\
\>"],
  ImageRangeCache->{{{0, 503}, {167, 0}} -> {-29.8221, -6.51722, 0.229826, \
0.0827375}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Plot windowing function", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(x[t_] := Window[t, \ 3];\)\), "\n", 
    \(\(xdb = \ sampler[x, fs, {0, 3}];\)\), "\[IndentingNewLine]", 
    \(\(xd2 = \ 
        Table[{n, 0}, {n, \(-fs\), \(-1\)}]~Join~xdb~Join~\ 
          Table[{n, 0}, {n, 3*fs + 1, 4*fs}];\)\), "\[IndentingNewLine]", 
    \(\ \(If[OddQ[Length[xdb]], \ xdb\  = \ Drop[xdb, \(-1\)]];\)\), "\n", 
    \(\(gwb\  = \ 
        DiscreteListPlot2[xd2, \ Blue, \ Frame \[Rule] True, 
          Axes \[Rule] {True, False}, \ AspectRatio \[Rule] 1/3, \ 
          ImageSize \[Rule] 504, \ PlotRange \[Rule] All];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .33333 
%%ImageSize: 504 168 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.214286 0.00952381 0.00793651 0.31746 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.21429 -0.0125 -3 -9 ]
[.21429 -0.0125 3 0 ]
[.40476 -0.0125 -6 -9 ]
[.40476 -0.0125 6 0 ]
[.59524 -0.0125 -6 -9 ]
[.59524 -0.0125 6 0 ]
[.78571 -0.0125 -6 -9 ]
[.78571 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00794 -6 -4.5 ]
[-0.0125 .00794 0 4.5 ]
[-0.0125 .07143 -18 -4.5 ]
[-0.0125 .07143 0 4.5 ]
[-0.0125 .13492 -18 -4.5 ]
[-0.0125 .13492 0 4.5 ]
[-0.0125 .19841 -18 -4.5 ]
[-0.0125 .19841 0 4.5 ]
[-0.0125 .2619 -18 -4.5 ]
[-0.0125 .2619 0 4.5 ]
[-0.0125 .3254 -6 -4.5 ]
[-0.0125 .3254 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .33333 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-20)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(0)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(20)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(40)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(60)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(80)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00794 m
.00625 .00794 L
s
[(0)] -0.0125 .00794 1 0 Mshowa
0 .07143 m
.00625 .07143 L
s
[(0.2)] -0.0125 .07143 1 0 Mshowa
0 .13492 m
.00625 .13492 L
s
[(0.4)] -0.0125 .13492 1 0 Mshowa
0 .19841 m
.00625 .19841 L
s
[(0.6)] -0.0125 .19841 1 0 Mshowa
0 .2619 m
.00625 .2619 L
s
[(0.8)] -0.0125 .2619 1 0 Mshowa
0 .3254 m
.00625 .3254 L
s
[(1)] -0.0125 .3254 1 0 Mshowa
.125 Mabswid
0 .02381 m
.00375 .02381 L
s
0 .03968 m
.00375 .03968 L
s
0 .05556 m
.00375 .05556 L
s
0 .0873 m
.00375 .0873 L
s
0 .10317 m
.00375 .10317 L
s
0 .11905 m
.00375 .11905 L
s
0 .15079 m
.00375 .15079 L
s
0 .16667 m
.00375 .16667 L
s
0 .18254 m
.00375 .18254 L
s
0 .21429 m
.00375 .21429 L
s
0 .23016 m
.00375 .23016 L
s
0 .24603 m
.00375 .24603 L
s
0 .27778 m
.00375 .27778 L
s
0 .29365 m
.00375 .29365 L
s
0 .30952 m
.00375 .30952 L
s
.25 Mabswid
0 0 m
0 .33333 L
s
.02381 .32708 m
.02381 .33333 L
s
.21429 .32708 m
.21429 .33333 L
s
.40476 .32708 m
.40476 .33333 L
s
.59524 .32708 m
.59524 .33333 L
s
.78571 .32708 m
.78571 .33333 L
s
.97619 .32708 m
.97619 .33333 L
s
.125 Mabswid
.07143 .32958 m
.07143 .33333 L
s
.11905 .32958 m
.11905 .33333 L
s
.16667 .32958 m
.16667 .33333 L
s
.2619 .32958 m
.2619 .33333 L
s
.30952 .32958 m
.30952 .33333 L
s
.35714 .32958 m
.35714 .33333 L
s
.45238 .32958 m
.45238 .33333 L
s
.5 .32958 m
.5 .33333 L
s
.54762 .32958 m
.54762 .33333 L
s
.64286 .32958 m
.64286 .33333 L
s
.69048 .32958 m
.69048 .33333 L
s
.7381 .32958 m
.7381 .33333 L
s
.83333 .32958 m
.83333 .33333 L
s
.88095 .32958 m
.88095 .33333 L
s
.92857 .32958 m
.92857 .33333 L
s
.25 Mabswid
0 .33333 m
1 .33333 L
s
.99375 .00794 m
1 .00794 L
s
.99375 .07143 m
1 .07143 L
s
.99375 .13492 m
1 .13492 L
s
.99375 .19841 m
1 .19841 L
s
.99375 .2619 m
1 .2619 L
s
.99375 .3254 m
1 .3254 L
s
.125 Mabswid
.99625 .02381 m
1 .02381 L
s
.99625 .03968 m
1 .03968 L
s
.99625 .05556 m
1 .05556 L
s
.99625 .0873 m
1 .0873 L
s
.99625 .10317 m
1 .10317 L
s
.99625 .11905 m
1 .11905 L
s
.99625 .15079 m
1 .15079 L
s
.99625 .16667 m
1 .16667 L
s
.99625 .18254 m
1 .18254 L
s
.99625 .21429 m
1 .21429 L
s
.99625 .23016 m
1 .23016 L
s
.99625 .24603 m
1 .24603 L
s
.99625 .27778 m
1 .27778 L
s
.99625 .29365 m
1 .29365 L
s
.99625 .30952 m
1 .30952 L
s
.25 Mabswid
1 0 m
1 .33333 L
s
0 .00794 m
1 .00794 L
s
0 0 1 r
.5 Mabswid
.02381 .00794 m
.02381 .00794 L
s
.03333 .00794 m
.03333 .00794 L
s
.04286 .00794 m
.04286 .00794 L
s
.05238 .00794 m
.05238 .00794 L
s
.0619 .00794 m
.0619 .00794 L
s
.07143 .00794 m
.07143 .00794 L
s
.08095 .00794 m
.08095 .00794 L
s
.09048 .00794 m
.09048 .00794 L
s
.1 .00794 m
.1 .00794 L
s
.10952 .00794 m
.10952 .00794 L
s
.11905 .00794 m
.11905 .00794 L
s
.12857 .00794 m
.12857 .00794 L
s
.1381 .00794 m
.1381 .00794 L
s
.14762 .00794 m
.14762 .00794 L
s
.15714 .00794 m
.15714 .00794 L
s
.16667 .00794 m
.16667 .00794 L
s
.17619 .00794 m
.17619 .00794 L
s
.18571 .00794 m
.18571 .00794 L
s
.19524 .00794 m
.19524 .00794 L
s
.20476 .00794 m
.20476 .00794 L
s
.21429 .00794 m
.21429 .03333 L
s
.22381 .00794 m
.22381 .03413 L
s
.23333 .00794 m
.23333 .03652 L
s
.24286 .00794 m
.24286 .04048 L
s
.25238 .00794 m
.25238 .04596 L
s
.2619 .00794 m
.2619 .0529 L
s
.27143 .00794 m
.27143 .06122 L
s
.28095 .00794 m
.28095 .07084 L
s
.29048 .00794 m
.29048 .08165 L
s
.3 .00794 m
.3 .09353 L
s
.30952 .00794 m
.30952 .10635 L
s
.31905 .00794 m
.31905 .11997 L
s
.32857 .00794 m
.32857 .13424 L
s
.3381 .00794 m
.3381 .149 L
s
.34762 .00794 m
.34762 .1641 L
s
.35714 .00794 m
.35714 .17937 L
s
.36667 .00794 m
.36667 .19463 L
s
.37619 .00794 m
.37619 .20973 L
s
.38571 .00794 m
.38571 .22449 L
s
.39524 .00794 m
.39524 .23876 L
s
.40476 .00794 m
.40476 .25238 L
s
.41429 .00794 m
.41429 .2652 L
s
.42381 .00794 m
.42381 .27708 L
s
.43333 .00794 m
.43333 .28789 L
s
.44286 .00794 m
.44286 .29751 L
s
.45238 .00794 m
.45238 .30583 L
s
.4619 .00794 m
.4619 .31277 L
s
.47143 .00794 m
.47143 .31825 L
s
.48095 .00794 m
.48095 .32221 L
s
.49048 .00794 m
.49048 .3246 L
s
.5 .00794 m
.5 .3254 L
s
.50952 .00794 m
.50952 .3246 L
s
.51905 .00794 m
.51905 .32221 L
s
.52857 .00794 m
.52857 .31825 L
s
.5381 .00794 m
.5381 .31277 L
s
.54762 .00794 m
.54762 .30583 L
s
.55714 .00794 m
.55714 .29751 L
s
.56667 .00794 m
.56667 .28789 L
s
.57619 .00794 m
.57619 .27708 L
s
.58571 .00794 m
.58571 .2652 L
s
.59524 .00794 m
.59524 .25238 L
s
.60476 .00794 m
.60476 .23876 L
s
.61429 .00794 m
.61429 .22449 L
s
.62381 .00794 m
.62381 .20973 L
s
.63333 .00794 m
.63333 .19463 L
s
.64286 .00794 m
.64286 .17937 L
s
.65238 .00794 m
.65238 .1641 L
s
.6619 .00794 m
.6619 .149 L
s
.67143 .00794 m
.67143 .13424 L
s
.68095 .00794 m
.68095 .11997 L
s
.69048 .00794 m
.69048 .10635 L
s
.7 .00794 m
.7 .09353 L
s
.70952 .00794 m
.70952 .08165 L
s
.71905 .00794 m
.71905 .07084 L
s
.72857 .00794 m
.72857 .06122 L
s
.7381 .00794 m
.7381 .0529 L
s
.74762 .00794 m
.74762 .04596 L
s
.75714 .00794 m
.75714 .04048 L
s
.76667 .00794 m
.76667 .03652 L
s
.77619 .00794 m
.77619 .03413 L
s
.78571 .00794 m
.78571 .03333 L
s
.79524 .00794 m
.79524 .00794 L
s
.80476 .00794 m
.80476 .00794 L
s
.81429 .00794 m
.81429 .00794 L
s
.82381 .00794 m
.82381 .00794 L
s
.83333 .00794 m
.83333 .00794 L
s
.84286 .00794 m
.84286 .00794 L
s
.85238 .00794 m
.85238 .00794 L
s
.8619 .00794 m
.8619 .00794 L
s
.87143 .00794 m
.87143 .00794 L
s
.88095 .00794 m
.88095 .00794 L
s
.89048 .00794 m
.89048 .00794 L
s
.9 .00794 m
.9 .00794 L
s
.90952 .00794 m
.90952 .00794 L
s
.91905 .00794 m
.91905 .00794 L
s
.92857 .00794 m
.92857 .00794 L
s
.9381 .00794 m
.9381 .00794 L
s
.94762 .00794 m
.94762 .00794 L
s
.95714 .00794 m
.95714 .00794 L
s
.96667 .00794 m
.96667 .00794 L
s
.97619 .00794 m
.97619 .00794 L
s
.005 w
.02381 .00794 Mdot
.03333 .00794 Mdot
.04286 .00794 Mdot
.05238 .00794 Mdot
.0619 .00794 Mdot
.07143 .00794 Mdot
.08095 .00794 Mdot
.09048 .00794 Mdot
.1 .00794 Mdot
.10952 .00794 Mdot
.11905 .00794 Mdot
.12857 .00794 Mdot
.1381 .00794 Mdot
.14762 .00794 Mdot
.15714 .00794 Mdot
.16667 .00794 Mdot
.17619 .00794 Mdot
.18571 .00794 Mdot
.19524 .00794 Mdot
.20476 .00794 Mdot
.21429 .03333 Mdot
.22381 .03413 Mdot
.23333 .03652 Mdot
.24286 .04048 Mdot
.25238 .04596 Mdot
.2619 .0529 Mdot
.27143 .06122 Mdot
.28095 .07084 Mdot
.29048 .08165 Mdot
.3 .09353 Mdot
.30952 .10635 Mdot
.31905 .11997 Mdot
.32857 .13424 Mdot
.3381 .149 Mdot
.34762 .1641 Mdot
.35714 .17937 Mdot
.36667 .19463 Mdot
.37619 .20973 Mdot
.38571 .22449 Mdot
.39524 .23876 Mdot
.40476 .25238 Mdot
.41429 .2652 Mdot
.42381 .27708 Mdot
.43333 .28789 Mdot
.44286 .29751 Mdot
.45238 .30583 Mdot
.4619 .31277 Mdot
.47143 .31825 Mdot
.48095 .32221 Mdot
.49048 .3246 Mdot
.5 .3254 Mdot
.50952 .3246 Mdot
.51905 .32221 Mdot
.52857 .31825 Mdot
.5381 .31277 Mdot
.54762 .30583 Mdot
.55714 .29751 Mdot
.56667 .28789 Mdot
.57619 .27708 Mdot
.58571 .2652 Mdot
.59524 .25238 Mdot
.60476 .23876 Mdot
.61429 .22449 Mdot
.62381 .20973 Mdot
.63333 .19463 Mdot
.64286 .17937 Mdot
.65238 .1641 Mdot
.6619 .149 Mdot
.67143 .13424 Mdot
.68095 .11997 Mdot
.69048 .10635 Mdot
.7 .09353 Mdot
.70952 .08165 Mdot
.71905 .07084 Mdot
.72857 .06122 Mdot
.7381 .0529 Mdot
.74762 .04596 Mdot
.75714 .04048 Mdot
.76667 .03652 Mdot
.77619 .03413 Mdot
.78571 .03333 Mdot
.79524 .00794 Mdot
.80476 .00794 Mdot
.81429 .00794 Mdot
.82381 .00794 Mdot
.83333 .00794 Mdot
.84286 .00794 Mdot
.85238 .00794 Mdot
.8619 .00794 Mdot
.87143 .00794 Mdot
.88095 .00794 Mdot
.89048 .00794 Mdot
.9 .00794 Mdot
.90952 .00794 Mdot
.91905 .00794 Mdot
.92857 .00794 Mdot
.9381 .00794 Mdot
.94762 .00794 Mdot
.95714 .00794 Mdot
.96667 .00794 Mdot
.97619 .00794 Mdot
0 0 m
1 0 L
1 .33333 L
0 .33333 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{504, 168},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007h0000Z2000`400?l00000o`00003ooooooooi
ooooo`00:oooool5o`0000?ooooo0_l0001?ooooo`;o0000D?ooool5o`0000?ooooo0_l0001>oooo
o`?o00000oooool2o`0004kooooo0ol00004ooooo`;o0000COooool3o`0000Cooooo0_l0000Eoooo
o`00;?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0004gooooo00Co0000
oooooooooooo0000D?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0004ko
oooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo04[ooooo00Go0000oooo
ooooooooooooo`000002ooooo`04o`000?ooooooooooo`0004_ooooo00Go0000oooooooooooooooo
o`000002ooooo`04o`000?ooooooooooo`0001Cooooo000Uooooo`Go00000oooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0004gooooo00Co0000oooooooooooo0000DOooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0004_ooooo1Ol00002ooooo`04o`000?oooooo
ooooo`0004cooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0004_o
oooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0001Cooooo000^oooo
o`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`1;ooooo`04o`000?oooooo
ooooo`0005;ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo04Wooooo
00Co0000oooooooooooo00000oooool01?l0003oooooooooool0001<ooooo`Co00000oooool01?l0
003oooooooooool0001<ooooo`?o00000oooool01?l0003oooooooooool0000Dooooo`00:oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000COooool01?l0003ooooo
ooooool0001?ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0001<
ooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooo0000C?ooool00ol0003ooooooooo
o`04ooooo`04o`000?ooooooooooo`0004_ooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0001Cooooo000[ooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0001=ooooo`04o`000?ooooooooooo`0004oooooo00Go0000oooooooooooooooo
o`000002ooooo`04o`000?ooooooooooo`0004gooooo0_l00003ooooo`04o`000?ooooooooooo`00
04gooooo00?o0000ooooooooool00oooool01?l0003oooooooooool0001;ooooo`05o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool0000Dooooo`00;?ooool3o`0000Cooooo0_l0
001?ooooo`;o0000DOooool3o`0000Cooooo0_l0001?ooooo`03o`000?oooooooooo00;ooooo0_l0
001?ooooo`;o00001?ooool2o`0004gooooo0ol00004ooooo`;o00005Oooool00?oooooonOooool0
0?oooooonOooool00?oooooonOooool00?oooooonOooool00?oooooonOooool00?oooooonOooool0
0?oooooonOooool002Coooooool00038o`0000gooooo000Jooooo`;o00002?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00_ooooo000Iooooo`04o`000?ooooooooooo`0000Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0;ooooo`006Oooool01?l0003ooooooooo
ool00007ooooo`03o`000?oooooooooo00Oooooo0_l00?l2ooooo`;o003o0_ooool2o`00o`?ooooo
0_l00?l2ooooo`;o003o0_ooool2o`00o`?ooooo0_l00?l2ooooo`;o003o0_ooool2o`00o`?ooooo
0_l00?l2ooooo`;o003o0_ooool2o`00o`?ooooo0_l00?l2ooooo`;o003o0_ooool2o`00o`?ooooo
0_l00?l2ooooo`;o003o0_ooool2o`00o`?ooooo0_l00?l2ooooo`;o003o0oooool00ol0003ooooo
ooooo`1Dooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool0E?ooool00ol0003ooooo
ooooo`02o`00o`?ooooo0_l00?l2ooooo`;o003o0_ooool2o`00o`?ooooo0_l00?l2ooooo`;o003o
0_ooool2o`00o`?ooooo0_l00?l2ooooo`;o003o0_ooool2o`00o`?ooooo0_l00?l2ooooo`;o003o
0_ooool2o`00o`?ooooo0_l00?l2ooooo`;o003o0_ooool2o`00o`;ooooo0_l00?l3ooooo`;o003o
0_ooool2o`00o`;ooooo0_l00?l:ooooo`03o`000?oooooooooo00_ooooo000Iooooo`04o`000?oo
ooooooooo`0000Oooooo2_l00002o`00o`;o00000_l00?l2o`0000;o003o0ol00002o`00o`;o0000
0_l00?l2o`0000;o003o0ol00002o`00o`;o00000_l00?l2o`0000;o003o0ol00002o`00o`;o0000
0_l00?l2o`0000;o003o0ol00002o`00o`;o00000_l00?l2o`0000;o003o0ol00002o`00o`;o0000
0_l00?l2o`0000;o003o0ol00002o`00o`;o00000_l00?l3o`000005o`00ool0003o0000o`000?l0
0?l01?l000001Ol00?oo0000o`000?l0003o003o00?o000000?o003oo`000?l000000_l000001Ol0
0?oo0000o`000?l0003o003o00?o000000?o003oo`000?l000000_l000001Ol00?oo0000o`000?l0
003o003o00?o000000?o003oo`000?l000000_l000001Ol00?oo0000o`000?l0003o003o00?o0000
00?o003oo`000?l000000_l000001Ol00?oo0000o`000?l0003o003o00?o000000?o003oo`000?l0
00000_l000001Ol00?oo0000o`000?l0003o003o00?o000000?o003oo`000?l000000_l000001Ol0
0?oo0000o`000?l0003o003o00?o000000Go003oo`000?l0003o0000o`00o`04o`000005o`00ool0
003o0000o`000?l00?l00ol000000ol00?oo0000o`000002o`000005o`00ool0003o0000o`000?l0
0?l00ol000000ol00?oo0000o`000002o`000005o`00ool0003o0000o`000?l00?l00ol000000ol0
0?oo0000o`000002o`000005o`00ool0003o0000o`000?l00?l00ol000000ol00?oo0000o`000002
o`000005o`00ool0003o0000o`000?l00?l00ol000000ol00?oo0000o`000002o`000005o`00ool0
003o0000o`000?l00?l00ol000000ol00?oo0000o`000002o`000005o`00ool0003o0000o`000?l0
0?l00ol000000ol00?oo0000o`000002o`000005o`00ool0003o0000o`000?l00?l00ol000000ol0
0?oo0000o`000002o`000005o`00ool0003o0000o`000?l00?l00ol000000ol00?oo0000o`000002
o`000005o`00ool0003o0000o`000?l00?l00ol000000ol00?oo0000o`000002o`000005o`00ool0
003o0000o`000?l00?l00ol000000ol00?oo0000o`000002o`000005o`00ool0003o0000o`000?l0
0?l00ol000000ol00?oo0000o`000002o`000003o`00ool0003o000000;o003o0ol00002o`00o`;o
00000_l00?l2o`0000;o003o0ol00002o`00o`;o00000_l00?l2o`0000;o003o0ol00002o`00o`;o
00000_l00?l2o`0000;o003o0ol00002o`00o`;o00000_l00?l2o`0000;o003o0ol00002o`00o`;o
00000_l00?l2o`0000;o003o0_l00002o`00o`?o00000_l00?l2o`0000;o003o0_l00002o`00o`_o
00003Oooool001Wooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`1Nooooo`05
o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
05kooooo00?o0000ooooooooool02oooool001Wooooo00Co0000oooooooooooo00001oooool00ol0
003oooooooooo`1Nooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo05kooooo00?o0000ooooooooool02oooool001[ooooo0_l00008oooo
o`03o`000?oooooooooo05kooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02oooo
o`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool0G_ooool00ol0003oooooooooo`0;ooooo`009?ooool00ol0
003oooooooooo`1Nooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo05kooooo00?o0000ooooooooool02oooool002Cooooo00?o0000oooo
ooooool0G_ooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;o
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`1Nooooo`03o`000?oooooooooo00_ooooo000Tooooo`03o`000?oooooooooo
05kooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool0G_ooool00ol0003oooooooooo`0;ooooo`009?ooool2o`0005oooooo00Go003ooooo
ooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Co
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;o
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;o
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0G?ooool3
o`0000gooooo000Tooooo`03o`000?oooooooooo05kooooo00Go003oooooooooooooooooo`00o`04
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooo
oooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooo
oooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0G_ooool00ol0003oooooooooo`0;
ooooo`009?ooool00ol0003oooooooooo`1Nooooo`05o`00ooooooooooooooooool00?l01?ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo05kooooo00?o0000ooooooooool02oooool0
02Cooooo00?o0000ooooooooool0G_ooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`1Nooooo`03o`000?oooooooooo00_ooooo000Toooo
o`03o`000?oooooooooo05gooooo0_l00?l3ooooo`;o003o0oooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
0_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02oooo
o`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02oooo
o`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool2o`00o`;ooooo0_l00?mPoooo
o`03o`000?oooooooooo00_ooooo000Tooooo`03o`000?oooooooooo05gooooo0_l00?l3ooooo`;o
003o0_ooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooo
ooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_l00?l3ooooo`;o003o
0_ooool2o`00of3ooooo00?o0000ooooooooool02oooool002Cooooo00?o0000ooooooooool0I_oo
ool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooo
oooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooo
oooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_l00?mYooooo`03o`000?oooooo
oooo00_ooooo000Tooooo`;o0000Joooool2o`00o`?ooooo00?o003oooooooooool00_ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool01?l00?ooooooooooooooool2o`00of_ooooo0ol0000=ooooo`00
9?ooool00ol0003oooooooooo`1Zooooo`;o003o0oooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;o
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;o
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`04o`00ooooooooooooooooo`;o003oKOooool00ol0003ooooooooo
o`0;ooooo`009?ooool00ol0003oooooooooo`1_ooooo`03o`00oooooooooooo00;ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool0L?ooool00ol0003oooooooooo`0;ooooo`00
9?ooool00ol0003oooooooooo`1_ooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool2
o`00og7ooooo00?o0000ooooooooool02oooool002Cooooo00?o0000ooooooooool0Koooool2o`00
o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00?ooooo0_l00?maooooo`03o`000?oooooooooo00_ooooo
000Tooooo`03o`000?oooooooooo07Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;o
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o07Kooooo00?o0000oooo
ooooool02oooool002Cooooo00?o0000ooooooooool0Loooool2o`00o`?ooooo00Go003ooooooooo
ooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol0
0?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooo
oooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooo
oooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_l00?mfooooo`03o`000?oooooo
oooo00_ooooo000Tooooo`;o0000M?ooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`04
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooo
oooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool00_l00?mdooooo`?o00003Oooool002Cooooo00?o0000
ooooooooool0N?ooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`1hooooo`03o`000?oooooooooo00_ooooo000Tooooo`03o`000?oooooooooo07Sooooo00Go
003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02oooo
o`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0N?ooool00ol0003o
ooooooooo`0;ooooo`009?ooool00ol0003oooooooooo`1gooooo`;o003o0oooool00ol00?oooooo
ooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`04
o`00ooooooooooooooooo`;o003oN_ooool00ol0003oooooooooo`0;ooooo`009?ooool00ol0003o
ooooooooo`1gooooo`;o003o0oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;o
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;o
oooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00ooooooooooooooooo`;o003oN_ooool0
0ol0003oooooooooo`0;ooooo`003_ooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol00007
ooooo`03o`000?oooooooooo07cooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`1mooooo`03o`000?oo
oooooooo00_ooooo000=ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000
1oooool00ol0003oooooooooo`1looooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
0_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
0_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0OOooool00ol0003o
ooooooooo`0;ooooo`003Oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0O?ooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
0_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
0_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oo
oooooooooooooooo003o00?ooooo0_l00?mnooooo`03o`000?oooooooooo00_ooooo000=ooooo`04
o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool01_ooool3o`0007cooooo0_l00?l3oooo
o`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`;o003oNoooool4
o`0000gooooo000=ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00
0007ooooo`03o`000?oooooooooo087ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;o
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooo
oooooooo003o08?ooooo00?o0000ooooooooool02oooool000gooooo00Co0000oooooooooooo0000
1oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool0POooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
0_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04oooo
o`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02oooo
o`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0Poooool00ol0003oooooooooo`0;oooo
o`003_ooool2o`0000Wooooo0ol00008ooooo`03o`000?oooooooooo087ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooo
oooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo
00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool00_ooool01Ol00?oooooooooooooooooo003o08?ooooo00?o0000ooooooooool02oooool002Co
oooo00?o0000ooooooooool0P?ooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`04oooo
o`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_l00?n3ooooo`03
o`000?oooooooooo00_ooooo000Tooooo`03o`000?oooooooooo083ooooo0_l00?l3ooooo`05o`00
ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo00;o003oPoooool00ol0003oooooooooo`0;ooooo`009?ooool00ol0003ooooooooo
o`25ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo08Gooooo00?o0000ooooooooool02oooool002Cooooo0_l00026
ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo08?ooooo0ol0000=ooooo`009?ooool00ol0003oooooooooo`25oooo
o`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
0_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02oooo
o`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo08Gooooo00?o0000ooooooooool02oooool002Cooooo00?o0000oooooooo
ool0Q?ooool2o`00o`?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01?l00?oooooo
ooooooooool2o`00ohOooooo00?o0000ooooooooool02oooool002Cooooo00?o0000ooooooooool0
Q?ooool2o`00o`?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01?l00?oooooooooo
ooooool2o`00ohOooooo00?o0000ooooooooool02oooool002Cooooo00?o0000ooooooooool0ROoo
ool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooo
ooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo08[ooooo00?o0000
ooooooooool02oooool002Cooooo00?o0000ooooooooool0ROooool00ol00?ooooooooooo`02oooo
o`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo08[ooooo00?o0000ooooooooool02oooool002Cooooo
00?o0000ooooooooool0ROooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooo
oooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooo
oooooooo08[ooooo00?o0000ooooooooool02oooool002Cooooo0_l0002:ooooo`03o`00oooooooo
oooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
0_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
0_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool0R?ooool3o`0000gooooo000Tooooo`03
o`000?oooooooooo08Wooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooo
oooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooo
oooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`;o003oRoooool00ol0003ooooo
ooooo`0;ooooo`009?ooool00ol0003oooooooooo`29ooooo`;o003o0oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`04ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool2
o`00oh_ooooo00?o0000ooooooooool02oooool002Cooooo00?o0000ooooooooool0S_ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l0T?ooool00ol0003oooooooooo`0;ooooo`009?ooool00ol0003oooooooooo`2>ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;o
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;o
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00
o`2@ooooo`03o`000?oooooooooo00_ooooo000Tooooo`03o`000?oooooooooo08kooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
093ooooo00?o0000ooooooooool02oooool002Cooooo00?o0000ooooooooool0S_ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02oooo
o`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02oooo
o`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0
T?ooool00ol0003oooooooooo`0;ooooo`009?ooool2o`0008kooooo0_l00?l3ooooo`05o`00oooo
ooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo00;o003oS_ooool3o`0000gooooo000Tooooo`03
o`000?oooooooooo08gooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo00;o003oT?ooool00ol0003oooooooooo`0;ooooo`009?ooool00ol0003oooooooooo`2B
ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo09;ooooo00?o0000oooooooo
ool02oooool002Cooooo00?o0000ooooooooool0T_ooool01Ol00?oooooooooooooooooo003o00Co
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`2Booooo`03o`000?oooooooooo00_ooooo000Tooooo`03o`000?oooooooooo
09;ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0T_ooool00ol0003ooooo
ooooo`0;ooooo`003_ooool2o`0000Cooooo00?o0000ooooooooool00oooool3o`0000Oooooo00?o
0000ooooooooool0T_ooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
0_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
0_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`2Boooo
o`03o`000?oooooooooo00_ooooo000=ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`2Booooo`05o`00ooooooooooooooooool00?l01?ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo09;ooooo00?o0000ooooooooool02oooool000gooooo00Co0000oooooooooooo0000
1oooool5o`0000Oooooo0ol0002Aooooo`;o003o0oooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;o
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;o
oooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00ooooooooooooooooo`;o003oTOooool4
o`0000gooooo000=ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00002?oo
ool00ol0003oooooooooo`2Aooooo`;o003o0oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol0
0?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooo
oooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooo
oooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo
00Go003oooooooooooooooooo`00o`03ooooo`04o`00ooooooooooooooooo`;o003oU?ooool00ol0
003oooooooooo`0;ooooo`003Oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo0000
00Sooooo00?o0000ooooooooool0U_ooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo09Oooooo00?o0000ooooooooool02ooo
ool000gooooo00Co0000oooooooooooo00002Oooool2o`0000Sooooo00?o0000ooooooooool0U_oo
ool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo09Oooooo00?o0000ooooooooool02oooool000kooooo0_l0000;ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0U_ooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;o
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;o
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo09Oooooo00?o0000oooo
ooooool02oooool002Cooooo00?o0000ooooooooool0U_ooool00ol00?ooooooooooo`02ooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo09Oooooo00?o0000
ooooooooool02oooool002Cooooo00?o0000ooooooooool0U_ooool2o`00o`?ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool0
1Ol00?oooooooooooooooooo003o00?ooooo0_l00?nHooooo`03o`000?oooooooooo00_ooooo000T
ooooo`03o`000?oooooooooo09Kooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`;o003oV?ooool00ol0003oooooooooo`0;ooooo`009?ooool2o`0009cooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
0_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
0_ooool01Ol00?oooooooooooooooooo003o09_ooooo0ol0000=ooooo`009?ooool00ol0003ooooo
ooooo`2Kooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooo
ooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`2Mooooo`03o`000?oooooooooo
00_ooooo000Tooooo`03o`000?oooooooooo09_ooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0
1?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
0_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo
003o09gooooo00?o0000ooooooooool02oooool002Cooooo00?o0000ooooooooool0Voooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l0WOooool00ol0003oooooooooo`0;ooooo`009?ooool0
0ol0003oooooooooo`2Kooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;o
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`2Mooooo`03o`00
0?oooooooooo00_ooooo000Tooooo`03o`000?oooooooooo09[ooooo0_l00?l3ooooo`05o`00oooo
ooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;o003o
WOooool00ol0003oooooooooo`0;ooooo`009?ooool00ol0003oooooooooo`2Jooooo`;o003o0ooo
ool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`02o`00oigooooo00?o0000ooooooooool02oooool002Cooooo0_l0002Pooooo`05o`00oooo
ooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo09gooooo
0ol0000=ooooo`009?ooool00ol0003oooooooooo`2Oooooo`05o`00ooooooooooooooooool00?l0
1?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02oooo
o`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo09oooooo00?o0000ooooooooool0
2oooool002Cooooo00?o0000ooooooooool0Woooool01Ol00?oooooooooooooooooo003o00Cooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`2Oooooo`03o`000?oooooooooo00_ooooo
000Tooooo`03o`000?oooooooooo09oooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;o
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool0Woooool00ol0003oooooooooo`0;ooooo`009?oo
ool00ol0003oooooooooo`2Oooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo09oooooo00?o0000ooooooooool02oooool002Cooooo00?o
0000ooooooooool0W_ooool2o`00o`?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01?l00?oooooooooo
ooooool2o`00oj7ooooo00?o0000ooooooooool02oooool002Cooooo00?o0000ooooooooool0W_oo
ool2o`00o`?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool01?l00?ooooooooooooooool2o`00oj7ooooo
00?o0000ooooooooool02oooool002Cooooo0_l0002Tooooo`03o`00oooooooooooo00;ooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
0_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool0X_ooool3o`0000gooooo000Tooooo`03o`000?oooooooooo0:?ooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`2Tooooo`03o`000?oooooooooo00_ooooo000Toooo
o`03o`000?oooooooooo0:?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02oooo
o`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`2Toooo
o`03o`000?oooooooooo00_ooooo000Tooooo`03o`000?oooooooooo0:?ooooo00?o003ooooooooo
ool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`2Tooooo`03o`000?oooooooooo00_ooooo000Tooooo`03o`00
0?oooooooooo0:?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`2Tooooo`03o`00
0?oooooooooo00_ooooo000>ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00002?oo
ool00ol0003oooooooooo`2Sooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool2o`00ojGooooo00?o0000ooooooooool02ooo
ool000gooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Oooooo
00?o0000ooooooooool0Xoooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00?ooooo0_l00?nUooooo`03o`000?oooooooooo00_ooooo
000=ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000007ooooo`?o
0000Z?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l0Yoooool4o`0000gooooo000=ooooo`04o`000?ooooooooooo`0000Oooooo1?l00008ooooo`03
o`000?oooooooooo0:Sooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o0:[ooooo00?o0000ooooooooool02oooool000gooooo00Co0000oooooooooooo
00001oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0:Sooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o0:[ooooo00?o0000oooooooo
ool02oooool000gooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo0:Sooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o0:[ooooo00?o0000ooooooooool02oooool000kooooo0_l0000:ooooo`;o0000
2?ooool00ol0003oooooooooo`2Xooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go
003oooooooooooooooooo`00o`2Zooooo`03o`000?oooooooooo00_ooooo000Tooooo`03o`000?oo
oooooooo0:Oooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;o003oZ_ooool0
0ol0003oooooooooo`0;ooooo`009?ooool00ol0003oooooooooo`2Wooooo`;o003o0oooool01Ol0
0?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`02o`00oj[ooooo00?o0000ooooooooool02oooool002Cooooo
00?o0000ooooooooool0[?ooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`2/ooooo`03o`000?oo
oooooooo00_ooooo000Tooooo`;o0000[Oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
0_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`2Zoooo
o`?o00003Oooool002Cooooo00?o0000ooooooooool0[?ooool01Ol00?oooooooooooooooooo003o
00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`2/ooooo`03o`000?oooooooooo00_ooooo000Tooooo`03o`000?oooooooooo0:cooooo00Go
003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool0[?ooool00ol0003oooooooooo`0;ooooo`009?ooool00ol0
003oooooooooo`2/ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo0:cooooo00?o0000oooooooo
ool02oooool002Cooooo00?o0000ooooooooool0Zoooool2o`00o`?ooooo00?o003oooooooooool0
0_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04oooo
o`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02oooo
o`05o`00ooooooooooooooooool00?l00oooool01?l00?ooooooooooooooool2o`00ojkooooo00?o
0000ooooooooool02oooool002Cooooo00?o0000ooooooooool0Zoooool2o`00o`?ooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01?l00?ooooooooooooooool2o`00
ojkooooo00?o0000ooooooooool02oooool002Cooooo00?o0000ooooooooool0/?ooool00ol00?oo
ooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo0;7ooooo00?o
0000ooooooooool02oooool002Cooooo0_l0002aooooo`03o`00oooooooooooo00;ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool0[oooool3o`0000gooooo000Tooooo`03o`00
0?oooooooooo0;3ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`2aooooo`03o`000?oooooooooo00_ooooo000Tooooo`03o`000?oooooooooo
0;3ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`2aooooo`03o`000?oooooooooo00_ooooo000Tooooo`03o`000?oooooooooo0;3ooooo0_l0
0?l3ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Co
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;o
oooo00Go003oooooooooooooooooo`00o`03ooooo`;o003o/_ooool00ol0003oooooooooo`0;oooo
o`009?ooool00ol0003oooooooooo`2`ooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00ooo
ool2o`00ok;ooooo00?o0000ooooooooool02oooool002Cooooo00?o0000ooooooooool0]Oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l0]oooool00ol0003oooooooooo`0;ooooo`009?ooool00ol0003ooooo
ooooo`2eooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`2gooooo`03o`000?oooooooooo00_ooooo000Toooo
o`;o0000]_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`04ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l0]Oooool3o`0000gooooo000Tooooo`03o`000?oo
oooooooo0;Gooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool0
0?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool00_ooool01Ol00?oooooooooooooooooo003o0;Oooooo00?o0000ooooooooool02oooool002Co
oooo00?o0000ooooooooool0]?ooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_l00?ngooooo`03o`000?oooooooooo
00_ooooo000Tooooo`03o`000?oooooooooo0;Cooooo0_l00?l3ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;o003o]oooool00ol0
003oooooooooo`0;ooooo`009?ooool00ol0003oooooooooo`2iooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo0;Wooooo00?o0000oooo
ooooool02oooool000kooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00008ooooo`03
o`000?oooooooooo0;Wooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool0^Oooool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003o
ooooooooool00007ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`2i
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo0;Wooooo00?o0000ooooooooool02oooool000gooooo00Co0000oooooooooooo00001ooo
ool01Ol0003ooooooooooooooooo000000Oooooo0ol0002iooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo0;Kooooo1?l0000=ooooo`00
3Oooool01?l0003oooooooooool00008ooooo`?o00002?ooool00ol0003oooooooooo`2hooooo`;o
003o0oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooo
oooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`04o`00ooooooooooooooooo`;o003o^oooool00ol0003oooooooooo`0;
ooooo`003Oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001ooo
ool00ol0003oooooooooo`2hooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00Cooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooo
oooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00ooooooooooooooooo`;o
003o^oooool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003oooooooooool00007ooooo`05
o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`2mooooo`05o`00oooooooooooo
ooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool0__ooool00ol0003oooooooooo`0;ooooo`003_ooool2o`0000Wooooo0ol00008oooo
o`03o`000?oooooooooo0;gooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02oooo
o`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`2nooooo`03o`000?oooooo
oooo00_ooooo000Tooooo`03o`000?oooooooooo0;gooooo00Go003oooooooooooooooooo`00o`04
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`2n
ooooo`03o`000?oooooooooo00_ooooo000Tooooo`03o`000?oooooooooo0;gooooo00Go003ooooo
ooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`2nooooo`03o`000?oooooooooo00_ooooo000Tooooo`;o0000__ooool2o`00
o`;ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
00?ooooo0_l00?nmooooo`?o00003Oooool002Cooooo00?o0000ooooooooool0_Oooool2o`00o`;o
oooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?o
oooo0_l00?noooooo`03o`000?oooooooooo00_ooooo000Tooooo`03o`000?oooooooooo0<7ooooo
00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o0<Cooooo
00?o0000ooooooooool02oooool002Cooooo00?o0000ooooooooool0`Oooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0a?ooool00ol0003ooooooooo
o`0;ooooo`009?ooool00ol0003oooooooooo`31ooooo`03o`00oooooooooooo00;ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`34ooooo`03o`000?oooooooooo00_ooooo000Toooo
o`03o`000?oooooooooo0<7ooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;o
003oa?ooool00ol0003oooooooooo`0;ooooo`009?ooool00ol0003oooooooooo`31ooooo`;o003o
0oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`02o`00olCooooo00?o0000ooooooooool02ooo
ool002Cooooo00?o0000ooooooooool0a_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
0_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`36oooo
o`03o`000?oooooooooo00_ooooo000Tooooo`;o0000aoooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`34ooooo`?o00003Oooool002Cooooo00?o0000ooooooooool0aOooool2o`00o`?ooooo00Go
003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02oooo
o`05o`00ooooooooooooooooool00?l00oooool01?l00?ooooooooooooooool2o`00olSooooo00?o
0000ooooooooool02oooool002Cooooo00?o0000ooooooooool0aOooool2o`00o`?ooooo00Go003o
ooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05
o`00ooooooooooooooooool00?l00oooool01?l00?ooooooooooooooool2o`00olSooooo00?o0000
ooooooooool02oooool002Cooooo00?o0000ooooooooool0b_ooool01Ol00?oooooooooooooooooo
003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo0<_ooooo00?o0000ooooooooool02oooool002Cooooo
00?o0000ooooooooool0b_ooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooo
oooooooo0<_ooooo00?o0000ooooooooool02oooool002Cooooo00?o0000ooooooooool0b_ooool2
o`00o`;ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
0_ooool01Ol00?oooooooooooooooooo003o00?ooooo0_l00?o<ooooo`03o`000?oooooooooo00_o
oooo000Tooooo`03o`000?oooooooooo0<[ooooo0_l00?l2ooooo`03o`00oooooooooooo00;ooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03
ooooo`;o003oc?ooool00ol0003oooooooooo`0;ooooo`009?ooool2o`000<oooooo00?o003ooooo
ooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooo
oooooooo003o0<oooooo0ol0000=ooooo`009?ooool00ol0003oooooooooo`3>ooooo`;o003o0ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02o`00om7o
oooo00?o0000ooooooooool02oooool002Cooooo00?o0000ooooooooool0c_ooool2o`00o`?ooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_l00?oAoooo
o`03o`000?oooooooooo00_ooooo000Tooooo`03o`000?oooooooooo0=;ooooo0_l00?l3ooooo`05
o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Co003o
oooooooooooooooo0_l00?oEooooo`03o`000?oooooooooo00_ooooo000Iooooo`?o00002?ooool0
0ol0003oooooooooo`3Booooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go
003oooooooooooooooooo`00o`03ooooo`04o`00ooooooooooooooooo`;o003oeOooool00ol0003o
ooooooooo`0;ooooo`006_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0=Kooooo
0_l00?l3ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`;o
003ofOooool00ol0003oooooooooo`0;ooooo`006_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0=Kooooo0_l00?l3ooooo`;o003o0oooool00ol00?ooooooooooo`02o`00o`?ooooo
0_l00?oIooooo`03o`000?oooooooooo00_ooooo000Jooooo`03o`000?oooooooooo00Oooooo0ol0
003Kooooo`;o003o0_ooool2o`00o`;ooooo0_l00?oKooooo`Co00003Oooool001[ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05Cooooo00?o0000
ooooooooool0E?ooool00ol0003oooooooooo`0Wooooo`;o003o:_ooool00ol0003oooooooooo`1D
ooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0;
ooooo`006Oooool2o`0000Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0;oooo
o`006_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool02oooool002Coooooool00038o`0000gooooo0000\
\>"],
  ImageRangeCache->{{{0, 503}, {167, 0}} -> {-30.8536, -0.126788, 0.231139, \
0.00693418}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Sampled and windowed sequence", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(x[
          t_] := \((1\  + \ 2\ Cos[2 \((1 + 1/6)\) \[Pi]\ t]\  + \ 
              4\ Cos[\((4  \[Pi]\  + \ 2  \[Pi]\ \((1/6)\))\) t])\) 
          Window[t, 3];\)\), "\n", 
    \(\(xdc = \ sampler[x, fs, {0, 3}];\)\), "\[IndentingNewLine]", 
    \(\(xd2 = \ 
        Table[{n, 0}, {n, \(-fs\), \(-1\)}]~Join~xdc~Join~\ 
          Table[{n, 0}, {n, 3*fs + 1, 4*fs}];\)\), "\[IndentingNewLine]", 
    \(\ \(If[OddQ[Length[xdc]], \ xdc\  = \ Drop[xdc, \(-1\)]];\)\), "\n", 
    \(\(gwc\  = \ 
        DiscreteListPlot2[xd2, \ Blue, \ Frame \[Rule] True, 
          Axes \[Rule] {True, False}, \ AspectRatio \[Rule] 1/3, \ 
          ImageSize \[Rule] 504, \ PlotRange \[Rule] All];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .33333 
%%ImageSize: 504 168 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.214286 0.00952381 0.135444 0.0354061 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.21429 -0.0125 -3 -9 ]
[.21429 -0.0125 3 0 ]
[.40476 -0.0125 -6 -9 ]
[.40476 -0.0125 6 0 ]
[.59524 -0.0125 -6 -9 ]
[.59524 -0.0125 6 0 ]
[.78571 -0.0125 -6 -9 ]
[.78571 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .06463 -12 -4.5 ]
[-0.0125 .06463 0 4.5 ]
[-0.0125 .13544 -6 -4.5 ]
[-0.0125 .13544 0 4.5 ]
[-0.0125 .20626 -6 -4.5 ]
[-0.0125 .20626 0 4.5 ]
[-0.0125 .27707 -6 -4.5 ]
[-0.0125 .27707 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .33333 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-20)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(0)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(20)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(40)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(60)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(80)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .06463 m
.00625 .06463 L
s
[(-2)] -0.0125 .06463 1 0 Mshowa
0 .13544 m
.00625 .13544 L
s
[(0)] -0.0125 .13544 1 0 Mshowa
0 .20626 m
.00625 .20626 L
s
[(2)] -0.0125 .20626 1 0 Mshowa
0 .27707 m
.00625 .27707 L
s
[(4)] -0.0125 .27707 1 0 Mshowa
.125 Mabswid
0 .08233 m
.00375 .08233 L
s
0 .10004 m
.00375 .10004 L
s
0 .11774 m
.00375 .11774 L
s
0 .15315 m
.00375 .15315 L
s
0 .17085 m
.00375 .17085 L
s
0 .18855 m
.00375 .18855 L
s
0 .22396 m
.00375 .22396 L
s
0 .24166 m
.00375 .24166 L
s
0 .25937 m
.00375 .25937 L
s
0 .04693 m
.00375 .04693 L
s
0 .02923 m
.00375 .02923 L
s
0 .01152 m
.00375 .01152 L
s
0 .29477 m
.00375 .29477 L
s
0 .31247 m
.00375 .31247 L
s
0 .33018 m
.00375 .33018 L
s
.25 Mabswid
0 0 m
0 .33333 L
s
.02381 .32708 m
.02381 .33333 L
s
.21429 .32708 m
.21429 .33333 L
s
.40476 .32708 m
.40476 .33333 L
s
.59524 .32708 m
.59524 .33333 L
s
.78571 .32708 m
.78571 .33333 L
s
.97619 .32708 m
.97619 .33333 L
s
.125 Mabswid
.07143 .32958 m
.07143 .33333 L
s
.11905 .32958 m
.11905 .33333 L
s
.16667 .32958 m
.16667 .33333 L
s
.2619 .32958 m
.2619 .33333 L
s
.30952 .32958 m
.30952 .33333 L
s
.35714 .32958 m
.35714 .33333 L
s
.45238 .32958 m
.45238 .33333 L
s
.5 .32958 m
.5 .33333 L
s
.54762 .32958 m
.54762 .33333 L
s
.64286 .32958 m
.64286 .33333 L
s
.69048 .32958 m
.69048 .33333 L
s
.7381 .32958 m
.7381 .33333 L
s
.83333 .32958 m
.83333 .33333 L
s
.88095 .32958 m
.88095 .33333 L
s
.92857 .32958 m
.92857 .33333 L
s
.25 Mabswid
0 .33333 m
1 .33333 L
s
.99375 .06463 m
1 .06463 L
s
.99375 .13544 m
1 .13544 L
s
.99375 .20626 m
1 .20626 L
s
.99375 .27707 m
1 .27707 L
s
.125 Mabswid
.99625 .08233 m
1 .08233 L
s
.99625 .10004 m
1 .10004 L
s
.99625 .11774 m
1 .11774 L
s
.99625 .15315 m
1 .15315 L
s
.99625 .17085 m
1 .17085 L
s
.99625 .18855 m
1 .18855 L
s
.99625 .22396 m
1 .22396 L
s
.99625 .24166 m
1 .24166 L
s
.99625 .25937 m
1 .25937 L
s
.99625 .04693 m
1 .04693 L
s
.99625 .02923 m
1 .02923 L
s
.99625 .01152 m
1 .01152 L
s
.99625 .29477 m
1 .29477 L
s
.99625 .31247 m
1 .31247 L
s
.99625 .33018 m
1 .33018 L
s
.25 Mabswid
1 0 m
1 .33333 L
s
0 .13544 m
1 .13544 L
s
0 0 1 r
.5 Mabswid
.02381 .13544 m
.02381 .13544 L
s
.03333 .13544 m
.03333 .13544 L
s
.04286 .13544 m
.04286 .13544 L
s
.05238 .13544 m
.05238 .13544 L
s
.0619 .13544 m
.0619 .13544 L
s
.07143 .13544 m
.07143 .13544 L
s
.08095 .13544 m
.08095 .13544 L
s
.09048 .13544 m
.09048 .13544 L
s
.1 .13544 m
.1 .13544 L
s
.10952 .13544 m
.10952 .13544 L
s
.11905 .13544 m
.11905 .13544 L
s
.12857 .13544 m
.12857 .13544 L
s
.1381 .13544 m
.1381 .13544 L
s
.14762 .13544 m
.14762 .13544 L
s
.15714 .13544 m
.15714 .13544 L
s
.16667 .13544 m
.16667 .13544 L
s
.17619 .13544 m
.17619 .13544 L
s
.18571 .13544 m
.18571 .13544 L
s
.19524 .13544 m
.19524 .13544 L
s
.20476 .13544 m
.20476 .13544 L
s
.21429 .13544 m
.21429 .15527 L
s
.22381 .13544 m
.22381 .1529 L
s
.23333 .13544 m
.23333 .14602 L
s
.24286 .13544 m
.24286 .13578 L
s
.25238 .13544 m
.25238 .12508 L
s
.2619 .13544 m
.2619 .11849 L
s
.27143 .13544 m
.27143 .12043 L
s
.28095 .13544 m
.28095 .13216 L
s
.29048 .13544 m
.29048 .14959 L
s
.3 .13544 m
.3 .16385 L
s
.30952 .13544 m
.30952 .16543 L
s
.31905 .13544 m
.31905 .15012 L
s
.32857 .13544 m
.32857 .12341 L
s
.3381 .13544 m
.3381 .10004 L
s
.34762 .13544 m
.34762 .09774 L
s
.35714 .13544 m
.35714 .12752 L
s
.36667 .13544 m
.36667 .1856 L
s
.37619 .13544 m
.37619 .25193 L
s
.38571 .13544 m
.38571 .29742 L
s
.39524 .13544 m
.39524 .29734 L
s
.40476 .13544 m
.40476 .24449 L
s
.41429 .13544 m
.41429 .15516 L
s
.42381 .13544 m
.42381 .06375 L
s
.43333 .13544 m
.43333 .00794 L
s
.44286 .13544 m
.44286 .01097 L
s
.45238 .13544 m
.45238 .07009 L
s
.4619 .13544 m
.4619 .15713 L
s
.47143 .13544 m
.47143 .23173 L
s
.48095 .13544 m
.48095 .26072 L
s
.49048 .13544 m
.49048 .23435 L
s
.5 .13544 m
.5 .17085 L
s
.50952 .13544 m
.50952 .10717 L
s
.51905 .13544 m
.51905 .08026 L
s
.52857 .13544 m
.52857 .10838 L
s
.5381 .13544 m
.5381 .18175 L
s
.54762 .13544 m
.54762 .26725 L
s
.55714 .13544 m
.55714 .32451 L
s
.56667 .13544 m
.56667 .3254 L
s
.57619 .13544 m
.57619 .26717 L
s
.58571 .13544 m
.58571 .17311 L
s
.59524 .13544 m
.59524 .08092 L
s
.60476 .13544 m
.60476 .02504 L
s
.61429 .13544 m
.61429 .02178 L
s
.62381 .13544 m
.62381 .06397 L
s
.63333 .13544 m
.63333 .12693 L
s
.64286 .13544 m
.64286 .1816 L
s
.65238 .13544 m
.65238 .20798 L
s
.6619 .13544 m
.6619 .20231 L
s
.67143 .13544 m
.67143 .17565 L
s
.68095 .13544 m
.68095 .14575 L
s
.69048 .13544 m
.69048 .12741 L
s
.7 .13544 m
.7 .12613 L
s
.70952 .13544 m
.70952 .13774 L
s
.71905 .13544 m
.71905 .15276 L
s
.72857 .13544 m
.72857 .16235 L
s
.7381 .13544 m
.7381 .16243 L
s
.74762 .13544 m
.74762 .15429 L
s
.75714 .13544 m
.75714 .14237 L
s
.76667 .13544 m
.76667 .13124 L
s
.77619 .13544 m
.77619 .12383 L
s
.78571 .13544 m
.78571 .12128 L
s
.79524 .13544 m
.79524 .13544 L
s
.80476 .13544 m
.80476 .13544 L
s
.81429 .13544 m
.81429 .13544 L
s
.82381 .13544 m
.82381 .13544 L
s
.83333 .13544 m
.83333 .13544 L
s
.84286 .13544 m
.84286 .13544 L
s
.85238 .13544 m
.85238 .13544 L
s
.8619 .13544 m
.8619 .13544 L
s
.87143 .13544 m
.87143 .13544 L
s
.88095 .13544 m
.88095 .13544 L
s
.89048 .13544 m
.89048 .13544 L
s
.9 .13544 m
.9 .13544 L
s
.90952 .13544 m
.90952 .13544 L
s
.91905 .13544 m
.91905 .13544 L
s
.92857 .13544 m
.92857 .13544 L
s
.9381 .13544 m
.9381 .13544 L
s
.94762 .13544 m
.94762 .13544 L
s
.95714 .13544 m
.95714 .13544 L
s
.96667 .13544 m
.96667 .13544 L
s
.97619 .13544 m
.97619 .13544 L
s
.005 w
.02381 .13544 Mdot
.03333 .13544 Mdot
.04286 .13544 Mdot
.05238 .13544 Mdot
.0619 .13544 Mdot
.07143 .13544 Mdot
.08095 .13544 Mdot
.09048 .13544 Mdot
.1 .13544 Mdot
.10952 .13544 Mdot
.11905 .13544 Mdot
.12857 .13544 Mdot
.1381 .13544 Mdot
.14762 .13544 Mdot
.15714 .13544 Mdot
.16667 .13544 Mdot
.17619 .13544 Mdot
.18571 .13544 Mdot
.19524 .13544 Mdot
.20476 .13544 Mdot
.21429 .15527 Mdot
.22381 .1529 Mdot
.23333 .14602 Mdot
.24286 .13578 Mdot
.25238 .12508 Mdot
.2619 .11849 Mdot
.27143 .12043 Mdot
.28095 .13216 Mdot
.29048 .14959 Mdot
.3 .16385 Mdot
.30952 .16543 Mdot
.31905 .15012 Mdot
.32857 .12341 Mdot
.3381 .10004 Mdot
.34762 .09774 Mdot
.35714 .12752 Mdot
.36667 .1856 Mdot
.37619 .25193 Mdot
.38571 .29742 Mdot
.39524 .29734 Mdot
.40476 .24449 Mdot
.41429 .15516 Mdot
.42381 .06375 Mdot
.43333 .00794 Mdot
.44286 .01097 Mdot
.45238 .07009 Mdot
.4619 .15713 Mdot
.47143 .23173 Mdot
.48095 .26072 Mdot
.49048 .23435 Mdot
.5 .17085 Mdot
.50952 .10717 Mdot
.51905 .08026 Mdot
.52857 .10838 Mdot
.5381 .18175 Mdot
.54762 .26725 Mdot
.55714 .32451 Mdot
.56667 .3254 Mdot
.57619 .26717 Mdot
.58571 .17311 Mdot
.59524 .08092 Mdot
.60476 .02504 Mdot
.61429 .02178 Mdot
.62381 .06397 Mdot
.63333 .12693 Mdot
.64286 .1816 Mdot
.65238 .20798 Mdot
.6619 .20231 Mdot
.67143 .17565 Mdot
.68095 .14575 Mdot
.69048 .12741 Mdot
.7 .12613 Mdot
.70952 .13774 Mdot
.71905 .15276 Mdot
.72857 .16235 Mdot
.7381 .16243 Mdot
.74762 .15429 Mdot
.75714 .14237 Mdot
.76667 .13124 Mdot
.77619 .12383 Mdot
.78571 .12128 Mdot
.79524 .13544 Mdot
.80476 .13544 Mdot
.81429 .13544 Mdot
.82381 .13544 Mdot
.83333 .13544 Mdot
.84286 .13544 Mdot
.85238 .13544 Mdot
.8619 .13544 Mdot
.87143 .13544 Mdot
.88095 .13544 Mdot
.89048 .13544 Mdot
.9 .13544 Mdot
.90952 .13544 Mdot
.91905 .13544 Mdot
.92857 .13544 Mdot
.9381 .13544 Mdot
.94762 .13544 Mdot
.95714 .13544 Mdot
.96667 .13544 Mdot
.97619 .13544 Mdot
0 0 m
1 0 L
1 .33333 L
0 .33333 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{504, 168},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007h0000Z2000`400?l00000o`00003ooooooooi
ooooo`009oooool5o`0000?ooooo0_l0001?ooooo`;o0000D?ooool5o`0000?ooooo0_l0001?oooo
o`?o00000oooool2o`0004kooooo0ol00004ooooo`;o0000C_ooool3o`0000Cooooo0_l0000Goooo
o`00:?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0004gooooo00Co0000
oooooooooooo0000D?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0004oo
oooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo04[ooooo00Go0000oooo
ooooooooooooo`000002ooooo`04o`000?ooooooooooo`0004cooooo00Go0000oooooooooooooooo
o`000002ooooo`04o`000?ooooooooooo`0001Kooooo000Qooooo`Go00000oooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0004gooooo00Co0000oooooooooooo0000DOooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0004cooooo1Ol00002ooooo`04o`000?oooooo
ooooo`0004cooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0004co
oooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0001Kooooo000Zoooo
o`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`1;ooooo`04o`000?oooooo
ooooo`0005;ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo04[ooooo
00Co0000oooooooooooo00000oooool01?l0003oooooooooool0001<ooooo`Co00000oooool01?l0
003oooooooooool0001=ooooo`?o00000oooool01?l0003oooooooooool0000Fooooo`009oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000COooool01?l0003ooooo
ooooool0001?ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0001=
ooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooo0000C?ooool00ol0003ooooooooo
o`04ooooo`04o`000?ooooooooooo`0004cooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0001Kooooo000Wooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0001=ooooo`04o`000?ooooooooooo`0004oooooo00Go0000oooooooooooooooo
o`000002ooooo`04o`000?ooooooooooo`0004kooooo0_l00003ooooo`04o`000?ooooooooooo`00
04gooooo00?o0000ooooooooool00oooool01?l0003oooooooooool0001<ooooo`05o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool0000Fooooo`00:?ooool3o`0000Cooooo0_l0
001?ooooo`;o0000DOooool3o`0000Cooooo0_l0001@ooooo`03o`000?oooooooooo00;ooooo0_l0
001?ooooo`;o00001?ooool2o`0004kooooo0ol00004ooooo`;o00005oooool00?oooooonOooool0
0?oooooonOooool00?oooooonOooool00?oooooonOooool00?oooooonOooool00?oooooonOooool0
0?oooooonOooool001ooooooool0003;o`0000oooooo000Oooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool03Oooool001oooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0=ooooo`007oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo05Cooooo00?o0000
ooooooooool0E?ooool00ol0003oooooooooo`0:ooooo`;o003oB?ooool00ol0003oooooooooo`1D
ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0=
ooooo`007oooool00ol0003oooooooooo`33ooooo`;o003oooooool2ooooo`03o`000?oooooooooo
00gooooo000Oooooo`?o0000`oooool01?l00?ooooooooooooooool2o`00oocooooo0_l0000?oooo
o`007oooool00ol0003oooooooooo`33ooooo`04o`00ooooooooooooooooo`;o003ooOooool00ol0
003oooooooooo`0=ooooo`007oooool00ol0003oooooooooo`33ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool0noooool00ol0003oooooooooo`0=ooooo`007oooool00ol0003ooooo
ooooo`33ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0noooool00ol0003ooooo
ooooo`0=ooooo`007oooool00ol0003oooooooooo`33ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool0noooool00ol0003oooooooooo`0=ooooo`007oooool00ol0003oooooooooo`33
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0B_ooool2o`00ojoooooo00?o0000
ooooooooool03Oooool001oooooo00?o0000ooooooooool0`oooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo04Kooooo0_l00?l2ooooo`;o003o[oooool00ol0003oooooooooo`0=oooo
o`007oooool00ol0003oooooooooo`33ooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool0A_ooool2o`00o`?ooooo00?o003oooooooooool0[Oooool00ol0003oooooooooo`0=ooooo`00
7oooool00ol0003oooooooooo`33ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
Aoooool01Ol00?oooooooooooooooooo003o0:oooooo00?o0000ooooooooool03Oooool001oooooo
0ol00033ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0Aoooool01Ol00?oooooo
oooooooooooo003o0:kooooo0_l0000?ooooo`007oooool00ol0003oooooooooo`33ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool0Aoooool01Ol00?oooooooooooooooooo003o0:oo
oooo00?o0000ooooooooool03Oooool001oooooo00?o0000ooooooooool0`oooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo04Oooooo00Go003oooooooooooooooooo`00o`2_ooooo`03
o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo0<?ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`17ooooo`05o`00ooooooooooooooooool00?l0[oooool00ol0003o
ooooooooo`0=ooooo`007oooool00ol0003oooooooooo`33ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool0Aoooool01Ol00?oooooooooooooooooo003o0:oooooo00?o0000oooooooo
ool03Oooool001oooooo00?o0000ooooooooool0`oooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo04Oooooo00Go003oooooooooooooooooo`00o`2_ooooo`03o`000?oooooooooo00go
oooo000Oooooo`03o`000?oooooooooo0<?ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`17ooooo`05o`00ooooooooooooooooool00?l0[oooool00ol0003oooooooooo`0=ooooo`00
7oooool00ol0003oooooooooo`33ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
Aoooool01Ol00?oooooooooooooooooo003o0:oooooo00?o0000ooooooooool03Oooool001oooooo
0ol00033ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0Aoooool01Ol00?oooooo
oooooooooooo003o0:kooooo0_l0000?ooooo`007oooool00ol0003oooooooooo`33ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool0Aoooool01Ol00?oooooooooooooooooo003o0:oo
oooo00?o0000ooooooooool03Oooool001oooooo00?o0000ooooooooool0`oooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo04Oooooo00Go003oooooooooooooooooo`00o`2_ooooo`03
o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo0<?ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`17ooooo`05o`00ooooooooooooooooool00?l0[oooool00ol0003o
ooooooooo`0=ooooo`007oooool00ol0003oooooooooo`33ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool0Aoooool01Ol00?oooooooooooooooooo003o0:oooooo00?o0000oooooooo
ool03Oooool001Cooooo1Ol00006ooooo`03o`000?oooooooooo0<?ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`17ooooo`05o`00ooooooooooooooooool00?l0[oooool00ol0003o
ooooooooo`0=ooooo`005Oooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo0<?o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`17ooooo`05o`00oooooooooooooooo
ool00?l0[oooool00ol0003oooooooooo`0=ooooo`003_ooool5o`0000?ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`2nooooo`;o003o0oooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo04Oooooo00Go003oooooooooooooooooo`00o`03ooooo`;o003oZ_ooool00ol0
003oooooooooo`0=ooooo`005oooool00ol0003oooooooooo`05ooooo`Co0000_Oooool2o`00o`?o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`17ooooo`05o`00oooooooooooooooo
ool00?l00oooool2o`00ojOooooo1?l0000?ooooo`005?ooool01Ol0003ooooooooooooooooo0000
00Kooooo00?o0000ooooooooool0_oooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003o
ooooooooool0Aoooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0ZOoo
ool00ol0003oooooooooo`0=ooooo`005?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o
0000ooooooooool0_oooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool0
0_l00?m5ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`2Yooooo`03
o`000?oooooooooo00gooooo000Eooooo`?o00001oooool00ol0003oooooooooo`2oooooo`05o`00
ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`02o`00odGooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo0:Wooooo00?o0000ooooooooool03Oooool001oo
oooo00?o0000ooooooooool0_oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooo
ooooooooooooo`00o`15ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`2Yooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo0;oooooo00Go003o
ooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l0AOooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool0ZOooool00ol0003oooooooooo`0=ooooo`00
7oooool00ol0003oooooooooo`2oooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oo
oooooooooooooooo003o04Gooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo0:Wooooo00?o0000ooooooooool03Oooool001oooooo00?o0000ooooooooool0_oooool01Ol0
0?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`0Mooooo`;o003o8Ooo
ool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo0:Wooooo
00?o0000ooooooooool03Oooool001oooooo0ol0002oooooo`05o`00ooooooooooooooooool00?l0
1?ooool01Ol00?oooooooooooooooooo003o01gooooo0_l00?lQooooo`;o003o0oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool0Z?ooool2o`0000oooooo000Oooooo`03
o`000?oooooooooo0;oooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooooooooooo
ooooool00?l07Oooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo00;ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo0:Wooooo00?o0000ooooooooool03Ooo
ool001oooooo00?o0000ooooooooool0_oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go
003oooooooooooooooooo`00o`0Mooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool0
0_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0ZOooool00ol0003o
ooooooooo`0=ooooo`007oooool00ol0003oooooooooo`2oooooo`05o`00ooooooooooooooooool0
0?l01?ooool01Ol00?oooooooooooooooooo003o01gooooo00?o003oooooooooool08?ooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`2Y
ooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo0;oooooo00Go003ooooo
ooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l07Oooool00ol00?oooooooooo
o`0Pooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo0:Wooooo00?o0000ooooooooool03Oooool001oooooo00?o0000ooooooooool0_ooo
ool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`0Mooooo`03
o`00oooooooooooo023ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool0ZOooool00ol0003oooooooooo`0=ooooo`007oooool00ol0003o
ooooooooo`2Looooo`;o003o8Oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooo
ooooooooooooo`00o`0Mooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool00_ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0ZOooool00ol0003ooooooooo
o`0=ooooo`007oooool00ol0003oooooooooo`2Looooo`;o003o8Oooool01Ol00?oooooooooooooo
oooo003o00Cooooo00Go003oooooooooooooooooo`00o`0Mooooo`03o`00oooooooooooo023ooooo
00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool0ZOooool00ol0003oooooooooo`0=ooooo`007oooool3o`0009Oooooo0_l00?l3ooooo`03o`00
oooooooooooo023ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooooooooooooooo
ool00?l07Oooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo00;ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo0:Sooooo0_l0000?ooooo`007oooool00ol0
003oooooooooo`2Gooooo`;o003o0oooool00ol00?ooooooooooo`0Pooooo`05o`00oooooooooooo
ooooool00?l01?ooool01Ol00?oooooooooooooooooo003o01gooooo00?o003oooooooooool08?oo
ool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`2Yooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo09Sooooo00Go
003oooooooooooooooooo`00o`0Rooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oo
oooooooooooooooo003o01gooooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`02oooo
o`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`2Yooooo`03o`000?oooooo
oooo00gooooo000Oooooo`03o`000?oooooooooo09Sooooo00Go003oooooooooooooooooo`00o`0R
ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o01Wooooo
0_l00?l2ooooo`04o`00ooooooooooooooooo`;o003o7Oooool00ol00?ooooooooooo`02ooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`2Yooooo`03o`000?oooooooooo
00gooooo000Oooooo`03o`000?oooooooooo09Sooooo00Go003oooooooooooooooooo`00o`0Roooo
o`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o01Wooooo0_l0
0?l2ooooo`04o`00ooooooooooooooooo`;o003o7Oooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`2Yooooo`03o`000?oooooooooo00go
oooo000Oooooo`03o`000?oooooooooo09Sooooo00Go003oooooooooooooooooo`00o`0Rooooo`05
o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o01Wooooo00Go003o
ooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0ZOooool00ol0003ooooo
ooooo`0=ooooo`007oooool00ol0003oooooooooo`2Hooooo`05o`00ooooooooooooooooool00?l0
8_ooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`0Ioooo
o`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooo
oooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo0:Wooooo00?o
0000ooooooooool03Oooool001oooooo00?o0000ooooooooool0V?ooool01Ol00?oooooooooooooo
oooo003o02;ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool0
0?l06Oooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool06oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`2Y
ooooo`03o`000?oooooooooo00gooooo000Oooooo`?o0000M?ooool2o`00ob;ooooo00Go003ooooo
ooooooooooooo`00o`0Rooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooo
oooooooo003o01Wooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo01_o
oooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool0Z?ooool2o`0000oooooo000Oooooo`03o`000?oooooooooo07Cooooo0_l00?l3ooooo`;o
003o7Oooool01Ol00?oooooooooooooooooo003o02;ooooo00Go003oooooooooooooooooo`00o`04
ooooo`05o`00ooooooooooooooooool00?l06Oooool01Ol00?oooooooooooooooooo003o00Cooooo
00?o003oooooooooool06oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`17ooooo`;o003oH?ooool00ol0003oooooooooo`0=ooooo`00
7oooool00ol0003oooooooooo`1eooooo`04o`00ooooooooooooooooo`;o003o6?ooool2o`00o`?o
oooo00Go003oooooooooooooooooo`00o`0Rooooo`05o`00ooooooooooooooooool00?l01?ooool0
1Ol00?oooooooooooooooooo003o01Wooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00
oooooooooooo01_ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool0@_ooool2o`00o`?ooooo0_l00?mPooooo`03o`000?oooooooooo00go
oooo000Oooooo`03o`000?oooooooooo073ooooo0_l00?l3ooooo`05o`00ooooooooooooooooool0
0?l06Oooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`0Rooooo`05o`00oooooooooooo
ooooool00?l01?ooool01Ol00?oooooooooooooooooo003o01Wooooo00Go003ooooooooooooooooo
o`00o`04ooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool08?ooool2o`00ob3ooooo0_l00?l3ooooo`03
o`00oooooooooooo05oooooo00?o0000ooooooooool03Oooool001oooooo00?o0000ooooooooool0
L?ooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`0Iooooo`03o`00oooooooooooo00;o
oooo00Go003oooooooooooooooooo`00o`03ooooo`;o003o7Oooool01Ol00?oooooooooooooooooo
003o00Cooooo00Go003oooooooooooooooooo`00o`0Iooooo`05o`00ooooooooooooooooool00?l0
1?ooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`04o`00ooooooooooooooooo`;o003o6?ooool2o`00o`?ooooo0_l00?lQoooo
o`05o`00ooooooooooooooooool00?l0HOooool00ol0003oooooooooo`0=ooooo`007oooool00ol0
003oooooooooo`1aooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0G
ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`;o003o7Ooo
ool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`0Iooooo`05
o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00ooooooooooooooooo`;o003o6?oo
ool2o`00o`?ooooo00?o003oooooooooool08?ooool01Ol00?oooooooooooooooooo003o067ooooo
00?o0000ooooooooool03Oooool001Kooooo0_l00007ooooo`03o`000?oooooooooo077ooooo00Go
003oooooooooooooooooo`00o`03ooooo`04o`00ooooooooooooooooo`;o003o5?ooool00ol00?oo
ooooooooo`02ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`0Koooo
o`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o01Wooooo00Go
003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool0
0_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`0Gooooo`05o`00ooooooooooooooooool00?l07Oooool2o`00o`?ooooo00Go003ooooo
ooooooooooooo`00o`1Qooooo`03o`000?oooooooooo00gooooo000Eooooo`04o`000?oooooooooo
o`0000Kooooo00?o0000ooooooooool0LOooool01Ol00?oooooooooooooooooo003o00?ooooo00Co
003ooooooooooooooooo0_l00?lDooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooo
ooooo`00o`04ooooo`03o`00oooooooooooo01_ooooo00Go003oooooooooooooooooo`00o`04oooo
o`05o`00ooooooooooooooooool00?l06Oooool01Ol00?oooooooooooooooooo003o00Cooooo00?o
003oooooooooool06oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01Oooooo00Go003ooooooooooooo
ooooo`00o`0Mooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o067ooooo00?o0000oooo
ooooool03Oooool001Gooooo00Co0000oooooooooooo00001_ooool;o`0000;o003o0_l00002o`00
o`;o00000_l00?l3o`0000;o003o0_l00002o`00o`;o00000_l00?l3o`0000;o003o0_l00002o`00
o`;o00000_l00?l3o`0000;o003o0_l00002o`00o`;o00000_l00?l3o`0000;o003o0_l00002o`00
o`?o00000_l00?l2o`0000;o003o0_l00002o`00o`?o00000_l00?l2o`0000;o003o0_l00002o`00
o`?o000000?o003oo`000?l000000_l000001Ol00?oo0000o`000?l0003o003o00?o00000_l00?l3
o`000005o`00ool0003o0000o`000?l00?l00ol000000ol00?oo0000o`000002o`000005o`00ool0
003o0000o`000?l00?l00ol000000ol00?oo0000o`000002o`000005o`00ool0003o0000o`000?l0
0?l00ol000000ol00?oo0000o`000002o`000005o`00ool0003o0000o`000?l00?l01?l000001Ol0
0?oo0000o`000?l0003o003o00?o000000?o003oo`000?l000000_l000001Ol00?oo0000o`000?l0
003o003o00?o000000?o003oo`000?l000000_l000001Ol00?oo0000o`000?l0003o003o00?o0000
00?o003oo`000?l000000_l000001Ol00?oo0000o`000?l0003o003o00?o000000?o003oo`000?l0
00000_l000001Ol00?oo0000o`000?l0003o003o00?o000000?o003oo`000?l000000_l000001Ol0
0?oo0000o`000?l0003o003o00?o000000?o003oo`000?l000000_l000001Ol00?oo0000o`000?l0
003o003o00Co000000Go003oo`000?l0003o0000o`00o`03o`000003o`00ool0003o000000;o0000
00Go003oo`000?l0003o0000o`00o`03o`000003o`00ool0003o000000;o000000Go003oo`000?l0
003o0000o`00o`03o`000003o`00ool0003o000000;o000000Go003oo`000?l0003o0000o`00o`03
o`000003o`00ool0003o000000;o000000Go003oo`000?l0003o0000o`00o`03o`000003o`00ool0
003o000000;o000000Go003oo`000?l0003o0000o`00o`04o`000005o`00ool0003o0000o`000?l0
0?l00ol000000ol00?oo0000o`000002o`000005o`00ool0003o0000o`000?l00?l00ol000000ol0
0?oo0000o`000002o`000005o`00ool0003o0000o`000?l00?l00ol000001?l00?oo0000o`000?l0
0002o`00o`;o00000_l00?l3o`0000;o003o0_l00002o`00o`;o00000_l00?l3o`0000;o003o0_l0
0002o`00o`?o00000_l00?l2o`0000;o003o0_l00002o`00o`?o00000_l00?l2o`0000;o003o0_l0
0002o`00o`?o00000_l00?l2o`0000;o003o0_l00002o`00o`?o00000_l00?l2o`0000;o003o0_l0
0002o`00o`?o00000_l00?l:o`0000oooooo000Eooooo`04o`000?ooooooooooo`0000Kooooo00?o
0000ooooooooool02?ooool2o`00o`;ooooo0_l00?l2ooooo`;o003o0oooool2o`00o`;ooooo0_l0
0?l2ooooo`;o003o0oooool2o`00o`;ooooo0_l00?l2ooooo`;o003o0oooool2o`00o`;ooooo0_l0
0?l2ooooo`;o003o0oooool2o`00o`;ooooo0_l00?l3ooooo`;o003o0_ooool2o`00o`;ooooo0_l0
0?l3ooooo`;o003o0_ooool2o`00o`;ooooo0_l00?l3ooooo`03o`00oooooooooooo00;ooooo00Go
003oooooooooooooooooo`00o`03ooooo`;o003o5?ooool01Ol00?oooooooooooooooooo003o00Co
oooo00Go003oooooooooooooooooo`00o`0Eooooo`05o`00ooooooooooooooooool00?l01?ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`0Booooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooooooo
ool00?l06Oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo00[ooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l0
1?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool03_ooool2o`00o`;o
oooo0_l00?l3ooooo`;o003o0_ooool2o`00o`;ooooo0_l00?l3ooooo`;o003o0_ooool2o`00o`?o
oooo0_l00?l2ooooo`;o003o0_ooool2o`00o`?ooooo0_l00?l2ooooo`;o003o0_ooool2o`00o`?o
oooo0_l00?l2ooooo`;o003o0_ooool2o`00o`?ooooo0_l00?l2ooooo`;o003o0_ooool2o`00o`?o
oooo0_l00?l9ooooo`03o`000?oooooooooo00gooooo000Eooooo`04o`000?ooooooooooo`0000Ko
oooo00?o0000ooooooooool0Goooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooooooo
ool00?l06Oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00
o`0Eooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00;o
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool03_ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l06Oooool01Ol00?oooooooooo
oooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00[o
oooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o003oooooooooool0K?ooool00ol0003oooooooooo`0=ooooo`005Oooool01?l0
003oooooooooool00006ooooo`03o`000?oooooooooo05oooooo00?o003oooooooooool00_ooool0
1Ol00?oooooooooooooooooo003o01Wooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00
ooooooooooooooooool00?l05Oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04_ooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool00_ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o01Wo
oooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`0?ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooo
oooooooo003o00?ooooo0_l00?m]ooooo`03o`000?oooooooooo00gooooo000Fooooo`;o00001ooo
ool00ol0003oooooooooo`1Oooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`0Iooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o
01Gooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`0>ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`0Iooooo`05o`00oooooooooooo
ooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo0_l00?l@ooooo`05o`00oooo
ooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo0_l00?m]ooooo`03
o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo05oooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`02o`00oaWooooo00Go003oooooooooooooooooo`00o`04ooooo`05
o`00ooooooooooooooooool00?l05Oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04_oo
ool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
01Wooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00ooo
ool2o`00oa3ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool0
0?l0L_ooool00ol0003oooooooooo`0=ooooo`007oooool00ol0003oooooooooo`1Oooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool00_l00?lHooooo`;o003o0oooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00;o003o5Oooool01Ol00?oooooooooooooooooo003o00Co
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool04_ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool00_ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooo
oooooooo003o01Wooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooooooooooooooo
ool00?l05Oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00
o`1booooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo05oooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`0Jooooo`;o003o0oooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo00;o003o5Oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
4_ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool00_ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo
003o01Wooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l0
5Oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`1boooo
o`03o`000?oooooooooo00gooooo000Oooooo`?o0000Goooool01?l00?ooooooooooooooool2o`00
ob7ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Gooooo`05o`00oooooooooooo
ooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool03_ooool00ol00?oooooo
ooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05
o`00ooooooooooooooooool00?l06Oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003o
ooooooooooooooooo`00o`0Dooooo`;o003o0oooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo00;o003oLOooool2o`0000oooooo000Oooooo`03o`000?oooooooooo05oooooo0_l00?l2
ooooo`;o003o8Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01Oooooo00Go003o
ooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01?l00?oooooo
ooooooooool2o`00oaCooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003o
ooooooooooooooooo`00o`0Iooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooo
oooooooooooo003o01Cooooo0_l00?l3ooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool00_l00?mbooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo05oooooo
0_l00?lUooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool05oooool01Ol00?oooooo
oooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00oooooooooooo
ooooo`;o003o5?ooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l06Oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`0I
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0M?ooool00ol0003oooooooooo`0=
ooooo`007oooool00ol0003oooooooooo`26ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool05oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo01Oooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool0
0_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oo
oooooooooooooooo003o01Wooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooooooo
ooooooooool00?l06Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo07Cooooo00?o
0000ooooooooool03Oooool001oooooo00?o0000ooooooooool0Q_ooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo01Oooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`0Looooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00kooooo00?o003ooooooooo
ool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol0
0?oooooooooooooooooo003o01Wooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooo
ooooooooooooool00?l06Oooool2o`00o`;ooooo0_l00?mfooooo`03o`000?oooooooooo00gooooo
000Oooooo`03o`000?oooooooooo08Kooooo0_l00?l2ooooo`;o003o6Oooool01Ol00?oooooooooo
oooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01co
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool03_ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l06Oooool01Ol00?oooooooooo
oooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`0Iooooo`;o003o0_ooool2o`00ogKo
oooo00?o0000ooooooooool03Oooool001oooooo00?o0000ooooooooool0Q_ooool2o`00o`;ooooo
0_l00?lIooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool07?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00;ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`0Iooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o
09Gooooo00?o0000ooooooooool03Oooool001oooooo00?o0000ooooooooool0YOooool01Ol00?oo
oooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo01cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool03_ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l06Oooool01Ol00?oo
oooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`2Eooooo`03o`000?oooooo
oooo00gooooo000Oooooo`?o0000YOooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01cooooo00Go003ooooooooooooooooo
o`00o`03ooooo`04o`00ooooooooooooooooo`;o003o4?ooool00ol00?ooooooooooo`02ooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooo
ooooool00?l06Oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooooooooooooooo
o`00o`2Dooooo`;o00003oooool001oooooo00?o0000ooooooooool0YOooool01Ol00?oooooooooo
oooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01co
oooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00ooooooooooooooooo`;o003o4?ooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo00;o003o6Oooool01Ol00?oooooooooooooooooo003o00Cooooo
00Go003oooooooooooooooooo`00o`2Eooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`00
0?oooooooooo0:Gooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`0Looooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_l00?lIooooo`05o`00oooo
ooooooooooooool00?l01?ooool00ol00?ooooooooooo`02o`00oiGooooo00?o0000ooooooooool0
3Oooool001oooooo00?o0000ooooooooool0YOooool01Ol00?oooooooooooooooooo003o00Cooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01cooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool00_ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0K
ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`02o`00oiGooooo00?o
0000ooooooooool03Oooool001oooooo00?o0000ooooooooool0YOooool01Ol00?oooooooooooooo
oooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01cooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01?ooooo00?o003ooooooooo
ool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`2G
ooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo0:Gooooo00Go003ooooo
ooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`0Looooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Cooooo`;o003o
0oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`0Jooooo`;o003o0oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo09Oo
oooo00?o0000ooooooooool03Oooool001oooooo00?o0000ooooooooool0YOooool01Ol00?oooooo
oooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
01cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01?ooooo0_l00?l3
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo01[ooooo0_l00?l3ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0Uooo
ool00ol0003oooooooooo`0=ooooo`007oooool00ol0003oooooooooo`2Tooooo`;o003o0oooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`0Looooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Hooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01oo
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`2Gooooo`03o`000?oooooooooo00go
oooo000Oooooo`?o0000Y?ooool2o`00o`?ooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool07?ooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool06?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool0U_ooool2o`0000oooooo000Oooooo`03o`000?oooooooooo0:Wooooo00?o003ooooo
ooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool07?ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool06?ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Oooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool0Uoooool00ol0003oooooooooo`0=ooooo`007ooo
ool00ol0003oooooooooo`2Yooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo01cooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo01Sooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool07oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
09Oooooo00?o0000ooooooooool03Oooool001oooooo00?o0000ooooooooool0ZOooool00ol00?oo
ooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Loooo
o`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Hooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01oooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`2Gooooo`03o`000?oooooooooo00gooooo000O
ooooo`03o`000?oooooooooo0:Wooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool07?ooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool06?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool0Uoooool00ol0003oooooooooo`0=ooooo`007oooool00ol0003oooooooooo`2Yooooo`03o`00
oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01co
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01Sooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool07oooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo09Oooooo00?o0000ooooooooool03Oooool0
01Cooooo1Ol00006ooooo`03o`000?oooooooooo0:Wooooo00?o003oooooooooool00_ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool07?ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool06?ooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Oooooo`04o`00ooooooooooooooooo`;o
003oVOooool00ol0003oooooooooo`0=ooooo`005Oooool01?l0003oooooooooool00006ooooo`03
o`000?oooooooooo0:Wooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool07?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool06?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`0Oooooo`04o`00ooooooooooooooooo`;o003oVOooool00ol0003ooooo
ooooo`0=ooooo`005_ooool00ol0003oooooooooo`06ooooo`Co0000Z?ooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Looooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Hooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01oooooo00?o003ooooo
ooooool0VOooool4o`0000oooooo000Gooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0ZOooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`0Looooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0H
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo01oooooo0_l00?nMooooo`03o`000?oooooooooo00gooooo000Dooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`2Yooooo`03o`00oooooooooooo00;ooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01cooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo01Sooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool07oooool2o`00oigooooo00?o0000oooo
ooooool03Oooool001Cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo
0:Wooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool07?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool06?oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`2nooooo`03o`000?oooooooooo00gooooo000Eooooo`?o00001oooool00ol0003ooooooooo
o`2Yooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo01cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01So
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool0__ooool00ol0003oooooooooo`0=ooooo`007oooool00ol0003oooooooooo`2Yooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
01cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01Sooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0__oo
ool00ol0003oooooooooo`0=ooooo`007oooool00ol0003oooooooooo`2Yooooo`03o`00oooooooo
oooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01cooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01Sooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0__ooool00ol0003o
ooooooooo`0=ooooo`007oooool00ol0003oooooooooo`2Yooooo`03o`00oooooooooooo00;ooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01cooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo01Sooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0__ooool00ol0003oooooooooo`0=
ooooo`007oooool00ol0003oooooooooo`2Yooooo`03o`00oooooooooooo00;ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo01cooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo01Sooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool0__ooool00ol0003oooooooooo`0=ooooo`007ooo
ool3o`000:Wooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool07?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool06?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`2mooooo`;o00003oooool001oooooo00?o0000ooooooooool0ZOooool00ol00?oo
ooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Loooo
o`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Hooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo0;kooooo00?o
0000ooooooooool03Oooool001oooooo00?o0000ooooooooool0ZOooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Looooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`0Hooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo0;kooooo00?o0000oooooooo
ool03Oooool001oooooo00?o0000ooooooooool0ZOooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Kooooo`;o003o0oooool01Ol00?oo
oooooooooooooooo003o01[ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool0__ooool00ol0003oooooooooo`0=ooooo`007oooool00ol0
003oooooooooo`2Yooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo01_ooooo0_l00?l3ooooo`04o`00ooooooooooooooooo`;o003o6Ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`2nooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo0:Wooooo00?o
003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
8?ooool01?l00?ooooooooooooooool2o`00oaWooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool0__ooool00ol0003oooooooooo`0=oooo
o`007oooool00ol0003oooooooooo`2Yooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool07?ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`2n
ooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo0:Wooooo00?o003ooooo
ooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool08?ooool0
0ol00?ooooooooooo`0Looooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo0;kooooo00?o0000ooooooooool03Oooool001oooooo0ol0002Y
ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooo
oooooooo023ooooo00?o003oooooooooool07?ooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`2mooooo`;o00003oooool001oooooo00?o
0000ooooooooool0ZOooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0
0oooool2o`00ob7ooooo00?o003oooooooooool07?ooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`2nooooo`03o`000?oooooooooo00go
oooo000Oooooo`03o`000?oooooooooo0:Wooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o00?ooooo0_l00?lQooooo`03o`00oooooooooooo01cooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0__ooool00ol0
003oooooooooo`0=ooooo`007oooool00ol0003oooooooooo`2Yooooo`03o`00oooooooooooo00;o
oooo00Go003oooooooooooooooooo`00o`0Vooooo`03o`00oooooooooooo01cooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0__ooool0
0ol0003oooooooooo`0=ooooo`007oooool00ol0003oooooooooo`2Yooooo`;o003o0oooool01Ol0
0?oooooooooooooooooo003o02Kooooo00?o003oooooooooool07?ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`2nooooo`03o`000?oo
oooooooo00gooooo000Oooooo`03o`000?oooooooooo0:Wooooo0_l00?l3ooooo`05o`00oooooooo
ooooooooool00?l09_ooool00ol00?ooooooooooo`0Looooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo0;kooooo00?o0000ooooooooool0
3Oooool001oooooo00?o0000ooooooooool0[_ooool01Ol00?oooooooooooooooooo003o02Kooooo
00?o003oooooooooool07?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`2nooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`00
0?oooooooooo0:kooooo00Go003oooooooooooooooooo`00o`0Vooooo`03o`00oooooooooooo01co
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool0__ooool00ol0003oooooooooo`0=ooooo`007oooool3o`000:kooooo00Go003ooooooooo
ooooooooo`00o`0Uooooo`;o003o7_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`2mooooo`;o00003oooool001oooooo00?o0000oooo
ooooool0[_ooool01Ol00?oooooooooooooooooo003o02Gooooo0_l00?lNooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo0;kooooo00?o
0000ooooooooool03Oooool001oooooo00?o0000ooooooooool0[_ooool01Ol00?oooooooooooooo
oooo003o04Gooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool0__ooool00ol0003oooooooooo`0=ooooo`007oooool00ol0003ooooooooo
o`2^ooooo`05o`00ooooooooooooooooool00?l0A?ooool2o`00o`?ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`;o003o`?ooool00ol0003oooooooooo`0=ooooo`007oooool00ol0003ooooo
ooooo`2^ooooo`05o`00ooooooooooooooooool00?l0A?ooool2o`00o`?ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`;o003o`?ooool00ol0003oooooooooo`0=ooooo`005_ooool3o`0000Ko
oooo00?o0000ooooooooool0[_ooool01Ol00?oooooooooooooooooo003o04Wooooo00Go003ooooo
ooooooooooooo`00o`35ooooo`03o`000?oooooooooo00gooooo000Gooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0[_ooool01Ol00?oooooooooooooooooo003o04Wooooo00Go003o
ooooooooooooooooo`00o`35ooooo`03o`000?oooooooooo00gooooo000Dooooo`Go00001_ooool0
0ol0003oooooooooo`2^ooooo`05o`00ooooooooooooooooool00?l0BOooool01Ol00?oooooooooo
oooooooo003o0<Gooooo00?o0000ooooooooool03Oooool001Cooooo00Co0000oooooooooooo0000
1oooool4o`000:gooooo00Go003oooooooooooooooooo`00o`19ooooo`05o`00oooooooooooooooo
ool00?l0`_ooool4o`0000oooooo000Eooooo`03o`000?oooooo000000Oooooo00?o0000oooooooo
ool0[_ooool01Ol00?oooooooooooooooooo003o04Wooooo00Go003oooooooooooooooooo`00o`35
ooooo`03o`000?oooooooooo00gooooo000Fooooo`;o00001oooool00ol0003oooooooooo`2^oooo
o`05o`00ooooooooooooooooool00?l0BOooool01Ol00?oooooooooooooooooo003o0<Gooooo00?o
0000ooooooooool03Oooool001Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2^
ooooo`05o`00ooooooooooooooooool00?l0BOooool01Ol00?oooooooooooooooooo003o0<Gooooo
00?o0000ooooooooool03Oooool001oooooo00?o0000ooooooooool0[_ooool01Ol00?oooooooooo
oooooooo003o04Wooooo00Go003oooooooooooooooooo`00o`35ooooo`03o`000?oooooooooo00go
oooo000Oooooo`03o`000?oooooooooo0:kooooo00Go003oooooooooooooooooo`00o`19ooooo`05
o`00ooooooooooooooooool00?l0aOooool00ol0003oooooooooo`0=ooooo`007oooool00ol0003o
ooooooooo`2^ooooo`05o`00ooooooooooooooooool00?l0BOooool01Ol00?oooooooooooooooooo
003o0<Gooooo00?o0000ooooooooool03Oooool001oooooo00?o0000ooooooooool0[_ooool01Ol0
0?oooooooooooooooooo003o04Wooooo00Go003oooooooooooooooooo`00o`35ooooo`03o`000?oo
oooooooo00gooooo000Oooooo`?o0000[_ooool01Ol00?oooooooooooooooooo003o04Wooooo00Go
003oooooooooooooooooo`00o`34ooooo`;o00003oooool001oooooo00?o0000ooooooooool0[Ooo
ool2o`00o`;ooooo0_l00?m9ooooo`05o`00ooooooooooooooooool00?l0aOooool00ol0003ooooo
ooooo`0=ooooo`007oooool00ol0003oooooooooo`2]ooooo`;o003o0_ooool2o`00odWooooo00Go
003oooooooooooooooooo`00o`35ooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oo
oooooooo0?cooooo00Go003oooooooooooooooooo`00o`35ooooo`03o`000?oooooooooo00gooooo
000Oooooo`03o`000?oooooooooo0?cooooo00Go003oooooooooooooooooo`00o`35ooooo`03o`00
0?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo0?cooooo00Go003ooooooooooooooooo
o`00o`35ooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo0?cooooo00Go
003oooooooooooooooooo`00o`35ooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oo
oooooooo0?cooooo00Go003oooooooooooooooooo`00o`35ooooo`03o`000?oooooooooo00gooooo
000Oooooo`?o0000o?ooool01Ol00?oooooooooooooooooo003o0<Cooooo0_l0000?ooooo`007ooo
ool00ol0003oooooooooo`3looooo`05o`00ooooooooooooooooool00?l0aOooool00ol0003ooooo
ooooo`0=ooooo`007oooool00ol0003oooooooooo`3looooo`05o`00ooooooooooooooooool00?l0
aOooool00ol0003oooooooooo`0=ooooo`007oooool00ol0003oooooooooo`3looooo`05o`00oooo
ooooooooooooool00?l0aOooool00ol0003oooooooooo`0=ooooo`007oooool00ol0003ooooooooo
o`3looooo`05o`00ooooooooooooooooool00?l0aOooool00ol0003oooooooooo`0=ooooo`007ooo
ool00ol0003oooooooooo`3kooooo`;o003o0oooool2o`00olCooooo00?o0000ooooooooool03Ooo
ool001oooooo00?o0000ooooooooool0noooool2o`00o`?ooooo0_l00?o4ooooo`03o`000?oooooo
oooo00gooooo000Oooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0E?ooool00ol0
003oooooooooo`1Dooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0E?ooool00ol0
003oooooooooo`1Dooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03Oooool001oo
oooo0ol00008ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`07ooooo`;o00003oooool001ooooooool0003;o`0000oooooo0000\
\>"],
  ImageRangeCache->{{{0, 503}, {167, 0}} -> {-29.8221, -4.73492, 0.229826, \
0.0618204}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Show together", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[GraphicsArray[{{gwa}, {gwb}, {gwc}}], \ 
        ImageSize \[Rule] 504];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.06667 
%%ImageSize: 504 537.6 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0253968 0.952381 [
[ 0 0 0 0 ]
[ 1 1.06667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.06667 L
0 1.06667 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0253968 0.97619 0.342857 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.214286 0.00952381 0.135444 0.0354061 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.21429 -0.0125 -3 -9 ]
[.21429 -0.0125 3 0 ]
[.40476 -0.0125 -6 -9 ]
[.40476 -0.0125 6 0 ]
[.59524 -0.0125 -6 -9 ]
[.59524 -0.0125 6 0 ]
[.78571 -0.0125 -6 -9 ]
[.78571 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .06463 -12 -4.5 ]
[-0.0125 .06463 0 4.5 ]
[-0.0125 .13544 -6 -4.5 ]
[-0.0125 .13544 0 4.5 ]
[-0.0125 .20626 -6 -4.5 ]
[-0.0125 .20626 0 4.5 ]
[-0.0125 .27707 -6 -4.5 ]
[-0.0125 .27707 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .33333 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-20)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(0)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(20)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(40)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(60)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(80)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .06463 m
.00625 .06463 L
s
[(-2)] -0.0125 .06463 1 0 Mshowa
0 .13544 m
.00625 .13544 L
s
[(0)] -0.0125 .13544 1 0 Mshowa
0 .20626 m
.00625 .20626 L
s
[(2)] -0.0125 .20626 1 0 Mshowa
0 .27707 m
.00625 .27707 L
s
[(4)] -0.0125 .27707 1 0 Mshowa
.125 Mabswid
0 .08233 m
.00375 .08233 L
s
0 .10004 m
.00375 .10004 L
s
0 .11774 m
.00375 .11774 L
s
0 .15315 m
.00375 .15315 L
s
0 .17085 m
.00375 .17085 L
s
0 .18855 m
.00375 .18855 L
s
0 .22396 m
.00375 .22396 L
s
0 .24166 m
.00375 .24166 L
s
0 .25937 m
.00375 .25937 L
s
0 .04693 m
.00375 .04693 L
s
0 .02923 m
.00375 .02923 L
s
0 .01152 m
.00375 .01152 L
s
0 .29477 m
.00375 .29477 L
s
0 .31247 m
.00375 .31247 L
s
0 .33018 m
.00375 .33018 L
s
.25 Mabswid
0 0 m
0 .33333 L
s
.02381 .32708 m
.02381 .33333 L
s
.21429 .32708 m
.21429 .33333 L
s
.40476 .32708 m
.40476 .33333 L
s
.59524 .32708 m
.59524 .33333 L
s
.78571 .32708 m
.78571 .33333 L
s
.97619 .32708 m
.97619 .33333 L
s
.125 Mabswid
.07143 .32958 m
.07143 .33333 L
s
.11905 .32958 m
.11905 .33333 L
s
.16667 .32958 m
.16667 .33333 L
s
.2619 .32958 m
.2619 .33333 L
s
.30952 .32958 m
.30952 .33333 L
s
.35714 .32958 m
.35714 .33333 L
s
.45238 .32958 m
.45238 .33333 L
s
.5 .32958 m
.5 .33333 L
s
.54762 .32958 m
.54762 .33333 L
s
.64286 .32958 m
.64286 .33333 L
s
.69048 .32958 m
.69048 .33333 L
s
.7381 .32958 m
.7381 .33333 L
s
.83333 .32958 m
.83333 .33333 L
s
.88095 .32958 m
.88095 .33333 L
s
.92857 .32958 m
.92857 .33333 L
s
.25 Mabswid
0 .33333 m
1 .33333 L
s
.99375 .06463 m
1 .06463 L
s
.99375 .13544 m
1 .13544 L
s
.99375 .20626 m
1 .20626 L
s
.99375 .27707 m
1 .27707 L
s
.125 Mabswid
.99625 .08233 m
1 .08233 L
s
.99625 .10004 m
1 .10004 L
s
.99625 .11774 m
1 .11774 L
s
.99625 .15315 m
1 .15315 L
s
.99625 .17085 m
1 .17085 L
s
.99625 .18855 m
1 .18855 L
s
.99625 .22396 m
1 .22396 L
s
.99625 .24166 m
1 .24166 L
s
.99625 .25937 m
1 .25937 L
s
.99625 .04693 m
1 .04693 L
s
.99625 .02923 m
1 .02923 L
s
.99625 .01152 m
1 .01152 L
s
.99625 .29477 m
1 .29477 L
s
.99625 .31247 m
1 .31247 L
s
.99625 .33018 m
1 .33018 L
s
.25 Mabswid
1 0 m
1 .33333 L
s
0 .13544 m
1 .13544 L
s
0 0 1 r
.5 Mabswid
.02381 .13544 m
.02381 .13544 L
s
.03333 .13544 m
.03333 .13544 L
s
.04286 .13544 m
.04286 .13544 L
s
.05238 .13544 m
.05238 .13544 L
s
.0619 .13544 m
.0619 .13544 L
s
.07143 .13544 m
.07143 .13544 L
s
.08095 .13544 m
.08095 .13544 L
s
.09048 .13544 m
.09048 .13544 L
s
.1 .13544 m
.1 .13544 L
s
.10952 .13544 m
.10952 .13544 L
s
.11905 .13544 m
.11905 .13544 L
s
.12857 .13544 m
.12857 .13544 L
s
.1381 .13544 m
.1381 .13544 L
s
.14762 .13544 m
.14762 .13544 L
s
.15714 .13544 m
.15714 .13544 L
s
.16667 .13544 m
.16667 .13544 L
s
.17619 .13544 m
.17619 .13544 L
s
.18571 .13544 m
.18571 .13544 L
s
.19524 .13544 m
.19524 .13544 L
s
.20476 .13544 m
.20476 .13544 L
s
.21429 .13544 m
.21429 .15527 L
s
.22381 .13544 m
.22381 .1529 L
s
.23333 .13544 m
.23333 .14602 L
s
.24286 .13544 m
.24286 .13578 L
s
.25238 .13544 m
.25238 .12508 L
s
.2619 .13544 m
.2619 .11849 L
s
.27143 .13544 m
.27143 .12043 L
s
.28095 .13544 m
.28095 .13216 L
s
.29048 .13544 m
.29048 .14959 L
s
.3 .13544 m
.3 .16385 L
s
.30952 .13544 m
.30952 .16543 L
s
.31905 .13544 m
.31905 .15012 L
s
.32857 .13544 m
.32857 .12341 L
s
.3381 .13544 m
.3381 .10004 L
s
.34762 .13544 m
.34762 .09774 L
s
.35714 .13544 m
.35714 .12752 L
s
.36667 .13544 m
.36667 .1856 L
s
.37619 .13544 m
.37619 .25193 L
s
.38571 .13544 m
.38571 .29742 L
s
.39524 .13544 m
.39524 .29734 L
s
.40476 .13544 m
.40476 .24449 L
s
.41429 .13544 m
.41429 .15516 L
s
.42381 .13544 m
.42381 .06375 L
s
.43333 .13544 m
.43333 .00794 L
s
.44286 .13544 m
.44286 .01097 L
s
.45238 .13544 m
.45238 .07009 L
s
.4619 .13544 m
.4619 .15713 L
s
.47143 .13544 m
.47143 .23173 L
s
.48095 .13544 m
.48095 .26072 L
s
.49048 .13544 m
.49048 .23435 L
s
.5 .13544 m
.5 .17085 L
s
.50952 .13544 m
.50952 .10717 L
s
.51905 .13544 m
.51905 .08026 L
s
.52857 .13544 m
.52857 .10838 L
s
.5381 .13544 m
.5381 .18175 L
s
.54762 .13544 m
.54762 .26725 L
s
.55714 .13544 m
.55714 .32451 L
s
.56667 .13544 m
.56667 .3254 L
s
.57619 .13544 m
.57619 .26717 L
s
.58571 .13544 m
.58571 .17311 L
s
.59524 .13544 m
.59524 .08092 L
s
.60476 .13544 m
.60476 .02504 L
s
.61429 .13544 m
.61429 .02178 L
s
.62381 .13544 m
.62381 .06397 L
s
.63333 .13544 m
.63333 .12693 L
s
.64286 .13544 m
.64286 .1816 L
s
.65238 .13544 m
.65238 .20798 L
s
.6619 .13544 m
.6619 .20231 L
s
.67143 .13544 m
.67143 .17565 L
s
.68095 .13544 m
.68095 .14575 L
s
.69048 .13544 m
.69048 .12741 L
s
.7 .13544 m
.7 .12613 L
s
.70952 .13544 m
.70952 .13774 L
s
.71905 .13544 m
.71905 .15276 L
s
.72857 .13544 m
.72857 .16235 L
s
.7381 .13544 m
.7381 .16243 L
s
.74762 .13544 m
.74762 .15429 L
s
.75714 .13544 m
.75714 .14237 L
s
.76667 .13544 m
.76667 .13124 L
s
.77619 .13544 m
.77619 .12383 L
s
.78571 .13544 m
.78571 .12128 L
s
.79524 .13544 m
.79524 .13544 L
s
.80476 .13544 m
.80476 .13544 L
s
.81429 .13544 m
.81429 .13544 L
s
.82381 .13544 m
.82381 .13544 L
s
.83333 .13544 m
.83333 .13544 L
s
.84286 .13544 m
.84286 .13544 L
s
.85238 .13544 m
.85238 .13544 L
s
.8619 .13544 m
.8619 .13544 L
s
.87143 .13544 m
.87143 .13544 L
s
.88095 .13544 m
.88095 .13544 L
s
.89048 .13544 m
.89048 .13544 L
s
.9 .13544 m
.9 .13544 L
s
.90952 .13544 m
.90952 .13544 L
s
.91905 .13544 m
.91905 .13544 L
s
.92857 .13544 m
.92857 .13544 L
s
.9381 .13544 m
.9381 .13544 L
s
.94762 .13544 m
.94762 .13544 L
s
.95714 .13544 m
.95714 .13544 L
s
.96667 .13544 m
.96667 .13544 L
s
.97619 .13544 m
.97619 .13544 L
s
.005 w
.02381 .13544 Mdot
.03333 .13544 Mdot
.04286 .13544 Mdot
.05238 .13544 Mdot
.0619 .13544 Mdot
.07143 .13544 Mdot
.08095 .13544 Mdot
.09048 .13544 Mdot
.1 .13544 Mdot
.10952 .13544 Mdot
.11905 .13544 Mdot
.12857 .13544 Mdot
.1381 .13544 Mdot
.14762 .13544 Mdot
.15714 .13544 Mdot
.16667 .13544 Mdot
.17619 .13544 Mdot
.18571 .13544 Mdot
.19524 .13544 Mdot
.20476 .13544 Mdot
.21429 .15527 Mdot
.22381 .1529 Mdot
.23333 .14602 Mdot
.24286 .13578 Mdot
.25238 .12508 Mdot
.2619 .11849 Mdot
.27143 .12043 Mdot
.28095 .13216 Mdot
.29048 .14959 Mdot
.3 .16385 Mdot
.30952 .16543 Mdot
.31905 .15012 Mdot
.32857 .12341 Mdot
.3381 .10004 Mdot
.34762 .09774 Mdot
.35714 .12752 Mdot
.36667 .1856 Mdot
.37619 .25193 Mdot
.38571 .29742 Mdot
.39524 .29734 Mdot
.40476 .24449 Mdot
.41429 .15516 Mdot
.42381 .06375 Mdot
.43333 .00794 Mdot
.44286 .01097 Mdot
.45238 .07009 Mdot
.4619 .15713 Mdot
.47143 .23173 Mdot
.48095 .26072 Mdot
.49048 .23435 Mdot
.5 .17085 Mdot
.50952 .10717 Mdot
.51905 .08026 Mdot
.52857 .10838 Mdot
.5381 .18175 Mdot
.54762 .26725 Mdot
.55714 .32451 Mdot
.56667 .3254 Mdot
.57619 .26717 Mdot
.58571 .17311 Mdot
.59524 .08092 Mdot
.60476 .02504 Mdot
.61429 .02178 Mdot
.62381 .06397 Mdot
.63333 .12693 Mdot
.64286 .1816 Mdot
.65238 .20798 Mdot
.6619 .20231 Mdot
.67143 .17565 Mdot
.68095 .14575 Mdot
.69048 .12741 Mdot
.7 .12613 Mdot
.70952 .13774 Mdot
.71905 .15276 Mdot
.72857 .16235 Mdot
.7381 .16243 Mdot
.74762 .15429 Mdot
.75714 .14237 Mdot
.76667 .13124 Mdot
.77619 .12383 Mdot
.78571 .12128 Mdot
.79524 .13544 Mdot
.80476 .13544 Mdot
.81429 .13544 Mdot
.82381 .13544 Mdot
.83333 .13544 Mdot
.84286 .13544 Mdot
.85238 .13544 Mdot
.8619 .13544 Mdot
.87143 .13544 Mdot
.88095 .13544 Mdot
.89048 .13544 Mdot
.9 .13544 Mdot
.90952 .13544 Mdot
.91905 .13544 Mdot
.92857 .13544 Mdot
.9381 .13544 Mdot
.94762 .13544 Mdot
.95714 .13544 Mdot
.96667 .13544 Mdot
.97619 .13544 Mdot
0 0 m
1 0 L
1 .33333 L
0 .33333 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.374603 0.97619 0.692063 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.214286 0.00952381 0.00793651 0.31746 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.21429 -0.0125 -3 -9 ]
[.21429 -0.0125 3 0 ]
[.40476 -0.0125 -6 -9 ]
[.40476 -0.0125 6 0 ]
[.59524 -0.0125 -6 -9 ]
[.59524 -0.0125 6 0 ]
[.78571 -0.0125 -6 -9 ]
[.78571 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00794 -6 -4.5 ]
[-0.0125 .00794 0 4.5 ]
[-0.0125 .07143 -18 -4.5 ]
[-0.0125 .07143 0 4.5 ]
[-0.0125 .13492 -18 -4.5 ]
[-0.0125 .13492 0 4.5 ]
[-0.0125 .19841 -18 -4.5 ]
[-0.0125 .19841 0 4.5 ]
[-0.0125 .2619 -18 -4.5 ]
[-0.0125 .2619 0 4.5 ]
[-0.0125 .3254 -6 -4.5 ]
[-0.0125 .3254 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .33333 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-20)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(0)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(20)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(40)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(60)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(80)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00794 m
.00625 .00794 L
s
[(0)] -0.0125 .00794 1 0 Mshowa
0 .07143 m
.00625 .07143 L
s
[(0.2)] -0.0125 .07143 1 0 Mshowa
0 .13492 m
.00625 .13492 L
s
[(0.4)] -0.0125 .13492 1 0 Mshowa
0 .19841 m
.00625 .19841 L
s
[(0.6)] -0.0125 .19841 1 0 Mshowa
0 .2619 m
.00625 .2619 L
s
[(0.8)] -0.0125 .2619 1 0 Mshowa
0 .3254 m
.00625 .3254 L
s
[(1)] -0.0125 .3254 1 0 Mshowa
.125 Mabswid
0 .02381 m
.00375 .02381 L
s
0 .03968 m
.00375 .03968 L
s
0 .05556 m
.00375 .05556 L
s
0 .0873 m
.00375 .0873 L
s
0 .10317 m
.00375 .10317 L
s
0 .11905 m
.00375 .11905 L
s
0 .15079 m
.00375 .15079 L
s
0 .16667 m
.00375 .16667 L
s
0 .18254 m
.00375 .18254 L
s
0 .21429 m
.00375 .21429 L
s
0 .23016 m
.00375 .23016 L
s
0 .24603 m
.00375 .24603 L
s
0 .27778 m
.00375 .27778 L
s
0 .29365 m
.00375 .29365 L
s
0 .30952 m
.00375 .30952 L
s
.25 Mabswid
0 0 m
0 .33333 L
s
.02381 .32708 m
.02381 .33333 L
s
.21429 .32708 m
.21429 .33333 L
s
.40476 .32708 m
.40476 .33333 L
s
.59524 .32708 m
.59524 .33333 L
s
.78571 .32708 m
.78571 .33333 L
s
.97619 .32708 m
.97619 .33333 L
s
.125 Mabswid
.07143 .32958 m
.07143 .33333 L
s
.11905 .32958 m
.11905 .33333 L
s
.16667 .32958 m
.16667 .33333 L
s
.2619 .32958 m
.2619 .33333 L
s
.30952 .32958 m
.30952 .33333 L
s
.35714 .32958 m
.35714 .33333 L
s
.45238 .32958 m
.45238 .33333 L
s
.5 .32958 m
.5 .33333 L
s
.54762 .32958 m
.54762 .33333 L
s
.64286 .32958 m
.64286 .33333 L
s
.69048 .32958 m
.69048 .33333 L
s
.7381 .32958 m
.7381 .33333 L
s
.83333 .32958 m
.83333 .33333 L
s
.88095 .32958 m
.88095 .33333 L
s
.92857 .32958 m
.92857 .33333 L
s
.25 Mabswid
0 .33333 m
1 .33333 L
s
.99375 .00794 m
1 .00794 L
s
.99375 .07143 m
1 .07143 L
s
.99375 .13492 m
1 .13492 L
s
.99375 .19841 m
1 .19841 L
s
.99375 .2619 m
1 .2619 L
s
.99375 .3254 m
1 .3254 L
s
.125 Mabswid
.99625 .02381 m
1 .02381 L
s
.99625 .03968 m
1 .03968 L
s
.99625 .05556 m
1 .05556 L
s
.99625 .0873 m
1 .0873 L
s
.99625 .10317 m
1 .10317 L
s
.99625 .11905 m
1 .11905 L
s
.99625 .15079 m
1 .15079 L
s
.99625 .16667 m
1 .16667 L
s
.99625 .18254 m
1 .18254 L
s
.99625 .21429 m
1 .21429 L
s
.99625 .23016 m
1 .23016 L
s
.99625 .24603 m
1 .24603 L
s
.99625 .27778 m
1 .27778 L
s
.99625 .29365 m
1 .29365 L
s
.99625 .30952 m
1 .30952 L
s
.25 Mabswid
1 0 m
1 .33333 L
s
0 .00794 m
1 .00794 L
s
0 0 1 r
.5 Mabswid
.02381 .00794 m
.02381 .00794 L
s
.03333 .00794 m
.03333 .00794 L
s
.04286 .00794 m
.04286 .00794 L
s
.05238 .00794 m
.05238 .00794 L
s
.0619 .00794 m
.0619 .00794 L
s
.07143 .00794 m
.07143 .00794 L
s
.08095 .00794 m
.08095 .00794 L
s
.09048 .00794 m
.09048 .00794 L
s
.1 .00794 m
.1 .00794 L
s
.10952 .00794 m
.10952 .00794 L
s
.11905 .00794 m
.11905 .00794 L
s
.12857 .00794 m
.12857 .00794 L
s
.1381 .00794 m
.1381 .00794 L
s
.14762 .00794 m
.14762 .00794 L
s
.15714 .00794 m
.15714 .00794 L
s
.16667 .00794 m
.16667 .00794 L
s
.17619 .00794 m
.17619 .00794 L
s
.18571 .00794 m
.18571 .00794 L
s
.19524 .00794 m
.19524 .00794 L
s
.20476 .00794 m
.20476 .00794 L
s
.21429 .00794 m
.21429 .03333 L
s
.22381 .00794 m
.22381 .03413 L
s
.23333 .00794 m
.23333 .03652 L
s
.24286 .00794 m
.24286 .04048 L
s
.25238 .00794 m
.25238 .04596 L
s
.2619 .00794 m
.2619 .0529 L
s
.27143 .00794 m
.27143 .06122 L
s
.28095 .00794 m
.28095 .07084 L
s
.29048 .00794 m
.29048 .08165 L
s
.3 .00794 m
.3 .09353 L
s
.30952 .00794 m
.30952 .10635 L
s
.31905 .00794 m
.31905 .11997 L
s
.32857 .00794 m
.32857 .13424 L
s
.3381 .00794 m
.3381 .149 L
s
.34762 .00794 m
.34762 .1641 L
s
.35714 .00794 m
.35714 .17937 L
s
.36667 .00794 m
.36667 .19463 L
s
.37619 .00794 m
.37619 .20973 L
s
.38571 .00794 m
.38571 .22449 L
s
.39524 .00794 m
.39524 .23876 L
s
.40476 .00794 m
.40476 .25238 L
s
.41429 .00794 m
.41429 .2652 L
s
.42381 .00794 m
.42381 .27708 L
s
.43333 .00794 m
.43333 .28789 L
s
.44286 .00794 m
.44286 .29751 L
s
.45238 .00794 m
.45238 .30583 L
s
.4619 .00794 m
.4619 .31277 L
s
.47143 .00794 m
.47143 .31825 L
s
.48095 .00794 m
.48095 .32221 L
s
.49048 .00794 m
.49048 .3246 L
s
.5 .00794 m
.5 .3254 L
s
.50952 .00794 m
.50952 .3246 L
s
.51905 .00794 m
.51905 .32221 L
s
.52857 .00794 m
.52857 .31825 L
s
.5381 .00794 m
.5381 .31277 L
s
.54762 .00794 m
.54762 .30583 L
s
.55714 .00794 m
.55714 .29751 L
s
.56667 .00794 m
.56667 .28789 L
s
.57619 .00794 m
.57619 .27708 L
s
.58571 .00794 m
.58571 .2652 L
s
.59524 .00794 m
.59524 .25238 L
s
.60476 .00794 m
.60476 .23876 L
s
.61429 .00794 m
.61429 .22449 L
s
.62381 .00794 m
.62381 .20973 L
s
.63333 .00794 m
.63333 .19463 L
s
.64286 .00794 m
.64286 .17937 L
s
.65238 .00794 m
.65238 .1641 L
s
.6619 .00794 m
.6619 .149 L
s
.67143 .00794 m
.67143 .13424 L
s
.68095 .00794 m
.68095 .11997 L
s
.69048 .00794 m
.69048 .10635 L
s
.7 .00794 m
.7 .09353 L
s
.70952 .00794 m
.70952 .08165 L
s
.71905 .00794 m
.71905 .07084 L
s
.72857 .00794 m
.72857 .06122 L
s
.7381 .00794 m
.7381 .0529 L
s
.74762 .00794 m
.74762 .04596 L
s
.75714 .00794 m
.75714 .04048 L
s
.76667 .00794 m
.76667 .03652 L
s
.77619 .00794 m
.77619 .03413 L
s
.78571 .00794 m
.78571 .03333 L
s
.79524 .00794 m
.79524 .00794 L
s
.80476 .00794 m
.80476 .00794 L
s
.81429 .00794 m
.81429 .00794 L
s
.82381 .00794 m
.82381 .00794 L
s
.83333 .00794 m
.83333 .00794 L
s
.84286 .00794 m
.84286 .00794 L
s
.85238 .00794 m
.85238 .00794 L
s
.8619 .00794 m
.8619 .00794 L
s
.87143 .00794 m
.87143 .00794 L
s
.88095 .00794 m
.88095 .00794 L
s
.89048 .00794 m
.89048 .00794 L
s
.9 .00794 m
.9 .00794 L
s
.90952 .00794 m
.90952 .00794 L
s
.91905 .00794 m
.91905 .00794 L
s
.92857 .00794 m
.92857 .00794 L
s
.9381 .00794 m
.9381 .00794 L
s
.94762 .00794 m
.94762 .00794 L
s
.95714 .00794 m
.95714 .00794 L
s
.96667 .00794 m
.96667 .00794 L
s
.97619 .00794 m
.97619 .00794 L
s
.005 w
.02381 .00794 Mdot
.03333 .00794 Mdot
.04286 .00794 Mdot
.05238 .00794 Mdot
.0619 .00794 Mdot
.07143 .00794 Mdot
.08095 .00794 Mdot
.09048 .00794 Mdot
.1 .00794 Mdot
.10952 .00794 Mdot
.11905 .00794 Mdot
.12857 .00794 Mdot
.1381 .00794 Mdot
.14762 .00794 Mdot
.15714 .00794 Mdot
.16667 .00794 Mdot
.17619 .00794 Mdot
.18571 .00794 Mdot
.19524 .00794 Mdot
.20476 .00794 Mdot
.21429 .03333 Mdot
.22381 .03413 Mdot
.23333 .03652 Mdot
.24286 .04048 Mdot
.25238 .04596 Mdot
.2619 .0529 Mdot
.27143 .06122 Mdot
.28095 .07084 Mdot
.29048 .08165 Mdot
.3 .09353 Mdot
.30952 .10635 Mdot
.31905 .11997 Mdot
.32857 .13424 Mdot
.3381 .149 Mdot
.34762 .1641 Mdot
.35714 .17937 Mdot
.36667 .19463 Mdot
.37619 .20973 Mdot
.38571 .22449 Mdot
.39524 .23876 Mdot
.40476 .25238 Mdot
.41429 .2652 Mdot
.42381 .27708 Mdot
.43333 .28789 Mdot
.44286 .29751 Mdot
.45238 .30583 Mdot
.4619 .31277 Mdot
.47143 .31825 Mdot
.48095 .32221 Mdot
.49048 .3246 Mdot
.5 .3254 Mdot
.50952 .3246 Mdot
.51905 .32221 Mdot
.52857 .31825 Mdot
.5381 .31277 Mdot
.54762 .30583 Mdot
.55714 .29751 Mdot
.56667 .28789 Mdot
.57619 .27708 Mdot
.58571 .2652 Mdot
.59524 .25238 Mdot
.60476 .23876 Mdot
.61429 .22449 Mdot
.62381 .20973 Mdot
.63333 .19463 Mdot
.64286 .17937 Mdot
.65238 .1641 Mdot
.6619 .149 Mdot
.67143 .13424 Mdot
.68095 .11997 Mdot
.69048 .10635 Mdot
.7 .09353 Mdot
.70952 .08165 Mdot
.71905 .07084 Mdot
.72857 .06122 Mdot
.7381 .0529 Mdot
.74762 .04596 Mdot
.75714 .04048 Mdot
.76667 .03652 Mdot
.77619 .03413 Mdot
.78571 .03333 Mdot
.79524 .00794 Mdot
.80476 .00794 Mdot
.81429 .00794 Mdot
.82381 .00794 Mdot
.83333 .00794 Mdot
.84286 .00794 Mdot
.85238 .00794 Mdot
.8619 .00794 Mdot
.87143 .00794 Mdot
.88095 .00794 Mdot
.89048 .00794 Mdot
.9 .00794 Mdot
.90952 .00794 Mdot
.91905 .00794 Mdot
.92857 .00794 Mdot
.9381 .00794 Mdot
.94762 .00794 Mdot
.95714 .00794 Mdot
.96667 .00794 Mdot
.97619 .00794 Mdot
0 0 m
1 0 L
1 .33333 L
0 .33333 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.72381 0.97619 1.04127 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.214286 0.00952381 0.140212 0.026455 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.21429 -0.0125 -3 -9 ]
[.21429 -0.0125 3 0 ]
[.40476 -0.0125 -6 -9 ]
[.40476 -0.0125 6 0 ]
[.59524 -0.0125 -6 -9 ]
[.59524 -0.0125 6 0 ]
[.78571 -0.0125 -6 -9 ]
[.78571 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .03439 -12 -4.5 ]
[-0.0125 .03439 0 4.5 ]
[-0.0125 .0873 -12 -4.5 ]
[-0.0125 .0873 0 4.5 ]
[-0.0125 .14021 -6 -4.5 ]
[-0.0125 .14021 0 4.5 ]
[-0.0125 .19312 -6 -4.5 ]
[-0.0125 .19312 0 4.5 ]
[-0.0125 .24603 -6 -4.5 ]
[-0.0125 .24603 0 4.5 ]
[-0.0125 .29894 -6 -4.5 ]
[-0.0125 .29894 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .33333 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-20)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(0)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(20)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(40)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(60)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(80)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .03439 m
.00625 .03439 L
s
[(-4)] -0.0125 .03439 1 0 Mshowa
0 .0873 m
.00625 .0873 L
s
[(-2)] -0.0125 .0873 1 0 Mshowa
0 .14021 m
.00625 .14021 L
s
[(0)] -0.0125 .14021 1 0 Mshowa
0 .19312 m
.00625 .19312 L
s
[(2)] -0.0125 .19312 1 0 Mshowa
0 .24603 m
.00625 .24603 L
s
[(4)] -0.0125 .24603 1 0 Mshowa
0 .29894 m
.00625 .29894 L
s
[(6)] -0.0125 .29894 1 0 Mshowa
.125 Mabswid
0 .04762 m
.00375 .04762 L
s
0 .06085 m
.00375 .06085 L
s
0 .07407 m
.00375 .07407 L
s
0 .10053 m
.00375 .10053 L
s
0 .11376 m
.00375 .11376 L
s
0 .12698 m
.00375 .12698 L
s
0 .15344 m
.00375 .15344 L
s
0 .16667 m
.00375 .16667 L
s
0 .17989 m
.00375 .17989 L
s
0 .20635 m
.00375 .20635 L
s
0 .21958 m
.00375 .21958 L
s
0 .2328 m
.00375 .2328 L
s
0 .25926 m
.00375 .25926 L
s
0 .27249 m
.00375 .27249 L
s
0 .28571 m
.00375 .28571 L
s
0 .02116 m
.00375 .02116 L
s
0 .00794 m
.00375 .00794 L
s
0 .31217 m
.00375 .31217 L
s
0 .3254 m
.00375 .3254 L
s
.25 Mabswid
0 0 m
0 .33333 L
s
.02381 .32708 m
.02381 .33333 L
s
.21429 .32708 m
.21429 .33333 L
s
.40476 .32708 m
.40476 .33333 L
s
.59524 .32708 m
.59524 .33333 L
s
.78571 .32708 m
.78571 .33333 L
s
.97619 .32708 m
.97619 .33333 L
s
.125 Mabswid
.07143 .32958 m
.07143 .33333 L
s
.11905 .32958 m
.11905 .33333 L
s
.16667 .32958 m
.16667 .33333 L
s
.2619 .32958 m
.2619 .33333 L
s
.30952 .32958 m
.30952 .33333 L
s
.35714 .32958 m
.35714 .33333 L
s
.45238 .32958 m
.45238 .33333 L
s
.5 .32958 m
.5 .33333 L
s
.54762 .32958 m
.54762 .33333 L
s
.64286 .32958 m
.64286 .33333 L
s
.69048 .32958 m
.69048 .33333 L
s
.7381 .32958 m
.7381 .33333 L
s
.83333 .32958 m
.83333 .33333 L
s
.88095 .32958 m
.88095 .33333 L
s
.92857 .32958 m
.92857 .33333 L
s
.25 Mabswid
0 .33333 m
1 .33333 L
s
.99375 .03439 m
1 .03439 L
s
.99375 .0873 m
1 .0873 L
s
.99375 .14021 m
1 .14021 L
s
.99375 .19312 m
1 .19312 L
s
.99375 .24603 m
1 .24603 L
s
.99375 .29894 m
1 .29894 L
s
.125 Mabswid
.99625 .04762 m
1 .04762 L
s
.99625 .06085 m
1 .06085 L
s
.99625 .07407 m
1 .07407 L
s
.99625 .10053 m
1 .10053 L
s
.99625 .11376 m
1 .11376 L
s
.99625 .12698 m
1 .12698 L
s
.99625 .15344 m
1 .15344 L
s
.99625 .16667 m
1 .16667 L
s
.99625 .17989 m
1 .17989 L
s
.99625 .20635 m
1 .20635 L
s
.99625 .21958 m
1 .21958 L
s
.99625 .2328 m
1 .2328 L
s
.99625 .25926 m
1 .25926 L
s
.99625 .27249 m
1 .27249 L
s
.99625 .28571 m
1 .28571 L
s
.99625 .02116 m
1 .02116 L
s
.99625 .00794 m
1 .00794 L
s
.99625 .31217 m
1 .31217 L
s
.99625 .3254 m
1 .3254 L
s
.25 Mabswid
1 0 m
1 .33333 L
s
0 .14021 m
1 .14021 L
s
0 0 1 r
.5 Mabswid
.02381 .14021 m
.02381 .14021 L
s
.03333 .14021 m
.03333 .14021 L
s
.04286 .14021 m
.04286 .14021 L
s
.05238 .14021 m
.05238 .14021 L
s
.0619 .14021 m
.0619 .14021 L
s
.07143 .14021 m
.07143 .14021 L
s
.08095 .14021 m
.08095 .14021 L
s
.09048 .14021 m
.09048 .14021 L
s
.1 .14021 m
.1 .14021 L
s
.10952 .14021 m
.10952 .14021 L
s
.11905 .14021 m
.11905 .14021 L
s
.12857 .14021 m
.12857 .14021 L
s
.1381 .14021 m
.1381 .14021 L
s
.14762 .14021 m
.14762 .14021 L
s
.15714 .14021 m
.15714 .14021 L
s
.16667 .14021 m
.16667 .14021 L
s
.17619 .14021 m
.17619 .14021 L
s
.18571 .14021 m
.18571 .14021 L
s
.19524 .14021 m
.19524 .14021 L
s
.20476 .14021 m
.20476 .14021 L
s
.21429 .14021 m
.21429 .3254 L
s
.22381 .14021 m
.22381 .2983 L
s
.23333 .14021 m
.23333 .22799 L
s
.24286 .14021 m
.24286 .14265 L
s
.25238 .14021 m
.25238 .07553 L
s
.2619 .14021 m
.2619 .05076 L
s
.27143 .14021 m
.27143 .07337 L
s
.28095 .14021 m
.28095 .12783 L
s
.29048 .14021 m
.29048 .18572 L
s
.3 .14021 m
.3 .21893 L
s
.30952 .14021 m
.30952 .21249 L
s
.31905 .14021 m
.31905 .17129 L
s
.32857 .14021 m
.32857 .11762 L
s
.3381 .14021 m
.3381 .08069 L
s
.34762 .14021 m
.34762 .08295 L
s
.35714 .14021 m
.35714 .12925 L
s
.36667 .14021 m
.36667 .20394 L
s
.37619 .14021 m
.37619 .27714 L
s
.38571 .14021 m
.38571 .31763 L
s
.39524 .14021 m
.39524 .30658 L
s
.40476 .14021 m
.40476 .24603 L
s
.41429 .14021 m
.41429 .15839 L
s
.42381 .14021 m
.42381 .07703 L
s
.43333 .14021 m
.43333 .03217 L
s
.44286 .14021 m
.44286 .03825 L
s
.45238 .14021 m
.45238 .08817 L
s
.4619 .14021 m
.4619 .15709 L
s
.47143 .14021 m
.47143 .21381 L
s
.48095 .14021 m
.48095 .23477 L
s
.49048 .14021 m
.49048 .2143 L
s
.5 .14021 m
.5 .16667 L
s
.50952 .14021 m
.50952 .11903 L
s
.51905 .14021 m
.51905 .09856 L
s
.52857 .14021 m
.52857 .11952 L
s
.5381 .14021 m
.5381 .17625 L
s
.54762 .14021 m
.54762 .24516 L
s
.55714 .14021 m
.55714 .29508 L
s
.56667 .14021 m
.56667 .30116 L
s
.57619 .14021 m
.57619 .25631 L
s
.58571 .14021 m
.58571 .17494 L
s
.59524 .14021 m
.59524 .0873 L
s
.60476 .14021 m
.60476 .02676 L
s
.61429 .14021 m
.61429 .01571 L
s
.62381 .14021 m
.62381 .0562 L
s
.63333 .14021 m
.63333 .12939 L
s
.64286 .14021 m
.64286 .20408 L
s
.65238 .14021 m
.65238 .25039 L
s
.6619 .14021 m
.6619 .25265 L
s
.67143 .14021 m
.67143 .21572 L
s
.68095 .14021 m
.68095 .16204 L
s
.69048 .14021 m
.69048 .12085 L
s
.7 .14021 m
.7 .11441 L
s
.70952 .14021 m
.70952 .14761 L
s
.71905 .14021 m
.71905 .2055 L
s
.72857 .14021 m
.72857 .25997 L
s
.7381 .14021 m
.7381 .28258 L
s
.74762 .14021 m
.74762 .25781 L
s
.75714 .14021 m
.75714 .19069 L
s
.76667 .14021 m
.76667 .10535 L
s
.77619 .14021 m
.77619 .03503 L
s
.78571 .14021 m
.78571 .00794 L
s
.79524 .14021 m
.79524 .14021 L
s
.80476 .14021 m
.80476 .14021 L
s
.81429 .14021 m
.81429 .14021 L
s
.82381 .14021 m
.82381 .14021 L
s
.83333 .14021 m
.83333 .14021 L
s
.84286 .14021 m
.84286 .14021 L
s
.85238 .14021 m
.85238 .14021 L
s
.8619 .14021 m
.8619 .14021 L
s
.87143 .14021 m
.87143 .14021 L
s
.88095 .14021 m
.88095 .14021 L
s
.89048 .14021 m
.89048 .14021 L
s
.9 .14021 m
.9 .14021 L
s
.90952 .14021 m
.90952 .14021 L
s
.91905 .14021 m
.91905 .14021 L
s
.92857 .14021 m
.92857 .14021 L
s
.9381 .14021 m
.9381 .14021 L
s
.94762 .14021 m
.94762 .14021 L
s
.95714 .14021 m
.95714 .14021 L
s
.96667 .14021 m
.96667 .14021 L
s
.97619 .14021 m
.97619 .14021 L
s
.005 w
.02381 .14021 Mdot
.03333 .14021 Mdot
.04286 .14021 Mdot
.05238 .14021 Mdot
.0619 .14021 Mdot
.07143 .14021 Mdot
.08095 .14021 Mdot
.09048 .14021 Mdot
.1 .14021 Mdot
.10952 .14021 Mdot
.11905 .14021 Mdot
.12857 .14021 Mdot
.1381 .14021 Mdot
.14762 .14021 Mdot
.15714 .14021 Mdot
.16667 .14021 Mdot
.17619 .14021 Mdot
.18571 .14021 Mdot
.19524 .14021 Mdot
.20476 .14021 Mdot
.21429 .3254 Mdot
.22381 .2983 Mdot
.23333 .22799 Mdot
.24286 .14265 Mdot
.25238 .07553 Mdot
.2619 .05076 Mdot
.27143 .07337 Mdot
.28095 .12783 Mdot
.29048 .18572 Mdot
.3 .21893 Mdot
.30952 .21249 Mdot
.31905 .17129 Mdot
.32857 .11762 Mdot
.3381 .08069 Mdot
.34762 .08295 Mdot
.35714 .12925 Mdot
.36667 .20394 Mdot
.37619 .27714 Mdot
.38571 .31763 Mdot
.39524 .30658 Mdot
.40476 .24603 Mdot
.41429 .15839 Mdot
.42381 .07703 Mdot
.43333 .03217 Mdot
.44286 .03825 Mdot
.45238 .08817 Mdot
.4619 .15709 Mdot
.47143 .21381 Mdot
.48095 .23477 Mdot
.49048 .2143 Mdot
.5 .16667 Mdot
.50952 .11903 Mdot
.51905 .09856 Mdot
.52857 .11952 Mdot
.5381 .17625 Mdot
.54762 .24516 Mdot
.55714 .29508 Mdot
.56667 .30116 Mdot
.57619 .25631 Mdot
.58571 .17494 Mdot
.59524 .0873 Mdot
.60476 .02676 Mdot
.61429 .01571 Mdot
.62381 .0562 Mdot
.63333 .12939 Mdot
.64286 .20408 Mdot
.65238 .25039 Mdot
.6619 .25265 Mdot
.67143 .21572 Mdot
.68095 .16204 Mdot
.69048 .12085 Mdot
.7 .11441 Mdot
.70952 .14761 Mdot
.71905 .2055 Mdot
.72857 .25997 Mdot
.7381 .28258 Mdot
.74762 .25781 Mdot
.75714 .19069 Mdot
.76667 .10535 Mdot
.77619 .03503 Mdot
.78571 .00794 Mdot
.79524 .14021 Mdot
.80476 .14021 Mdot
.81429 .14021 Mdot
.82381 .14021 Mdot
.83333 .14021 Mdot
.84286 .14021 Mdot
.85238 .14021 Mdot
.8619 .14021 Mdot
.87143 .14021 Mdot
.88095 .14021 Mdot
.89048 .14021 Mdot
.9 .14021 Mdot
.90952 .14021 Mdot
.91905 .14021 Mdot
.92857 .14021 Mdot
.9381 .14021 Mdot
.94762 .14021 Mdot
.95714 .14021 Mdot
.96667 .14021 Mdot
.97619 .14021 Mdot
0 0 m
1 0 L
1 .33333 L
0 .33333 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{504, 537.562},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007h00026B000`400?l00000o`00003ooooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00<Oooool5o`0000?ooooo0_l0
001;ooooo`;o0000C?ooool5o`0000?ooooo0_l0001;ooooo`?o00000oooool2o`0004[ooooo0ol0
0004ooooo`;o0000B_ooool3o`0000Cooooo0_l0000Qooooo`00<_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0004Wooooo00Co0000oooooooooooo0000C?ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0004_ooooo00Go0000ooooooooooooooooo`00
0002ooooo`03o`000?oooooooooo04Kooooo00Go0000ooooooooooooooooo`000002ooooo`04o`00
0?ooooooooooo`0004Sooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooooooo
o`00023ooooo000[ooooo`Go00000oooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0004Wooooo00Co0000oooooooooooo0000COooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0004Sooooo1Ol00002ooooo`04o`000?ooooooooooo`0004Sooooo00Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooo`0004Sooooo00Go0000ooooooooooooooooo`00
0002ooooo`04o`000?ooooooooooo`00023ooooo000dooooo`05o`000?ooooooooooooooool00000
0_ooool00ol0003oooooooooo`17ooooo`04o`000?ooooooooooo`0004kooooo00Go0000oooooooo
ooooooooo`000002ooooo`03o`000?oooooooooo04Kooooo00Co0000oooooooooooo00000oooool0
1?l0003oooooooooool00018ooooo`Co00000oooool01?l0003oooooooooool00019ooooo`?o0000
0oooool01?l0003oooooooooool0000Pooooo`00<Oooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo0000BOooool01?l0003oooooooooool0001;ooooo`05o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool00019ooooo`03o`000?oooooo000000?ooooo
00Co0000oooooooooooo0000B?ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`00
04Sooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`00023ooooo000a
ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00019ooooo`04o`00
0?ooooooooooo`0004_ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooooooo
o`0004[ooooo0_l00003ooooo`04o`000?ooooooooooo`0004Wooooo00?o0000ooooooooool00ooo
ool01?l0003oooooooooool00018ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool0000Pooooo`00<_ooool3o`0000Cooooo0_l0001;ooooo`;o0000COooool3o`0000Co
oooo0_l0001<ooooo`03o`000?oooooooooo00;ooooo0_l0001;ooooo`;o00001?ooool2o`0004[o
oooo0ol00004ooooo`;o00008Oooool00?oooooonOooool00?oooooonOooool00?oooooonOooool0
0?oooooonOooool00?oooooonOooool00?oooooonOooool002[oooooool0002eo`0001[ooooo000Z
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06?ooool002[ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0Hooooo`00:_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo053ooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`09ooooo`;o
003oAOooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo053ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Hooooo`00:_ooool00ol0003oooooooooo`2iooooo`;o003o
mOooool00ol0003oooooooooo`0Hooooo`00:_ooool2o`000;_ooooo00?o003oooooooooool00_l0
0?o`ooooo`;o00006_ooool002[ooooo00?o0000ooooooooool0^_ooool00ol00?ooooooooooo`02
o`00oo7ooooo00?o0000ooooooooool06?ooool002[ooooo00?o0000ooooooooool0^_ooool01Ol0
0?oooooooooooooooooo003o0?7ooooo00?o0000ooooooooool06?ooool002[ooooo00?o0000oooo
ooooool0^_ooool01Ol00?oooooooooooooooooo003o0?7ooooo00?o0000ooooooooool06?ooool0
02[ooooo00?o0000ooooooooool0^_ooool01Ol00?oooooooooooooooooo003o04Wooooo0_l00?nV
ooooo`03o`000?oooooooooo01Sooooo000Zooooo`03o`000?oooooooooo0;[ooooo00Go003ooooo
ooooooooooooo`00o`19ooooo`;o003oY_ooool00ol0003oooooooooo`0Hooooo`00:_ooool00ol0
003oooooooooo`2jooooo`05o`00ooooooooooooooooool00?l0AOooool2o`00o`;ooooo00?o003o
ooooooooool0YOooool00ol0003oooooooooo`0Hooooo`00:_ooool00ol0003oooooooooo`2joooo
o`05o`00ooooooooooooooooool00?l0AOooool2o`00o`;ooooo00?o003oooooooooool0YOooool0
0ol0003oooooooooo`0Hooooo`00:_ooool2o`000;_ooooo00Go003oooooooooooooooooo`00o`15
ooooo`05o`00ooooooooooooooooool00?l0Y_ooool2o`0001[ooooo000Zooooo`03o`000?oooooo
oooo0;[ooooo00Go003oooooooooooooooooo`00o`15ooooo`05o`00ooooooooooooooooool00?l0
Yoooool00ol0003oooooooooo`0Hooooo`00:_ooool00ol0003oooooooooo`2jooooo`05o`00oooo
ooooooooooooool00?l0AOooool01Ol00?oooooooooooooooooo003o0:Oooooo00?o0000oooooooo
ool06?ooool002[ooooo00?o0000ooooooooool0^_ooool01Ol00?oooooooooooooooooo003o04Go
oooo00Go003oooooooooooooooooo`00o`2Wooooo`03o`000?oooooooooo01Sooooo000Zooooo`03
o`000?oooooooooo0;[ooooo00Go003oooooooooooooooooo`00o`15ooooo`05o`00oooooooooooo
ooooool00?l0Yoooool00ol0003oooooooooo`0Hooooo`00:_ooool00ol0003oooooooooo`2joooo
o`05o`00ooooooooooooooooool00?l0AOooool01Ol00?oooooooooooooooooo003o0:Oooooo00?o
0000ooooooooool06?ooool002[ooooo00?o0000ooooooooool0^_ooool01Ol00?oooooooooooooo
oooo003o04Gooooo00Go003oooooooooooooooooo`00o`2Wooooo`03o`000?oooooooooo01Sooooo
000Zooooo`03o`000?oooooooooo0;[ooooo00Go003oooooooooooooooooo`00o`15ooooo`05o`00
ooooooooooooooooool00?l0Yoooool00ol0003oooooooooo`0Hooooo`00:_ooool2o`000;_ooooo
00Go003oooooooooooooooooo`00o`15ooooo`05o`00ooooooooooooooooool00?l0Y_ooool2o`00
01[ooooo000Zooooo`03o`000?oooooooooo0;[ooooo00Go003oooooooooooooooooo`00o`15oooo
o`05o`00ooooooooooooooooool00?l0Yoooool00ol0003oooooooooo`0Hooooo`00:_ooool00ol0
003oooooooooo`2jooooo`05o`00ooooooooooooooooool00?l0AOooool01Ol00?oooooooooooooo
oooo003o0:Oooooo00?o0000ooooooooool06?ooool002[ooooo00?o0000ooooooooool0^_ooool0
1Ol00?oooooooooooooooooo003o04Gooooo00Go003oooooooooooooooooo`00o`2Wooooo`03o`00
0?oooooooooo01Sooooo000Zooooo`03o`000?oooooooooo0;[ooooo00Go003ooooooooooooooooo
o`00o`15ooooo`05o`00ooooooooooooooooool00?l0Yoooool00ol0003oooooooooo`0Hooooo`00
7_ooool5o`0000Oooooo00?o0000ooooooooool0^_ooool01Ol00?oooooooooooooooooo003o04Go
oooo00Go003oooooooooooooooooo`00o`2Wooooo`03o`000?oooooooooo01Sooooo000Oooooo`04
o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool0^_ooool01Ol00?oooooooooooooooooo
003o04Gooooo00Go003oooooooooooooooooo`00o`2Wooooo`03o`000?oooooooooo01Sooooo000H
ooooo`Go00000oooool00ol0003oooooooooo`07ooooo`?o0000]Oooool2o`00o`?ooooo00Go003o
ooooooooooooooooo`00o`15ooooo`05o`00ooooooooooooooooool00?l00oooool2o`00oj3ooooo
0ol0000Jooooo`008Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0;Gooooo0_l0
0?l3ooooo`05o`00ooooooooooooooooool00?l0AOooool01Ol00?oooooooooooooooooo003o00?o
oooo0_l00?nRooooo`03o`000?oooooooooo01Sooooo000Nooooo`05o`000?ooooooooooooooool0
00001oooool00ol0003oooooooooo`2eooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooo
ooooooooo`00o`02ooooo`;o003o@Oooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003o
ooooooooool0X?ooool00ol0003oooooooooo`0Hooooo`007_ooool01Ol0003ooooooooooooooooo
000000Oooooo00?o0000ooooooooool0]Oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooo
ooooooooool00?l00_ooool2o`00od7ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00
oooooooooooo0:3ooooo00?o0000ooooooooool06?ooool001oooooo0ol00008ooooo`03o`000?oo
oooooooo0;Gooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool0?oooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003ooooooooo
ool0X?ooool00ol0003oooooooooo`0Hooooo`00:_ooool00ol0003oooooooooo`2eooooo`03o`00
oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo03oo
oooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo0:3ooooo00?o0000oooo
ooooool06?ooool002[ooooo00?o0000ooooooooool0]Oooool00ol00?ooooooooooo`02ooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0oooooo`05o`00oooooooooooo
ooooool00?l01?ooool00ol00?ooooooooooo`2Pooooo`03o`000?oooooooooo01Sooooo000Zoooo
o`03o`000?oooooooooo0;Gooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o003oooooooooool06Oooool2o`00ob3ooooo0_l00?l2ooooo`05o`00oooooooo
ooooooooool00?l01?ooool00ol00?ooooooooooo`2Pooooo`03o`000?oooooooooo01Sooooo000Z
ooooo`;o0000]_ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`0Iooooo`;o003o8?ooool2o`00o`;ooooo00Go003ooooooooooooooooo
o`00o`04ooooo`03o`00oooooooooooo09oooooo0_l0000Jooooo`00:_ooool00ol0003ooooooooo
o`2eooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo01[ooooo00?o003oooooooooool07_ooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`2Pooooo`03o`000?oooooooooo01So
oooo000Zooooo`03o`000?oooooooooo0;Gooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool06_ooool00ol00?ooooooooooo`0Nooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
0:3ooooo00?o0000ooooooooool06?ooool002[ooooo00?o0000ooooooooool0]Oooool00ol00?oo
ooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Joooo
o`03o`00oooooooooooo01kooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool0X?ooool00ol0003oooooooooo`0Hooooo`00:_ooool00ol0
003oooooooooo`2eooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo01[ooooo00?o003oooooooooool07_ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`2Pooooo`03o`000?oo
oooooooo01Sooooo000Zooooo`03o`000?oooooooooo0;Gooooo00?o003oooooooooool00_ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool06_ooool00ol00?oooooooooo
o`0Nooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo0:3ooooo00?o0000ooooooooool06?ooool002[ooooo00?o0000ooooooooool0U?oo
ool2o`00oaoooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool06_ooool00ol00?ooooooooooo`0Nooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo0:3ooooo00?o0000oooooooo
ool06?ooool002[ooooo00?o0000ooooooooool0T?ooool2o`00o`;ooooo0_l00?lOooooo`03o`00
oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01[o
oooo00?o003oooooooooool07_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`2Pooooo`03o`000?oooooooooo01Sooooo000Zooooo`;o
0000TOooool2o`00o`;ooooo00?o003oooooooooool07_ooool00ol00?ooooooooooo`02ooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo
01kooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool0Woooool2o`0001[ooooo000Zooooo`03o`000?oooooooooo093ooooo00Go003ooooo
ooooooooooooo`00o`0Pooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo01[ooooo00?o003oooooooooool07_ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`2Pooooo`03o`00
0?oooooooooo01Sooooo000Zooooo`03o`000?oooooooooo093ooooo00Go003ooooooooooooooooo
o`00o`0Pooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo01Gooooo0_l00?l3ooooo`03o`00oooooooooooo01kooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0X?ooool00ol0
003oooooooooo`0Hooooo`00:_ooool00ol0003oooooooooo`2@ooooo`05o`00oooooooooooooooo
ool00?l08?ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`0Eooooo`;o003o0oooool01?l00?ooooooooooooooool2o`00oa_ooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
X?ooool00ol0003oooooooooo`0Hooooo`00:_ooool00ol0003oooooooooo`2@ooooo`05o`00oooo
ooooooooooooool00?l08?ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`0Fooooo`05o`00ooooooooooooooooool00?l00oooool2o`00
oa_ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool0X?ooool00ol0003oooooooooo`0Hooooo`00:_ooool00ol0003oooooooooo`2@oooo
o`05o`00ooooooooooooooooool00?l08?ooool00ol00?ooooooooooo`02ooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`0Fooooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`0Jooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo0:3ooooo00?o0000ooooooooool06?ooool002[ooooo
00?o0000ooooooooool0T?ooool01Ol00?oooooooooooooooooo003o023ooooo00?o003ooooooooo
ool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool05_ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool06_ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`2Pooooo`03o`000?oo
oooooooo01Sooooo000Zooooo`;o0000Koooool2o`00ob3ooooo00Go003oooooooooooooooooo`00
o`0Pooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo01Kooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01[o
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool0Woooool2o`0001[ooooo000Zooooo`03o`000?oooooooooo06kooooo0_l00?l2ooooo`;o
003o7?ooool01Ol00?oooooooooooooooooo003o023ooooo00?o003oooooooooool00_ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool05_ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool06_ooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`2Pooooo`03o`000?oooooooooo01Sooooo
000Zooooo`03o`000?oooooooooo06oooooo00?o003oooooooooool00_l00?lLooooo`05o`00oooo
ooooooooooooool00?l08?ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`0Fooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`0Jooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo04?ooooo0_l00?mKooooo`03o`000?oooooooooo01Sooooo000Zoooo
o`03o`000?oooooooooo06[ooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l05oooool2
o`00o`?ooooo00Go003oooooooooooooooooo`00o`0Pooooo`03o`00oooooooooooo00;ooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01Kooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo01[ooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool0?_ooool2o`00o`?ooooo0_l00?mKoooo
o`03o`000?oooooooooo01Sooooo000Zooooo`03o`000?oooooooooo06[ooooo0_l00?l3ooooo`05
o`00ooooooooooooooooool00?l05oooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`03
ooooo`;o003o6oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`0Fooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`0Jooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo00;o003o5oooool2o`00o`;ooooo0_l00?lOooooo`;o003o0oooool00ol00?oo
ooooooooo`1Jooooo`03o`000?oooooooooo01Sooooo000Zooooo`03o`000?oooooooooo06_ooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01Kooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`04o`00ooooooooooooooooo`;o003o6oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Fooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`0Jooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;o003o5oooool2o`00o`;o
oooo0_l00?lPooooo`05o`00ooooooooooooooooool00?l0G?ooool00ol0003oooooooooo`0Hoooo
o`008?ooool2o`0000Sooooo00?o0000ooooooooool0Joooool01Ol00?oooooooooooooooooo003o
00?ooooo00Co003ooooooooooooooooo0_l00?lCooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o01cooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool05_ooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool06_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o01Sooooo00Go003ooooooooooooooooo
o`00o`0Kooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o05cooooo00?o0000oooooooo
ool06?ooool001oooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`1[ooooo`05
o`00ooooooooooooooooool00?l00oooool01?l00?ooooooooooooooool2o`00oa?ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l07?ooool00ol00?oooooo
ooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Fooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Jooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l06?oo
ool01Ol00?oooooooooooooooooo003o01_ooooo0_l00?l3ooooo`05o`00ooooooooooooooooool0
0?l0G?ooool00ol0003oooooooooo`0Hooooo`007oooool01?l0003oooooooooool00007ooooo`[o
00000_l00?l2o`0000;o003o0_l00002o`00o`;o00000_l00?l2o`0000;o003o0_l00002o`00o`;o
00000_l00?l3o`0000;o003o0_l00002o`00o`;o00000_l00?l2o`0000;o003o0_l00002o`00o`;o
00000_l00?l3o`0000;o003o0_l00002o`00o`;o00000_l00?l2o`0000;o003o0_l00002o`00o`;o
00000_l00?l2o`0000;o003o0ol000001Ol00?oo0000o`000?l0003o003o00?o000000Co003oo`00
0?l0003o00000_l00?l3o`000005o`00ool0003o0000o`000?l00?l00ol000001Ol00?oo0000o`00
0?l0003o003o00?o000000Go003oo`000?l0003o0000o`00o`04o`000005o`00ool0003o0000o`00
0?l00?l00ol000001Ol00?oo0000o`000?l0003o003o00?o000000Go003oo`000?l0003o0000o`00
o`04o`000005o`00ool0003o0000o`000?l00?l00ol000001Ol00?oo0000o`000?l0003o003o00?o
000000Go003oo`000?l0003o0000o`00o`03o`000003o`00ool0003o000000;o000000Go003oo`00
0?l0003o0000o`00o`03o`000005o`00ool0003o0000o`000?l00?l00ol000001Ol00?oo0000o`00
0?l0003o003o00?o000000?o003oo`000?l000000_l000001Ol00?oo0000o`000?l0003o003o00?o
000000Go003oo`000?l0003o0000o`00o`03o`000005o`00ool0003o0000o`000?l00?l01?l00000
1Ol00?oo0000o`000?l0003o003o00?o000000Go003oo`000?l0003o0000o`00o`03o`000005o`00
ool0003o0000o`000?l00?l00ol000000ol00?oo0000o`000002o`000005o`00ool0003o0000o`00
0?l00?l00ol000001Ol00?oo0000o`000?l0003o003o00?o000000Go003oo`000?l0003o0000o`00
o`03o`000003o`00ool0003o000000;o000000Go003oo`000?l0003o0000o`00o`03o`000005o`00
ool0003o0000o`000?l00?l00ol000001Ol00?oo0000o`000?l0003o003o00Co000000Go003oo`00
0?l0003o0000o`00o`03o`000005o`00ool0003o0000o`000?l00?l00ol000001?l00?oo0000o`00
0?l00002o`00o`;o00000_l00?l2o`0000;o003o0_l00002o`00o`;o00000_l00?l2o`0000;o003o
0ol00002o`00o`;o00000_l00?l2o`0000;o003o0_l00002o`00o`;o00000_l00?l2o`0000;o003o
0ol00002o`00o`;o00000_l00?l2o`0000;o003o0_l00002o`00o`;o00000_l00?l2o`0000;o003o
0_l00002o`00o`?o00000_l00?l9o`0001[ooooo000Oooooo`04o`000?ooooooooooo`0000Oooooo
00?o0000ooooooooool01oooool2o`00o`;ooooo0_l00?l2ooooo`;o003o0_ooool2o`00o`;ooooo
0_l00?l2ooooo`;o003o0_ooool2o`00o`?ooooo0_l00?l2ooooo`;o003o0_ooool2o`00o`;ooooo
0_l00?l2ooooo`;o003o0_ooool2o`00o`?ooooo0_l00?l2ooooo`;o003o0_ooool2o`00o`;ooooo
0_l00?l2ooooo`;o003o0_ooool2o`00o`;ooooo0_l00?l3ooooo`05o`00ooooooooooooooooool0
0?l00oooool01?l00?ooooooooooooooool2o`00oa?ooooo00Go003oooooooooooooooooo`00o`04
ooooo`05o`00ooooooooooooooooool00?l05?ooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l05?ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooo
oooooooo00gooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o01Sooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`09ooooo`;o003o0ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o00oooooo0_l00?l2ooooo`;o003o0_ooool2o`00o`;ooooo0_l00?l2ooooo`;o
003o0_ooool2o`00o`?ooooo0_l00?l2ooooo`;o003o0_ooool2o`00o`;ooooo0_l00?l2ooooo`;o
003o0_ooool2o`00o`?ooooo0_l00?l2ooooo`;o003o0_ooool2o`00o`;ooooo0_l00?l2ooooo`;o
003o0_ooool2o`00o`;ooooo0_l00?l3ooooo`;o003o2?ooool00ol0003oooooooooo`0Hooooo`00
7oooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo05[ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo01Kooooo00Go003oooooooooooooooooo`00o`04
ooooo`05o`00ooooooooooooooooool00?l05?ooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l05?ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooo
oooooooo00gooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o01Sooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`09ooooo`;o003o0ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o06Sooooo00?o0000ooooooooool06?ooool001oooooo00Co0000oooooooooooo
00001oooool00ol0003oooooooooo`1Jooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`0Fooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooo
oooo003o01Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o01Cooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`0=ooooo`05o`00oooo
ooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`0Hooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool03_ooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`02o`00ofSooooo00?o0000ooooooooool0
6?ooool0023ooooo0_l00008ooooo`03o`000?oooooooooo05[ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`;o003o5oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooooooo
ooooooooo`00o`0Dooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`0Dooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool03Oooool01Ol0
0?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l06?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`;o003o3oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`02o`00ofSooooo00?o0000ooooooooool06?ooool0
02[ooooo00?o0000ooooooooool0F_ooool01Ol00?oooooooooooooooooo003o00?ooooo0_l00?lG
ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o01Cooooo
00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol0
0?oooooooooooooooooo003o01Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l01?ooool00ol00?ooooooooooo`0=ooooo`05o`00ooooooooooooooooool0
0?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`0H
ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo
0_l00?l?ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo06[ooooo00?o0000ooooooooool06?ooool002[ooooo00?o0000ooooooooool0
F_ooool01Ol00?oooooooooooooooooo003o01cooooo0_l00?l2ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool00_l00?lDooooo`05o`00ooooooooooooooooool00?l00oooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`0Dooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003ooooooooo
ool03Oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l06?ooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`0Dooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo06[ooooo00?o0000ooooooooool06?ooool002[o
oooo00?o0000ooooooooool0F_ooool01?l00?ooooooooooooooool2o`00oa_ooooo0_l00?l2oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_l00?lDooooo`05o`00oooooooooooo
ooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`0Dooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00Cooooo00?o003oooooooooool03Oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l06?ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`0Dooooo`;o003o0_ooool01Ol0
0?oooooooooooooooooo003o00Cooooo00?o003oooooooooool0J_ooool00ol0003oooooooooo`0H
ooooo`00:_ooool2o`0005_ooooo0_l00?l2ooooo`;o003o7oooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo01Kooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l00oooool01?l00?ooooooooooooooool2o`00oa?ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`0=oooo
o`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`0Hooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o01Cooooo0_l00?l2ooooo`05o`00ooooooooooooooooool00?l00oooool2
o`00of_ooooo0_l0000Jooooo`00:_ooool00ol0003oooooooooo`1Jooooo`;o003o8oooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo01Kooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l00oooool01?l00?ooooooooooooooool2o`00oa;ooooo
0_l00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo00gooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooooooooooo
ooooool00?l00oooool01Ol00?oooooooooooooooooo003o01Sooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l06?ooool01Ol00?oooooooooooooooooo003o
00?ooooo0_l00?m/ooooo`03o`000?oooooooooo01Sooooo000Zooooo`03o`000?oooooooooo07oo
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Fooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool05Oooool2
o`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool03Oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l06?ooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`0Hooooo`05o`00ooooooooooooooooool00?l0
LOooool00ol0003oooooooooo`0Hooooo`00:_ooool00ol0003oooooooooo`1oooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool05_ooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01[ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool03Oooool01Ol0
0?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l06?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`0Hooooo`;o003o0_ooool00ol00?ooooooooooo`1_ooooo`03o`000?oooooooooo
01Sooooo000Zooooo`03o`000?oooooooooo07oooooo0_l00?l3ooooo`03o`00oooooooooooo01Ko
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`0Jooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo00gooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o01Sooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l06?ooool2o`00o`;ooooo0_l0
0?m`ooooo`03o`000?oooooooooo01Sooooo000Zooooo`03o`000?oooooooooo07oooooo0_l00?l2
ooooo`;o003o6?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo01[ooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool03Oooool01Ol00?oooooooooooooooooo003o
00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l06?oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`0Looooo`;o
003oL?ooool00ol0003oooooooooo`0Hooooo`00:_ooool00ol0003oooooooooo`23ooooo`;o003o
6?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo01[ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool03Oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l06?ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`2>ooooo`03o`000?oooooo
oooo01Sooooo000Zooooo`03o`000?oooooooooo09gooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Jooooo`05o`00oooo
ooooooooooooool00?l00oooool01?l00?ooooooooooooooool2o`00o`oooooo00Go003ooooooooo
ooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o01Sooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool0
0?l0S_ooool00ol0003oooooooooo`0Hooooo`00:_ooool2o`0009kooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Joooo
o`05o`00ooooooooooooooooool00?l00oooool01?l00?ooooooooooooooool2o`00o`oooooo00Go
003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`02o`00oaSooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l0SOooool2o`0001[ooooo000Zooooo`03o`000?oooooooooo09gooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`0Jooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Booooo`05o`00
ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool00_l00?lHooooo`05o`00ooooooooooooooooool00?l00oooool01?l00?oooooooooooooo
ool2o`00ohgooooo00?o0000ooooooooool06?ooool002[ooooo00?o0000ooooooooool0WOooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo01[ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01;o
oooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`0Jooooo`05o`00ooooooooooooooooool00?l00oooool01?l00?oooooooooo
ooooool2o`00ohgooooo00?o0000ooooooooool06?ooool002[ooooo00?o0000ooooooooool0WOoo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo01[ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
01;ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`0Jooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`2@ooooo`03o`000?oooooooooo01Sooooo000Zooooo`03o`000?oooooooooo09gooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`0Jooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Boooo
o`;o003o0_ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`0Iooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o09;ooooo00?o
0000ooooooooool06?ooool002[ooooo00?o0000ooooooooool0WOooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01[ooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01;ooooo0_l00?l2ooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
01Wooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l0T_ooool00ol0003oooooooooo`0H
ooooo`00:_ooool00ol0003oooooooooo`2Looooo`;o003o0oooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`0Looooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo01kooooo00Go003oooooooooooooooooo`00o`2Boooo
o`03o`000?oooooooooo01Sooooo000Zooooo`;o0000WOooool2o`00o`?ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l07?ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`0Nooooo`05o`00ooooooooooooooooool0
0?l0TOooool2o`0001[ooooo000Zooooo`03o`000?oooooooooo0:7ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l07?ooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`02ooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`0Nooooo`05o`00ooooooooooooooooool00?l0
T_ooool00ol0003oooooooooo`0Hooooo`00:_ooool00ol0003oooooooooo`2Qooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o01cooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool00_ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool07_ooool01Ol00?oooooooooooooo
oooo003o09;ooooo00?o0000ooooooooool06?ooool002[ooooo00?o0000ooooooooool0XOooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`0Looooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo00;o
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01kooooo00Go003ooooo
ooooooooooooo`00o`2Booooo`03o`000?oooooooooo01Sooooo000Zooooo`03o`000?oooooooooo
0:7ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l07?oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool05_ooool00ol00?oooooo
ooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Nooooo`05
o`00ooooooooooooooooool00?l0T_ooool00ol0003oooooooooo`0Hooooo`00:_ooool00ol0003o
ooooooooo`2Qooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o01cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01Kooooo00?o
003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
7_ooool01Ol00?oooooooooooooooooo003o09;ooooo00?o0000ooooooooool06?ooool001kooooo
1Ol00007ooooo`03o`000?oooooooooo0:7ooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l07?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool05_ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`0Nooooo`04o`00ooooooooooooooooo`;o003oTOooool00ol0003ooooo
ooooo`0Hooooo`007oooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo0:7ooooo
00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l07?ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Nooooo`04o`00oooo
ooooooooooooo`;o003oTOooool00ol0003oooooooooo`0Hooooo`008?ooool00ol0003ooooooooo
o`07ooooo`?o0000XOooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`0Looooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Foooo
o`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo01gooooo0_l00?nDooooo`?o00006_ooool0027ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`2Qooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o01cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01Kooooo
00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool07Oooool2o`00oiKooooo00?o0000ooooooooool06?ooool001kooooo00Go0000oooooooooooo
ooooo`000007ooooo`03o`000?oooooooooo0:7ooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l07?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool05_ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`2eooooo`03o`000?oooooooooo01Sooooo000Nooooo`05o`000?oo
ooooooooooooool000001oooool00ol0003oooooooooo`2Qooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o01cooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool0]Oooool00ol0003oooooooooo`0Hooooo`007oooool3
o`0000Sooooo00?o0000ooooooooool0XOooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`0Looooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`0Fooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo0;Gooooo00?o0000ooooooooool06?ooool002[ooooo00?o0000oooooooo
ool0XOooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`0L
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Fooooo`03o`00oooo
oooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo0;Gooooo
00?o0000ooooooooool06?ooool002[ooooo00?o0000ooooooooool0XOooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`0Looooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo00;ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo0;Gooooo00?o0000ooooooooool06?ooool0
02[ooooo00?o0000ooooooooool0XOooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`0Looooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`0Fooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo0;Gooooo00?o0000ooooooooool06?ooool002[ooooo0_l0002Rooooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o01cooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool00_ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0]?ooool2o`0001[ooooo000Z
ooooo`03o`000?oooooooooo0:7ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l07?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool05_ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`2eooooo`03o`000?oooooooooo01Sooooo000Zooooo`03o`000?oooooooooo0:7o
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l07?ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool05_ooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`2eooooo`03o`00
0?oooooooooo01Sooooo000Zooooo`03o`000?oooooooooo0:7ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l07?ooool2o`00o`;ooooo00Go003ooooooooo
ooooooooo`00o`0Hooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo0;Gooooo00?o0000ooooooooool06?ooool002[ooooo00?o0000oooo
ooooool0XOooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`0Looooo`;o003o0_ooool01?l00?ooooooooooooooool2o`00oaOooooo00?o003oooooooooool0
0_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0]Oooool00ol0003o
ooooooooo`0Hooooo`00:_ooool00ol0003oooooooooo`2Qooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o023ooooo00Co003ooooooooooooooooo0_l00?lG
ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooo
oooooooo0;Gooooo00?o0000ooooooooool06?ooool002[ooooo00?o0000ooooooooool0XOooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`0Pooooo`03o`00
oooooooooooo01[ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool0]Oooool00ol0003oooooooooo`0Hooooo`00:_ooool2o`000:;ooooo
00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l08?ooool00ol0
0?ooooooooooo`0Jooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo0;Cooooo0_l0000Jooooo`00:_ooool00ol0003oooooooooo`2Qoooo
o`05o`00ooooooooooooooooool00?l00oooool01?l00?ooooooooooooooool2o`00oaoooooo00?o
003oooooooooool06_ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`2eooooo`03o`000?oooooooooo01Sooooo000Zooooo`03o`000?oo
oooooooo0:7ooooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00ooooooooooooooooo`;o
003o7oooool00ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo0;Gooooo00?o0000ooooooooool06?ooool002[o
oooo00?o0000ooooooooool0XOooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool08_ooool00ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo00;ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo0;Gooooo00?o0000ooooooooool06?ooool0
02[ooooo00?o0000ooooooooool0XOooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool08_ooool00ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo00;ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo0;Gooooo00?o0000ooooooooool06?oo
ool002[ooooo00?o0000ooooooooool0X?ooool2o`00o`?ooooo00Go003oooooooooooooooooo`00
o`0Tooooo`03o`00oooooooooooo01[ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool0]Oooool00ol0003oooooooooo`0Hooooo`00:_oo
ool00ol0003oooooooooo`2Pooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o02Cooooo
00?o003oooooooooool06_ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`2eooooo`03o`000?oooooooooo01Sooooo000Zooooo`03o`00
0?oooooooooo0:Gooooo00Go003oooooooooooooooooo`00o`0Tooooo`03o`00oooooooooooo01[o
oooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool0]Oooool00ol0003oooooooooo`0Hooooo`00:_ooool2o`000:Kooooo00Go003ooooooooo
ooooooooo`00o`0Tooooo`;o003o6oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`2dooooo`;o00006_ooool002[ooooo00?o0000oooo
ooooool0YOooool01Ol00?oooooooooooooooooo003o02Cooooo0_l00?lKooooo`03o`00oooooooo
oooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo0;Gooooo00?o
0000ooooooooool06?ooool002[ooooo00?o0000ooooooooool0YOooool01Ol00?oooooooooooooo
oooo003o047ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool0]Oooool00ol0003oooooooooo`0Hooooo`00:_ooool00ol0003ooooooooo
o`2Uooooo`05o`00ooooooooooooooooool00?l0@Oooool2o`00o`?ooooo00Go003ooooooooooooo
ooooo`00o`02ooooo`;o003o]oooool00ol0003oooooooooo`0Hooooo`00:_ooool00ol0003ooooo
ooooo`2Uooooo`05o`00ooooooooooooooooool00?l0@Oooool2o`00o`?ooooo00Go003ooooooooo
ooooooooo`00o`02ooooo`;o003o]oooool00ol0003oooooooooo`0Hooooo`008?ooool3o`0000Oo
oooo00?o0000ooooooooool0YOooool01Ol00?oooooooooooooooooo003o04Kooooo00Go003ooooo
ooooooooooooo`00o`2kooooo`03o`000?oooooooooo01Sooooo000Qooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0YOooool01Ol00?oooooooooooooooooo003o04Kooooo00Go003o
ooooooooooooooooo`00o`2kooooo`03o`000?oooooooooo01Sooooo000Nooooo`Go00001oooool0
0ol0003oooooooooo`2Uooooo`05o`00ooooooooooooooooool00?l0A_ooool01Ol00?oooooooooo
oooooooo003o0;_ooooo00?o0000ooooooooool06?ooool001kooooo00Co0000oooooooooooo0000
2?ooool3o`000:Gooooo00Go003oooooooooooooooooo`00o`16ooooo`05o`00oooooooooooooooo
ool00?l0^Oooool3o`0001[ooooo000Oooooo`03o`000?oooooo000000Sooooo00?o0000oooooooo
ool0YOooool01Ol00?oooooooooooooooooo003o04Kooooo00Go003oooooooooooooooooo`00o`2k
ooooo`03o`000?oooooooooo01Sooooo000Pooooo`;o00002?ooool00ol0003oooooooooo`2Uoooo
o`05o`00ooooooooooooooooool00?l0A_ooool01Ol00?oooooooooooooooooo003o0;_ooooo00?o
0000ooooooooool06?ooool0027ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2U
ooooo`05o`00ooooooooooooooooool00?l0A_ooool01Ol00?oooooooooooooooooo003o0;_ooooo
00?o0000ooooooooool06?ooool002[ooooo00?o0000ooooooooool0YOooool01Ol00?oooooooooo
oooooooo003o04Kooooo00Go003oooooooooooooooooo`00o`2kooooo`03o`000?oooooooooo01So
oooo000Zooooo`03o`000?oooooooooo0:Gooooo00Go003oooooooooooooooooo`00o`16ooooo`05
o`00ooooooooooooooooool00?l0^oooool00ol0003oooooooooo`0Hooooo`00:_ooool00ol0003o
ooooooooo`2Uooooo`05o`00ooooooooooooooooool00?l0A_ooool01Ol00?oooooooooooooooooo
003o0;_ooooo00?o0000ooooooooool06?ooool002[ooooo00?o0000ooooooooool0YOooool01Ol0
0?oooooooooooooooooo003o04Kooooo00Go003oooooooooooooooooo`00o`2kooooo`03o`000?oo
oooooooo01Sooooo000Zooooo`;o0000YOooool2o`00o`;ooooo0_l00?m6ooooo`05o`00oooooooo
ooooooooool00?l0^_ooool2o`0001[ooooo000Zooooo`03o`000?oooooooooo0:Cooooo0_l00?l2
ooooo`;o003oA_ooool01Ol00?oooooooooooooooooo003o0;_ooooo00?o0000ooooooooool06?oo
ool002[ooooo00?o0000ooooooooool0l?ooool01Ol00?oooooooooooooooooo003o0;_ooooo00?o
0000ooooooooool06?ooool002[ooooo00?o0000ooooooooool0l?ooool01Ol00?oooooooooooooo
oooo003o0;_ooooo00?o0000ooooooooool06?ooool002[ooooo00?o0000ooooooooool0l?ooool0
1Ol00?oooooooooooooooooo003o0;_ooooo00?o0000ooooooooool06?ooool002[ooooo00?o0000
ooooooooool0l?ooool01Ol00?oooooooooooooooooo003o0;_ooooo00?o0000ooooooooool06?oo
ool002[ooooo00?o0000ooooooooool0l?ooool01Ol00?oooooooooooooooooo003o0;_ooooo00?o
0000ooooooooool06?ooool002[ooooo0_l0003aooooo`05o`00ooooooooooooooooool00?l0^_oo
ool2o`0001[ooooo000Zooooo`03o`000?oooooooooo0?3ooooo00Go003oooooooooooooooooo`00
o`2kooooo`03o`000?oooooooooo01Sooooo000Zooooo`03o`000?oooooooooo0?3ooooo00Go003o
ooooooooooooooooo`00o`2kooooo`03o`000?oooooooooo01Sooooo000Zooooo`03o`000?oooooo
oooo0?3ooooo00Go003oooooooooooooooooo`00o`2kooooo`03o`000?oooooooooo01Sooooo000Z
ooooo`03o`000?oooooooooo0?3ooooo00Go003oooooooooooooooooo`00o`2kooooo`03o`000?oo
oooooooo01Sooooo000Zooooo`03o`000?oooooooooo0>oooooo0_l00?l3ooooo`03o`00oooooooo
oooo0;Wooooo00?o0000ooooooooool06?ooool002[ooooo00?o0000ooooooooool0koooool2o`00
o`;ooooo0_l00?nkooooo`03o`000?oooooooooo01Sooooo000Zooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo04?o
oooo0_l00?l;ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0D?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo01Sooooo000Zooooo`;o00002?ooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01_ooool2o`0001[ooooo
000Zoooooooo0000]Ol0000Jooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00
oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00
oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00
oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00=_ooool5o`0000?ooooo0_l0001:oooo
o`;o0000Boooool5o`0000?ooooo0_l0001;ooooo`?o00000oooool2o`0004Wooooo0ol00004oooo
o`;o0000B_ooool3o`0000Cooooo0_l0000Oooooo`00=oooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0004Sooooo00Co0000oooooooooooo0000Boooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0004_ooooo00Go0000ooooooooooooooooo`000002oooo
o`03o`000?oooooooooo04Gooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo
ooooo`0004Sooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0001ko
oooo000`ooooo`Go00000oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0004So
oooo00Co0000oooooooooooo0000C?ooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0004Sooooo1Ol00002ooooo`04o`000?ooooooooooo`0004Oooooo00Go0000oooooooooooooooo
o`000002ooooo`04o`000?ooooooooooo`0004Sooooo00Go0000ooooooooooooooooo`000002oooo
o`04o`000?ooooooooooo`0001kooooo000iooooo`05o`000?ooooooooooooooool000000_ooool0
0ol0003oooooooooo`16ooooo`04o`000?ooooooooooo`0004gooooo00Go0000oooooooooooooooo
o`000002ooooo`03o`000?oooooooooo04Kooooo00Co0000oooooooooooo00000oooool01?l0003o
ooooooooool00017ooooo`Co00000oooool01?l0003oooooooooool00019ooooo`?o00000oooool0
1?l0003oooooooooool0000Nooooo`00=_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co
0000oooooooooooo0000B?ooool01?l0003oooooooooool0001:ooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00019ooooo`03o`000?oooooo000000?ooooo00Co0000
oooooooooooo0000Aoooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0004Sooooo
00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0001kooooo000fooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00018ooooo`04o`000?oooooo
ooooo`0004[ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0004[o
oooo0_l00003ooooo`04o`000?ooooooooooo`0004Sooooo00?o0000ooooooooool00oooool01?l0
003oooooooooool00018ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooooooo
ool0000Nooooo`00=oooool3o`0000Cooooo0_l0001:ooooo`;o0000C?ooool3o`0000Cooooo0_l0
001<ooooo`03o`000?oooooooooo00;ooooo0_l0001:ooooo`;o00001?ooool2o`0004[ooooo0ol0
0004ooooo`;o00007oooool00?oooooonOooool00?oooooonOooool00?oooooonOooool00?oooooo
nOooool00?oooooonOooool00?oooooonOooool00?oooooonOooool002koooooool0002co`0001So
oooo000Uooooo`;o00001oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Kooooo
000Tooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`1?ooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool0D?ooool00ol0003ooooo
ooooo`1?ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0Fooooo`009?ooool01?l0003oooooooooool00006ooooo`[o00000_l00?l2o`0000;o003o
0_l00002o`00o`;o00000_l00?l3o`0000;o003o0_l00002o`00o`;o00000_l00?l2o`0000;o003o
0_l00002o`00o`;o00000_l00?l2o`0000;o003o0_l00002o`00o`?o00000_l00?l2o`0000;o003o
0_l00002o`00o`;o00000_l00?l2o`0000;o003o0_l00002o`00o`;o00000_l00?l2o`0000;o003o
0ol000001Ol00?oo0000o`000?l0003o003o00?o000000Go003oo`000?l0003o0000o`00o`04o`00
0005o`00ool0003o0000o`000?l00?l00ol000001Ol00?oo0000o`000?l0003o003o00?o000000Go
003oo`000?l0003o0000o`00o`03o`000005o`00ool0003o0000o`000?l00?l00ol000000ol00?oo
0000o`000002o`000005o`00ool0003o0000o`000?l00?l00ol000001Ol00?oo0000o`000?l0003o
003o00?o000000Go003oo`000?l0003o0000o`00o`03o`000005o`00ool0003o0000o`000?l00?l0
1?l000001Ol00?oo0000o`000?l0003o003o00?o000000Go003oo`000?l0003o0000o`00o`03o`00
0005o`00ool0003o0000o`000?l00?l00ol000001Ol00?oo0000o`000?l0003o003o00?o000000?o
003oo`000?l000000_l000001Ol00?oo0000o`000?l0003o003o00?o000000Go003oo`000?l0003o
0000o`00o`03o`000005o`00ool0003o0000o`000?l00?l00ol000001Ol00?oo0000o`000?l0003o
003o00Co000000Go003oo`000?l0003o0000o`00o`03o`000005o`00ool0003o0000o`000?l00?l0
0ol000001Ol00?oo0000o`000?l0003o003o00?o000000Go003oo`000?l0003o0000o`00o`04o`00
0005o`00ool0003o0000o`000?l00?l00ol000001Ol00?oo0000o`000?l0003o003o00?o000000Go
003oo`000?l0003o0000o`00o`03o`000005o`00ool0003o0000o`000?l00?l00ol000000ol00?oo
0000o`000002o`000005o`00ool0003o0000o`000?l00?l00ol000001Ol00?oo0000o`000?l0003o
003o00?o000000Go003oo`000?l0003o0000o`00o`03o`0000;o003o0_l00002o`00o`;o00000_l0
0?l2o`0000;o003o0_l00002o`00o`;o00000_l00?l2o`0000;o003o0ol00002o`00o`;o00000_l0
0?l2o`0000;o003o0_l00002o`00o`;o00000_l00?l2o`0000;o003o0_l00002o`00o`;o00000_l0
0?l3o`0000;o003o0_l00002o`00o`;o00000_l00?l2o`0000;o003o0_l00002o`00o`[o00006?oo
ool002Cooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`07ooooo`;o003o0_oo
ool2o`00o`;ooooo0_l00?l2ooooo`;o003o0oooool2o`00o`;ooooo0_l00?l2ooooo`;o003o0_oo
ool2o`00o`;ooooo0_l00?l2ooooo`;o003o0_ooool2o`00o`;ooooo0_l00?l3ooooo`;o003o0_oo
ool2o`00o`;ooooo0_l00?l2ooooo`;o003o0_ooool2o`00o`;ooooo0_l00?l2ooooo`;o003o0_oo
ool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool0
0?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool0
0?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool2o`00o`;ooooo0_l00?l2
ooooo`;o003o0_ooool2o`00o`;ooooo0_l00?l2ooooo`;o003o0_ooool2o`00o`?ooooo0_l00?l2
ooooo`;o003o0_ooool2o`00o`;ooooo0_l00?l2ooooo`;o003o0_ooool2o`00o`;ooooo0_l00?l2
ooooo`;o003o0oooool2o`00o`;ooooo0_l00?l2ooooo`;o003o0_ooool2o`00o`;ooooo0_l00?l9
ooooo`03o`000?oooooooooo01Kooooo000Tooooo`04o`000?ooooooooooo`0000Kooooo00?o0000
ooooooooool0F_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`1Looooo`03o`000?oooooooooo
01Kooooo000Tooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool0F_ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo
00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`1Looooo`03o`000?oooooooooo01Kooooo000Uooooo`;o0000
1oooool00ol0003oooooooooo`1Jooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o05cooooo00?o
0000ooooooooool05_ooool002kooooo00?o0000ooooooooool0F_ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`1Looooo`03o`000?oooooooooo01Kooooo000^ooooo`03o`000?oooooooooo05[o
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Co
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l0G?ooool00ol0003oooooooooo`0Fooooo`00;_oo
ool3o`0005[ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool0
0?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool0
0?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0F_ooool3o`0001Sooooo000^oooo
o`03o`000?oooooooooo05[ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0G?ooool00ol0003o
ooooooooo`0Fooooo`00;_ooool00ol0003oooooooooo`1Jooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o05cooooo00?o0000ooooooooool05_ooool002kooooo00?o0000ooooooooool0F_ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Co
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`1Looooo`03o`000?oooooooooo01Kooooo000^ooooo`03
o`000?oooooooooo05Wooooo0_l00?l3ooooo`;o003o0_ooool01Ol00?oooooooooooooooooo003o
00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l00_ooool2o`00o`?ooooo0_l00?mKooooo`03o`000?oooooooooo01Kooooo000^oooo
o`03o`000?oooooooooo05Wooooo0_l00?l3ooooo`;o003o0_ooool2o`00o`;ooooo00?o003ooooo
ooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool00_l00?l2ooooo`;o003o0oooool2o`00oe_ooooo00?o0000ooooooooool05_ooool002ko
oooo00?o0000ooooooooool0H_ooool2o`00o`;ooooo00?o003oooooooooool00_ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
0_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
0_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_l00?mTooooo`03
o`000?oooooooooo01Kooooo000^ooooo`?o0000I_ooool2o`00o`?ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooooooo
ooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go
003oooooooooooooooooo`00o`02ooooo`;o003oI_ooool3o`0001Sooooo000^ooooo`03o`000?oo
oooooooo06Kooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00_oo
ool2o`00ofSooooo00?o0000ooooooooool05_ooool002kooooo00?o0000ooooooooool0J_ooool2
o`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
0_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooooooo
ooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo00;o003oK?ooool00ol0003oooooooooo`0Fooooo`00;_ooool00ol0003o
ooooooooo`1Zooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Co
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool00_l00?m/ooooo`03o`000?oooooooooo01Kooooo
000^ooooo`03o`000?oooooooooo06oooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo06kooooo00?o0000ooooooooool05_ooool0
02kooooo00?o0000ooooooooool0K_ooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool0
0?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo
00Co003ooooooooooooooooo0_l00?m`ooooo`03o`000?oooooooooo01Kooooo000^ooooo`03o`00
0?oooooooooo06kooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0
1?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00oooooooo
ooooooooo`;o003oL?ooool00ol0003oooooooooo`0Fooooo`00;_ooool3o`0007?ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool0LOooool3o`0001Sooooo000^ooooo`03o`00
0?oooooooooo07?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;o
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0Loooool0
0ol0003oooooooooo`0Fooooo`00;_ooool00ol0003oooooooooo`1booooo`;o003o0oooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool0
0?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo
0_l00?mdooooo`03o`000?oooooooooo01Kooooo000^ooooo`03o`000?oooooooooo07;ooooo0_l0
0?l3ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l00oooool2o`00ogCooooo00?o0000ooooooooool05_ooool001Wooooo0_l00004ooooo`04
o`000?ooooooooooooooo`Go00001_ooool00ol0003oooooooooo`1gooooo`05o`00oooooooooooo
ooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0NOooool00ol0003ooooo
ooooo`0Fooooo`006?ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Ko
oooo00?o0000ooooooooool0Moooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o07Wooooo00?o0000ooooooooool05_ooool001Sooooo00Co0000
oooooooooooo00002Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo07Kooooo0_l0
0?l3ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01?l00?ooooooooooooooool2o`00ogSo
oooo00?o0000ooooooooool05_ooool001Sooooo00Co0000oooooooooooo00002_ooool00ol0003o
ooooooooo`05ooooo`Co0000MOooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooo
ooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03oooo
o`04o`00ooooooooooooooooo`;o003oMOooool4o`0001Sooooo000Hooooo`04o`000?oooooooooo
o`0000Oooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo07_ooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0
1?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo07_ooooo00?o0000ooooooooool0
5_ooool001Sooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooooooool0Noooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool0Noooool00ol0003oooooooooo`0Fooooo`006Oooool2o`0000Wooooo0ol00007ooooo`03
o`000?oooooooooo07_ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
07_ooooo00?o0000ooooooooool05_ooool002kooooo00?o0000ooooooooool0N_ooool2o`00o`?o
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;o
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l00oooool2o`00ogcooooo00?o0000ooooooooool05_ooool002kooooo00?o0000oooooooo
ool0N_ooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l00oooool2o`00ogcooooo00?o0000ooooooooool05_ooool002ko
oooo00?o0000ooooooooool0Ooooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`21ooooo`03o`000?oooooooooo01Kooooo000^ooooo`?o
0000Ooooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04
ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo
00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`1oooooo`?o00006?ooool002kooooo00?o0000ooooooooool0Ooooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooooooo
ooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`21oooo
o`03o`000?oooooooooo01Kooooo000^ooooo`03o`000?oooooooooo07oooooo0_l00?l2ooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooo
ooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Co003ooooooooooooooooo0_l00?n0ooooo`03
o`000?oooooooooo01Kooooo000^ooooo`03o`000?oooooooooo07oooooo0_l00?l2ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Co003ooooooooooooooooo0_l00?n0ooooo`03o`00
0?oooooooooo01Kooooo000^ooooo`03o`000?oooooooooo08?ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`23ooooo`03o`000?oooooooooo01Kooooo000^oooo
o`03o`000?oooooooooo08?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0
1?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`23ooooo`03o`000?oooooooooo01Kooooo000^ooooo`?o0000Poooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo087ooooo0ol0000Hooooo`00;_ooool0
0ol0003oooooooooo`23ooooo`;o003o0_ooool01Ol00?oooooooooooooooooo003o00Cooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooooooo
ooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00_ooool2o`00ohGooooo00?o0000oooo
ooooool05_ooool002kooooo00?o0000ooooooooool0Poooool2o`00o`;ooooo00Go003ooooooooo
ooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool0
0?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04
ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00;ooooo
0_l00?n5ooooo`03o`000?oooooooooo01Kooooo000^ooooo`03o`000?oooooooooo08Oooooo00Go
003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o08Wooooo00?o0000ooooooooool05_ooool002kooooo00?o0000ooooooooool0Qoooool01Ol0
0?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool0
0?l0ROooool00ol0003oooooooooo`0Fooooo`00;_ooool00ol0003oooooooooo`27ooooo`05o`00
ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`29ooooo`03o`000?oooooooooo01Kooooo000^ooooo`03o`000?oooooooooo08Oooooo00Go003o
ooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
08Wooooo00?o0000ooooooooool05_ooool002kooooo0ol00027ooooo`;o003o0_ooool00ol00?oo
ooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0
1?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04oooo
o`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02o`00ohOooooo0ol0000H
ooooo`00;_ooool00ol0003oooooooooo`27ooooo`;o003o0_ooool00ol00?ooooooooooo`02oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
0_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`02o`00ohWooooo00?o0000ooooooooool05_oo
ool002kooooo00?o0000ooooooooool0Roooool00ol00?ooooooooooo`02ooooo`05o`00oooooooo
ooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`2;ooooo`03o`000?oooooooooo01Kooooo000^ooooo`03o`000?oo
oooooooo08_ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol0
0?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool0Roooool00ol0003oooooooooo`0Fooooo`00;_ooool00ol0003oooooooooo`2;ooooo`03o`00
oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Co
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo08_ooooo00?o0000oooo
ooooool05_ooool001Wooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0ol00006ooooo`03
o`000?oooooooooo08_ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool0Roooool00ol0003oooooooooo`0Fooooo`006?ooool01?l0003oooooooooool0000:
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Roooool2o`00o`?ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooooooooooo
ooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooooooooooooooo
o`00o`02ooooo`;o003oSOooool00ol0003oooooooooo`0Fooooo`006?ooool01?l0003ooooooooo
ool00007ooooo`Go00001_ooool4o`0008[ooooo0_l00?l3ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00_ooool2o`00
oh[ooooo1?l0000Hooooo`006?ooool01?l0003oooooooooool00007ooooo`04o`000?oooooooooo
o`0000Oooooo00?o0000ooooooooool0T?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o097ooooo00?o0000ooooooooool0
5_ooool001Sooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`000007ooooo`03o`00
0?oooooooooo093ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Co
oooo00Go003oooooooooooooooooo`00o`2Aooooo`03o`000?oooooooooo01Kooooo000Hooooo`04
o`000?ooooooooooo`0000Wooooo0_l00007ooooo`03o`000?oooooooooo093ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00
o`2Aooooo`03o`000?oooooooooo01Kooooo000Iooooo`;o00002oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo093ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o00Cooooo00Go003oooooooooooooooooo`00o`2Aooooo`03o`000?oooooooooo01Kooooo
000^ooooo`03o`000?oooooooooo093ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`2Aooooo`03o`000?oooooooooo01Ko
oooo000^ooooo`03o`000?oooooooooo08oooooo0_l00?l3ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l01?ooool00ol00?ooooooooooo`02o`00oi7ooooo00?o0000ooooooooool0
5_ooool002kooooo0ol0002?ooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o00Cooooo00?o003oooooooooool00_l00?n?ooooo`?o00006?ooool002kooooo00?o0000
ooooooooool0U?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003o
ooooooooool0Toooool00ol0003oooooooooo`0Fooooo`00;_ooool00ol0003oooooooooo`2Doooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooooooo
ooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`2Coooo
o`03o`000?oooooooooo01Kooooo000^ooooo`03o`000?oooooooooo09Cooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo09?ooooo00?o0000oooooooo
ool05_ooool002kooooo00?o0000ooooooooool0U?ooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00Cooooo00?o003oooooooooool0Toooool00ol0003oooooooooo`0Fooooo`00;_oo
ool00ol0003oooooooooo`2Cooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo
00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`;o003oUOoo
ool00ol0003oooooooooo`0Fooooo`00;_ooool00ol0003oooooooooo`2Cooooo`;o003o0oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`;o003oUOooool00ol0003oooooooooo`0Fooooo`00;_ooool3o`00
09Sooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l0V?ooool3o`0001Sooooo000^ooooo`03o`000?oooooooooo09So
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l0V_ooool00ol0003oooooooooo`0Fooooo`00;_ooool00ol0003ooooo
ooooo`2Hooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooo
ooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o09[ooooo00?o0000ooooooooool05_ooool002kooooo00?o
0000ooooooooool0V?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`2Jooooo`03o`000?oooooooooo01Kooooo000^
ooooo`03o`000?oooooooooo09Sooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo
00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0V_ooool00ol0003oooooooooo`0F
ooooo`00;_ooool00ol0003oooooooooo`2Gooooo`;o003o0oooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`03ooooo`04o`00ooooooooooooooooo`;o003oVOooool00ol0003o
ooooooooo`0Fooooo`00;_ooool00ol0003oooooooooo`2Gooooo`;o003o0oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00ooooooooooooooooo`;o003oVOoo
ool00ol0003oooooooooo`0Fooooo`00;_ooool3o`0009cooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`2Jooooo`?o00006?ooool002kooooo
00?o0000ooooooooool0W?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo09cooooo00?o0000ooooooooool05_ooool002kooooo00?o0000oooo
ooooool0W?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo09cooooo00?o0000ooooooooool05_ooool002kooooo00?o0000ooooooooool0W?oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
09cooooo00?o0000ooooooooool05_ooool001Wooooo0_l00004ooooo`03o`000?oooooooooo00;o
oooo0ol00007ooooo`03o`000?oooooooooo09cooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooo
ooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`2Looooo`03o`000?oooooooooo01Kooooo000H
ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo09_ooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`;o003oWOooool0
0ol0003oooooooooo`0Fooooo`006?ooool01?l0003oooooooooool00007ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`2Kooooo`;o003o0oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l00oooool2o`00oigooooo00?o0000ooooooooool05_ooool001Sooooo00Co0000oooooooo
oooo00001oooool4o`0000Oooooo1?l0002Oooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`2Oooooo`Co0000
6?ooool001Sooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo0:3ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o0:;ooooo00?o0000ooooooooool05_ooool0
01Sooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo0:3ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0
1?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o0:;ooooo00?o0000ooooooooool05_ooool001Wooooo
0_l0000:ooooo`;o00001oooool00ol0003oooooooooo`2Pooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`2R
ooooo`03o`000?oooooooooo01Kooooo000^ooooo`03o`000?oooooooooo0:3ooooo0_l00?l2oooo
o`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooo
ooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00oooooooo
ooooooooo`;o003oXOooool00ol0003oooooooooo`0Fooooo`00;_ooool00ol0003oooooooooo`2P
ooooo`;o003o0_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01?l00?ooooooooooooooool2o`00oj7ooooo00?o0000ooooooooool05_ooool002kooooo00?o
0000ooooooooool0Y?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
0_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`2Tooooo`03o`000?oooooooooo01Kooooo000^ooooo`?o0000Y?oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`2Rooooo`?o00006?ooool002kooooo00?o0000ooooooooool0Y?ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`2Tooooo`03o`00
0?oooooooooo01Kooooo000^ooooo`03o`000?oooooooooo0:Cooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0Y?ooool00ol0003ooooo
ooooo`0Fooooo`00;_ooool00ol0003oooooooooo`2Tooooo`;o003o0_ooool01Ol00?oooooooooo
oooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00;ooooo0_l00?nVooooo`03o`000?oooooooooo01Kooooo000^ooooo`03o`000?oo
oooooooo0:Cooooo0_l00?l2ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00_ooool2o`00ojKooooo
00?o0000ooooooooool05_ooool002kooooo00?o0000ooooooooool0Z?ooool01Ol00?oooooooooo
oooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o0:[ooooo00?o0000ooooooooool05_ooool002kooooo0ol0002Xooooo`05o`00oooo
ooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol0
0?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l0Z?ooool3o`0001Sooooo000^ooooo`03o`000?oooooooooo0:Sooooo00Go
003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`2Zooooo`03o`000?oooooooooo01Kooooo000^ooooo`03o`000?oo
oooooooo0:Sooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`2Zooooo`03o`000?oooooooooo01Kooooo
000^ooooo`03o`000?oooooooooo0:Sooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`2Zooooo`03o`00
0?oooooooooo01Kooooo000^ooooo`03o`000?oooooooooo0:Sooooo0_l00?l2ooooo`03o`00oooo
oooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
o`00oj[ooooo00?o0000ooooooooool05_ooool002kooooo00?o0000ooooooooool0Z?ooool2o`00
o`;ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo00;o003oZ_ooool00ol0003oooooooooo`0Fooooo`00;_ooool00ol0003ooooo
ooooo`2/ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`2/ooooo`03o`000?oooooooooo01Kooooo000^ooooo`?o0000[?ooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool0Z_ooool3o`0001Sooooo000^ooooo`03o`000?oooooooooo0:cooooo00?o003ooooooooo
ool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo0:cooooo
00?o0000ooooooooool05_ooool002kooooo00?o0000ooooooooool0[?ooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0[?ooool0
0ol0003oooooooooo`0Fooooo`00;_ooool00ol0003oooooooooo`2/ooooo`;o003o0oooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo
00Go003oooooooooooooooooo`00o`02ooooo`;o003o[_ooool00ol0003oooooooooo`0Fooooo`00
;_ooool00ol0003oooooooooo`2/ooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00
o`02ooooo`;o003o[_ooool00ol0003oooooooooo`0Fooooo`006Oooool2o`0000Cooooo00?o0000
ooooooooool00_ooool3o`0000Oooooo00?o0000ooooooooool0/Oooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooooooo
ooooooooo`00o`2booooo`03o`000?oooooooooo01Kooooo000Hooooo`04o`000?ooooooooooo`00
00Oooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0;7ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05
o`00ooooooooooooooooool00?l0/_ooool00ol0003oooooooooo`0Fooooo`006?ooool01?l0003o
ooooooooool00007ooooo`05o`000?ooooooooooooooool000001_ooool4o`000;3ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05
o`00ooooooooooooooooool00?l0[oooool4o`0001Sooooo000Hooooo`04o`000?ooooooooooo`00
00Sooooo0ol00007ooooo`03o`000?oooooooooo0;3ooooo0_l00?l3ooooo`05o`00oooooooooooo
ooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool00_l00?nbooooo`03o`00
0?oooooooooo01Kooooo000Hooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooooooo
ooooo`000006ooooo`03o`000?oooooooooo0;3ooooo0_l00?l3ooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool00_l00?nbooooo`03o`000?oo
oooooooo01Kooooo000Hooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo0;Gooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l01?ooool00ol00?ooooooooooo`2dooooo`03o`000?oooooooooo01Kooooo000Ioooo
o`;o00002Oooool3o`0000Oooooo00?o0000ooooooooool0]Oooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo0;Cooooo00?o0000ooooooooool0
5_ooool002kooooo00?o0000ooooooooool0]Oooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol0
0?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`04ooooo`03o`00oooooooooooo0;Cooooo00?o0000ooooooooool05_ooool002ko
oooo00?o0000ooooooooool0]?ooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00?ooooo0_l00?nfooooo`03o`000?oooooooooo01Kooooo000^ooooo`?o0000]?ooool2o`00
o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo0_l00?ndooooo`?o00006?oo
ool002kooooo00?o0000ooooooooool0^Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0
^oooool00ol0003oooooooooo`0Fooooo`00;_ooool00ol0003oooooooooo`2iooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`2kooooo`03o`000?oooooooooo01Kooooo000^ooooo`03o`00
0?oooooooooo0;Wooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o0;_ooooo00?o0000oooo
ooooool05_ooool002kooooo00?o0000ooooooooool0^?ooool2o`00o`?ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Co003ooooooooooooooooo0_l00?nj
ooooo`03o`000?oooooooooo01Kooooo000^ooooo`03o`000?oooooooooo0;Sooooo0_l00?l3oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00oooooooo
ooooooooo`;o003o^_ooool00ol0003oooooooooo`0Fooooo`00;_ooool00ol0003oooooooooo`2m
ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooo
oooooooo0;gooooo00?o0000ooooooooool05_ooool002kooooo0ol0002mooooo`05o`00oooooooo
ooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo0;_ooooo0ol0
000Hooooo`00;_ooool00ol0003oooooooooo`2looooo`;o003o0oooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo
00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol0
0?oooooooooooooooooo003o00?ooooo0_l00?nnooooo`03o`000?oooooooooo01Kooooo000^oooo
o`03o`000?oooooooooo0;cooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l00oooool2o`00okkooooo00?o0000ooooooooool05_ooool002kooooo00?o0000oooooooo
ool0`Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o0<?ooooo00?o0000oooooooo
ool05_ooool002kooooo00?o0000ooooooooool0`Oooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o0<?ooooo00?o0000ooooooooool05_ooool002kooooo00?o0000ooooooooool0`?oo
ool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool0
0?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03
ooooo`04o`00ooooooooooooooooo`;o003o`_ooool00ol0003oooooooooo`0Fooooo`00;_ooool0
0ol0003oooooooooo`30ooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Co003ooooooooooooooooo0_l00?o2ooooo`03o`000?oooooo
oooo01Kooooo000^ooooo`?o0000aOooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool0`oooool3o`0001Sooooo000^ooooo`03o`00
0?oooooooooo0<Gooooo0_l00?l2ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00?ooooo0_l00?o6ooooo`03o`000?oooooooooo01Kooooo000^ooooo`03o`000?oooooooooo
0<Gooooo0_l00?l2ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo
0_l00?o6ooooo`03o`000?oooooooooo01Kooooo000^ooooo`03o`000?oooooooooo0<Wooooo0_l0
0?l2ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool00_l00?o;ooooo`03o`000?oooooooooo01Kooooo000Tooooo`?o0000
1oooool00ol0003oooooooooo`39ooooo`;o003o0_ooool01Ol00?oooooooooooooooooo003o00Co
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;o003oboooool00ol0
003oooooooooo`0Fooooo`009Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0<go
oooo0_l00?l2ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`02oooo
o`;o003ocoooool00ol0003oooooooooo`0Fooooo`009Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo0<gooooo0_l00?l2ooooo`;o003o0_ooool2o`00o`;ooooo0_l00?l2ooooo`;o
003ocoooool00ol0003oooooooooo`0Fooooo`009Oooool00ol0003oooooooooo`06ooooo`Co0000
1oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool0
8_ooool2o`00o`;ooooo0_l00?l2ooooo`;o003o9?ooool00ol0003oooooooooo`1?ooooo`03o`00
0?oooooooooo053ooooo00?o0000ooooooooool01?ooool4o`0001Sooooo000Uooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Fooooo`009?ooool2
o`0000Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Fooooo`009Oooool00ol0
003oooooooooo`06oooooooo0000/ol0000Hooooo`00oooooooiooooo`00oooooooiooooo`00oooo
oooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooo
oooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooo
oooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00<Ooo
ool5o`0000?ooooo0_l0001;ooooo`;o0000C?ooool5o`0000?ooooo0_l0001;ooooo`?o00000ooo
ool2o`0004[ooooo0ol00004ooooo`;o0000B_ooool3o`0000Cooooo0_l0000Qooooo`00<_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0004Wooooo00Co0000oooooooooooo
0000C?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0004_ooooo00Go0000
ooooooooooooooooo`000002ooooo`03o`000?oooooooooo04Kooooo00Go0000oooooooooooooooo
o`000002ooooo`04o`000?ooooooooooo`0004Sooooo00Go0000ooooooooooooooooo`000002oooo
o`04o`000?ooooooooooo`00023ooooo000[ooooo`Go00000oooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0004Wooooo00Co0000oooooooooooo0000COooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0004Sooooo1Ol00002ooooo`04o`000?ooooooooooo`0004So
oooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0004Sooooo00Go0000
ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`00023ooooo000dooooo`05o`000?oo
ooooooooooooool000000_ooool00ol0003oooooooooo`17ooooo`04o`000?ooooooooooo`0004ko
oooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo04Kooooo00Co0000oooo
oooooooo00000oooool01?l0003oooooooooool00018ooooo`Co00000oooool01?l0003ooooooooo
ool00019ooooo`?o00000oooool01?l0003oooooooooool0000Pooooo`00<Oooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo0000BOooool01?l0003oooooooooool0001;
ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00019ooooo`03o`00
0?oooooo000000?ooooo00Co0000oooooooooooo0000B?ooool00ol0003oooooooooo`04ooooo`04
o`000?ooooooooooo`0004Sooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo
ooooo`00023ooooo000aooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooooooo
ool00019ooooo`04o`000?ooooooooooo`0004_ooooo00Go0000ooooooooooooooooo`000002oooo
o`04o`000?ooooooooooo`0004[ooooo0_l00003ooooo`04o`000?ooooooooooo`0004Wooooo00?o
0000ooooooooool00oooool01?l0003oooooooooool00018ooooo`05o`000?ooooooooooooooool0
00000_ooool01?l0003oooooooooool0000Pooooo`00<_ooool3o`0000Cooooo0_l0001;ooooo`;o
0000COooool3o`0000Cooooo0_l0001<ooooo`03o`000?oooooooooo00;ooooo0_l0001;ooooo`;o
00001?ooool2o`0004[ooooo0ol00004ooooo`;o00008Oooool00?oooooonOooool00?oooooonOoo
ool00?oooooonOooool00?oooooonOooool00?oooooonOooool00?oooooonOooool00?oooooonOoo
ool002[oooooool0002eo`0001[ooooo000Zooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool06?ooool002[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1@ooooo`03
o`000?oooooooooo053ooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`1@ooooo`03
o`000?oooooooooo053ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Hooooo`00
:_ooool2o`000?ooooooEOooool2o`00oe[ooooo0_l0000Jooooo`00:_ooool00ol0003ooooooooo
o`3ooooooeCooooo0_l00?mKooooo`03o`000?oooooooooo01Sooooo000Zooooo`03o`000?oooooo
oooo0?ooooooE?ooool00ol00?ooooooooooo`1Jooooo`03o`000?oooooooooo01Sooooo000Zoooo
o`03o`000?oooooooooo0?oooooo2Oooool2o`00odWooooo00?o003oooooooooool0F_ooool00ol0
003oooooooooo`0Hooooo`00:_ooool00ol0003oooooooooo`3oooooo`Wooooo0_l00?m9ooooo`03
o`00oooooooooooo05[ooooo00?o0000ooooooooool06?ooool002[ooooo00?o0000ooooooooool0
ooooool9ooooo`03o`00oooooooooooo04Sooooo00?o003oooooooooool0F_ooool00ol0003ooooo
ooooo`0Hooooo`00:_ooool2o`000?oooooo2_ooool00ol00?ooooooooooo`18ooooo`03o`00oooo
oooooooo05Wooooo0_l0000Jooooo`00:_ooool00ol0003oooooooooo`3oooooo`Wooooo00?o003o
ooooooooool0B?ooool00ol00?ooooooooooo`1Jooooo`03o`000?oooooooooo01Sooooo000Zoooo
o`03o`000?oooooooooo0?oooooo1Oooool2o`00o`;ooooo00?o003oooooooooool0B?ooool00ol0
0?ooooooooooo`1Jooooo`03o`000?oooooooooo01Sooooo000Pooooo`?o00001oooool00ol0003o
ooooooooo`3oooooo`Gooooo0_l00?l2ooooo`03o`00oooooooooooo04Sooooo00?o003ooooooooo
ool0F_ooool00ol0003oooooooooo`0Hooooo`008Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo0;Wooooo0_l00?m9ooooo`05o`00ooooooooooooooooool00?l0B_ooool00ol00?oo
ooooooooo`1Jooooo`03o`000?oooooooooo01Sooooo000Hooooo`Go000000?oooooo`000?l00000
0ol00007ooooo`?o0000^Oooool2o`00odWooooo00Go003oooooooooooooooooo`00o`15ooooo`;o
003o0oooool00ol00?ooooooooooo`1Hooooo`?o00006_ooool001kooooo00Co0000oooooooooooo
00002?ooool00ol0003oooooooooo`2jooooo`03o`00oooooooooooo04Oooooo00Go003ooooooooo
ooooooooo`00o`15ooooo`;o003o0oooool00ol00?ooooooooooo`1Jooooo`03o`000?oooooooooo
01Sooooo000Oooooo`03o`000?oooooo000000Sooooo00?o0000ooooooooool0^_ooool00ol00?oo
ooooooooo`02o`00odGooooo00Go003oooooooooooooooooo`00o`16ooooo`05o`00oooooooooooo
ooooool00?l0G?ooool00ol0003oooooooooo`0Hooooo`008?ooool2o`0000Sooooo00?o0000oooo
ooooool0^_ooool00ol00?ooooooooooo`02o`00odGooooo00Go003oooooooooooooooooo`00o`16
ooooo`05o`00ooooooooooooooooool00?l0G?ooool00ol0003oooooooooo`0Hooooo`008Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo0;[ooooo00Go003oooooooooooooooooo`00
o`15ooooo`05o`00ooooooooooooooooool00?l0A_ooool01Ol00?oooooooooooooooooo003o05co
oooo00?o0000ooooooooool06?ooool002[ooooo00?o0000ooooooooool0^_ooool01Ol00?oooooo
oooooooooooo003o04Gooooo00Go003oooooooooooooooooo`00o`16ooooo`05o`00oooooooooooo
ooooool00?l0G?ooool00ol0003oooooooooo`0Hooooo`00:_ooool2o`000;_ooooo00Go003ooooo
ooooooooooooo`00o`15ooooo`05o`00ooooooooooooooooool00?l0A_ooool01Ol00?oooooooooo
oooooooo003o05_ooooo0_l0000Jooooo`00:_ooool00ol0003oooooooooo`1^ooooo`;o003oB_oo
ool01Ol00?oooooooooooooooooo003o04Gooooo00Go003oooooooooooooooooo`00o`16ooooo`05
o`00ooooooooooooooooool00?l0G?ooool00ol0003oooooooooo`0Hooooo`00:_ooool00ol0003o
ooooooooo`1^ooooo`;o003oB_ooool01Ol00?oooooooooooooooooo003o04Gooooo00Go003ooooo
ooooooooooooo`00o`16ooooo`05o`00ooooooooooooooooool00?l0G?ooool00ol0003ooooooooo
o`0Hooooo`00:_ooool00ol0003oooooooooo`1_ooooo`03o`00oooooooooooo04Sooooo00Go003o
ooooooooooooooooo`00o`15ooooo`05o`00ooooooooooooooooool00?l0A_ooool01Ol00?oooooo
oooooooooooo003o05cooooo00?o0000ooooooooool06?ooool002[ooooo00?o0000ooooooooool0
Koooool00ol00?ooooooooooo`18ooooo`05o`00ooooooooooooooooool00?l0AOooool01Ol00?oo
oooooooooooooooo003o00?ooooo0_l00?m1ooooo`05o`00ooooooooooooooooool00?l0G?ooool0
0ol0003oooooooooo`0Hooooo`00:_ooool00ol0003oooooooooo`1_ooooo`03o`00oooooooooooo
04Sooooo00Go003oooooooooooooooooo`00o`15ooooo`05o`00ooooooooooooooooool00?l00ooo
ool2o`00od7ooooo00Go003oooooooooooooooooo`00o`1Looooo`03o`000?oooooooooo01Sooooo
000Zooooo`;o0000L?ooool00ol00?ooooooooooo`18ooooo`05o`00ooooooooooooooooool00?l0
AOooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool0?oooool01Ol00?oo
oooooooooooooooo003o05_ooooo0_l0000Jooooo`00:_ooool00ol0003oooooooooo`1_ooooo`03
o`00oooooooooooo04Sooooo00Go003oooooooooooooooooo`00o`15ooooo`05o`00oooooooooooo
ooooool00?l01?ooool00ol00?ooooooooooo`0oooooo`05o`00ooooooooooooooooool00?l0G?oo
ool00ol0003oooooooooo`0Hooooo`00:_ooool00ol0003oooooooooo`1_ooooo`03o`00oooooooo
oooo04Sooooo00Go003oooooooooooooooooo`00o`15ooooo`05o`00ooooooooooooooooool00?l0
1?ooool00ol00?ooooooooooo`0oooooo`05o`00ooooooooooooooooool00?l0G?ooool00ol0003o
ooooooooo`0Hooooo`00:_ooool00ol0003oooooooooo`1_ooooo`03o`00oooooooooooo04Sooooo
00Go003oooooooooooooooooo`00o`15ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol0
0?ooooooooooo`0oooooo`05o`00ooooooooooooooooool00?l0G?ooool00ol0003oooooooooo`0H
ooooo`00:_ooool00ol0003oooooooooo`1_ooooo`03o`00oooooooooooo04Sooooo00Go003ooooo
ooooooooooooo`00o`15ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?oooooooooo
o`0oooooo`05o`00ooooooooooooooooool00?l0G?ooool00ol0003oooooooooo`0Hooooo`00:_oo
ool00ol0003oooooooooo`1_ooooo`03o`00oooooooooooo00;o003oA_ooool01Ol00?oooooooooo
oooooooo003o04Gooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo03oo
oooo00Go003oooooooooooooooooo`00o`1Looooo`03o`000?oooooooooo01Sooooo000Zooooo`;o
0000Joooool2o`00o`?ooooo00?o003oooooooooool00_l00?m6ooooo`05o`00oooooooooooooooo
ool00?l0AOooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool0?oooool0
1Ol00?oooooooooooooooooo003o05_ooooo0_l0000Jooooo`00:_ooool00ol0003oooooooooo`1Z
ooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o047ooooo0_l00?l3ooooo`05o`00oooo
ooooooooooooool00?l0AOooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003ooooooooo
ool0?oooool01Ol00?oooooooooooooooooo003o05cooooo00?o0000ooooooooool06?ooool002[o
oooo00?o0000ooooooooool0Joooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool06_ooool2o`00ob?ooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l0AOooool0
1Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool0?oooool01Ol00?oooooooooo
oooooooo003o05cooooo00?o0000ooooooooool06?ooool001kooooo1Ol00007ooooo`03o`000?oo
oooooooo06_ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01[ooooo
0_l00?l2ooooo`;o003o7oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l0AOooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool0?oooool01Ol0
0?oooooooooooooooooo003o05cooooo00?o0000ooooooooool06?ooool001oooooo00Co0000oooo
oooooooo00001oooool00ol0003oooooooooo`1[ooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`0Jooooo`04o`00ooooooooooooooooo`;o003o7oooool00ol00?oooooo
ooooo`02ooooo`05o`00ooooooooooooooooool00?l0AOooool01Ol00?oooooooooooooooooo003o
00Cooooo00?o003oooooooooool0?oooool01Ol00?oooooooooooooooooo003o05cooooo00?o0000
ooooooooool06?ooool001Sooooo1Ol00003ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0Joooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool06_ooool0
1Ol00?oooooooooooooooooo003o023ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooo
oooooooo003o00;ooooo0_l00?lmooooo`;o003o0_ooool01Ol00?oooooooooooooooooo003o00Co
oooo00?o003oooooooooool0?oooool01Ol00?oooooooooooooooooo003o05cooooo00?o0000oooo
ooooool06?ooool0027ooooo00?o0000ooooooooool01_ooool3o`0006_ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo01[ooooo00Go003oooooooooooooooooo`00o`0P
ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`02ooooo`;o003o?Ooo
ool2o`00o`;ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo03oooooo
00Go003oooooooooooooooooo`00o`1Jooooo`?o00006_ooool001kooooo00Go0000oooooooooooo
ooooo`000007ooooo`03o`000?oooooooooo06_ooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo01[ooooo00Go003oooooooooooooooooo`00o`0Pooooo`03o`00oooooooo
oooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo03_ooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
?oooool01Ol00?oooooooooooooooooo003o05cooooo00?o0000ooooooooool06?ooool001kooooo
00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo06_ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo01[ooooo00Go003oooooooooooooooooo`00o`0P
ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooo
oooooooo03_ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool0?oooool01Ol00?oooooooooooooooooo003o05cooooo00?o0000oooooooo
ool06?ooool001oooooo0ol00008ooooo`03o`000?oooooooooo06_ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo01[ooooo00Go003oooooooooooooooooo`00o`0Poooo
o`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo03_ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool0?oooool01Ol00?oooooooooooooooooo003o05cooooo00?o0000ooooooooool0
6?ooool002[ooooo00?o0000ooooooooool0Joooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool06_ooool01Ol00?oooooooooooooooooo003o023ooooo00?o003ooooooooo
ool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool06Oooool2o`00
ob3ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool0?oooool01Ol00?oooooooooooooooooo003o05cooooo00?o0000ooooooooool06?oo
ool002[ooooo0_l0001/ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`0Jooooo`05o`00ooooooooooooooooool00?l08?ooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Iooooo`;o003o8?ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0ooooo
o`05o`00ooooooooooooooooool00?l0Foooool2o`0001[ooooo000Zooooo`03o`000?oooooooooo
06_ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01[ooooo00Go003o
ooooooooooooooooo`00o`0Pooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo01[ooooo00?o003oooooooooool07_ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0oooooo`05
o`00ooooooooooooooooool00?l0G?ooool00ol0003oooooooooo`0Hooooo`00:_ooool00ol0003o
ooooooooo`1[ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Joooo
o`05o`00ooooooooooooooooool00?l08?ooool00ol00?ooooooooooo`02ooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo01kooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
>_ooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`1Looooo`03o`000?oooooooooo01So
oooo000Zooooo`03o`000?oooooooooo06_ooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo01[ooooo00Go003oooooooooooooooooo`00o`0Pooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01[ooooo00?o003o
ooooooooool07_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`0jooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o05cooooo
00?o0000ooooooooool06?ooool002[ooooo00?o0000ooooooooool0Joooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool06_ooool01Ol00?oooooooooooooooooo003o023o
oooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool06_ooool00ol00?ooooooooooo`0Nooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo03_ooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo05[ooooo00?o0000ooooooooool06?ooool002[ooooo00?o0000
ooooooooool0Joooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool06_oo
ool01Ol00?oooooooooooooooooo003o023ooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool06_ooool00ol00?ooooooooooo`0Nooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
03_ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo05[ooooo00?o0000
ooooooooool06?ooool002[ooooo0_l0001/ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`0Jooooo`05o`00ooooooooooooooooool00?l08?ooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Jooooo`03o`00
oooooooooooo01kooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool07Oooool2o`00oacooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo05Wooooo0_l0000Jooooo`00:_ooool00ol0003oooooooooo`1[ooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Eooooo`;o003o0oooool01Ol0
0?oooooooooooooooooo003o023ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool06_ooool00ol00?ooooooooooo`0Nooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01gooooo
0_l00?lLooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`1Jooooo`03
o`000?oooooooooo01Sooooo000Zooooo`03o`000?oooooooooo06_ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo01Gooooo0_l00?l3ooooo`05o`00oooooooooooooooo
ool00?l08?ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`0Eooooo`;o003o0oooool01?l00?ooooooooooooooool2o`00oa_ooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
7_ooool00ol00?ooooooooooo`0Jooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`1Jooooo`03o`000?oooooooooo01Sooooo000Zooooo`03o`000?oooooooooo06_ooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01Kooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo01kooooo00?o003oooooooooool00_ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool05Oooool2o`00o`?ooooo00Co003o
oooooooooooooooo0_l00?lKooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo01Wooooo0_l00?l3ooooo`03o`00oooooooooooo01[ooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo05[ooooo00?o0000oooooooo
ool06?ooool002[ooooo00?o0000ooooooooool0Joooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool05_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool07_ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`0Fooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`0Jooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo01Wooooo0_l00?l3ooooo`03o`00oooooooooooo01[ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo05[ooooo00?o0000ooooooooool06?ooool002[ooooo
00?o0000ooooooooool0Joooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool05_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool07_ooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0F
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Jooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01[ooooo
00Go003oooooooooooooooooo`00o`0Looooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`1Jooooo`03o`000?oooooooooo01Sooooo000Zooooo`;o0000K?ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Co003ooooooooooooooooo0_l00?lCooooo`05o`00oooooooo
ooooooooool00?l00oooool01?l00?ooooooooooooooool2o`00oa_ooooo00?o003oooooooooool0
0_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool05_ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool06_ooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02o`00oaSooooo00Go003o
ooooooooooooooooo`00o`0Looooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`1Iooooo`;o00006_ooool002[ooooo00?o0000ooooooooool0Joooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Co003ooooooooooooooooo0_l00?lCooooo`05o`00oooooooooooooooo
ool00?l00oooool01?l00?ooooooooooooooool2o`00oa_ooooo00?o003oooooooooool00_ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool05_ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool06_ooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02o`00oaSooooo00Go003ooooooooo
ooooooooo`00o`0Looooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`1J
ooooo`03o`000?oooooooooo01Sooooo000Zooooo`03o`000?oooooooooo06_ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l05?ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`0Looooo`03o`00oooooooooooo00;o
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01Kooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo01[ooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`0Hooooo`05o`00
ooooooooooooooooool00?l07?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool0F_ooool00ol0003oooooooooo`0Hooooo`008?ooool2o`0000Sooooo00?o0000oooooooo
ool0Joooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`0D
ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o01cooooo
00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool05_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool06_ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooo
oooo003o01Sooooo00Go003oooooooooooooooooo`00o`0Looooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`1Jooooo`03o`000?oooooooooo01Sooooo000Oooooo`04o`00
0?ooooooooooo`0000Oooooo00?o0000ooooooooool0Joooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`0Dooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o01cooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool05_ooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool06_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o01Sooooo00Go003ooooooooooooooooo
o`00o`0Looooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`1Jooooo`03
o`000?oooooooooo01Sooooo000Oooooo`04o`000?ooooooooooo`0000Oooooo00?o0000oooooooo
ool01oooool2o`00o`;ooooo0_l00?l2ooooo`;o003o0_ooool2o`00o`;ooooo0_l00?l2ooooo`;o
003o0_ooool2o`00o`?ooooo0_l00?l2ooooo`;o003o0_ooool2o`00o`;ooooo0_l00?l2ooooo`;o
003o0_ooool2o`00o`?ooooo0_l00?l2ooooo`;o003o0_ooool2o`00o`;ooooo0_l00?l2ooooo`;o
003o0_ooool2o`00o`;ooooo0_l00?lDooooo`05o`00ooooooooooooooooool00?l00oooool01Ol0
0?oooooooooooooooooo003o01Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l07?ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`0Fooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`0Jooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l06?ooool01Ol00?oooooooooooooooooo003o01cooooo
00Go003oooooooooooooooooo`00o`03ooooo`04o`00ooooooooooooooooo`;o003o0_ooool2o`00
o`;ooooo0_l00?l2ooooo`;o003o0_ooool2o`00o`;ooooo0_l00?l3ooooo`;o003o0_ooool2o`00
o`;ooooo0_l00?l2ooooo`;o003o0_ooool2o`00o`;ooooo0_l00?l3ooooo`;o003o0_ooool2o`00
o`;ooooo0_l00?l2ooooo`;o003o0_ooool2o`00o`;ooooo0_l00?l2ooooo`;o003o0oooool2o`00
o`Sooooo00?o0000ooooooooool06?ooool001oooooo00Co0000oooooooooooo00001oooool:o`00
00;o003o0_l00002o`00o`;o00000_l00?l2o`0000;o003o0_l00002o`00o`;o00000_l00?l2o`00
00;o003o0ol00002o`00o`;o00000_l00?l2o`0000;o003o0_l00002o`00o`;o00000_l00?l2o`00
00;o003o0ol00002o`00o`;o00000_l00?l2o`0000;o003o0_l00002o`00o`;o00000_l00?l2o`00
00;o003o0_l00002o`00o`?o000000Go003oo`000?l0003o0000o`00o`03o`000004o`00ool0003o
0000o`0000;o003o0ol000001Ol00?oo0000o`000?l0003o003o00?o000000Go003oo`000?l0003o
0000o`00o`03o`000005o`00ool0003o0000o`000?l00?l01?l000001Ol00?oo0000o`000?l0003o
003o00?o000000Go003oo`000?l0003o0000o`00o`03o`000005o`00ool0003o0000o`000?l00?l0
1?l000001Ol00?oo0000o`000?l0003o003o00?o000000Go003oo`000?l0003o0000o`00o`03o`00
0005o`00ool0003o0000o`000?l00?l00ol000000ol00?oo0000o`000002o`000005o`00ool0003o
0000o`000?l00?l00ol000001Ol00?oo0000o`000?l0003o003o00?o000000Go003oo`000?l0003o
0000o`00o`03o`000003o`00ool0003o000000;o000000Go003oo`000?l0003o0000o`00o`03o`00
0005o`00ool0003o0000o`000?l00?l00ol000001Ol00?oo0000o`000?l0003o003o00Co000000Go
003oo`000?l0003o0000o`00o`03o`000005o`00ool0003o0000o`000?l00?l00ol000001Ol00?oo
0000o`000?l0003o003o00?o000000?o003oo`000?l000000_l000001Ol00?oo0000o`000?l0003o
003o00?o000000Go003oo`000?l0003o0000o`00o`03o`000005o`00ool0003o0000o`000?l00?l0
0ol000000ol00?oo0000o`000002o`000005o`00ool0003o0000o`000?l00?l00ol000001Ol00?oo
0000o`000?l0003o003o00?o000000Go003oo`000?l0003o0000o`00o`04o`000005o`00ool0003o
0000o`000?l00?l00ol000001Ol00?oo0000o`000?l0003o003o00?o000000Co003oo`000?l0003o
00000_l00?l2o`0000;o003o0_l00002o`00o`;o00000_l00?l2o`0000;o003o0_l00002o`00o`?o
00000_l00?l2o`0000;o003o0_l00002o`00o`;o00000_l00?l2o`0000;o003o0_l00002o`00o`?o
00000_l00?l2o`0000;o003o0_l00002o`00o`;o00000_l00?l2o`0000;o003o0_l00002o`00o`;o
00000_l00?l3o`0000;o003o2Ol0000Jooooo`007oooool01?l0003oooooooooool00007ooooo`03
o`000?oooooooooo05[ooooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00oooooooooooo
ooooo`;o003o4oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooooooooooooooo
o`00o`0Dooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`0Dooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool03Oooool01Ol00?oooooo
oooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l06?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo00[ooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o06Sooooo00?o0000
ooooooooool06?ooool001oooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`1J
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Fooooo`05o`00oooo
ooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o01Cooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o01Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool0
0?l01?ooool00ol00?ooooooooooo`0=ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`0Hooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool02Oooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`1Xooooo`03o`000?oooooooooo01Sooooo000Poooo
o`;o00002?ooool00ol0003oooooooooo`1Jooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`0Fooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooo
oooooooo003o01Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o01Cooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`0=ooooo`05o`00
ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`0Hooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool02Oooool2o`00o`?ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`1Xoooo
o`03o`000?oooooooooo01Sooooo000Zooooo`03o`000?oooooooooo05[ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo01Kooooo00Go003oooooooooooooooooo`00o`04
ooooo`05o`00ooooooooooooooooool00?l05?ooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l05?ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooo
oooooooo00gooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o01Sooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0>ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l0J?ooool00ol0003oooooooooo`0Hooooo`00:_ooool2o`0005_ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo01Kooooo00Go003oooooooooooooooooo`00o`04oooo
o`05o`00ooooooooooooooooool00?l05?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l05?ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooo
oooo00gooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o01Sooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0>ooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0
Ioooool2o`0001[ooooo000Zooooo`03o`000?oooooooooo05[ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo01Kooooo00Go003oooooooooooooooooo`00o`04ooooo`05
o`00ooooooooooooooooool00?l05?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l05?ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo
00gooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o01Sooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0>ooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0J?oo
ool00ol0003oooooooooo`0Hooooo`00:_ooool00ol0003oooooooooo`1Jooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`0Fooooo`05o`00ooooooooooooooooool00?l0
1?ooool01Ol00?oooooooooooooooooo003o01Cooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l00oooool01?l00?ooooooooooooooool2o`00oa;ooooo0_l0
0?l3ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo00gooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o01Sooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0>ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooooooo
ool00?l0J?ooool00ol0003oooooooooo`0Hooooo`00:_ooool00ol0003oooooooooo`1Jooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Fooooo`05o`00oooooooooooo
ooooool00?l01?ooool01Ol00?oooooooooooooooooo003o01Cooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01?l00?ooooooooooooooool2o`00
oa;ooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo00gooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o01Sooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0>
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l0J?ooool00ol0003oooooooooo`0Hooooo`00:_ooool00ol0003ooooooooo
o`1Jooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Fooooo`05o`00
ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o01Cooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`0Jooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo00gooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o01Sooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l00oooool2o`00o`oooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`1Xoooo
o`03o`000?oooooooooo01Sooooo000Zooooo`03o`000?oooooooooo05[ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo01Kooooo00Go003oooooooooooooooooo`00o`04
ooooo`05o`00ooooooooooooooooool00?l05?ooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01[ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool03Oooool01Ol0
0?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l06?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`;o003o3oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o06Sooooo00?o0000ooooooooool06?oo
ool002[ooooo0_l0001Kooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`0Fooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o01Co
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`0Jooooo`05o`00ooooooooooooooooool00?l00oooool01?l00?oooooooooo
ooooool2o`00o`oooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o01Sooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l05?ooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o06Oooooo0_l0000Joooo
o`00:_ooool00ol0003oooooooooo`1Jooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`0Fooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooo
oooo003o01Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`0Jooooo`05o`00ooooooooooooooooool00?l00oooool01?l0
0?ooooooooooooooool2o`00o`oooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o01Sooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l05?ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o06Sooooo
00?o0000ooooooooool06?ooool002[ooooo00?o0000ooooooooool0F_ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool05_ooool01Ol00?oooooooooooooooooo003o00Co
oooo00?o003oooooooooool00_l00?lDooooo`05o`00ooooooooooooooooool00?l00oooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool06_ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool04_ooool01Ol00?oooooooooooooooooo003o00Cooooo
00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l06?ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`0Dooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l0J?ooool00ol0003oooooooooo`0Hooooo`00:_ooool00ol0003oooooooooo`1Jooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Fooooo`05o`00oooooooooooooooo
ool00?l01?ooool00ol00?ooooooooooo`02o`00oaCooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Jooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`0Booooo`05o`00ooooooooooooooooool0
0?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_l00?lHoooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o01Cooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooo
ooooo`00o`1Xooooo`03o`000?oooooooooo01Sooooo000Zooooo`03o`000?oooooooooo05[ooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01Kooooo00Go003ooooooooo
ooooooooo`00o`04ooooo`03o`00oooooooooooo01Kooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Jooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`0Booooo`;o003o0_ooool00ol00?oooooo
ooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02o`00oaSo
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l05?ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooo
oooooooo003o06Sooooo00?o0000ooooooooool06?ooool002[ooooo00?o0000ooooooooool0F_oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool05_ooool01Ol00?oooooo
oooooooooooo003o00Cooooo00?o003oooooooooool05_ooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01[ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01;ooooo0_l00?l2ooooo`03o`00oooo
oooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01[ooooo
00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l05?ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooo
oooo003o06Sooooo00?o0000ooooooooool06?ooool002[ooooo0_l0001Kooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`0Fooooo`05o`00ooooooooooooooooool00?l0
1?ooool00ol00?ooooooooooo`0Fooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool06_ooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`02ooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`0Jooooo`05o`00ooooooooooooooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o01Cooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`1Wooooo`;o00006_ooool0
02[ooooo00?o0000ooooooooool0F_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool05_ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool05_oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo01[ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
01Kooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool06_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`0Dooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05
o`00ooooooooooooooooool00?l0J?ooool00ol0003oooooooooo`0Hooooo`00:_ooool00ol0003o
ooooooooo`1Jooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Foooo
o`;o003o0_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01Kooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`0Jooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Fooooo`03o`00
oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01[o
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l05?ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooo
oooooooo003o06Sooooo00?o0000ooooooooool06?ooool001kooooo1Ol00007ooooo`03o`000?oo
oooooooo05[ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01Kooooo
0_l00?l2ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool05_ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
01[ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01Kooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool06_oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`0Dooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooo
ooooool00?l0J?ooool00ol0003oooooooooo`0Hooooo`007oooool01?l0003oooooooooool00007
ooooo`03o`000?oooooooooo05[ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooo
oooooooo01[ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Fooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool06_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool05_ooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0J
ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o01Cooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool00_l00?mXooooo`03o`000?oooooooooo01Sooooo000Pooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0F_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool06_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01Kooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0J
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Fooooo`03o`00oooo
oooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01[ooooo
00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l05?ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02
o`00ofSooooo00?o0000ooooooooool06?ooool0027ooooo00?o0000ooooooooool01_ooool3o`00
05[ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01[ooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`0Fooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool06_ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`02ooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Jooooo`05o`00oooooooooooo
ooooool00?l00oooool01Ol00?oooooooooooooooooo003o01Cooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0J?ooool3o`0001[ooooo
000Nooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`1Jooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool05_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo01[ooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool00_ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool06_ooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`0Dooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo06[ooooo00?o0000ooooooooool06?ooool0
01kooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo05[ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01[ooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`0Fooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool06_ooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`0Jooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o01Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool0J_ooool00ol0003oooooooooo`0Hooooo`00
7oooool3o`0000Sooooo00?o0000ooooooooool0F_ooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool06_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01Ko
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`0Jooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`0Fooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo01[ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l05?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`1Zooooo`03o`000?oooooooooo01Sooooo000Zooooo`03o`000?oooooooooo
05[ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01[ooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`0Eooooo`;o003o0oooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`0Looooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo01Wooooo0_l00?l3ooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`0Booooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo06[ooooo00?o0000ooooooooool06?oo
ool002[ooooo0_l0001Kooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`0Jooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool05Oooool2o`00o`?ooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l07?ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`02oooo
o`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Iooooo`;o003o0oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool04_ooool2o`00o`;ooooo00Go
003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo06Wooooo0_l0000Jooooo`00:_oo
ool00ol0003oooooooooo`1Jooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`0Jooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool06_ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`0Looooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo00;ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01kooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo01;ooooo0_l00?l2ooooo`05o`00ooooooooooooooooool0
0?l01?ooool00ol00?ooooooooooo`1Zooooo`03o`000?oooooooooo01Sooooo000Zooooo`03o`00
0?oooooooooo05[ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01[o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Jooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o01cooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool00_ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool07_ooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool05_ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003ooooo
ooooool0J_ooool00ol0003oooooooooo`0Hooooo`00:_ooool00ol0003oooooooooo`1Jooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Jooooo`04o`00oooooooooooo
ooooo`;o003o7?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`0Looooo`;o003o0_ooool01?l00?ooooooooooooooool2o`00oaOooooo00?o003ooooooooo
ool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool07_ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool05_ooool01Ol00?oooooooooooooo
oooo003o00Cooooo00?o003oooooooooool0J_ooool00ol0003oooooooooo`0Hooooo`00:_ooool0
0ol0003oooooooooo`1Jooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`0Jooooo`04o`00ooooooooooooooooo`;o003o7?ooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`0Looooo`;o003o0_ooool01?l00?ooooooooooooooool2
o`00oaOooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool07_ooool01Ol00?oooooooooooooooooo003o00?ooooo0_l00?lGooooo`05o`00
ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`1Zooooo`03o`000?oooooooooo01So
oooo000Zooooo`03o`000?oooooooooo05[ooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo01[ooooo0_l00?lPooooo`05o`00ooooooooooooooooool00?l00oooool01Ol0
0?oooooooooooooooooo003o023ooooo00?o003oooooooooool06_ooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Nooooo`05o`00oooo
ooooooooooooool00?l00oooool2o`00oaOooooo00Go003oooooooooooooooooo`00o`04ooooo`03
o`00oooooooooooo06[ooooo00?o0000ooooooooool06?ooool002[ooooo0_l0001Kooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Jooooo`;o003o8?ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`0Pooooo`03o`00oooooooo
oooo01[ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool07_ooool01Ol00?oooooooooooooooooo003o01cooooo00Go003ooooooooooooo
ooooo`00o`04ooooo`03o`00oooooooooooo06Wooooo0_l0000Jooooo`00:_ooool00ol0003ooooo
ooooo`1Jooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0looooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o023ooooo00?o003o
ooooooooool06_ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`0Nooooo`05o`00ooooooooooooooooool00?l07?ooool01Ol00?oooooo
oooooooooooo003o00Cooooo00?o003oooooooooool0J_ooool00ol0003oooooooooo`0Hooooo`00
:_ooool00ol0003oooooooooo`1Jooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`0looooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o023ooooo00?o003oooooooooool06_ooool00ol00?ooooooooooo`02ooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`0Nooooo`05o`00ooooooooooooooooool00?l0
7?ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool0J_ooool00ol0003o
ooooooooo`0Hooooo`00:_ooool00ol0003oooooooooo`1Jooooo`05o`00ooooooooooooooooool0
0?l00oooool2o`00ocgooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l08?ooool00ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo00;ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01kooooo00Go003ooooooooooooooooo
o`00o`0Looooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`1Zooooo`03
o`000?oooooooooo01Sooooo000Zooooo`03o`000?oooooooooo05[ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`;o003o?Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`0Pooooo`03o`00oooooooooooo01[ooooo00?o003oooooooooool00_ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool07_ooool01Ol00?oooooooooo
oooooooo003o01cooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo06[o
oooo00?o0000ooooooooool06?ooool002[ooooo00?o0000ooooooooool0F_ooool01Ol00?oooooo
oooooooooooo003o04;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l08?ooool00ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo00;ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01kooooo00Go003ooooooooooooooooo
o`00o`0Looooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`1Zooooo`03
o`000?oooooooooo01Sooooo000Zooooo`;o0000Foooool01Ol00?oooooooooooooooooo003o04;o
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l08?ooool2
o`00oa_ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool07_ooool01Ol00?oooooooooooooooooo003o01cooooo00Go003ooooooooooooo
ooooo`00o`04ooooo`03o`00oooooooooooo06Wooooo0_l0000Jooooo`00:_ooool00ol0003ooooo
ooooo`1Jooooo`05o`00ooooooooooooooooool00?l0@_ooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`0Pooooo`;o003o6oooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Nooooo`05o`00oooo
ooooooooooooool00?l07?ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003ooooooooo
ool0J_ooool00ol0003oooooooooo`0Hooooo`00:_ooool00ol0003oooooooooo`1Jooooo`05o`00
ooooooooooooooooool00?l0@_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`0mooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo01kooooo00Go003oooooooooooooooooo`00o`0Looooo`05o`00
ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`1Zooooo`03o`000?oooooooooo01So
oooo000Pooooo`?o00001oooool00ol0003oooooooooo`1Jooooo`05o`00ooooooooooooooooool0
0?l0@_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`0m
ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooo
oooooooo01kooooo00Go003oooooooooooooooooo`00o`0Looooo`05o`00ooooooooooooooooool0
0?l01?ooool00ol00?ooooooooooo`1Zooooo`03o`000?oooooooooo01Sooooo000Qooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0F_ooool01Ol00?oooooooooooooooooo003o04;o
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0?Oooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`0Nooooo`05o`00ooooooooooooooooool00?l07?ooool01Ol00?oooooooooooooooooo003o00Co
oooo00?o003oooooooooool0J_ooool00ol0003oooooooooo`0Hooooo`007_ooool5o`0000Oooooo
00?o0000ooooooooool0F_ooool01Ol00?oooooooooooooooooo003o04;ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`04o`00ooooooooooooooooo`;o003o??ooool2o`00o`?ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01kooooo00Go003ooooooooooooooooo
o`00o`0Looooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`1Zooooo`03
o`000?oooooooooo01Sooooo000Nooooo`04o`000?ooooooooooo`0000Sooooo0ol0001Jooooo`05
o`00ooooooooooooooooool00?l0@_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Co003o
oooooooooooooooo0_l00?llooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool07_ooool01Ol00?oooooooooooooooooo003o01cooooo00Go003ooooooooo
ooooooooo`00o`04ooooo`03o`00oooooooooooo06Sooooo0ol0000Jooooo`007oooool00ol0003o
ooooo`000008ooooo`03o`000?oooooooooo05[ooooo00Go003oooooooooooooooooo`00o`12oooo
o`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`14ooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`0Mooooo`;o003o0oooool00ol00?oooooooooo
o`0Jooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`1Zooooo`03o`00
0?oooooooooo01Sooooo000Pooooo`;o00002?ooool00ol0003oooooooooo`1Jooooo`05o`00oooo
ooooooooooooool00?l0@_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool0A?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool07Oooool2o`00
o`?ooooo0_l00?lKooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`1Z
ooooo`03o`000?oooooooooo01Sooooo000Qooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0F_ooool01Ol00?oooooooooooooooooo003o04;ooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo04Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo02;ooooo0_l00?lKooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?oo
ooooooooo`1Zooooo`03o`000?oooooooooo01Sooooo000Zooooo`03o`000?oooooooooo05[ooooo
00Go003oooooooooooooooooo`00o`12ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`14ooooo`05o`00ooooooooooooooooool00?l00_ooool2o`00od7ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`;o003oK?ooool00ol0003oooooooooo`0Hooooo`00:_ooool2
o`0005_ooooo00Go003oooooooooooooooooo`00o`12ooooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`14ooooo`05o`00ooooooooooooooooool00?l00_ooool2o`00od7o
oooo0_l00?l2ooooo`04o`00ooooooooooooooooo`;o003oJoooool2o`0001[ooooo000Zooooo`03
o`000?oooooooooo05[ooooo00Go003oooooooooooooooooo`00o`12ooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`14ooooo`05o`00ooooooooooooooooool00?l0AOoo
ool2o`00o`;ooooo00?o003oooooooooool0Koooool00ol0003oooooooooo`0Hooooo`00:_ooool0
0ol0003oooooooooo`1Jooooo`05o`00ooooooooooooooooool00?l0@_ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool0A?ooool01Ol00?oooooooooooooooooo003o04Wo
oooo00?o003oooooooooool0Koooool00ol0003oooooooooo`0Hooooo`00:_ooool00ol0003ooooo
ooooo`1Jooooo`05o`00ooooooooooooooooool00?l0@_ooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool0A?ooool01Ol00?oooooooooooooooooo003o04Wooooo00?o003o
ooooooooool0Koooool00ol0003oooooooooo`0Hooooo`00:_ooool00ol0003oooooooooo`1Joooo
o`05o`00ooooooooooooooooool00?l0@_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool0A?ooool01Ol00?oooooooooooooooooo003o04Wooooo00?o003oooooooooool0
Koooool00ol0003oooooooooo`0Hooooo`00:_ooool00ol0003oooooooooo`1Jooooo`05o`00oooo
ooooooooooooool00?l0@_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool0A?ooool01Ol00?oooooooooooooooooo003o04Wooooo00?o003oooooooooool0Koooool00ol0
003oooooooooo`0Hooooo`00:_ooool2o`0005_ooooo00Go003oooooooooooooooooo`00o`12oooo
o`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`14ooooo`05o`00oooooooo
ooooooooool00?l0BOooool00ol00?ooooooooooo`1^ooooo`;o00006_ooool002[ooooo00?o0000
ooooooooool0F_ooool01Ol00?oooooooooooooooooo003o04;ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo04Cooooo00Go003oooooooooooooooooo`00o`19ooooo`03
o`00oooooooooooo06oooooo00?o0000ooooooooool06?ooool002[ooooo00?o0000ooooooooool0
F_ooool01Ol00?oooooooooooooooooo003o047ooooo0_l00?l3ooooo`05o`00oooooooooooooooo
ool00?l0A_ooool01Ol00?oooooooooooooooooo003o04Wooooo00?o003oooooooooool0Koooool0
0ol0003oooooooooo`0Hooooo`00:_ooool00ol0003oooooooooo`1Jooooo`05o`00oooooooooooo
ooooool00?l0@Oooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`16ooooo`05o`00oooo
ooooooooooooool00?l0BOooool00ol00?ooooooooooo`1_ooooo`03o`000?oooooooooo01Sooooo
000Zooooo`03o`000?oooooooooo05[ooooo00Go003oooooooooooooooooo`00o`16ooooo`05o`00
ooooooooooooooooool00?l0A_ooool01Ol00?oooooooooooooooooo003o04Wooooo0_l00?m`oooo
o`03o`000?oooooooooo01Sooooo000Zooooo`03o`000?oooooooooo05[ooooo00Go003ooooooooo
ooooooooo`00o`16ooooo`05o`00ooooooooooooooooool00?l0A_ooool01Ol00?oooooooooooooo
oooo003o04Wooooo0_l00?m`ooooo`03o`000?oooooooooo01Sooooo000Zooooo`;o0000Foooool0
1Ol00?oooooooooooooooooo003o04Kooooo00Go003oooooooooooooooooo`00o`16ooooo`05o`00
ooooooooooooooooool00?l0^_ooool2o`0001[ooooo000Zooooo`03o`000?oooooooooo05[ooooo
00Go003oooooooooooooooooo`00o`16ooooo`05o`00ooooooooooooooooool00?l0A_ooool01Ol0
0?oooooooooooooooooo003o0;_ooooo00?o0000ooooooooool06?ooool002[ooooo00?o0000oooo
ooooool0F_ooool01Ol00?oooooooooooooooooo003o04Kooooo00Go003oooooooooooooooooo`00
o`16ooooo`05o`00ooooooooooooooooool00?l0^oooool00ol0003oooooooooo`0Hooooo`007ooo
ool3o`0000Sooooo00?o0000ooooooooool0F_ooool01Ol00?oooooooooooooooooo003o04Kooooo
00Go003oooooooooooooooooo`00o`16ooooo`05o`00ooooooooooooooooool00?l0^oooool00ol0
003oooooooooo`0Hooooo`007_ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000oooo
ooooool0F_ooool01Ol00?oooooooooooooooooo003o04Kooooo00Go003oooooooooooooooooo`00
o`15ooooo`;o003o0oooool00ol00?ooooooooooo`2iooooo`03o`000?oooooooooo01Sooooo000N
ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`1Jooooo`04o`00oooo
ooooooooooooo`;o003oAOooool01Ol00?oooooooooooooooooo003o04Gooooo0_l00?l3ooooo`03
o`00oooooooooooo0;Wooooo00?o0000ooooooooool06?ooool001kooooo1?l00008ooooo`?o0000
F_ooool01?l00?ooooooooooooooool2o`00odGooooo00Go003oooooooooooooooooo`00o`19oooo
o`;o003o^Oooool3o`0001[ooooo000Nooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool0F_ooool00ol00?ooooooooooo`18ooooo`05o`00ooooooooooooooooool00?l0BOooool2o`00
ok_ooooo00?o0000ooooooooool06?ooool001oooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`1Jooooo`03o`00oooooooooooo04Sooooo00Go003oooooooooooooooooo`00o`3ooooo
o`Oooooo00?o0000ooooooooool06?ooool0023ooooo0_l00008ooooo`03o`000?oooooooooo05[o
oooo00?o003oooooooooool0B?ooool00ol00?ooooooooooo`02o`00oooooooo1oooool00ol0003o
ooooooooo`0Hooooo`00:_ooool00ol0003oooooooooo`1Jooooo`03o`00oooooooooooo04Sooooo
00?o003oooooooooool00_l00?ooooooo`Oooooo00?o0000ooooooooool06?ooool002[ooooo00?o
0000ooooooooool0F_ooool00ol00?ooooooooooo`18ooooo`03o`00oooooooooooo0?oooooo2Ooo
ool00ol0003oooooooooo`0Hooooo`00:_ooool2o`0005_ooooo00?o003oooooooooool0B?ooool0
0ol00?ooooooooooo`3oooooo`Sooooo0_l0000Jooooo`00:_ooool00ol0003oooooooooo`1Joooo
o`03o`00oooooooooooo04Oooooo0_l00?ooooooo`_ooooo00?o0000ooooooooool06?ooool002[o
oooo00?o0000ooooooooool0F_ooool00ol00?ooooooooooo`17ooooo`;o003oooooool;ooooo`03
o`000?oooooooooo01Sooooo000Zooooo`03o`000?oooooooooo05[ooooo00?o003oooooooooool0
oooooomDooooo`03o`000?oooooooooo01Sooooo000Zooooo`03o`000?oooooooooo05[ooooo00?o
003oooooooooool0oooooomDooooo`03o`000?oooooooooo01Sooooo000Zooooo`;o0000Foooool2
o`00ooooooooE?ooool2o`0001[ooooo000Zooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0D?ooool2o`00oe7ooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`1@oooo
o`03o`000?oooooooooo053ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Hoooo
o`00:_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Sooooo000Zooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool06?ooool002[oooooool0002eo`0001[ooooo003o
ooooooWooooo003oooooooWooooo003oooooooWooooo003oooooooWooooo003oooooooWooooo003o
ooooooWooooo003oooooooWooooo003oooooooWooooo003oooooooWooooo003oooooooWooooo003o
ooooooWooooo003oooooooWooooo0000\
\>"],
  ImageRangeCache->{{{0, 503}, {536.562, 0}} -> {-0.0250052, -0.0267009, \
0.0020875, 0.0020875}, {{11.9375, 491}, {523.75, 364.062}} -> {-32.6858, \
-5.59243, 0.240979, 0.0648204}, {{11.9375, 491}, {348.062, 188.438}} -> \
{-33.8842, -1.503, 0.242805, 0.00728415}, {{11.9375, 491}, {172.438, 12.75}} -> \
{-32.6858, -38.1421, 0.240979, 0.0867525}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Magnitude plot of unwindowed DTFT as a function of frequency", \
"Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(X\[Theta]\  = DTFT[xda, \[Theta]]\  // \ Simplify; 
    g1 = Plot[
        Abs[X\[Theta]\  /. \ \[Theta] \[Rule] \ 2  \[Pi]\ f/fs], {f, \(-fs\)/
            2, fs/2}, \ PlotStyle \[Rule] {Blue, \ Dashing[{ .01}]}, \ 
        PlotRange \[Rule] All, PlotPoints \[Rule] 200];\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.047619 0.0108341 0.00484525 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01083 -6 -4.5 ]
[-0.0125 .01083 0 4.5 ]
[-0.0125 .10774 -12 -4.5 ]
[-0.0125 .10774 0 4.5 ]
[-0.0125 .20464 -12 -4.5 ]
[-0.0125 .20464 0 4.5 ]
[-0.0125 .30155 -12 -4.5 ]
[-0.0125 .30155 0 4.5 ]
[-0.0125 .39845 -12 -4.5 ]
[-0.0125 .39845 0 4.5 ]
[-0.0125 .49536 -18 -4.5 ]
[-0.0125 .49536 0 4.5 ]
[-0.0125 .59226 -18 -4.5 ]
[-0.0125 .59226 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01083 m
.00625 .01083 L
s
[(0)] -0.0125 .01083 1 0 Mshowa
0 .10774 m
.00625 .10774 L
s
[(20)] -0.0125 .10774 1 0 Mshowa
0 .20464 m
.00625 .20464 L
s
[(40)] -0.0125 .20464 1 0 Mshowa
0 .30155 m
.00625 .30155 L
s
[(60)] -0.0125 .30155 1 0 Mshowa
0 .39845 m
.00625 .39845 L
s
[(80)] -0.0125 .39845 1 0 Mshowa
0 .49536 m
.00625 .49536 L
s
[(100)] -0.0125 .49536 1 0 Mshowa
0 .59226 m
.00625 .59226 L
s
[(120)] -0.0125 .59226 1 0 Mshowa
.125 Mabswid
0 .03506 m
.00375 .03506 L
s
0 .05929 m
.00375 .05929 L
s
0 .08351 m
.00375 .08351 L
s
0 .13197 m
.00375 .13197 L
s
0 .15619 m
.00375 .15619 L
s
0 .18042 m
.00375 .18042 L
s
0 .22887 m
.00375 .22887 L
s
0 .2531 m
.00375 .2531 L
s
0 .27732 m
.00375 .27732 L
s
0 .32578 m
.00375 .32578 L
s
0 .35 m
.00375 .35 L
s
0 .37423 m
.00375 .37423 L
s
0 .42268 m
.00375 .42268 L
s
0 .44691 m
.00375 .44691 L
s
0 .47113 m
.00375 .47113 L
s
0 .51959 m
.00375 .51959 L
s
0 .54381 m
.00375 .54381 L
s
0 .56804 m
.00375 .56804 L
s
0 .61649 m
.00375 .61649 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01083 m
1 .01083 L
s
.99375 .10774 m
1 .10774 L
s
.99375 .20464 m
1 .20464 L
s
.99375 .30155 m
1 .30155 L
s
.99375 .39845 m
1 .39845 L
s
.99375 .49536 m
1 .49536 L
s
.99375 .59226 m
1 .59226 L
s
.125 Mabswid
.99625 .03506 m
1 .03506 L
s
.99625 .05929 m
1 .05929 L
s
.99625 .08351 m
1 .08351 L
s
.99625 .13197 m
1 .13197 L
s
.99625 .15619 m
1 .15619 L
s
.99625 .18042 m
1 .18042 L
s
.99625 .22887 m
1 .22887 L
s
.99625 .2531 m
1 .2531 L
s
.99625 .27732 m
1 .27732 L
s
.99625 .32578 m
1 .32578 L
s
.99625 .35 m
1 .35 L
s
.99625 .37423 m
1 .37423 L
s
.99625 .42268 m
1 .42268 L
s
.99625 .44691 m
1 .44691 L
s
.99625 .47113 m
1 .47113 L
s
.99625 .51959 m
1 .51959 L
s
.99625 .54381 m
1 .54381 L
s
.99625 .56804 m
1 .56804 L
s
.99625 .61649 m
1 .61649 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
0 0 1 r
.5 Mabswid
[ .01 ] 0 setdash
.02381 .03991 m
.02395 .03989 L
.02408 .03987 L
.02423 .03981 L
.02437 .03973 L
.02462 .03954 L
.02489 .03926 L
.02519 .03886 L
.02551 .03833 L
.02608 .03711 L
.02722 .03375 L
.02847 .02882 L
.02973 .02297 L
.03043 .01967 L
.03077 .01816 L
.03109 .01694 L
.03125 .01645 L
.03139 .01609 L
.03147 .01593 L
.03156 .0158 L
.03171 .01569 L
.03179 .01569 L
.03188 .01574 L
.03197 .01584 L
.03206 .01598 L
.03221 .01634 L
.03238 .01685 L
.03299 .01933 L
.03355 .02196 L
.03476 .02765 L
.03605 .03294 L
.03714 .03644 L
.03777 .03793 L
.03805 .03847 L
.03836 .03897 L
.03863 .03933 L
.03892 .03963 L
.03908 .03975 L
.03923 .03984 L
.03938 .0399 L
.03952 .03994 L
.03965 .03995 L
.03978 .03995 L
.0399 .03993 L
.04003 .03989 L
.04017 .03983 L
.04031 .03974 L
.04058 .03952 L
.04089 .03917 L
.04122 .03867 L
Mistroke
.04183 .03745 L
.04243 .03592 L
.04298 .0342 L
.04525 .02473 L
.04644 .01908 L
.04673 .01784 L
.04705 .01671 L
.04722 .0162 L
.04731 .01602 L
.04739 .01588 L
.04746 .01578 L
.04755 .01571 L
.0477 .01571 L
.04778 .01577 L
.04786 .01588 L
.04802 .01618 L
.04819 .01667 L
.04836 .01723 L
.04905 .02021 L
.05029 .02612 L
.05155 .03161 L
.05217 .0339 L
.05273 .03571 L
.05326 .03716 L
.05383 .03843 L
.05415 .03897 L
.05444 .03938 L
.05472 .03969 L
.05487 .03982 L
.05501 .03992 L
.05517 .04001 L
.05531 .04006 L
.05546 .04009 L
.05555 .0401 L
.05563 .0401 L
.05576 .04008 L
.05591 .04004 L
.05606 .03997 L
.0562 .03988 L
.05653 .03959 L
.05683 .03922 L
.05716 .03871 L
.05751 .03804 L
.05866 .03497 L
.05989 .03041 L
.0621 .02014 L
.0627 .01752 L
.063 .01649 L
.06309 .01627 L
.06318 .01607 L
Mistroke
.06326 .01592 L
.06334 .01581 L
.06342 .01574 L
.06351 .01572 L
.0636 .01575 L
.06369 .01584 L
.06378 .01598 L
.06387 .01616 L
.06403 .01658 L
.06434 .01767 L
.06467 .01909 L
.06583 .02463 L
.0671 .03043 L
.06827 .03483 L
.0689 .03677 L
.06951 .03824 L
.06984 .03889 L
.0702 .03946 L
.07052 .03985 L
.07068 .04 L
.07082 .04012 L
.07096 .0402 L
.07111 .04027 L
.07119 .0403 L
.07127 .04032 L
.07142 .04034 L
.07158 .04033 L
.07172 .0403 L
.0718 .04027 L
.07188 .04024 L
.07205 .04015 L
.0722 .04004 L
.07233 .03992 L
.07264 .03957 L
.07294 .03913 L
.07326 .03855 L
.07437 .03573 L
.07504 .03346 L
.07568 .03096 L
.07688 .02557 L
.07804 .01996 L
.07837 .01845 L
.07868 .01719 L
.07882 .01672 L
.07897 .01631 L
.07912 .01598 L
.07927 .0158 L
.07941 .01576 L
.07954 .01584 L
.07968 .01606 L
Mistroke
.07982 .01638 L
.08006 .01715 L
.08033 .0182 L
.08149 .0237 L
.08262 .02905 L
.08383 .03402 L
.08453 .03633 L
.08517 .03805 L
.08547 .03874 L
.08581 .03937 L
.0861 .03982 L
.08642 .04021 L
.08658 .04037 L
.08674 .04048 L
.08689 .04057 L
.08704 .04064 L
.08718 .04068 L
.08731 .04069 L
.08745 .04068 L
.08761 .04065 L
.08769 .04062 L
.08777 .04059 L
.08795 .04048 L
.08811 .04036 L
.08827 .0402 L
.08856 .03985 L
.08888 .03936 L
.08944 .03821 L
.09006 .03661 L
.09116 .03281 L
.09353 .02194 L
.09418 .01884 L
.09454 .01736 L
.09471 .01675 L
.09487 .0163 L
.09503 .016 L
.0951 .0159 L
.09519 .01583 L
.09527 .01582 L
.09536 .01585 L
.09545 .01594 L
.09553 .01606 L
.09567 .01638 L
.09583 .01685 L
.09612 .01793 L
.09863 .02991 L
.09972 .03438 L
.1009 .03809 L
.10154 .03952 L
.10182 .04001 L
Mistroke
.10212 .04045 L
.10241 .04077 L
.10255 .04089 L
.10268 .04098 L
.10283 .04106 L
.10297 .04111 L
.10312 .04114 L
.10328 .04115 L
.10343 .04112 L
.10358 .04108 L
.10366 .04104 L
.10374 .041 L
.10391 .04088 L
.10424 .04055 L
.10459 .04008 L
.10517 .03899 L
.10581 .03739 L
.10705 .03313 L
.10817 .0282 L
.10949 .0217 L
.11007 .01892 L
.11037 .01761 L
.11054 .01699 L
.1107 .0165 L
.11085 .01617 L
.11101 .01594 L
.11115 .01589 L
.11128 .01596 L
.11141 .01615 L
.11155 .01646 L
.11169 .01688 L
.11183 .01736 L
.11302 .02296 L
.11424 .02902 L
.11553 .03456 L
.11669 .03836 L
.11735 .03993 L
.11766 .04051 L
.11796 .04096 L
.11823 .04128 L
.11837 .04141 L
.11852 .04153 L
.11865 .04161 L
.11879 .04167 L
.11892 .04171 L
.11904 .04173 L
.11919 .04173 L
.11933 .0417 L
.11945 .04166 L
.11959 .04159 L
Mistroke
.11974 .04149 L
.1199 .04136 L
.12019 .04104 L
.1205 .04059 L
.12084 .03999 L
.12143 .03861 L
.12207 .03672 L
.12277 .03418 L
.12405 .02858 L
.12521 .02275 L
.12578 .01984 L
.12609 .01842 L
.12641 .01713 L
.12655 .01669 L
.1267 .01632 L
.12678 .01616 L
.12686 .01606 L
.12701 .01597 L
.12714 .01603 L
.12728 .01622 L
.12742 .01655 L
.12756 .01696 L
.1282 .01966 L
.12878 .0226 L
.13008 .02923 L
.13121 .03428 L
.1324 .03849 L
.13302 .04013 L
.13335 .04083 L
.1337 .04145 L
.13403 .04188 L
.13432 .04217 L
.13447 .04227 L
.13462 .04236 L
.13477 .04241 L
.1349 .04244 L
.13506 .04244 L
.13514 .04243 L
.13522 .04241 L
.13538 .04235 L
.13552 .04228 L
.13569 .04215 L
.13584 .04201 L
.13618 .04159 L
.13648 .04112 L
.1368 .04049 L
.13739 .03906 L
.13855 .03513 L
.13963 .03043 L
.14072 .02495 L
Mistroke
.14189 .01896 L
.14223 .01749 L
.1424 .0169 L
.14256 .01647 L
.1427 .01621 L
.14285 .01608 L
.14294 .01608 L
.14302 .01614 L
.14317 .01636 L
.14332 .01672 L
.14347 .01721 L
.14375 .01832 L
.14437 .02139 L
.1456 .02789 L
.14677 .03352 L
.1479 .03801 L
.1484 .0396 L
.14895 .04104 L
.1495 .04213 L
.1498 .04258 L
.15008 .04291 L
.15023 .04304 L
.15038 .04315 L
.15052 .04322 L
.15067 .04328 L
.15082 .0433 L
.15091 .0433 L
.15099 .0433 L
.15115 .04326 L
.1513 .04319 L
.15145 .0431 L
.15161 .04298 L
.15193 .04262 L
.15223 .04218 L
.15251 .04167 L
.15314 .04018 L
.15382 .03809 L
.15504 .03318 L
.15637 .02654 L
.15703 .02301 L
.15765 .01977 L
.15792 .01848 L
.1582 .01732 L
.15835 .01684 L
.15843 .01663 L
.15851 .01644 L
.15866 .01624 L
.1588 .0162 L
.15896 .01633 L
.1591 .01662 L
Mistroke
.15918 .01682 L
.15927 .01708 L
.15944 .01771 L
.16004 .02057 L
.16117 .02674 L
.16249 .03351 L
.1637 .03858 L
.16429 .04054 L
.16484 .04202 L
.16541 .04318 L
.16572 .04364 L
.16604 .044 L
.16621 .04414 L
.16636 .04424 L
.16645 .04427 L
.16654 .0443 L
.16663 .04433 L
.16672 .04434 L
.1668 .04434 L
.16688 .04433 L
.16703 .04429 L
.16718 .04422 L
.16727 .04417 L
.16736 .04411 L
.16766 .04382 L
.16794 .04346 L
.16856 .04231 L
.16915 .04077 L
.16977 .03873 L
.17088 .03409 L
.1721 .0279 L
.17277 .0242 L
.1734 .02071 L
.17369 .01923 L
.17399 .01783 L
.17415 .01724 L
.17424 .01697 L
.17433 .01673 L
.17441 .01655 L
.17449 .01644 L
.17464 .01634 L
.17478 .01642 L
.17492 .01663 L
.17506 .01701 L
.17522 .01754 L
.17577 .02011 L
.17799 .03236 L
.17923 .03817 L
.17988 .04064 L
.18057 .04275 L
Mistroke
.18117 .04414 L
.18151 .04472 L
.18168 .04495 L
.18183 .04513 L
.18198 .04527 L
.18213 .04539 L
.18227 .04547 L
.1824 .04553 L
.18254 .04556 L
.18269 .04557 L
.18277 .04556 L
.18285 .04554 L
.183 .04549 L
.18315 .0454 L
.18329 .0453 L
.1836 .04498 L
.18388 .04456 L
.18415 .04408 L
.18476 .04266 L
.18542 .04062 L
.18674 .03508 L
.18796 .02863 L
.18905 .02233 L
.18965 .01908 L
.18995 .01775 L
.19009 .01724 L
.19022 .01687 L
.19038 .01659 L
.19046 .01652 L
.19055 .01651 L
.19063 .01656 L
.19071 .01666 L
.1908 .01683 L
.1909 .01706 L
.19105 .01757 L
.19119 .01814 L
.19151 .01969 L
.19271 .02665 L
.19496 .03867 L
.19558 .04122 L
.19624 .04347 L
.1968 .04497 L
.1971 .04562 L
.19741 .04617 L
.19757 .0464 L
.19774 .04661 L
.1979 .04676 L
.19805 .04687 L
.19813 .04693 L
.19822 .04697 L
Mistroke
.19832 .047 L
.1984 .04703 L
.19849 .04704 L
.19858 .04704 L
.19874 .04701 L
.19888 .04696 L
.19904 .04686 L
.19919 .04674 L
.19933 .04661 L
.19966 .04617 L
.19998 .04561 L
.20058 .04419 L
.20114 .04245 L
.20241 .03718 L
.20358 .03093 L
.20484 .02334 L
.20543 .01996 L
.20574 .01838 L
.2059 .01773 L
.20604 .01726 L
.20617 .01694 L
.20629 .01675 L
.20642 .0167 L
.20656 .01682 L
.20671 .0171 L
.20686 .01758 L
.20714 .01875 L
.20933 .03186 L
.21054 .0385 L
.21168 .04352 L
.21227 .04551 L
.21258 .04638 L
.21292 .04716 L
.21322 .04775 L
.2135 .04818 L
.21363 .04834 L
.21378 .04849 L
.21391 .0486 L
.21404 .04869 L
.21418 .04875 L
.21431 .04878 L
.21446 .04879 L
.2146 .04877 L
.21475 .04872 L
.2149 .04863 L
.21505 .04851 L
.21519 .04837 L
.21544 .04806 L
.2157 .04761 L
.21625 .04641 L
Mistroke
.21684 .04463 L
.21747 .04227 L
.21858 .03693 L
.2198 .02981 L
.22047 .02556 L
.2211 .02159 L
.22139 .0199 L
.2217 .01835 L
.22186 .01771 L
.22195 .01744 L
.22204 .0172 L
.22212 .01704 L
.2222 .01696 L
.22235 .01695 L
.22249 .01714 L
.22263 .01747 L
.22277 .01799 L
.22293 .01868 L
.22348 .02179 L
.2257 .03596 L
.22694 .0426 L
.2276 .04542 L
.22829 .04781 L
.22889 .04937 L
.22924 .05002 L
.2294 .05026 L
.22956 .05046 L
.2297 .05061 L
.22985 .05074 L
.22999 .05082 L
.23012 .05087 L
.23026 .0509 L
.23041 .0509 L
.23049 .05088 L
.23057 .05085 L
.23072 .05078 L
.2308 .05072 L
.23088 .05066 L
.23103 .05052 L
.23135 .05009 L
.23163 .04958 L
.23194 .0489 L
.23263 .04686 L
.23327 .0444 L
.23445 .03852 L
.23569 .03082 L
.23683 .02313 L
.23713 .02119 L
.23746 .0193 L
.23761 .01856 L
Mistroke
.23777 .01791 L
.23791 .0175 L
.23806 .01724 L
.23821 .0172 L
.23834 .01736 L
.23849 .01774 L
.23865 .01834 L
.23892 .01967 L
.23921 .02143 L
.24027 .02867 L
.24159 .03753 L
.24283 .04461 L
.24395 .04939 L
.24425 .0504 L
.24458 .05132 L
.24488 .05204 L
.24516 .05257 L
.24529 .05279 L
.24544 .05299 L
.24559 .05315 L
.24572 .05327 L
.24587 .05337 L
.24595 .05341 L
.24603 .05344 L
.24617 .05346 L
.24632 .05346 L
.24645 .05342 L
.24659 .05335 L
.24674 .05324 L
.24688 .0531 L
.24713 .05277 L
.2474 .05232 L
.24772 .05162 L
.24806 .05069 L
.24869 .04853 L
.24986 .04299 L
.25221 .02755 L
.25285 .02295 L
.25318 .02072 L
.25337 .01963 L
.25354 .01875 L
.25369 .01813 L
.25377 .01787 L
.25385 .01768 L
.25393 .01755 L
.25402 .01749 L
.25411 .01752 L
.25419 .01761 L
.25433 .01794 L
.25448 .0185 L
Mistroke
.25479 .02011 L
.25727 .03804 L
.25835 .04499 L
.25953 .05097 L
.26015 .05334 L
.26043 .05419 L
.26073 .05498 L
.261 .05555 L
.26129 .05603 L
.26144 .05623 L
.26159 .05638 L
.26173 .05649 L
.26188 .05657 L
.26203 .05661 L
.26218 .05661 L
.26226 .05659 L
.26234 .05656 L
.2625 .05648 L
.26265 .05636 L
.2628 .05619 L
.26308 .05578 L
.2634 .05514 L
.26371 .05438 L
.2644 .05207 L
.265 .04945 L
.26565 .04598 L
.26684 .03826 L
.26799 .02955 L
.26855 .02513 L
.26907 .02131 L
.26936 .01955 L
.26952 .01875 L
.26967 .0182 L
.26982 .01789 L
.26991 .01784 L
.26999 .01787 L
.27007 .01798 L
.27016 .01818 L
.27024 .01846 L
.27032 .01877 L
.27058 .02016 L
.27086 .0221 L
.27145 .02662 L
.27277 .03732 L
.27398 .04617 L
.27511 .0529 L
.27568 .05556 L
.27631 .05786 L
.27664 .0588 L
.27694 .05948 L
Mistroke
.27711 .05979 L
.27729 .06007 L
.27746 .06027 L
.27761 .06041 L
.27776 .0605 L
.27789 .06055 L
.27804 .06056 L
.27812 .06055 L
.2782 .06052 L
.27835 .06044 L
.27844 .06038 L
.27852 .06031 L
.27882 .05992 L
.27898 .05965 L
.27914 .05932 L
.27944 .05861 L
.2801 .05641 L
.28068 .05387 L
.2813 .05046 L
.28355 .03391 L
.28413 .02893 L
.28476 .02361 L
.28505 .02141 L
.28521 .02034 L
.28536 .01948 L
.28548 .0189 L
.28562 .01846 L
.28577 .01825 L
.28591 .01833 L
.28599 .01849 L
.28607 .01875 L
.28622 .01939 L
.28639 .02042 L
.28655 .02153 L
.28723 .02716 L
.28843 .03797 L
.28956 .04735 L
.29075 .05563 L
.29137 .05908 L
.29206 .06209 L
.29236 .06313 L
.29268 .06405 L
.29298 .06473 L
.29313 .06499 L
.29326 .06519 L
.2934 .06536 L
.29354 .06548 L
.29368 .06558 L
.29384 .06563 L
.29398 .06563 L
Mistroke
.29414 .06558 L
.29422 .06553 L
.2943 .06547 L
.29445 .06532 L
.2946 .06514 L
.29475 .06489 L
.29503 .06431 L
.29556 .06278 L
.29619 .06021 L
.29686 .05664 L
.29806 .04829 L
.29929 .03768 L
.30045 .02662 L
.30095 .02217 L
.3011 .02107 L
.30123 .02017 L
.30136 .01951 L
.30149 .019 L
.30164 .01874 L
.3018 .01885 L
.30193 .01925 L
.30208 .01997 L
.30222 .02085 L
.30236 .02195 L
.30263 .02423 L
.30497 .04736 L
.30628 .05841 L
.30749 .06613 L
.30809 .06887 L
.30839 .06998 L
.30872 .07095 L
.30889 .07136 L
.30905 .07167 L
.30921 .07193 L
.30935 .07212 L
.30944 .07221 L
.30952 .07227 L
.3096 .07233 L
.30969 .07237 L
.30978 .07238 L
.30988 .07238 L
.30997 .07236 L
.31005 .07232 L
.31019 .07223 L
.31034 .07207 L
.31049 .07187 L
.31062 .07165 L
.31093 .07094 L
.31123 .07005 L
.31183 .06765 L
Mistroke
.31248 .06414 L
.31373 .05495 L
.31486 .04428 L
.31618 .0301 L
.31676 .02406 L
.31692 .02259 L
.31709 .02122 L
.31717 .02065 L
.31725 .02018 L
.31739 .01956 L
.31753 .01931 L
.31767 .01944 L
.3178 .01987 L
.31794 .02063 L
.31808 .02171 L
.31824 .0231 L
.31852 .02598 L
.31972 .03975 L
.32102 .05436 L
.32223 .06595 L
.32345 .07482 L
.32409 .07815 L
.32445 .07957 L
.32478 .08056 L
.32493 .08093 L
.32509 .08125 L
.32523 .08148 L
.32538 .08166 L
.32546 .08174 L
.32554 .08179 L
.32563 .08183 L
.32572 .08185 L
.32587 .08184 L
.32595 .0818 L
.32603 .08175 L
.32617 .08162 L
.3263 .08145 L
.32644 .08121 L
.3266 .08088 L
.32691 .08002 L
.3272 .07898 L
.32778 .07629 L
.32839 .07246 L
.32949 .06328 L
.33198 .03406 L
.33258 .02651 L
.33274 .02468 L
.33291 .0229 L
.33307 .02152 L
.33322 .02055 L
Mistroke
.3333 .0202 L
.33339 .02001 L
.33355 .02016 L
.33364 .02052 L
.33374 .0211 L
.33391 .02256 L
.33425 .02631 L
.33455 .03026 L
.33699 .06338 L
.33812 .07639 L
.33931 .08704 L
.33993 .09111 L
.34029 .09291 L
.34062 .09425 L
.34078 .09476 L
.34092 .09518 L
.34106 .09549 L
.3412 .09577 L
.34136 .09599 L
.3415 .09612 L
.34165 .0962 L
.34174 .0962 L
.34182 .09618 L
.34196 .0961 L
.34212 .09594 L
.34226 .09571 L
.34239 .09545 L
.34271 .09457 L
.34301 .09343 L
.34361 .09026 L
.34426 .08553 L
.34542 .07387 L
.34649 .05993 L
.34759 .04328 L
.34819 .03361 L
.34876 .02508 L
.34892 .02319 L
.349 .02232 L
.34908 .02166 L
.34917 .02114 L
.34926 .02085 L
.34935 .02084 L
.34943 .0211 L
.34959 .02215 L
.34967 .02293 L
.34975 .02392 L
.35005 .02807 L
.35125 .04897 L
.35257 .07195 L
.35381 .09115 L
Mistroke
.35493 .10509 L
.35556 .11124 L
.35614 .11566 L
.35641 .11729 L
.3567 .11872 L
.35697 .11975 L
.35709 .12012 L
.35722 .12043 L
.35738 .12072 L
.35752 .1209 L
.3576 .12096 L
.35769 .121 L
.35784 .12098 L
.35798 .12088 L
.35812 .1207 L
.35827 .12042 L
.35842 .12002 L
.35871 .119 L
.35902 .1175 L
.35957 .11376 L
.36024 .10758 L
.36084 .10035 L
.36334 .05634 L
.36444 .0324 L
.36474 .02645 L
.36482 .02505 L
.36491 .02377 L
.36506 .0222 L
.36521 .02186 L
.36534 .02264 L
.36549 .02453 L
.36565 .02734 L
.36789 .08306 L
.37027 .13762 L
.37151 .15854 L
.3722 .16721 L
.37254 .17044 L
.37285 .17291 L
.37312 .17461 L
.37326 .17531 L
.37341 .17595 L
.3735 .17624 L
.37358 .17648 L
.37373 .17682 L
.37388 .177 L
.37403 .17705 L
.37411 .17701 L
.37419 .17693 L
.37428 .1768 L
.37437 .17661 L
Mistroke
.37452 .17618 L
.37468 .17552 L
.37499 .17382 L
.37528 .17167 L
.37588 .16524 L
.37654 .15538 L
.37716 .1433 L
.37774 .12979 L
.37998 .05711 L
.38054 .03552 L
.3807 .02977 L
.38085 .02527 L
.38099 .02315 L
.38114 .02418 L
.38129 .02795 L
.38142 .03267 L
.38171 .04513 L
.38223 .07015 L
.38472 .20321 L
.38724 .34282 L
.38955 .458 L
.39072 .5064 L
.39181 .54384 L
.39295 .57377 L
.39355 .58556 L
.39386 .59053 L
.3942 .59493 L
.3945 .59812 L
.39466 .59951 L
.39483 .60077 L
.39499 .6017 L
.39514 .60237 L
.39528 .60284 L
.39542 .60317 L
.39558 .60332 L
.39567 .60331 L
.39575 .60324 L
.39591 .60296 L
.39606 .6025 L
.39614 .60216 L
.39623 .60173 L
.39639 .6008 L
.39676 .59793 L
.39704 .5949 L
.39735 .5909 L
.39791 .5818 L
.39918 .55251 L
.4004 .51427 L
.40173 .4632 L
.40416 .35316 L
Mistroke
.40673 .22812 L
.40906 .12361 L
.41023 .07864 L
.41085 .05783 L
.41118 .04755 L
.4115 .03888 L
.41179 .03189 L
.41192 .02942 L
.41207 .02731 L
.41222 .02587 L
.41237 .02551 L
.41245 .02572 L
.41254 .02624 L
.41269 .02779 L
.41282 .02952 L
.41296 .03165 L
.41321 .03586 L
.41379 .04561 L
.41435 .05412 L
.41494 .06169 L
.41529 .06527 L
.4156 .06803 L
.41589 .07021 L
.41621 .07208 L
.41636 .07284 L
.41653 .07354 L
.41669 .07408 L
.41684 .07447 L
.41701 .07482 L
.4171 .07496 L
.41719 .07505 L
.41735 .07515 L
.41743 .07515 L
.41752 .07513 L
.41759 .07509 L
.41768 .07501 L
.41783 .07481 L
.41798 .07453 L
.41812 .0742 L
.41843 .0732 L
.41875 .0718 L
.41935 .06838 L
.4199 .06444 L
.42113 .05339 L
.42334 .03007 L
.42392 .02415 L
.42454 .01849 L
.4248 .01656 L
.42494 .01569 L
.42507 .01507 L
Mistroke
.42523 .01472 L
.42537 .01479 L
.4255 .01516 L
.42565 .01581 L
.42816 .02967 L
.42938 .03563 L
.43053 .04353 L
.43117 .04968 L
.43186 .05802 L
.43306 .07678 L
.43546 .12734 L
.438 .19041 L
.4404 .2472 L
.44145 .26829 L
.44258 .28733 L
.44321 .29577 L
.44379 .30214 L
.44435 .30686 L
.44463 .30871 L
.44494 .31034 L
.4451 .311 L
.44526 .31157 L
.44541 .31195 L
.44556 .31226 L
.44565 .31238 L
.44573 .31245 L
.44582 .3125 L
.44591 .31251 L
.44607 .31243 L
.44616 .31234 L
.44624 .31222 L
.44638 .31192 L
.44652 .31155 L
.44683 .31037 L
.44713 .30877 L
.44746 .30656 L
.44809 .30082 L
.44868 .29385 L
.45001 .27252 L
.45119 .24803 L
.45244 .21722 L
.45485 .14924 L
.45612 .1125 L
.45746 .07655 L
.45804 .06314 L
.45836 .05678 L
.45866 .05169 L
.45883 .0493 L
.45902 .04718 L
.4591 .04642 L
Mistroke
.45919 .04573 L
.45934 .04482 L
.4595 .04434 L
.45964 .04426 L
.45973 .04438 L
.45981 .04459 L
.45989 .04492 L
.45998 .04537 L
.46012 .04633 L
.46026 .0474 L
.46055 .05036 L
.46109 .05682 L
.4623 .07216 L
.46288 .07859 L
.4635 .08424 L
.46403 .08799 L
.46433 .08966 L
.46461 .09094 L
.46477 .09152 L
.46494 .09204 L
.46508 .09239 L
.46524 .0927 L
.46533 .09283 L
.46541 .09292 L
.46549 .093 L
.46559 .09305 L
.46567 .09307 L
.46576 .09306 L
.46591 .09298 L
.46606 .09283 L
.46621 .09258 L
.46636 .09228 L
.46649 .09193 L
.46682 .09085 L
.46712 .08951 L
.46768 .08637 L
.46829 .08196 L
.46953 .07076 L
.47067 .05949 L
.47124 .05449 L
.47176 .05076 L
.47204 .04928 L
.4722 .04865 L
.47234 .04822 L
.4725 .04789 L
.47259 .04779 L
.47267 .04774 L
.47282 .04776 L
.47298 .04796 L
.47312 .04826 L
Mistroke
.47326 .0487 L
.47352 .04981 L
.47382 .05158 L
.4741 .05356 L
.47541 .06529 L
.47662 .07631 L
.4772 .08076 L
.47774 .08423 L
.4783 .08698 L
.4786 .08804 L
.47877 .08851 L
.47892 .08886 L
.47907 .08912 L
.47923 .0893 L
.47932 .08937 L
.4794 .08941 L
.47956 .08941 L
.47964 .08938 L
.47973 .08932 L
.47988 .08914 L
.47997 .089 L
.48005 .08884 L
.48023 .0884 L
.48053 .08739 L
.48081 .08616 L
.48143 .08233 L
.482 .07744 L
.48262 .07088 L
.48372 .05597 L
.4844 .04556 L
.48473 .04054 L
.48504 .03637 L
.48518 .0347 L
.48531 .03339 L
.48545 .03238 L
.48561 .03176 L
.48576 .03174 L
.48591 .0323 L
.48598 .03284 L
.48607 .0336 L
.48622 .03541 L
.48651 .03988 L
.48681 .04591 L
.48736 .0588 L
.48862 .09294 L
.49115 .16889 L
.49353 .2367 L
.49478 .26758 L
.49612 .29484 L
.49679 .30588 L
Mistroke
.49742 .31453 L
.49799 .32078 L
.49828 .32341 L
.4986 .32585 L
.49889 .32757 L
.49919 .329 L
.49935 .3296 L
.49951 .33002 L
.49966 .33034 L
.4998 .33053 L
.49994 .33061 L
.50008 .33061 L
.5002 .33052 L
.50033 .33035 L
.50048 .33006 L
.50063 .32965 L
.50091 .32859 L
.5012 .32711 L
.50151 .32507 L
.50206 .32026 L
.50272 .31268 L
.50332 .3041 L
.50463 .28028 L
.50587 .25212 L
.51051 .11881 L
.51174 .08271 L
.5129 .05237 L
.51348 .04003 L
.51365 .0372 L
.51381 .03495 L
.51395 .03337 L
.51411 .03221 L
.5142 .03183 L
.51429 .03168 L
.51444 .03191 L
.51453 .03231 L
.51461 .03283 L
.5148 .03448 L
.51511 .0383 L
.51544 .04309 L
.51658 .06047 L
.51721 .06887 L
.51781 .07561 L
.51837 .08072 L
.51866 .08295 L
.51897 .08495 L
.51923 .08634 L
.51952 .08758 L
.51964 .08802 L
.51978 .08842 L
Mistroke
.5199 .08874 L
.52002 .08898 L
.52018 .08921 L
.52031 .08935 L
.52046 .08942 L
.52055 .08942 L
.52062 .0894 L
.52075 .08932 L
.52089 .08917 L
.52104 .08893 L
.52118 .08864 L
.5215 .08773 L
.52179 .0866 L
.52244 .08316 L
.52307 .0788 L
.52375 .07312 L
.52499 .06149 L
.52553 .05654 L
.52612 .05197 L
.52646 .04995 L
.5266 .04925 L
.52676 .04862 L
.52692 .04817 L
.52706 .04789 L
.52721 .04775 L
.52729 .04773 L
.52737 .04776 L
.52753 .04794 L
.52761 .0481 L
.52769 .04832 L
.52785 .04883 L
.52799 .04944 L
.52832 .05125 L
.52867 .05376 L
.5299 .06515 L
.53112 .07698 L
.53177 .08242 L
.53245 .0872 L
.53279 .08909 L
.53311 .09056 L
.5334 .0916 L
.53355 .09203 L
.53371 .09242 L
.53386 .09271 L
.534 .0929 L
.53415 .09302 L
.53424 .09306 L
.53432 .09307 L
.53445 .09303 L
.5346 .09291 L
Mistroke
.53474 .09272 L
.53487 .09248 L
.53502 .09215 L
.53517 .09172 L
.53543 .09075 L
.53572 .0894 L
.53604 .08757 L
.5366 .08339 L
.53713 .07851 L
.5384 .06344 L
.53903 .05531 L
.53931 .05194 L
.53961 .04864 L
.53975 .04731 L
.53991 .04609 L
.54005 .04519 L
.54019 .04461 L
.54034 .04428 L
.54042 .04425 L
.5405 .04433 L
.54064 .04475 L
.5408 .0456 L
.54088 .04626 L
.54096 .04698 L
.54114 .04897 L
.54147 .05373 L
.54208 .06568 L
.54432 .12509 L
.54679 .19627 L
.54909 .25422 L
.55023 .27691 L
.55131 .29366 L
.5519 .30075 L
.55221 .30383 L
.55255 .3066 L
.55283 .30852 L
.55313 .3102 L
.55327 .31079 L
.55341 .31133 L
.55355 .31175 L
.55368 .31205 L
.55383 .31232 L
.55397 .31246 L
.55412 .31251 L
.5542 .31249 L
.55428 .31245 L
.55441 .3123 L
.55455 .31205 L
.5547 .31169 L
.55483 .31126 L
Mistroke
.55515 .30992 L
.55544 .30828 L
.5561 .30318 L
.55672 .29654 L
.55741 .28748 L
.55865 .26659 L
.56356 .15107 L
.566 .09479 L
.5672 .07238 L
.56829 .05606 L
.56936 .0445 L
.56989 .04019 L
.57048 .03641 L
.57284 .02471 L
.57348 .02105 L
.57408 .01733 L
.57434 .01585 L
.57447 .01525 L
.57462 .01481 L
.57478 .01472 L
.57492 .01505 L
.57506 .01567 L
.57521 .01657 L
.57588 .02229 L
.57652 .02869 L
.57773 .04152 L
.57889 .05356 L
.58012 .06462 L
.58072 .06887 L
.58102 .07061 L
.58129 .07198 L
.58153 .07302 L
.58179 .07394 L
.58192 .07429 L
.58206 .07461 L
.5822 .07486 L
.58234 .07503 L
.58249 .07513 L
.58257 .07515 L
.58265 .07515 L
.58281 .07506 L
.5829 .07496 L
.58298 .07484 L
.58312 .07458 L
.58327 .0742 L
.58357 .07313 L
.5839 .07147 L
.58426 .06912 L
.5849 .06335 L
.58556 .05543 L
Mistroke
.58618 .04619 L
.58677 .03611 L
.58707 .03126 L
.58719 .02934 L
.58733 .02753 L
.58747 .0262 L
.5876 .02556 L
.58775 .02573 L
.58789 .02681 L
.58805 .02895 L
.58819 .03156 L
.58851 .03896 L
.58975 .07798 L
.59197 .1682 L
.59682 .39929 L
.59904 .49395 L
.6003 .53743 L
.60091 .55517 L
.60147 .5691 L
.60203 .58078 L
.60264 .59081 L
.60297 .5951 L
.60328 .59828 L
.60357 .6006 L
.60372 .6015 L
.60389 .60229 L
.60397 .6026 L
.60406 .60287 L
.60414 .60307 L
.60422 .6032 L
.60436 .60332 L
.60452 .60325 L
.60461 .60311 L
.6047 .6029 L
.60479 .60263 L
.60488 .60232 L
.60503 .60157 L
.6052 .60055 L
.6055 .5981 L
.60579 .59513 L
.60643 .5859 L
.60703 .5742 L
.60769 .55823 L
.60888 .521 L
.61112 .42685 L
.61346 .305 L
.61604 .16105 L
.61721 .09813 L
.61783 .06695 L
.61817 .05083 L
Mistroke
.61848 .03685 L
.61862 .03117 L
.61876 .02663 L
.61891 .0234 L
.61905 .02354 L
.61921 .0269 L
.61935 .03154 L
.61968 .04374 L
.62077 .08471 L
.62186 .11912 L
.62304 .14747 L
.62371 .15947 L
.62432 .1677 L
.62462 .17073 L
.62494 .17335 L
.62509 .17431 L
.62524 .17518 L
.62539 .17583 L
.62552 .17631 L
.62567 .17671 L
.62575 .17685 L
.62584 .17697 L
.62593 .17703 L
.62601 .17705 L
.62617 .17695 L
.62632 .17672 L
.62646 .17638 L
.62661 .17588 L
.62677 .17519 L
.6271 .17329 L
.62741 .17093 L
.62811 .16359 L
.62872 .15514 L
.62928 .14589 L
.63055 .12058 L
.63174 .09223 L
.63302 .05956 L
.63365 .04368 L
.63395 .0362 L
.63423 .02978 L
.63449 .02487 L
.63462 .02307 L
.63476 .02196 L
.6349 .02199 L
.63505 .02327 L
.6352 .02534 L
.63533 .02767 L
.63649 .0526 L
.63772 .07745 L
.63886 .09622 L
Mistroke
.63993 .10933 L
.64046 .11401 L
.64102 .11772 L
.64133 .11915 L
.6415 .11976 L
.64165 .12022 L
.64178 .12053 L
.64193 .12077 L
.64209 .12094 L
.64223 .121 L
.64238 .12097 L
.64246 .12091 L
.64255 .12082 L
.6427 .12058 L
.64285 .12027 L
.64301 .11979 L
.64317 .11926 L
.64352 .1177 L
.64414 .11371 L
.64473 .1086 L
.64589 .09527 L
.64712 .07706 L
.64934 .03842 L
.64994 .02822 L
.65025 .02391 L
.65033 .02295 L
.65042 .02208 L
.6505 .02144 L
.65058 .02104 L
.65067 .02082 L
.65075 .02088 L
.65084 .0212 L
.65094 .02183 L
.65102 .02256 L
.6511 .02338 L
.65128 .02561 L
.65192 .0354 L
.65436 .07122 L
.65554 .08383 L
.65614 .0886 L
.65648 .09082 L
.65679 .09251 L
.65706 .09372 L
.65735 .09476 L
.65751 .09521 L
.65766 .09555 L
.6578 .09581 L
.65795 .09602 L
.65808 .09613 L
.65821 .09619 L
Mistroke
.65834 .0962 L
.65846 .09615 L
.6586 .09604 L
.65875 .09585 L
.65889 .0956 L
.65902 .09531 L
.65934 .09437 L
.65964 .09323 L
.6603 .0897 L
.66089 .08553 L
.6615 .08015 L
.66375 .05378 L
.6649 .03782 L
.66553 .02915 L
.66584 .02525 L
.66597 .02371 L
.66612 .02221 L
.66626 .02109 L
.66639 .02036 L
.66653 .02 L
.66668 .02014 L
.66676 .02042 L
.66684 .02088 L
.667 .02202 L
.66728 .02493 L
.66834 .03819 L
.66956 .05318 L
.67071 .0651 L
.67135 .07048 L
.67203 .0752 L
.67234 .0769 L
.67266 .07843 L
.67294 .07952 L
.67324 .08047 L
.6734 .08087 L
.67354 .08118 L
.67368 .08142 L
.67383 .08163 L
.67397 .08175 L
.6741 .08183 L
.67423 .08185 L
.67438 .08183 L
.67453 .08174 L
.67461 .08167 L
.67469 .08158 L
.67485 .08135 L
.67502 .08104 L
.67533 .08027 L
.6756 .07936 L
.67615 .07701 L
Mistroke
.67674 .07364 L
.67781 .06554 L
.68016 .04112 L
.68141 .0267 L
.68177 .02303 L
.68194 .0215 L
.68203 .02087 L
.68211 .02036 L
.68226 .01965 L
.68241 .01931 L
.6825 .01933 L
.68259 .01949 L
.68267 .01978 L
.68275 .02015 L
.68289 .02104 L
.68304 .02224 L
.68332 .02479 L
.68394 .03142 L
.6852 .04491 L
.68639 .05599 L
.6875 .06401 L
.68809 .06729 L
.68873 .06991 L
.68905 .0709 L
.68936 .0716 L
.68954 .07191 L
.6897 .07212 L
.68978 .07221 L
.68988 .07228 L
.68997 .07234 L
.69006 .07237 L
.69021 .07238 L
.6903 .07237 L
.69038 .07234 L
.69052 .07224 L
.69068 .07209 L
.69082 .0719 L
.69094 .07169 L
.69124 .07106 L
.69155 .07017 L
.69184 .06916 L
.69249 .06623 L
.69368 .05869 L
.69479 .04958 L
.69608 .03713 L
.69671 .03071 L
.69729 .02499 L
.69756 .02256 L
.69781 .02063 L
.69794 .01984 L
Mistroke
.69808 .01921 L
.69823 .0188 L
.69837 .01875 L
.69852 .01903 L
.69866 .01958 L
.69881 .02043 L
.69897 .02156 L
.69954 .02646 L
.70073 .03784 L
.70202 .04892 L
.70265 .05353 L
.70325 .05729 L
.70383 .06032 L
.70437 .06255 L
.70489 .06411 L
.70517 .06475 L
.70543 .06517 L
.70558 .06536 L
.70571 .06548 L
.70586 .06558 L
.70602 .06563 L
.70616 .06563 L
.70629 .06559 L
.70643 .06551 L
.70658 .06538 L
.70673 .0652 L
.70689 .06496 L
.70722 .0643 L
.70752 .0635 L
.70781 .06258 L
.70845 .05994 L
.70914 .05626 L
.71157 .03795 L
.71282 .0267 L
.71314 .024 L
.71343 .02165 L
.7137 .01986 L
.71385 .01909 L
.71399 .01857 L
.71412 .01829 L
.71427 .01828 L
.71443 .01859 L
.71457 .01915 L
.71473 .01999 L
.71488 .02091 L
.7152 .02333 L
.71653 .0346 L
.71764 .04344 L
.71883 .05122 L
.71951 .05474 L
Mistroke
.72012 .05725 L
.72042 .05821 L
.72074 .05907 L
.72105 .05971 L
.72133 .06014 L
.72148 .06031 L
.72162 .06043 L
.72175 .0605 L
.7219 .06055 L
.72205 .06056 L
.72213 .06054 L
.72221 .06051 L
.72236 .06043 L
.7225 .06031 L
.72264 .06017 L
.72278 .05997 L
.72303 .05954 L
.72331 .05894 L
.7236 .05814 L
.72423 .05593 L
.72489 .05286 L
.7261 .04569 L
.7285 .02704 L
.72916 .02191 L
.72949 .01974 L
.72958 .01924 L
.72968 .01877 L
.72977 .01841 L
.72986 .01814 L
.72994 .01797 L
.73002 .01786 L
.7301 .01784 L
.73019 .01791 L
.73027 .01806 L
.73036 .01829 L
.73051 .01889 L
.73066 .01966 L
.73082 .02062 L
.73111 .02258 L
.73232 .03193 L
.73361 .04135 L
.73483 .04857 L
.73537 .05109 L
.73594 .05328 L
.73622 .05416 L
.73652 .05497 L
.73681 .05558 L
.73707 .05602 L
.73721 .05621 L
.73737 .05638 L
Mistroke
.73746 .05645 L
.73754 .05651 L
.73762 .05655 L
.7377 .05658 L
.73778 .0566 L
.73786 .05661 L
.73801 .0566 L
.73816 .05655 L
.7383 .05647 L
.73843 .05637 L
.73856 .05622 L
.73881 .05588 L
.73911 .05533 L
.73938 .0547 L
.73997 .05292 L
.74053 .05074 L
.74169 .04475 L
.74293 .03666 L
.74409 .02808 L
.7446 .02429 L
.74489 .02224 L
.74515 .02047 L
.7453 .01959 L
.74544 .01886 L
.74558 .01827 L
.7457 .01785 L
.74584 .01757 L
.74598 .01749 L
.74613 .01764 L
.74628 .01804 L
.74643 .0186 L
.74658 .01936 L
.74686 .02102 L
.7475 .02544 L
.74971 .04054 L
.75093 .04695 L
.75162 .04968 L
.75195 .05073 L
.75226 .05157 L
.75256 .05224 L
.75288 .05279 L
.75302 .05298 L
.75317 .05315 L
.7533 .05327 L
.75344 .05336 L
.75352 .05341 L
.7536 .05344 L
.75375 .05346 L
.75383 .05346 L
.75391 .05345 L
Mistroke
.754 .05343 L
.75409 .05339 L
.75423 .0533 L
.75437 .05319 L
.75453 .05303 L
.75469 .05281 L
.75499 .05229 L
.75532 .05158 L
.75591 .04989 L
.7566 .04724 L
.75724 .04427 L
.75966 .02918 L
.76079 .02142 L
.76106 .01977 L
.76136 .0183 L
.76144 .01795 L
.76152 .01768 L
.76168 .01732 L
.76182 .01719 L
.76198 .01728 L
.76214 .01762 L
.76223 .0179 L
.76231 .01822 L
.76266 .01996 L
.76329 .02392 L
.76449 .03201 L
.76568 .03919 L
.76632 .04253 L
.76692 .04519 L
.76748 .04724 L
.76799 .04872 L
.76826 .04936 L
.76855 .04993 L
.76871 .05019 L
.76886 .05039 L
.769 .05055 L
.76915 .05069 L
.76931 .0508 L
.76945 .05086 L
.76959 .0509 L
.76972 .0509 L
.76987 .05088 L
.77001 .05082 L
.77009 .05078 L
.77017 .05072 L
.77032 .05059 L
.7706 .05026 L
.77089 .04979 L
.77142 .04864 L
.77203 .04679 L
Mistroke
.7726 .04462 L
.77391 .03824 L
.77616 .02409 L
.77677 .02025 L
.77711 .01849 L
.77728 .0178 L
.77743 .01732 L
.77756 .01705 L
.7777 .01693 L
.77784 .01699 L
.77799 .01725 L
.77814 .01772 L
.77831 .01837 L
.7786 .01987 L
.77995 .02823 L
.78117 .03558 L
.78243 .04185 L
.78299 .04403 L
.7836 .04599 L
.78388 .04672 L
.78418 .04739 L
.78444 .04786 L
.78472 .04827 L
.78489 .04845 L
.78504 .04859 L
.78519 .04869 L
.78534 .04876 L
.78548 .04879 L
.78561 .04879 L
.78576 .04877 L
.78591 .04871 L
.78607 .04862 L
.78622 .0485 L
.78655 .04811 L
.78687 .04758 L
.78722 .04685 L
.78785 .04512 L
.78842 .04312 L
.78962 .03768 L
.79073 .0315 L
.79203 .02351 L
.79266 .01979 L
.79294 .0184 L
.79308 .01778 L
.79324 .01725 L
.79339 .01689 L
.79353 .01672 L
.79367 .01672 L
.7938 .01688 L
.79393 .01717 L
Mistroke
.79405 .01756 L
.79433 .01871 L
.7955 .02542 L
.79679 .03298 L
.79799 .039 L
.79908 .04319 L
.7997 .0449 L
.80026 .04604 L
.80058 .0465 L
.80073 .04667 L
.80087 .0468 L
.80102 .04691 L
.80111 .04695 L
.80119 .04699 L
.80128 .04702 L
.80137 .04703 L
.80145 .04704 L
.80154 .04703 L
.8017 .047 L
.80184 .04694 L
.80192 .04689 L
.80201 .04683 L
.80217 .0467 L
.80247 .04634 L
.80275 .0459 L
.80331 .04471 L
.80392 .04298 L
.80501 .03877 L
.8075 .02537 L
.8081 .02188 L
.80873 .01852 L
.80891 .01772 L
.809 .01738 L
.80909 .01711 L
.80925 .01673 L
.80933 .0166 L
.80942 .01652 L
.80957 .01655 L
.80972 .01676 L
.80981 .01695 L
.80988 .01717 L
.81006 .01778 L
.81065 .02069 L
.8113 .02439 L
.81248 .03109 L
.81372 .03718 L
.81487 .04158 L
.81545 .04321 L
.81575 .04389 L
.81608 .0445 L
Mistroke
.81626 .04479 L
.81643 .04502 L
.81661 .04521 L
.81677 .04535 L
.81693 .04545 L
.81708 .04552 L
.81724 .04556 L
.81733 .04557 L
.81741 .04557 L
.81756 .04554 L
.8177 .04549 L
.81783 .04542 L
.81797 .04531 L
.81829 .04499 L
.81858 .04457 L
.81911 .04354 L
.81968 .04207 L
.82086 .03781 L
.82217 .03156 L
.8233 .02527 L
.82392 .02176 L
.8245 .01875 L
.8248 .01746 L
.82497 .0169 L
.82512 .01655 L
.82521 .01642 L
.82529 .01636 L
.82538 .01634 L
.82548 .0164 L
.82564 .01665 L
.82573 .01687 L
.82581 .01712 L
.82611 .01829 L
.82639 .01961 L
.82701 .02296 L
.82822 .02959 L
.8295 .03582 L
.83012 .03833 L
.83071 .04034 L
.83123 .0418 L
.83153 .04249 L
.83181 .04304 L
.8321 .04351 L
.83237 .04386 L
.8325 .04399 L
.83265 .04412 L
.83281 .04422 L
.83296 .04429 L
.83309 .04432 L
.83323 .04434 L
Mistroke
.83337 .04433 L
.83351 .04429 L
.83364 .04423 L
.83376 .04417 L
.83402 .04395 L
.83431 .04361 L
.83458 .0432 L
.83519 .04195 L
.83578 .04031 L
.83642 .03814 L
.83882 .02678 L
.84008 .01992 L
.84039 .01844 L
.84072 .01712 L
.84082 .01682 L
.84091 .01658 L
.84099 .01641 L
.84108 .01628 L
.84117 .01621 L
.84126 .0162 L
.84135 .01625 L
.84142 .01634 L
.84158 .01665 L
.84166 .01686 L
.84175 .01714 L
.84205 .01831 L
.84272 .02165 L
.84393 .02817 L
.84512 .03393 L
.84625 .03833 L
.84684 .04014 L
.84715 .04093 L
.84748 .04166 L
.84776 .04217 L
.84807 .04262 L
.84835 .04293 L
.84848 .04305 L
.84861 .04314 L
.84876 .04322 L
.84885 .04326 L
.84893 .04328 L
.84902 .0433 L
.8491 .0433 L
.84924 .04329 L
.84939 .04326 L
.84952 .0432 L
.84967 .04312 L
.84983 .043 L
.85015 .04266 L
.85045 .04222 L
Mistroke
.85113 .04084 L
.85174 .03919 L
.85239 .03696 L
.85359 .0319 L
.85583 .02036 L
.85637 .01781 L
.85652 .01724 L
.85668 .01673 L
.85681 .0164 L
.85696 .01616 L
.85704 .01609 L
.85712 .01608 L
.85721 .01611 L
.85729 .0162 L
.85744 .01647 L
.85753 .01668 L
.8576 .01691 L
.85821 .01943 L
.85952 .02619 L
.86074 .03216 L
.86193 .0369 L
.86244 .03857 L
.86301 .04006 L
.86333 .04075 L
.86362 .04129 L
.86392 .04174 L
.86421 .04206 L
.86436 .04219 L
.86453 .04231 L
.86469 .04238 L
.86483 .04242 L
.86499 .04244 L
.86507 .04244 L
.86515 .04243 L
.86524 .04241 L
.86532 .04238 L
.86541 .04234 L
.8655 .0423 L
.86563 .04221 L
.86578 .04208 L
.86605 .04179 L
.86637 .04133 L
.86666 .04081 L
.86727 .03943 L
.8679 .03756 L
.86896 .03357 L
.87012 .02822 L
.87134 .02196 L
.87194 .01899 L
.87221 .01784 L
Mistroke
.87249 .01679 L
.87257 .01657 L
.87265 .01636 L
.8728 .01609 L
.87289 .01601 L
.87297 .01597 L
.87313 .01604 L
.87321 .01615 L
.8733 .01631 L
.87346 .01672 L
.87363 .01729 L
.87382 .01803 L
.87502 .02392 L
.87625 .02999 L
.87755 .0354 L
.87865 .03883 L
.87896 .03956 L
.87928 .04022 L
.87957 .0407 L
.87987 .04111 L
.88002 .04128 L
.88018 .04143 L
.88033 .04154 L
.88047 .04162 L
.88055 .04166 L
.88063 .04169 L
.88071 .04171 L
.88081 .04172 L
.88088 .04173 L
.88097 .04173 L
.88112 .0417 L
.88128 .04164 L
.88136 .0416 L
.88144 .04155 L
.88174 .0413 L
.88202 .04099 L
.88231 .04056 L
.88286 .0395 L
.88337 .03821 L
.88453 .03434 L
.88678 .02399 L
.88739 .02088 L
.88773 .01925 L
.88805 .01785 L
.88832 .01685 L
.88847 .01642 L
.88861 .01612 L
.88875 .01593 L
.88891 .01589 L
.88899 .01594 L
Mistroke
.88907 .01603 L
.88922 .01631 L
.88931 .01653 L
.88939 .01679 L
.88955 .01734 L
.88991 .01883 L
.89057 .02198 L
.89179 .02801 L
.89296 .03314 L
.8936 .03553 L
.89421 .03744 L
.8948 .03893 L
.89512 .03957 L
.89545 .04014 L
.89575 .04055 L
.89603 .04083 L
.89617 .04094 L
.89631 .04103 L
.89645 .04109 L
.89657 .04113 L
.8967 .04115 L
.89684 .04115 L
.89697 .04113 L
.89709 .04109 L
.89723 .04103 L
.89738 .04094 L
.89765 .04071 L
.89794 .04038 L
.89824 .03992 L
.89878 .03886 L
.89938 .03735 L
.89992 .03566 L
.90114 .03094 L
.90334 .02035 L
.90392 .01776 L
.90408 .01713 L
.90424 .01662 L
.90438 .01625 L
.90453 .01597 L
.90466 .01584 L
.90481 .01583 L
.90496 .01598 L
.9051 .01625 L
.90524 .0166 L
.90536 .01699 L
.90563 .01803 L
.90813 .02987 L
.90925 .03434 L
.90986 .03635 L
.91043 .03792 L
Mistroke
.91105 .03923 L
.91138 .03976 L
.91173 .0402 L
.91204 .04047 L
.91219 .04057 L
.91228 .04061 L
.91236 .04064 L
.9125 .04068 L
.91266 .04069 L
.9128 .04068 L
.91294 .04065 L
.91307 .04059 L
.91322 .04051 L
.91336 .04041 L
.91349 .0403 L
.91381 .03994 L
.91411 .03951 L
.9147 .03836 L
.91535 .03669 L
.9165 .03275 L
.91757 .02818 L
.91885 .02203 L
.91948 .01905 L
.91975 .01787 L
.92005 .01676 L
.92018 .01637 L
.92032 .01605 L
.92046 .01585 L
.92058 .01577 L
.92071 .01579 L
.92086 .01595 L
.921 .01623 L
.92113 .01657 L
.9214 .0175 L
.9217 .01873 L
.9223 .02155 L
.92353 .02748 L
.92483 .03297 L
.92594 .03662 L
.92657 .03818 L
.92715 .03926 L
.92744 .03967 L
.9276 .03984 L
.92776 .04 L
.9279 .04011 L
.92806 .04021 L
.9282 .04028 L
.92833 .04032 L
.92847 .04034 L
.9286 .04034 L
Mistroke
.92872 .04032 L
.92885 .04029 L
.92899 .04023 L
.92914 .04014 L
.92941 .03992 L
.92969 .0396 L
.93 .03916 L
.93055 .0381 L
.93121 .03644 L
.93182 .03455 L
.93429 .02404 L
.93491 .02104 L
.9355 .01835 L
.93575 .01732 L
.93602 .01643 L
.93616 .01608 L
.93632 .01583 L
.93646 .01573 L
.93659 .01575 L
.93673 .0159 L
.93688 .01619 L
.93702 .01656 L
.93715 .01698 L
.93766 .01905 L
.93881 .02452 L
.93995 .02973 L
.94118 .03446 L
.94185 .03648 L
.94246 .03797 L
.94304 .03904 L
.94334 .03944 L
.9435 .03962 L
.94366 .03977 L
.9438 .03988 L
.94395 .03997 L
.94409 .04004 L
.94422 .04007 L
.94436 .0401 L
.94451 .04009 L
.94459 .04008 L
.94467 .04007 L
.94482 .04001 L
.94495 .03994 L
.94509 .03985 L
.94538 .03959 L
.94565 .03926 L
.9459 .03889 L
.94651 .03771 L
.94717 .03601 L
.94837 .03192 L
Mistroke
.95061 .02181 L
.95116 .01923 L
.95147 .01792 L
.95175 .01684 L
.95192 .01635 L
.952 .01614 L
.95209 .01595 L
.95218 .01582 L
.95225 .01574 L
.9524 .0157 L
.95255 .0158 L
.95264 .01592 L
.95271 .01607 L
.95286 .01642 L
.95301 .01688 L
.95422 .02219 L
.95555 .0284 L
.95676 .03328 L
.9579 .03682 L
.95854 .03824 L
.9589 .03886 L
.95923 .03931 L
.9595 .0396 L
.95966 .03972 L
.95981 .03982 L
.95997 .03989 L
.96011 .03993 L
.96026 .03995 L
.96034 .03995 L
.96043 .03995 L
.96051 .03993 L
.96059 .03991 L
.96074 .03985 L
.96089 .03976 L
.96107 .03963 L
.96138 .03932 L
.96167 .03893 L
.96222 .03796 L
.9628 .03659 L
.96412 .03231 L
.96533 .02725 L
.96644 .022 L
.96705 .01914 L
.96735 .01785 L
.96763 .01683 L
.96777 .0164 L
.96792 .01603 L
.96808 .01578 L
.96817 .01571 L
.96824 .01568 L
Mistroke
.96833 .0157 L
.96842 .01577 L
.96857 .01601 L
.96866 .01621 L
.96874 .01642 L
.96893 .017 L
.97013 .02232 L
.97131 .02785 L
.97258 .03304 L
.9732 .03511 L
.97378 .03676 L
.97435 .03806 L
.97488 .03896 L
.97518 .03935 L
.97534 .0395 L
.97551 .03965 L
.9756 .03971 L
.97569 .03977 L
.97577 .03981 L
.97587 .03985 L
.97602 .03989 L
.97611 .0399 L
.97619 .03991 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`006Oooool3o`0000Cooooo0_l0000iooooo`?o0000>oooool2o`0003cooooo0ol0000ioooo
o`?o00001?ooool2o`0000Cooooo000Jooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo0000=oooool01Ol0003ooooooooooooooooo000003Wooooo00Co0000oooooooooooo0000>_oo
ool01Ol0003ooooooooooooooooo000003Wooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00003ooooo`004_ooool5o`0000?ooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool0000aooooo`Go00001Oooool00ol0003oooooooooo`0gooooo`04o`000?ooooooooooo`00
03kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000?ooooo000Jooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000>oooool0
0ol0003oooooooooo`0gooooo`04o`000?ooooooooooo`0003kooooo00?o0000ooooooooool0=ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo000Jooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo0000=oooool4o`0003[ooooo00Co0000oooooooooooo
0000>_ooool4o`0003[ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003oooo
o`006Oooool2o`0000Cooooo00Co0000oooooooooooo0000=oooool00ol0003oooooooooo`0koooo
o`04o`000?ooooooooooo`0003[ooooo00?o0000ooooooooool0>_ooool2o`0000Cooooo00Co0000
oooooooooooo00000oooool001[ooooo00?o0000ooooooooool00oooool2o`0003Sooooo1Ol0000j
ooooo`;o0000>oooool5o`0003Wooooo00?o0000ooooooooool00oooool2o`0000Cooooo003ooooo
ob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Eoooooooo00002ol00001
ooooo`003_ooool2o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00oooool1o`00007ooooo000=ooooo`04
o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0loooo
o`03o`000?oooooooooo03gooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0loooo
o`03o`000?oooooooooo00?ooooo0Ol00001ooooo`003Oooool01?l0003oooooooooool00004oooo
o`;o0000Poooool00ol0003oooooooooo`20ooooo`;o00000Oooool000gooooo00Co0000oooooooo
oooo00001?ooool00ol0003oooooooooo`05ooooo`03o`00oooooooooooo00Kooooo00Go003ooooo
ooooooooooooo`00o`07ooooo`04o`00ooooooooooooooooo`;o003o2oooool00ol00?oooooooooo
o`10ooooo`03o`00oooooooooooo017ooooo00?o0000ooooooooool04?ooool00ol00?oooooooooo
o`0looooo`03o`00oooooooooooo00Gooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00
oooooooooooo00Wooooo00Co003ooooooooooooooooo0_l00?l3ooooo`05o`00oooooooooooooooo
ool00?l01oooool1o`00007ooooo000=ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooo
ooooool01Oooool2o`00o`?ooooo00?o003oooooooooool00_l00?l3ooooo`05o`00oooooooooooo
ooooool00?l00oooool01?l00?ooooooooooooooool2o`00o`Oooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l00oooool2o`00o`?ooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`0Fooooo`03o`00oooooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0
0?ooooooooooo`0Jooooo`05o`00ooooooooooooooooool00?l02?ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool01Oooool2o`00o`?ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool2o`00o`?ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`;o003o0_ooool2o`00o`;ooooo0_l00?l3ooooo`03o`00oooooooooooo
00Gooooo0Ol00001ooooo`003Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo
00Kooooo00?o003oooooooooool00_l00?l2ooooo`03o`00oooooooooooo00;ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_l00?l3
ooooo`05o`00ooooooooooooooooool00?l00oooool2o`00o`?ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool2o`00o`;ooooo0_l00?l3ooooo`05
o`00ooooooooooooooooool00?l00oooool01?l00?ooooooooooooooool2o`00o`?ooooo00?o003o
ooooooooool08Oooool00ol0003oooooooooo`0@ooooo`;o003o3_ooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo
0_l00?l3ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`02o`00o`?o
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool0
1?l00?ooooooooooooooool2o`00o`;ooooo0_l00?l3ooooo`;o003o0_ooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`06ooooo`7o0000
0Oooool000kooooo0_l00005ooooo`03o`000?oooooooooo00Cooooo00?o003oooooooooool00_oo
ool2o`00o`Kooooo00?o003oooooooooool00_ooool2o`00o`;ooooo0_l00?l6ooooo`;o003o0_oo
ool3o`00o`;ooooo0_l00?l2ooooo`;o003o0_ooool2o`00o`;ooooo0_l00?l3ooooo`03o`00oooo
oooooooo00Gooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool0
0?l02?ooool01Ol00?oooooooooooooooooo003o00_ooooo00?o003oooooooooool00_l00?lCoooo
o`03o`000?oooooooooo013ooooo0_l00?l2ooooo`03o`00oooooooooooo00Wooooo0_l00?l3oooo
o`05o`00ooooooooooooooooool00?l00oooool01?l00?ooooooooooooooool2o`00o`;ooooo0_l0
0?l2ooooo`;o003o0_ooool2o`00o`Cooooo00?o003oooooooooool00_l00?l3ooooo`03o`00oooo
oooooooo00;o003o0_ooool00ol00?ooooooo`00o`02ooooo`;o003o0_ooool2o`00o`Kooooo00Oo
003oooooool00?ooooooo`00oooooooo003o00kooooo00?o003oooooooooool01_ooool1o`00007o
oooo000Eooooo`03o`000?oooooooooo00Cooooo00Oo003oooooooooooooooooo`00oooooooo003o
00?ooooo0_l00?l01_oooooo003oooooool00?ooooooo`00o`Gooooo00?o003oooooooooool00_l0
0?l2ooooo`?o003o00Coooooo`00oooooooo003o0oooool00ol00?ooooooooooo`02o`00o`;ooooo
00Co003ooooooooooooooooo0_l00?l4ooooo`03o`00oooooooooooo00;o003o0oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`;o003o0oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool01Oooool01_l00?oooooooooo
ool00?ooooooo`00oa;ooooo00?o0000ooooooooool04Oooool01?l00?ooooooooooool00?l7oooo
o`03o`00oooooooooooo00Gooooo0_l00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool2
o`00o`;ooooo0_l00?l2ooooo`;o003o0oooool01?l00?ooooooooooool00?l4ooooo`;o003o0_oo
ool2o`00o`;ooooo00?o003oooooooooool00oooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`03ooooo`05o`00oooooooo003oooooool0
0?l00_ooool2o`00o`;ooooo00Oo003oooooool00?ooooooo`00oooooooo003o00Kooooo0Ol00001
ooooo`005Oooool2o`0000Gooooo00?o003oooooool00?l01Oooool02_l00?ooooooooooool00?oo
ooooo`00oooooooo003oooooool00?l5ooooo`03o`00oooooooo003o00;ooooo00?o003oooooool0
0?l01Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Co003ooooooooooooo003o0oooool0
0ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00;o003o0_ooool2o`00o`?ooooo00Co003o
oooooooooooo003o1?ooool2o`00o`;ooooo0_l00?l2ooooo`03o`00oooooooooooo00;ooooo00Go
003oooooooooooooooooo`00o`07ooooo`06o`00ooooooooooooo`00oooooooo003o3_ooool01Ol0
0?oooooooooooooooooo000000;ooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`08
ooooo`03o`00oooooooooooo00Gooooo0_l00?l2ooooo`;o003o0oooool00ol00?ooooooooooo`05
ooooo`;o003o0_ooool01?l00?ooooooooooooooool2o`00o`;ooooo00?o003oooooool00?l00ooo
ool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo00?ooooo00Wo003ooooooooooooo
ooooo`00oooooooo003oooooool00?l00_ooool01Ol00?ooooooo`00oooooooo003o00Gooooo00Oo
003oooooool00?ooooooo`00oooooooo003o00;ooooo00Go003oooooool00?ooooooo`00o`03oooo
o`03o`00oooooooooooo00?ooooo0_l00001ooooo`005Oooool00ol0003oooooooooo`04ooooo`03
o`00oooooooooooo00;o003o0_ooool2o`00o`;ooooo00Co003oooooool00?oooooo0_l00?l2oooo
o`?o003o0oooool00ol00?ooooooooooo`02o`00o`Cooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooool00?l00oooool02Ol00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00o`02ooooo`;o003o0_ooool2o`00o`;ooooo00?o003ooooooooo
ool00oooool00ol00?ooooooooooo`02o`00o`;ooooo0_l00?l2ooooo`;o003o0oooool00ol00?oo
ooooooooo`06ooooo`05o`00ooooooooooooooooool00?l03_ooool01Ol00?oooooooooooooooooo
000000;ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0:ooooo`04o`00oooooooo
ooooooooo`;o003o0_ooool00ol00?ooooooooooo`02ooooo`06o`00ooooooooooooo`00oooooooo
003o0_ooool00ol00?ooooooooooo`05ooooo`0;o`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?l01Oooool2o`00o`?ooooo00Go003oooooool00?ooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l00_ooool2o`00o`;ooooo00Co003ooooooooooooooooo0ol00?l3
ooooo`03o`00oooooooooooo00;o003o0_ooool01?l00?ooooooooooooooool2o`00o`;ooooo0_l0
0?l5ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool01oooool2o`00o`;ooooo0_l00?l7
ooooo`04o`00ooooooooooooooooo`;o003o0oooool01?l00?ooooooooooool00?l3ooooo`;o003o
1?ooool01Ol00?oooooooooooooooooo003o00Kooooo00go003oooooooooooooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003o00;ooooo0_l00?l2ooooo`;o003o1?ooool00ol00?oo
ooooo`00o`04ooooo`;o003o0_ooool2o`00o`;ooooo0_l00?l<ooooo`03o`00oooooooooooo013o
oooo00Go003oooooooooooooooooo`000002ooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`09ooooo`;o003o2_ooool00ol00?ooooooo`00o`02oooo
o`;o003o0oooool00ol00?ooooooooooo`02ooooo`0;o`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?l00_ooool01Ol00?oooooooooooooooooo003o00?ooooo0_l00?l4oooo
o`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02o`00o`?ooooo00Co003o
oooooooooooooooo0_l00?l2ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?oooooo
ooooo`07ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool09Oooool01Ol00?oooooooooo
oooooooo003o00?ooooo0_l00?l2ooooo`;o003o0_ooool2o`00o`;ooooo00?o003oooooool00?l0
1oooool00ol00?ooooooooooo`02ooooo`0;o`00ooooooooooooooooool00?ooooooo`00oooooooo
003oooooool00?l01_ooool2o`00o`;ooooo0_l00?l;ooooo`;o003o00?oooooo`00ooooool02?oo
ool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00;ooooo00Go0000oooooooooooooooo
o`00o`05ooooo`03o`00oooooooooooo00Gooooo00Co003oooooool00?oooooo0_l00?l;ooooo`;o
003o0oooool01?l00?ooooooooooool00?l5ooooo`05o`00oooooooo003oooooool00?l00_ooool2
o`00o`;ooooo00Go003oooooool00?ooooooo`00o`05ooooo`03o`00oooooooo003o00;ooooo00Co
003ooooooooooooooooo0_l00?l2ooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o02Oo
oooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`0aooooo`;o003o1_ooool00ol00?oooooo
ooooo`02ooooo`;o003o1_ooool00ol00?ooooooooooo`03ooooo`07o`00oooooooo003oooooool0
0?ooooooo`00o`02ooooo`;o003o0oooool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooo
oooo00Gooooo0_l00?l01?oooooo003oooooool00?l7ooooo`03o`00oooooooooooo00;o003o00?o
ooooo`00ool00?l00oooool00ol0003oooooooooo`02o`00o`;ooooo00?o003oooooooooool00_l0
0?l8ooooo`04o`00oooooooo003oo`00o`Oooooo00Co003ooooooooooooooooo0_l00?l2ooooo`;o
003o0_ooool2o`00o`;ooooo00Oo003oooooool00?ooooooo`00oooooooo003o00;ooooo0_l00?l2
ooooo`03o`00oooooooo003o00?ooooo00?o003oooooool00?l00_ooool2o`00o`;ooooo0_l00?l2
ooooo`;o003o<oooool1o`00007ooooo000Eooooo`03o`000?oooooooooo03kooooo0_l00?l2oooo
o`;o003o0_ooool03Ol00?oooooooooooooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?l00_ooool2o`00o`;ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`05oooo
o`06o`00ooooooooooooo`00oooooooo003o1oooool00ol00?ooooooooooo`02o`00o`03ooooool0
0?oo003o00?ooooo00?o0000ooooooooool00_l00?l2ooooo`05o`00ooooooooooooooooool00?l0
2?ooool00ol00?ooooooo`00o`08ooooo`03o`00oooooooooooo00Gooooo0_l00?l2ooooo`05o`00
oooooooo003oooooool00?l01oooool00ol00?ooooooooooo`02o`00o`Oooooo00?o003ooooooooo
ool0?_ooool1o`00007ooooo000Eooooo`03o`000?oooooooooo04;ooooo0_l00?l2ooooo`;o003o
0_ooool00ol00?ooooooo`00o`05ooooo`05o`00oooooooo003oooooool00?l00_ooool2o`00o`?o
oooo00Go003oooooooooooooooooo`00o`08ooooo`05o`00oooooooo003oooooool00?l01oooool0
1Ol00?oooooooooooooooooo003o00;ooooo00Go003oooooooooooooooooo`000002ooooo`03o`00
oooooooooooo00;o003o2_ooool00ol00?ooooooooooo`0:ooooo`04o`00ooooooooooooooooo`;o
003o0_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo003o00?ooooo00?o003ooooooooo
ool01?ooool2o`00o`?ooooo00?o003oooooooooool0@_ooool1o`00007ooooo000Eooooo`;o0000
Aoooool2o`00o`;ooooo00Go003oooooooooooooooooo`00o`05ooooo`03o`00oooooooo003o00;o
oooo0_l00?l2ooooo`;o003o0oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00So
oooo0_l00?l6ooooo`05o`00ooooooooooooooooool000000_ooool00ol00?ooooooooooo`02o`00
o`;ooooo0_l00?l6ooooo`04o`00ooooooooooooooooo`;o003o1oooool01?l00?oooooooooooooo
ool2o`00o`;ooooo00?o003oooooooooool01Oooool01Ol00?ooooooo`00oooooooo003o00;ooooo
00?o003oooooooooool0B_ooool2o`00007ooooo000Eooooo`03o`000?oooooooooo04kooooo00?o
003oooooool00?l02?ooool2o`00o`;ooooo0_l00?l;ooooo`?o003o2_ooool01?l00?oooooooooo
ool00?l2ooooo`03o`00oooooooooooo00;ooooo00Oo0000ooooooooooooooooo`00oooooooo003o
00?ooooo0_l00?l6ooooo`03o`00oooooooooooo00?o003o1oooool01?l00?ooooooooooooooool2
o`00o`?ooooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooo`00o`02ooooo`;o003oC?oo
ool1o`00007ooooo000Eooooo`03o`000?oooooooooo04kooooo0ol00?l00ooooooo003oooooo`06
ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool01Oooool3o`00o`?ooooo00?o
003oooooooooool01oooool2o`00o`03ooooool00?oooooo00?ooooo00[o0000oooooooooooooooo
o`00oooooooo003oooooool00?oooooo0_l00?l6ooooo`03o`00oooooooooooo00?o003o1oooool2
o`00o`;ooooo0_l00?l2ooooo`;o003o0_ooool00ol00?ooooooo`00o`04ooooo`;o003o0_ooool0
0ol00?ooooooooooo`1;ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0Coooool02?l0
0?ooooooooooool00?ooooooo`00oooooooo003o0_ooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooool00?l00oooool00ol00?ooooooooooo`03ooooo`03o`00
oooooooooooo00?o003o00?oooooo`00ool00?l00oooool00ol0003oooooooooo`02o`00o`?ooooo
00Co003ooooooooooooo003o2Oooool00ol00?ooooooo`00o`08ooooo`03o`00oooooooooooo00Co
oooo00Wo003oooooool00?ooooooo`00oooooooo003oooooool00?l0E?ooool1o`00007ooooo000E
ooooo`03o`000?oooooooooo05?ooooo0_l00?l2ooooo`03o`00oooooooo003o00Cooooo00Go003o
ooooooooooooooooo`00o`07ooooo`03o`00oooooooo003o00?ooooo00?o003oooooooooool00ooo
ool00ol00?ooooooo`00o`02ooooo`04o`00oooooooo003oo`00o`?ooooo00?o0000ooooooooool0
0_l00?l01?oooooo003oooooool00?l8ooooo`03o`00oooooooooooo00cooooo00?o003ooooooooo
ool01?ooool02Ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`1Dooooo`7o00000Ooo
ool001Gooooo00?o0000ooooooooool0E?ooool02Ol00?ooooooooooool00?ooooooo`00oooooooo
003oooooo`02o`00o`?ooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`03ooooo`03
o`00oooooooo003o00;ooooo00Co003ooooooooooooo003o0oooool01?l0003oooooooooool00?l2
ooooo`04o`00oooooooo003oo`00o`Oooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`05ooooo`;o003o0_ooool2o`00o`;ooooo00?o003oooooooooool00oooool2o`00oeGooooo0Ol0
0001ooooo`005Oooool2o`0005Wooooo00So003ooooooooooooo003oooooool00?ooooooo`00o`[o
oooo00?o003oooooooooool02oooool2o`00o`?ooooo00?o003oooooooooool00_ooool01?l0003o
ooooooooooooool3o`00o`;ooooo00?o003oooooool00?l01Oooool00ol00?ooooooooooo`03oooo
o`03o`00oooooooooooo00Gooooo00Co003ooooooooooooooooo0_l00?l4ooooo`;o003oF?ooool2
o`00007ooooo000Eooooo`03o`000?oooooooooo05_ooooo00Go003oooooool00?ooooooo`00o`0:
ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool01Oooool2o`00o`;ooooo0_l00?l4
ooooo`03o`000?oooooooooo00;ooooo00Oo003oooooooooooooooooo`00oooooooo003o00Gooooo
00?o003oooooooooool00oooool00ol00?ooooooooooo`05ooooo`04o`00ooooooooooooooooo`;o
003o00Coooooo`00oooooooooooo0_l00?mIooooo`7o00000Oooool001Gooooo00?o0000oooooooo
ool0Eoooool00ol00?ooooooooooo`03ooooo`04o`00ooooooooooooooooo`;o003o1oooool00ol0
0?ooooooooooo`03ooooo`03o`00oooooooooooo00?ooooo00Co003ooooooooooooo003o0_ooool0
1?l00?ooooooooooool00?l2ooooo`06o`000?ooooooooooo`00oooooooo003o0_ooool01?l00?oo
ooooooooool00?l;ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool00oooool00ol0
0?ooooooooooo`02o`00oeWooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`1Gooooo`;o
003o0_ooool01_l00?oooooooooooooooooo003oooooo`;o003o1oooool00ol00?ooooooooooo`03
ooooo`03o`00oooooooooooo00?ooooo00Co003ooooooooooooo003o1Oooool01?l00?oooooooooo
ool00002ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool05?ooool00ol00?oooooo
ooooo`03ooooo`03o`00oooooooooooo00;o003oFOooool1o`00007ooooo0006ooooo`Go00000ooo
ool2o`0000Gooooo00?o0000ooooooooool0Eoooool2o`00o`;ooooo00Ko003oooooool00?oooooo
o`00ooooool2o`00o`gooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`06ooooo`04
o`00ooooooooooooo`0000;ooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0;oooo
o`;o003o0_ooool01?l00?ooooooooooool00?mMooooo`7o00000Oooool000Oooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo05_ooooo00Go
003oooooool00?ooooooo`00o`0Fooooo`03o`00oooooooooooo00Kooooo00Co003ooooooooooooo
00000_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00?ooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooooooo`04ooooo`05o`00ooooooooooooooooool00?l0H?ooool1o`00
007ooooo0008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001?ooool00ol0
003oooooooooo`1Kooooo`05o`00oooooooo003oooooool00?l02_ooool00ol00?ooooooooooo`03
ooooo`03o`00oooooooooooo00oooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`03
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool01?l00?ooooooooooool0
0?l2ooooo`03o`00oooooooooooo05cooooo0Ol00001ooooo`002Oooool01Ol0003ooooooooooooo
oooo000000;ooooo00?o0000ooooooooool00_ooool2o`0005gooooo00?o003oooooooooool00_oo
ool2o`00o`Oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooooooo00Kooooo00Ko003ooooooooooooo0000ooooool00?l8ooooo`03o`00oooooooooooo00[o
oooo00?o003oooooooooool01?ooool2o`00o`Cooooo0_l00?mLooooo`;o00000Oooool000Kooooo
00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooo
ooooool0HOooool2o`00o`Oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`03oooo
o`03o`00oooooooooooo00Kooooo00Ko003ooooooooooooo0000ooooool00?lMooooo`03o`00oooo
oooooooo00;ooooo0_l00?mMooooo`7o00000Oooool000Kooooo00Go0000ooooooooooooooooo`00
0002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0Foooool02Ol00?oooooo
oooooooooooo003oooooool00?ooooooo`00o`0<ooooo`03o`00oooooooooooo00?ooooo00?o003o
ooooooooool01_ooool01_l00?ooooooooooool0003oooooo`00o`kooooo00?o003oooooooooool0
2oooool2o`00o`04ooooool00?ooooooooooo`;o003oGOooool1o`00007ooooo0007ooooo`?o0000
1?ooool2o`0000Gooooo00?o0000ooooooooool0G?ooool01?l00?ooooooooooool00?l3ooooo`03
o`00oooooooooooo013ooooo00?o003oooooooooool01_ooool01_l00?ooooooooooool0003ooooo
o`00o`Sooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo00Cooooo0_l00?l00ooooooo003oooooo`1Pooooo`7o00000Oooool001Gooooo00?o0000oooo
ooooool0Goooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo01Kooooo00?o0000oooo
ooooool02?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool01?ooool01?l00?ooooooooooool00?mQooooo`7o00000Oooool001Gooooo00?o0000oooo
ooooool0HOooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool03oooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003ooooo
ooooool01?ooool2o`00o`03ooooool00?oooooo063ooooo0Ol00001ooooo`005Oooool2o`0006;o
oooo00?o003oooooool00?l01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00?o
oooo00?o003oooooooooool01_ooool01_l00?ooooooooooool0003oooooo`00o`Sooooo00?o003o
ooooooooool02_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo063ooooo0_l00001
ooooo`005Oooool00ol0003oooooooooo`1Oooooo`05o`00oooooooo003oooooool00?l01Oooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01_ooool0
1_l00?ooooooooooool0003oooooo`00o`kooooo00?o003oooooooooool03?ooool00ol00?oooooo
o`00o`1Qooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0Goooool01Ol00?ooooooo`00
oooooooo003o01;ooooo00?o003oooooooooool01_ooool01_l00?ooooooooooool0003oooooo`00
o`Sooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00?ooooo00Go003oooooool00?ooooooo`00o`1Qooooo`7o00000Oooool001Gooooo00?o0000oooo
ooooool0Goooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo01Kooooo00?o0000oooo
ooooool02?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool00oooool01Ol00?oooooooooooooooooo003o067ooooo0Ol00001ooooo`005Oooool00ol0
003oooooooooo`1Oooooo`03o`00oooooooo003o00Oooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`0>ooooo`03o`000?oooooooooo00Wooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00?ooooo00Go003oooooooooooooooooo`00o`1Q
ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0HOooool00ol00?ooooooo`00o`05oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`06oooo
o`06o`00ooooooooooooo`000?oooooo003o2Oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool0HOooool1o`00007ooooo000Eooooo`03o`000?oooooo
oooo05oooooo00Go003oooooool00?ooooooo`00o`05ooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`06ooooo`06o`00ooooooooooooo`000?oooooo
003o3Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo067ooooo0Ol00001ooooo`00
5Oooool2o`00063ooooo00Go003oooooool00?ooooooo`00o`0=ooooo`05o`00oooooooooooooooo
ool00?l02Oooool01_l00?ooooooooooool0003oooooo`00o`gooooo00?o003oooooooooool02ooo
ool01Ol00?ooooooo`00oooooooo003o063ooooo0_l00001ooooo`005Oooool00ol0003ooooooooo
o`1Oooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool01oooool01_l00?oooooooooo
ool0003oooooo`00o`Wooooo00Go003oooooooooooooooooo`00o`07ooooo`03o`00oooooooooooo
00?ooooo00Go003oooooooooooooooooo`00o`1Qooooo`7o00000Oooool001Gooooo00?o0000oooo
ooooool0H?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool03_ooool00ol0003oooooooooo`09ooooo`05o`00ooooooooooooooooool00?l01oooool0
0ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00;o003oHOooool1o`00007ooooo000Eoooo
o`03o`000?oooooooooo067ooooo00?o003oooooool00?l01Oooool00ol00?ooooooooooo`05oooo
o`05o`00ooooooooooooooooool00?l02Oooool01_l00?ooooooooooool0003oooooo`00o`Wooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`03ooooo`04o`00ooooooooooooo`00of;o
oooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`1Pooooo`04o`00ooooooooooooo`00o`Go
oooo00?o003oooooooooool01Oooool01Ol00?oooooooooooooooooo003o00Wooooo00Ko003ooooo
oooooooo0000ooooool00?lNooooo`03o`00oooooooooooo063ooooo0Ol00001ooooo`005Oooool0
0ol0003oooooooooo`1Pooooo`04o`00ooooooooooooo`00o`gooooo00Go003ooooooooooooooooo
o`00o`09ooooo`06o`00ooooooooooooo`000?oooooo003o3Oooool00ol00?ooooooooooo`0;oooo
o`04o`00ooooooooooooo`00of;ooooo0Ol00001ooooo`005Oooool2o`0007Kooooo00?o003ooooo
ooooool01oooool01_l00?ooooooooooool0003oooooo`00o`Wooooo00Go003ooooooooooooooooo
o`00o`07ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0H_ooool2o`00007ooooo
000Eooooo`03o`000?oooooooooo06Wooooo00?o003oooooooooool05_ooool00ol0003ooooooooo
o`09ooooo`05o`00ooooooooooooooooool00?l01oooool00ol00?ooooooooooo`03ooooo`03o`00
oooooooooooo06?ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`1Sooooo`03o`00oooo
oooooooo00?ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`000?oo
oooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooooooo06?ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`1Sooooo`03o`00oooooooo
oooo00?ooooo00?o003oooooooooool01Oooool01Ol00?oooooooooooooooooo003o00Wooooo00Ko
003ooooooooooooo0000ooooool00?l9ooooo`03o`00oooooooooooo00Wooooo00?o003ooooooooo
ool0JOooool1o`00007ooooo0008ooooo`?o00000oooool2o`0000Gooooo00?o0000ooooooooool0
Hoooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Gooooo00Go003ooooooooooooo
ooooo`00o`09ooooo`06o`00ooooooooooooo`000?oooooo003o3Oooool00ol00?ooooooooooo`1a
ooooo`7o00000Oooool000Wooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0Hoooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooo
oooo00Sooooo00Go003oooooool0003oooooo`00o`09ooooo`05o`00ooooooooooooooooool00?l0
1oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo06?ooooo0Ol00001ooooo`001_oo
ool5o`0000;ooooo00Co0000oooooooooooo00001?ooool2o`0006[ooooo00?o003oooooooooool0
5_ooool00ol0003oooooooooo`09ooooo`05o`00ooooooooooooooooool00?l01oooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooooooo06;ooooo0_l00001ooooo`001_ooool01?l0003ooooo
ooooool00003ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0Hoooool00ol0
0?ooooooooooo`03ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03_ooool00ol0
003oooooooooo`09ooooo`05o`00ooooooooooooooooool00?l01oooool00ol00?ooooooooooo`03
ooooo`03o`00oooooooooooo06?ooooo0Ol00001ooooo`001oooool00ol0003oooooo`000003oooo
o`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0Hoooool00ol00?ooooooooooo`03
ooooo`03o`00oooooooooooo00Gooooo00Go003oooooooooooooooooo`00o`0:ooooo`05o`00oooo
oooo0000ooooool00?l02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo06Wooooo
0Ol00001ooooo`002?ooool2o`0000?ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
ooooo`1Sooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool01Oooool01Ol00?oooooo
oooooooooooo003o00[ooooo00Go003oooooool0003oooooo`00o`0=ooooo`03o`00oooooooooooo
077ooooo0Ol00001ooooo`002Oooool00ol0003oooooooooo`02ooooo`;o00001Oooool00ol0003o
ooooooooo`1Sooooo`03o`00oooooooooooo00_ooooo00Go003oooooooooooooooooo`00o`0:oooo
o`04o`00oooooooo0000o`00o`kooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`1S
ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0JOooool00ol00?ooooooooooo`0Doooo
o`04o`00oooooooo0000o`00o`[ooooo00Go003oooooooooooooooooo`00o`07ooooo`03o`00oooo
oooooooo00?ooooo00?o003oooooooooool0Hoooool1o`00007ooooo000Eooooo`03o`000?oooooo
oooo06Wooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=ooooo`03o`000?oooooo
oooo00Wooooo00Go003oooooooooooooooooo`00o`07ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool0Hoooool1o`00007ooooo000Eooooo`;o0000I?ooool00ol00?ooooooooooo`03
ooooo`03o`00oooooooooooo00Kooooo00Co003ooooooooooooo003o2_ooool01?l00?ooooooo`00
0?l00?l:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool00oooool00ol00?oooooo
ooooo`1Rooooo`;o00000Oooool001Gooooo00?o0000ooooooooool0Hoooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo00Kooooo00Co003ooooooooooooo003o2_ooool01?l00?oooooo
o`000?l00?n2ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0Hoooool00ol00?oooooo
ooooo`0<ooooo`04o`00ooooooooooooo`00o`[ooooo00Co003oooooool0003o003o3Oooool00ol0
0?ooooooooooo`0<ooooo`03o`00oooooooooooo06?ooooo0Ol00001ooooo`005Oooool00ol0003o
ooooooooo`1eooooo`03o`00oooooooooooo00Sooooo00Co003oooooool0003o003o2_ooool01?l0
0?ooooooooooool00?l8ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0Hoooool1
o`00007ooooo000Eooooo`03o`000?oooooooooo06Wooooo00?o003oooooooooool05_ooool00ol0
003oooooooooo`09ooooo`04o`00ooooooooooooo`00o`Sooooo00?o003oooooooooool00oooool0
0ol00?ooooooooooo`1Sooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0Hoooool00ol0
0?ooooooooooo`03ooooo`03o`00oooooooooooo00Kooooo00Co003ooooooooooooo003o2_ooool0
0ol00?ooooooo`00000<ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool00oooool0
0ol00?ooooooooooo`1Sooooo`7o00000Oooool001Gooooo0_l0001Tooooo`03o`00oooooooooooo
00?ooooo00?o003oooooooooool01_ooool01?l00?ooooooooooool00?l:ooooo`04o`00oooooooo
0000o`00o`_ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`1Xooooo`;o00000Ooo
ool001Gooooo00?o0000ooooooooool0Hoooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooo
003o00_ooooo00Co003oooooool0003o003o3Oooool00ol00?ooooooooooo`1booooo`7o00000Ooo
ool001Gooooo00?o0000ooooooooool0Hoooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooo
oooo00Wooooo00Co003oooooool0003o003o2oooool00ol00?ooooooo`00o`08ooooo`03o`00oooo
oooooooo00?ooooo00?o003oooooooooool0Hoooool1o`00007ooooo000Eooooo`03o`000?oooooo
oooo06Wooooo00?o003oooooooooool05_ooool00ol0003oooooooooo`0:ooooo`03o`00oooooooo
003o00Sooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`1Sooooo`7o00000Oooool0
01Gooooo00?o0000ooooooooool0Hoooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool03Oooool00ol0003oooooooooo`0:ooooo`03o`00oooooooo003o
00Wooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1Sooooo`7o00000Oooool001Go
oooo00?o0000ooooooooool0Hoooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Ko
oooo00?o003oooooool00?l02oooool01?l00?ooooooo`000?l00?l;ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool0J?ooool1o`00007ooooo000Eooooo`03o`000?oooooooooo06?o
oooo00?o003oooooooooool00oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo003o00_o
oooo00Co003oooooool0003o003o3Oooool00ol00?ooooooooooo`1booooo`7o00000Oooool001Go
oooo0_l0001Tooooo`03o`00oooooooooooo00cooooo00?o003oooooool00?l02oooool01?l00?oo
ooooo`000?l00?l=ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0H_ooool2o`00
007ooooo000Eooooo`03o`000?oooooooooo06Wooooo00?o003oooooooooool05_ooool00ol0003o
ooooooooo`0:ooooo`03o`00oooooooo003o00Wooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`1Sooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0JOooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00gooooo00?o0000ooooooooool02_ooool00ol00?oooooo
o`00o`09ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0Hoooool1o`00007ooooo
000Eooooo`03o`000?oooooooooo06?ooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`07ooooo`03o`00oooooooo003o00_ooooo00Co003oooooool0003o003o2oooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0Hoooool1o`00007ooooo
0007ooooo`?o00001?ooool2o`0000Gooooo00?o0000ooooooooool0Hoooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo00Sooooo0_l00?l<ooooo`03o`00ool0003o003o08;ooooo0Ol0
0001ooooo`001_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`1Sooooo`03o`00oooooooooooo00gooooo0_l00?l<ooooo`03o`00
ool0003o003o00gooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1Sooooo`7o0000
0Oooool000Kooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Co
oooo0_l0001eooooo`03o`00oooooooooooo00[ooooo00?o003oo`000?l00?l02oooool00ol00?oo
ooooo`00o`09ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0H_ooool2o`00007o
oooo0006ooooo`Co00000oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo06So
oooo00?o003oooooooooool05_ooool00ol00?oo0000ooooo`0;ooooo`;o003o2_ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo06?ooooo0Ol00001ooooo`001_ooool00ol0003ooooo
ooooo`04ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0Hoooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02oooool2o`00o`go
oooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo06?o
oooo0Ol00001ooooo`001oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Co
oooo00?o0000ooooooooool0Hoooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00So
oooo00?o003oooooooooool02oooool2o`00o`gooooo00?o003oooooooooool0Loooool1o`00007o
oooo0008ooooo`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool0I?ooool00ol00?oooooo
ooooo`0Kooooo`03o`00oooooooooooo087ooooo0Ol00001ooooo`005Oooool00ol0003ooooooooo
o`1Tooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool05_ooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo06?ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`1X
ooooo`03o`00oooooooooooo01Kooooo00?o003oo`000?ooool05oooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo06?ooooo0Ol00001ooooo`005Oooool2o`0006Gooooo00Go003ooooo
ooooooooooooo`00o`0Hooooo`03o`00ool0003ooooo01Oooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`1Rooooo`;o00000Oooool001Gooooo00?o0000ooooooooool0I?ooool01Ol0
0?oooooooooooooooooo003o01Sooooo0_l00?lHooooo`03o`00oooooooooooo06Sooooo0Ol00001
ooooo`005Oooool00ol0003oooooooooo`1Tooooo`05o`00ooooooooooooooooool00?l06Oooool0
0ol0003oooooooooo`21ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0I?ooool00ol0
0?ooooooooooo`0Kooooo`03o`000?oooooooooo01Kooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`1Sooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0J?ooool00ol00?oo
ooooooooo`0Gooooo`03o`000?oooooooooo01Kooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`1Sooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0J?ooool00ol00?oooooo
ooooo`0Gooooo`03o`000?oooooooooo01Kooooo00Go003oooooooooooooooooo`00o`1Vooooo`7o
00000Oooool001Gooooo0_l0001Uooooo`05o`00ooooooooooooooooool00?l06Oooool00ol0003o
ooooooooo`0Fooooo`03o`00oooooooooooo06Oooooo0_l00001ooooo`005Oooool00ol0003ooooo
ooooo`1Tooooo`05o`00ooooooooooooooooool00?l06Oooool00ol0003oooooooooo`21ooooo`7o
00000Oooool001Gooooo00?o0000ooooooooool0I?ooool01Ol00?oooooooooooooooooo003o01Wo
oooo00?o0000ooooooooool06_ooool00ol00?ooooooooooo`1Tooooo`7o00000Oooool001Gooooo
00?o0000ooooooooool0J?ooool00ol00?ooooooooooo`0Gooooo`03o`000?oooooooooo01Kooooo
00Go003oooooooooooooooooo`00o`1Vooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0
P_ooool00ol0003oooooooooo`0Fooooo`05o`00ooooooooooooooooool00?l0I_ooool1o`00007o
oooo000Eooooo`03o`000?oooooooooo06Cooooo00Go003oooooooooooooooooo`00o`0Iooooo`03
o`000?oooooooooo01Kooooo00Go003oooooooooooooooooo`00o`1Vooooo`7o00000Oooool001Go
oooo00?o0000ooooooooool0I?ooool01Ol00?oooooooooooooooooo003o01Wooooo00?o0000oooo
ooooool0POooool1o`00007ooooo000Eooooo`;o0000IOooool01Ol00?oooooooooooooooooo003o
01Wooooo00?o0000ooooooooool06_ooool00ol00?ooooooooooo`1Sooooo`;o00000Oooool001Go
oooo00?o0000ooooooooool0I?ooool01Ol00?oooooooooooooooooo003o01Wooooo00?o0000oooo
ooooool05_ooool01Ol00?oooooooooooooooooo003o06Kooooo0Ol00001ooooo`005Oooool00ol0
003oooooooooo`22ooooo`03o`000?oooooooooo01Kooooo00Go003oooooooooooooooooo`00o`1V
ooooo`7o00000Oooool000Oooooo0ol00004ooooo`;o00001Oooool00ol0003oooooooooo`1Toooo
o`03o`00oooooooooooo01_ooooo00?o0000ooooooooool05_ooool01Ol00?oooooooooooooooooo
003o06Kooooo0Ol00001ooooo`001_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`1Tooooo`05o`00ooooooooooooooooool00?l0
6Oooool00ol0003oooooooooo`0Fooooo`03o`00oooooooooooo06Sooooo0Ol00001ooooo`001_oo
ool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`1Tooooo`05o`00ooooooooooooooooool00?l06Oooool00ol0003oooooooooo`21oooo
o`7o00000Oooool000Oooooo0ol00003ooooo`04o`000?ooooooooooo`0000Cooooo0_l0001Uoooo
o`05o`00ooooooooooooooooool00?l06Oooool00ol0003oooooooooo`0Fooooo`05o`00oooooooo
ooooooooool00?l0IOooool2o`00007ooooo0006ooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0
5_ooool01Ol00?oooooooooooooooooo003o06Kooooo0Ol00001ooooo`001_ooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`22oooo
o`03o`000?oooooooooo01Kooooo00Go003oooooooooooooooooo`00o`1Vooooo`7o00000Oooool0
00Oooooo0ol00004ooooo`;o00001Oooool00ol0003oooooooooo`1Tooooo`05o`00oooooooooooo
ooooool00?l06Oooool00ol0003oooooooooo`0Fooooo`03o`00oooooooooooo06Sooooo0Ol00001
ooooo`005Oooool00ol0003oooooooooo`1Tooooo`05o`00ooooooooooooooooool00?l06Oooool0
0ol0003oooooooooo`21ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0I?ooool01Ol0
0?oooooooooooooooooo003o01Wooooo00?o0000ooooooooool06_ooool00ol00?ooooooooooo`1T
ooooo`7o00000Oooool001Gooooo0_l0001Yooooo`03o`00oooooooooooo01Oooooo00?o0000oooo
ooooool05_ooool01Ol00?oooooooooooooooooo003o06Gooooo0_l00001ooooo`005Oooool00ol0
003oooooooooo`22ooooo`03o`000?oooooooooo01Kooooo00Go003oooooooooooooooooo`00o`1V
ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0I?ooool01Ol00?oooooooooooooooooo
003o01Wooooo00?o0000ooooooooool05_ooool01Ol00?oooooooooooooooooo003o06Kooooo0Ol0
0001ooooo`005Oooool00ol0003oooooooooo`1Tooooo`05o`00ooooooooooooooooool00?l06Ooo
ool00ol0003oooooooooo`21ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0I?ooool0
1Ol00?oooooooooooooooooo003o01Wooooo00?o0000ooooooooool06_ooool00ol00?oooooooooo
o`1Tooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0I?ooool01Ol00?oooooooooooooo
oooo003o01Wooooo00?o0000ooooooooool05oooool01?l00?ooooooooooool00?mVooooo`7o0000
0Oooool001Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`0Gooooo`04o`00oooo
ooooooooo`00ofKooooo0Ol00001ooooo`005Oooool2o`0006Gooooo00Go003ooooooooooooooooo
o`00o`0Iooooo`03o`000?oooooooooo01Oooooo00Co003ooooooooooooo003oIOooool2o`00007o
oooo000Eooooo`03o`000?oooooooooo06Cooooo00Go003oooooooooooooooooo`00o`0Iooooo`03
o`000?oooooooooo01Oooooo00?o003oooooooooool0Ioooool1o`00007ooooo000Eooooo`03o`00
0?oooooooooo06Cooooo00Go003oooooooooooooooooo`00o`0Iooooo`03o`000?oooooooooo087o
oooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`1Tooooo`05o`00ooooooooooooooooool0
0?l06Oooool00ol0003oooooooooo`0Gooooo`04o`00ooooooooooooo`00ofKooooo0Ol00001oooo
o`005Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo01Oooooo00Co003ooooooooo
oooo003oI_ooool1o`00007ooooo000Eooooo`03o`000?oooooooooo06Cooooo00?o003ooooooooo
ool06oooool00ol0003oooooooooo`0Gooooo`04o`00ooooooooooooo`00ofKooooo0Ol00001oooo
o`005Oooool2o`0006Gooooo00Co003ooooooooooooo003o6_ooool00ol0003oooooooooo`0Goooo
o`03o`00oooooooooooo06Kooooo0_l00001ooooo`005Oooool00ol0003oooooooooo`1Tooooo`04
o`00ooooooooooooo`00oa[ooooo00?o0000ooooooooool0POooool1o`00007ooooo000Eooooo`03
o`000?oooooooooo06Cooooo00Co003ooooooooooooo003o6_ooool00ol0003oooooooooo`0Joooo
o`03o`00oooooooooooo06Cooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`22ooooo`03
o`000?oooooooooo01Oooooo00Co003ooooooooooooo003oI_ooool1o`00007ooooo00001?oooooo
0000o`000?l00004ooooo`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool0P_ooool00ol0
003oooooooooo`0Gooooo`04o`00ooooooooooooo`00ofKooooo0Ol00001ooooo`000_ooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?oo
ool00ol0003oooooooooo`1Tooooo`04o`00ooooooooooooo`00oa[ooooo00?o0000ooooooooool0
5oooool01?l00?ooooooooooool00?mVooooo`7o00000Oooool000;ooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooo
ooooool0I?ooool01?l00?ooooooooooool00?lJooooo`03o`000?oooooooooo087ooooo0Ol00001
ooooo`000_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00001?ooool2o`0006Kooooo00?o003oooooool00?l06_ooool00ol0003ooooooooo
o`0Jooooo`03o`00oooooooooooo06?ooooo0_l00001ooooo`000_ooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
ooooo`1Wooooo`03o`00oooooooooooo01Sooooo00?o0000ooooooooool05oooool01?l00?oooooo
ooooool00?mVooooo`7o00000Oooool00003ooooool0003o000000Cooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo08;ooooo00?o0000oooo
ooooool05oooool01?l00?ooooooooooool00?mVooooo`7o00000Oooool000;ooooo00?o0000oooo
ooooool00oooool2o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo06Gooooo00?o003ooooo
ool00?l06_ooool00ol0003oooooooooo`0Gooooo`04o`00ooooooooooooo`00ofKooooo0Ol00001
ooooo`005Oooool00ol0003oooooooooo`1Uooooo`03o`00oooooooo003o01[ooooo00?o0000oooo
ooooool05oooool00ol00?ooooooooooo`1Wooooo`7o00000Oooool001Gooooo00?o0000oooooooo
ool0IOooool00ol00?ooooooo`00o`0Jooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`00
5Oooool2o`0006Kooooo00?o003oooooool00?l06_ooool00ol0003oooooooooo`0Gooooo`04o`00
ooooooooooooo`00ofGooooo0_l00001ooooo`005Oooool00ol0003oooooooooo`22ooooo`03o`00
0?oooooooooo01Oooooo00Co003ooooooooooooo003oI_ooool1o`00007ooooo000Eooooo`03o`00
0?oooooooooo06Gooooo00?o003oooooooooool06_ooool00ol0003oooooooooo`0Gooooo`03o`00
oooooooo003o06Oooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`1Uooooo`03o`00oooo
oooo003o01[ooooo00?o0000ooooooooool05oooool00ol00?ooooooooooo`1Wooooo`7o00000Ooo
ool001Gooooo00?o0000ooooooooool0IOooool00ol00?ooooooo`00o`0Jooooo`03o`000?oooooo
oooo087ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`1Uooooo`03o`00oooooooo003o
01[ooooo00?o0000ooooooooool06Oooool00ol00?ooooooooooo`1Uooooo`7o00000Oooool001Go
oooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`0Gooooo`03o`00oooooooo003o06Oo
oooo0Ol00001ooooo`005Oooool2o`0008?ooooo00?o0000ooooooooool05oooool00ol00?oooooo
o`00o`1Vooooo`;o00000Oooool001Gooooo00?o0000ooooooooool0IOooool00ol00?ooooooo`00
o`0Jooooo`03o`000?oooooooooo01Oooooo00?o003oooooool00?l0Ioooool1o`00007ooooo000E
ooooo`03o`000?oooooooooo06Gooooo00?o003oooooool00?l06_ooool00ol0003oooooooooo`21
ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0IOooool00ol00?ooooooo`00o`0Joooo
o`03o`000?oooooooooo01Wooooo00?o003oooooooooool0IOooool1o`00007ooooo000Eooooo`03
o`000?oooooooooo06Oooooo00?o003oooooooooool06?ooool00ol0003oooooooooo`0Gooooo`03
o`00oooooooo003o06Oooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`22ooooo`03o`00
0?oooooooooo01Oooooo00?o003oooooool00?l0Ioooool1o`00007ooooo000Eooooo`;o0000I_oo
ool00ol00?ooooooo`00o`0Jooooo`03o`000?oooooooooo01Sooooo0_l00?mVooooo`;o00000Ooo
ool001Gooooo00?o0000ooooooooool0IOooool00ol00?ooooooo`00o`0Jooooo`03o`000?oooooo
oooo087ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`1Uooooo`;o003o6oooool00ol0
003oooooooooo`21ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0IOooool2o`00oa_o
oooo00?o0000ooooooooool06?ooool2o`00ofOooooo0Ol00001ooooo`0000Coooooo`000?l0003o
00000_ooool5o`0000?ooooo0_l00005ooooo`03o`000?oooooooooo08;ooooo00?o0000oooooooo
ool06?ooool2o`00ofOooooo0Ol00001ooooo`000_ooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1Uoooo
o`03o`00oooooooooooo01[ooooo00?o0000ooooooooool06?ooool2o`00ofOooooo0Ol00001oooo
o`000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00001?ooool2o`0006Kooooo0_l00?lKooooo`03o`000?oooooooooo01Sooooo00?o003ooooo
ooooool0IOooool2o`00007ooooo0002ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooo
ooooooooo`000002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0I_ooool00ol0
0?ooooooooooo`0Iooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo06Kooooo00?o003oooooooooool06Oooool00ol0003oooooooooo`0H
ooooo`;o003oIoooool1o`00007ooooo00000ooooooo0000o`000003ooooo`05o`000?oooooooooo
ooooool000000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo08;ooooo00?o
0000ooooooooool06?ooool2o`00ofOooooo0Ol00001ooooo`000_ooool00ol0003oooooooooo`02
ooooo`?o00001?ooool2o`0000Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21
ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21oooo
o`7o00000Oooool001Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool00oooool1o`00007ooooo000Eoooooooo0000
2ol00001ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-12.1861, -12.0044, \
0.0790804, 0.7772}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Magnitude plot of DFT as a function of frequency", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(fft\  = \ DFT[xda];\)\), "\n", 
    \(\(g3 = 
        DiscreteListPlot[\({#[\([1]\)], \ Abs[#[\([2]\)]]} &\)\  /@ \ fft, 
          Red, \ PlotRange \[Rule] All, \ Frame \[Rule] True, \ 
          Axes \[Rule] False];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0161421 0.0147151 0.00684776 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18523 -0.0125 -6 -9 ]
[.18523 -0.0125 6 0 ]
[.34665 -0.0125 -6 -9 ]
[.34665 -0.0125 6 0 ]
[.50807 -0.0125 -6 -9 ]
[.50807 -0.0125 6 0 ]
[.66949 -0.0125 -6 -9 ]
[.66949 -0.0125 6 0 ]
[.83091 -0.0125 -6 -9 ]
[.83091 -0.0125 6 0 ]
[.99233 -0.0125 -6 -9 ]
[.99233 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .15167 -12 -4.5 ]
[-0.0125 .15167 0 4.5 ]
[-0.0125 .28863 -12 -4.5 ]
[-0.0125 .28863 0 4.5 ]
[-0.0125 .42558 -12 -4.5 ]
[-0.0125 .42558 0 4.5 ]
[-0.0125 .56254 -12 -4.5 ]
[-0.0125 .56254 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18523 0 m
.18523 .00625 L
s
[(10)] .18523 -0.0125 0 1 Mshowa
.34665 0 m
.34665 .00625 L
s
[(20)] .34665 -0.0125 0 1 Mshowa
.50807 0 m
.50807 .00625 L
s
[(30)] .50807 -0.0125 0 1 Mshowa
.66949 0 m
.66949 .00625 L
s
[(40)] .66949 -0.0125 0 1 Mshowa
.83091 0 m
.83091 .00625 L
s
[(50)] .83091 -0.0125 0 1 Mshowa
.99233 0 m
.99233 .00625 L
s
[(60)] .99233 -0.0125 0 1 Mshowa
.125 Mabswid
.05609 0 m
.05609 .00375 L
s
.08838 0 m
.08838 .00375 L
s
.12066 0 m
.12066 .00375 L
s
.15295 0 m
.15295 .00375 L
s
.21751 0 m
.21751 .00375 L
s
.2498 0 m
.2498 .00375 L
s
.28208 0 m
.28208 .00375 L
s
.31437 0 m
.31437 .00375 L
s
.37893 0 m
.37893 .00375 L
s
.41122 0 m
.41122 .00375 L
s
.4435 0 m
.4435 .00375 L
s
.47579 0 m
.47579 .00375 L
s
.54036 0 m
.54036 .00375 L
s
.57264 0 m
.57264 .00375 L
s
.60492 0 m
.60492 .00375 L
s
.63721 0 m
.63721 .00375 L
s
.70178 0 m
.70178 .00375 L
s
.73406 0 m
.73406 .00375 L
s
.76634 0 m
.76634 .00375 L
s
.79863 0 m
.79863 .00375 L
s
.8632 0 m
.8632 .00375 L
s
.89548 0 m
.89548 .00375 L
s
.92776 0 m
.92776 .00375 L
s
.96005 0 m
.96005 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .15167 m
.00625 .15167 L
s
[(20)] -0.0125 .15167 1 0 Mshowa
0 .28863 m
.00625 .28863 L
s
[(40)] -0.0125 .28863 1 0 Mshowa
0 .42558 m
.00625 .42558 L
s
[(60)] -0.0125 .42558 1 0 Mshowa
0 .56254 m
.00625 .56254 L
s
[(80)] -0.0125 .56254 1 0 Mshowa
.125 Mabswid
0 .04895 m
.00375 .04895 L
s
0 .08319 m
.00375 .08319 L
s
0 .11743 m
.00375 .11743 L
s
0 .18591 m
.00375 .18591 L
s
0 .22015 m
.00375 .22015 L
s
0 .25439 m
.00375 .25439 L
s
0 .32286 m
.00375 .32286 L
s
0 .3571 m
.00375 .3571 L
s
0 .39134 m
.00375 .39134 L
s
0 .45982 m
.00375 .45982 L
s
0 .49406 m
.00375 .49406 L
s
0 .5283 m
.00375 .5283 L
s
0 .59677 m
.00375 .59677 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.18523 .61178 m
.18523 .61803 L
s
.34665 .61178 m
.34665 .61803 L
s
.50807 .61178 m
.50807 .61803 L
s
.66949 .61178 m
.66949 .61803 L
s
.83091 .61178 m
.83091 .61803 L
s
.99233 .61178 m
.99233 .61803 L
s
.125 Mabswid
.05609 .61428 m
.05609 .61803 L
s
.08838 .61428 m
.08838 .61803 L
s
.12066 .61428 m
.12066 .61803 L
s
.15295 .61428 m
.15295 .61803 L
s
.21751 .61428 m
.21751 .61803 L
s
.2498 .61428 m
.2498 .61803 L
s
.28208 .61428 m
.28208 .61803 L
s
.31437 .61428 m
.31437 .61803 L
s
.37893 .61428 m
.37893 .61803 L
s
.41122 .61428 m
.41122 .61803 L
s
.4435 .61428 m
.4435 .61803 L
s
.47579 .61428 m
.47579 .61803 L
s
.54036 .61428 m
.54036 .61803 L
s
.57264 .61428 m
.57264 .61803 L
s
.60492 .61428 m
.60492 .61803 L
s
.63721 .61428 m
.63721 .61803 L
s
.70178 .61428 m
.70178 .61803 L
s
.73406 .61428 m
.73406 .61803 L
s
.76634 .61428 m
.76634 .61803 L
s
.79863 .61428 m
.79863 .61803 L
s
.8632 .61428 m
.8632 .61803 L
s
.89548 .61428 m
.89548 .61803 L
s
.92776 .61428 m
.92776 .61803 L
s
.96005 .61428 m
.96005 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .15167 m
1 .15167 L
s
.99375 .28863 m
1 .28863 L
s
.99375 .42558 m
1 .42558 L
s
.99375 .56254 m
1 .56254 L
s
.125 Mabswid
.99625 .04895 m
1 .04895 L
s
.99625 .08319 m
1 .08319 L
s
.99625 .11743 m
1 .11743 L
s
.99625 .18591 m
1 .18591 L
s
.99625 .22015 m
1 .22015 L
s
.99625 .25439 m
1 .25439 L
s
.99625 .32286 m
1 .32286 L
s
.99625 .3571 m
1 .3571 L
s
.99625 .39134 m
1 .39134 L
s
.99625 .45982 m
1 .45982 L
s
.99625 .49406 m
1 .49406 L
s
.99625 .5283 m
1 .5283 L
s
.99625 .59677 m
1 .59677 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .01472 m
.02381 .46667 L
s
.03995 .01472 m
.03995 .06978 L
s
.05609 .01472 m
.05609 .11568 L
s
.07224 .01472 m
.07224 .30844 L
s
.08838 .01472 m
.08838 .21533 L
s
.10452 .01472 m
.10452 .08156 L
s
.12066 .01472 m
.12066 .45716 L
s
.1368 .01472 m
.1368 .60332 L
s
.15295 .01472 m
.15295 .24534 L
s
.16909 .01472 m
.16909 .16934 L
s
.18523 .01472 m
.18523 .1349 L
s
.20137 .01472 m
.20137 .11484 L
s
.21751 .01472 m
.21751 .10155 L
s
.23366 .01472 m
.23366 .09206 L
s
.2498 .01472 m
.2498 .08492 L
s
.26594 .01472 m
.26594 .07937 L
s
.28208 .01472 m
.28208 .07493 L
s
.29822 .01472 m
.29822 .07132 L
s
.31437 .01472 m
.31437 .06834 L
s
.33051 .01472 m
.33051 .06587 L
s
.34665 .01472 m
.34665 .0638 L
s
.36279 .01472 m
.36279 .06206 L
s
.37893 .01472 m
.37893 .0606 L
s
.39508 .01472 m
.39508 .05938 L
s
.41122 .01472 m
.41122 .05838 L
s
.42736 .01472 m
.42736 .05756 L
s
.4435 .01472 m
.4435 .05691 L
s
.45964 .01472 m
.45964 .05642 L
s
.47579 .01472 m
.47579 .05607 L
s
.49193 .01472 m
.49193 .05587 L
s
.50807 .01472 m
.50807 .0558 L
s
.52421 .01472 m
.52421 .05587 L
s
.54036 .01472 m
.54036 .05607 L
s
.5565 .01472 m
.5565 .05642 L
s
.57264 .01472 m
.57264 .05691 L
s
.58878 .01472 m
.58878 .05756 L
s
.60492 .01472 m
.60492 .05838 L
s
.62107 .01472 m
.62107 .05938 L
s
.63721 .01472 m
.63721 .0606 L
s
.65335 .01472 m
.65335 .06206 L
s
.66949 .01472 m
.66949 .0638 L
s
.68563 .01472 m
.68563 .06587 L
s
.70178 .01472 m
.70178 .06834 L
s
.71792 .01472 m
.71792 .07132 L
s
.73406 .01472 m
.73406 .07493 L
s
.7502 .01472 m
.7502 .07937 L
s
.76634 .01472 m
.76634 .08492 L
s
.78249 .01472 m
.78249 .09206 L
s
.79863 .01472 m
.79863 .10155 L
s
.81477 .01472 m
.81477 .11484 L
s
.83091 .01472 m
.83091 .1349 L
s
.84705 .01472 m
.84705 .16934 L
s
.8632 .01472 m
.8632 .24534 L
s
.87934 .01472 m
.87934 .60332 L
s
.89548 .01472 m
.89548 .45716 L
s
.91162 .01472 m
.91162 .08156 L
s
.92776 .01472 m
.92776 .21533 L
s
.94391 .01472 m
.94391 .30844 L
s
.96005 .01472 m
.96005 .11568 L
s
.97619 .01472 m
.97619 .06978 L
s
.015 w
.02381 .46667 Mdot
.03995 .06978 Mdot
.05609 .11568 Mdot
.07224 .30844 Mdot
.08838 .21533 Mdot
.10452 .08156 Mdot
.12066 .45716 Mdot
.1368 .60332 Mdot
.15295 .24534 Mdot
.16909 .16934 Mdot
.18523 .1349 Mdot
.20137 .11484 Mdot
.21751 .10155 Mdot
.23366 .09206 Mdot
.2498 .08492 Mdot
.26594 .07937 Mdot
.28208 .07493 Mdot
.29822 .07132 Mdot
.31437 .06834 Mdot
.33051 .06587 Mdot
.34665 .0638 Mdot
.36279 .06206 Mdot
.37893 .0606 Mdot
.39508 .05938 Mdot
.41122 .05838 Mdot
.42736 .05756 Mdot
.4435 .05691 Mdot
.45964 .05642 Mdot
.47579 .05607 Mdot
.49193 .05587 Mdot
.50807 .0558 Mdot
.52421 .05587 Mdot
.54036 .05607 Mdot
.5565 .05642 Mdot
.57264 .05691 Mdot
.58878 .05756 Mdot
.60492 .05838 Mdot
.62107 .05938 Mdot
.63721 .0606 Mdot
.65335 .06206 Mdot
.66949 .0638 Mdot
.68563 .06587 Mdot
.70178 .06834 Mdot
.71792 .07132 Mdot
.73406 .07493 Mdot
.7502 .07937 Mdot
.76634 .08492 Mdot
.78249 .09206 Mdot
.79863 .10155 Mdot
.81477 .11484 Mdot
.83091 .1349 Mdot
.84705 .16934 Mdot
.8632 .24534 Mdot
.87934 .60332 Mdot
.89548 .45716 Mdot
.91162 .08156 Mdot
.92776 .21533 Mdot
.94391 .30844 Mdot
.96005 .11568 Mdot
.97619 .06978 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`005Oooool2o`0002Gooooo0ol00004ooooo`;o00008Oooool5o`0000?ooooo0_l0000Roooo
o`?o00001?ooool2o`0002?ooooo0ol00003ooooo`;o00008_ooool3o`0000Cooooo0_l0000Roooo
o`?o00001?ooool2o`0000Cooooo000Dooooo`04o`000?ooooooooooo`0002Gooooo00?o0000oooo
ooooool00_ooool01?l0003oooooooooool0000Qooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00008?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooo
oooo00008oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool07_ooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00008?ooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00000oooool001Cooooo00Co0000oooooooo
oooo00009Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0002;ooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool0000Tooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooooooool07_ooool5o`0000;ooooo00Co0000oooooooooooo00009?ooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo01kooooo00Go0000ooooooooooooooooo`000002
ooooo`04o`000?ooooooooooo`0000?ooooo000Dooooo`04o`000?ooooooooooo`0002Gooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool0000Sooooo`05o`000?ooooooooooooooool0
00000_ooool00ol0003oooooooooo`0Pooooo`;o00000oooool01?l0003oooooooooool0000Poooo
o`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00009?ooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooooooo01kooooo1?l00003ooooo`04o`000?ooooooooooo`0000?o
oooo000Dooooo`04o`000?ooooooooooo`0002Gooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool0000Pooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0
000Tooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool07oooool00ol0003ooooo
o`000003ooooo`04o`000?ooooooooooo`00023ooooo1?l00003ooooo`04o`000?ooooooooooo`00
023ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00003ooooo`005?ooool01?l0
003oooooooooool0000Tooooo`;o00001?ooool01?l0003oooooooooool0000Pooooo`05o`000?oo
ooooooooooooool000000_ooool01?l0003oooooooooool0000Pooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool0000Rooooo`;o00000oooool01?l0003oooooooooool0
000Pooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00008Oooool00ol0003ooooo
ooooo`03ooooo`04o`000?ooooooooooo`0000?ooooo000Eooooo`;o00009_ooool00ol0003ooooo
ooooo`03ooooo`;o00008_ooool3o`0000Cooooo0_l0000Rooooo`?o00001?ooool2o`0002Cooooo
00?o0000ooooooooool00_ooool2o`00027ooooo1Ol00003ooooo`;o00008oooool2o`0000Cooooo
0_l00004ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00
4?ooooooo`0000co00001Oooool000Sooooo0_l00006ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooool000001Oooool000Oooooo00Co0000oooooooooooo00001Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooo000000Gooooo0007ooooo`04o`000?ooooooooooo`0000Gooooo00?o
0000ooooooooool0ooooool8ooooo`03o`000?oooooooooo00?ooooo0007ooooo`04o`000?oooooo
ooooo`0000Gooooo0_l00004ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003ooooo
ooooo`02ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ooooo`05
ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooo
oooooooo00000oooool01Ooo003oooooooooooooooooo`0000Cooooo00Goo`00oooooooooooooooo
ool00003ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003ooooo`03
ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooo
oooooooo00001?ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_oo
ool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_ooool01Ooo003ooooo
ooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00004ooooo`05ool00?oooooooooo
oooooooo00000oooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00000ooo
ool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooo
ooooooooooooo`0000Cooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo
00;ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00Goo`00
ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00001?ooool01Ooo003ooooo
ooooooooooooo`0000?ooooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`00
00?ooooo00?oo`00ooooooooool00_ooool01?oo003oooooooooooooool3o`0000Gooooo0007oooo
o`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00oooool01Ooo003ooooooooooooo
ooooo`0000?ooooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000?ooooo
00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00oooooooo
ool00_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00004
ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ooooo`05ool00?oo
oooooooooooooooo00000oooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo
00000oooool01Ooo003oooooooooooooooooo`0000Cooooo00Goo`00ooooooooooooooooool00003
ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oo
oooooooo00;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo
00001?ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_ooool01Ooo
003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_ooool01Ooo003ooooooooooooo
ooooo`0000?ooooo00Goo`00ooooooooooooooooool00004ooooo`05ool00?oooooooooooooooooo
00000oooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00000oooool00ooo
003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooooooo
ooooo`0000Cooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo
00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`001oooool01?l0003oooooooooool00005ooooo`03
o`000?oooooooooo00?ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo
00;ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00Goo`00
ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00Goo`00oooooooooooooooo
ool00003ooooo`05ool00?oooooooooooooooooo00001?ooool01Ooo003oooooooooooooooooo`00
00?ooooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00
ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooooooooooo
ool00004ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ooooo`05
ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooo
oooooooo00000oooool01Ooo003oooooooooooooooooo`0000Cooooo00Goo`00oooooooooooooooo
ool00003ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003ooooo`03
ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooo
oooooooo00001?ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_oo
ool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_ooool01Ooo003ooooo
ooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00004ooooo`05ool00?oooooooooo
oooooooo00000oooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00000ooo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool000Sooooo0_l00006ooooo`03o`000?oooooooooo00?ooooo00Goo`00ooooooooooooooooool0
0003ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool0
0?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;o
oooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00001?ooool0
1Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_ooool01Ooo003ooooooooo
ooooooooo`0000?ooooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000?o
oooo00Goo`00ooooooooooooooooool00004ooooo`05ool00?oooooooooooooooooo00000oooool0
0ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003ooooooooo
o`02ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000Co
oooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00Goo`00oooo
ooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool0
0003ooooo`05ool00?oooooooooooooooooo00001?ooool01Ooo003oooooooooooooooooo`0000?o
oooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00oooo
ooooool00_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool0
0004ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ooooo`05ool0
0?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00?o
oooo00?o0000ooooooooool00oooool0013ooooo00?o0000ooooooooool00oooool01Ooo003ooooo
ooooooooooooo`0000?ooooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`00
00?ooooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00
ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooooooooooo
ool00004ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ooooo`05
ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooo
oooooooo00000oooool01Ooo003oooooooooooooooooo`0000Cooooo00Goo`00oooooooooooooooo
ool00003ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003ooooo`03
ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooo
oooooooo00001?ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_oo
ool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_ooool01Ooo003ooooo
ooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00004ooooo`05ool00?oooooooooo
oooooooo00000oooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00000ooo
ool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooo
ooooooooooooo`0000Cooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo
00;ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00oooool00ol0003oooooooooo`03ooooo`004?ooool00ol0003oooooooooo`03oooo
o`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ooooo`05ool00?oooooo
oooooooooooo00000oooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo0000
0oooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003o
ooooooooooooooooo`0000Cooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooo
oooo00;ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00Go
o`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00001?ooool01Ooo003o
ooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_ooool01Ooo003ooooooooooooooooo
o`0000?ooooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Go
o`00ooooooooooooooooool00004ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003o
ooooooooo`02ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02oooo
o`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000Cooooo00Go
o`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00Goo`00oooooooooooo
ooooool00003ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003oooo
o`05ool00?oooooooooooooooooo00001?ooool01Ooo003oooooooooooooooooo`0000?ooooo00?o
o`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo000@ooooo`03o`000?oo
oooooooo00?ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo
00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00Goo`00oooooooo
ooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003
ooooo`05ool00?oooooooooooooooooo00001?ooool01Ooo003oooooooooooooooooo`0000?ooooo
00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00oooooooo
ool00_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00004
ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ooooo`05ool00?oo
oooooooooooooooo00000oooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo
00000oooool01Ooo003oooooooooooooooooo`0000Cooooo00Goo`00ooooooooooooooooool00003
ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oo
oooooooo00;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo
00001?ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_ooool01Ooo
003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_ooool01Ooo003ooooooooooooo
ooooo`0000?ooooo00Goo`00ooooooooooooooooool00004ooooo`05ool00?oooooooooooooooooo
00000oooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00000oooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00?ooooo00?o0000ooooooooool00oooool0013o
oooo00?o0000ooooooooool00oooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00oooo
ooooool00_ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_ooool0
1Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_ooool01Ooo003ooooooooo
ooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00004ooooo`05ool00?oooooooooooooo
oooo00000oooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00000oooool0
0ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooo
ooooooooo`0000Cooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;o
oooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00Goo`00oooo
ooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00001?ooool01Ooo003ooooooooo
ooooooooo`0000?ooooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000?o
oooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooo
ooooooooooooool00004ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003ooooooooo
o`02ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ooooo`05ool0
0?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000Cooooo00Goo`00oooo
ooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool0
0003ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`004?ooool00ol0003oooooooooo`03ooooo`05ool00?oooooooooooooooooo00000ooo
ool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003ooooo
ooooo`02ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ooooo`05
ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000Cooooo00Goo`00
ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00Goo`00oooooooooooooooo
ool00003ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003ooooo`05
ool00?oooooooooooooooooo00001?ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00
ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_oo
ool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00004ooooo`05
ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooo
oooooooo00000oooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00000ooo
ool01Ooo003oooooooooooooooooo`0000Cooooo00Goo`00ooooooooooooooooool00003ooooo`03
ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo
00;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00001?oo
ool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_ooool01Ooo003ooooo
ooooooooooooo`0000?ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo000@ooooo`;o00001?ooool01Ooo003oooooooooooooooooo`0000?o
oooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00oooo
ooooool00_ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_ooool0
1Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00004ooooo`05ool0
0?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooo
oooo00000oooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00000oooool0
1Ooo003oooooooooooooooooo`0000Cooooo00Goo`00ooooooooooooooooool00003ooooo`03ool0
0?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;o
oooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00001?ooool0
1Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_ooool01Ooo003ooooooooo
ooooooooo`0000?ooooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000?o
oooo00Goo`00ooooooooooooooooool00004ooooo`05ool00?oooooooooooooooooo00000oooool0
0ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003ooooooooo
o`02ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000Co
oooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00Goo`00oooo
ooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool2
o`0000Gooooo000@ooooo`03o`000?oooooooooo00?ooooo00Goo`00ooooooooooooooooool00003
ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oo
oooooooo00;ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo
00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00001?ooool01Ooo
003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_ooool01Ooo003ooooooooooooo
ooooo`0000?ooooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000?ooooo
00Goo`00ooooooooooooooooool00004ooooo`05ool00?oooooooooooooooooo00000oooool00ooo
003oooooooooo`03ool000;ooooo0ooo00001Oooooooo`00ool00?oo003ooooo00?oo`0000Cooooo
ool00?oo003oo`000_ooool3ool00005oooooooo003oo`00ool00?ooool00ooo0002ooooo`?oo`00
0_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003o
ooooooooo`02ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooooooooooo
o`0000Cooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00Go
o`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00Goo`00oooooooooooo
ooooool00003ooooo`05ool00?oooooooooooooooooo00001?ooool01Ooo003ooooooooooooooooo
o`0000?ooooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000?ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo000@
ooooo`03o`000?oooooooooo00?ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oo
oooooooo00;ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo
00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00Goo`00oooooooo
ooooooooool00003ooooo`05ool00?oooooooooooooooooo00001?ooool01Ooo003ooooooooooooo
ooooo`0000?ooooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000?ooooo
00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00oooooooo
ool00ooo00001?ooooooo`00ool00?oo0002ooooo`?oo`0000Goooooool00?oo003oo`00ooooo`03
ool000;ooooo0ooo00001Oooooooo`00ool00?oo003ooooo00?oo`0000Coooooool00?oo003oo`00
0_ooool3ool00005oooooooo003oo`00ool00?ooool00ooo0002ooooo`?oo`0000Goooooool00?oo
003oo`00ooooo`03ool00004oooooooo003oo`00ool000;ooooo0ooo0003ooooo`05ool00?oooooo
oooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000Cooooo00Goo`00oooooooooooo
ooooool00003ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003oooo
o`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooo
oooooooooooo00001?ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool0
0_ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo000@ooooo`03o`000?oooooooooo00?ooooo
00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00Goo`00oooooooo
ooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003
ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oo
oooooooooooooooo00001?ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00oooooooo
ool00_ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooool00002ool000;ooooo0ooo00001Oooooooo`00ool00?oo003ooooo00?oo`000_ooool3
ool00005oooooooo003oo`00ool00?ooool00ooo0002ooooo`?oo`0000Goooooool00?oo003oo`00
ooooo`03ool00004oooooooo003oo`00ool000;ooooo0ooo00001Oooooooo`00ool00?oo003ooooo
00?oo`000_ooool3ool00005oooooooo003oo`00ool00?ooool00ooo00001?ooooooo`00ool00?oo
0002ooooo`?oo`0000Goooooool00?oo003oo`00ooooo`03ool000?ooooo00Goo`00oooooooooooo
ooooool00004ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02oooo
o`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ooooo`05ool00?oooooo
oooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000Cooooo00Goo`00oooooooooooo
ooooool00003ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00oooool00ol0003oooooooooo`03oooo
o`004?ooool00ol0003oooooooooo`03ooooo`05ool00?oooooooooooooooooo00000oooool00ooo
003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02
ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ooooo`05ool00?oo
oooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000Cooooo00Goo`00oooooooo
ooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003
ooooo`03ool00?oooooooooo00?oo`0000Coooooool00?oo003oo`000_ooool3ool00005oooooooo
003oo`00ool00?ooool00ooo0002ooooo`?oo`0000Coooooool00?oo003oo`00:?ooool3ool00005
oooooooo003oo`00ool00?ooool00ooo0002ooooo`?oo`0000Goooooool00?oo003oo`00ooooo`03
ool000;ooooo0ooo0002ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool0
0003ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool0
0?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooo
oooo00001?ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_ooool0
1Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo000@ooooo`03o`000?oooooooooo00?ooooo00?oo`00
ooooooooool00ooo0002ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool0
0003ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool0
0?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooo
oooo00001?ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`03ool00005oooooooo003oo`00ool00?ooool00ooo00001?ooooooo`00ool0
0?oo0002ooooo`?oo`00B_ooool3ool00004oooooooo003oo`00ool000;ooooo0ooo00001Ooooooo
o`00ool00?oo003ooooo00?oo`000oooool01Ooo003oooooooooooooooooo`0000Cooooo00Goo`00
ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00Goo`00oooooooooooooooo
ool00003ooooo`05ool00?oooooooooooooooooo00001?ooool01Ooo003oooooooooooooooooo`00
00?ooooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00
ooooooooool00ooo0005ooooo`03o`000?oooooooooo00?ooooo000@ooooo`03o`000?oooooooooo
00?ooooo00?oo`00ooooooooool00ooo0002ooooo`03ool00?oooooooooo00;ooooo00Goo`00oooo
ooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool0
0003ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool0
0?oooooooooooooooooo00001?ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00oooo
ooooool00ooo0002ooooo`?oo`0000Goooooool00?oo003oo`00ooooo`03ool005cooooo0ooo0000
1Oooooooo`00ool00?oo003ooooo00?oo`000_ooool3ool000;ooooo00?oo`00ooooooooool00_oo
ool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_ooool01Ooo003ooooo
ooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00004ooooo`05ool00?oooooooooo
oooooooo00000oooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00000ooo
ool00ooo003oooooooooo`03ool000Gooooo00?o0000ooooooooool00oooool0013ooooo00?o0000
ooooooooool00oooool00ooo003oooooooooo`03ool000;ooooo00?oo`00ooooooooool00_ooool0
1Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_ooool01Ooo003ooooooooo
ooooooooo`0000?ooooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000?o
oooo00Goo`00ooooooooooooooooool00004ooooo`05ool00?oooooooooooooooooo00000_ooool3
ool00004oooooooo003oo`00ool000;ooooo0ooo00001?ooooooo`00ool00?oo001Tooooo`?oo`00
00Coooooool00?oo003oo`000_ooool3ool00004oooooooo003oo`00ool000?ooooo00Goo`00oooo
ooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool0
0003ooooo`05ool00?oooooooooooooooooo00001?ooool01Ooo003oooooooooooooooooo`0000?o
oooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00oooo
ooooool00ooo0005ooooo`03o`000?oooooooooo00?ooooo000@ooooo`03o`000?oooooooooo00?o
oooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooo
oooo00000_ooool3ool000?ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooo
oooo00;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo0000
1?ooool01Ooo003oooooooooooooooooo`0000;ooooo0ooo00001?ooooooo`00ool00?oo001foooo
o`?oo`0000Coooooool00?oo003oo`000oooool01Ooo003oooooooooooooooooo`0000?ooooo00?o
o`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooooooo
ooooool00004ooooo`05ool00?oooooooooooooooooo00000_ooool3ool000?ooooo00Goo`00oooo
ooooooooooooool00003ooooo`03ool00?oooooooooo00Sooooo00?o0000ooooooooool00oooool0
013ooooo0_l00004ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool00_ooool01Ooo
003oooooooooooooooooo`0000;ooooo0ooo0003ooooo`05ool00?oooooooooooooooooo00000ooo
ool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooo
ooooooooooooo`0000Cooooo00?oo`00ooooooooool00ooo00001?ooooooo`00ool00?oo001noooo
o`?oo`0000Coooooool00?oo003oo`000oooool01Ooo003oooooooooooooooooo`0000Cooooo00Go
o`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00001?ooool01Ooo003o
ooooooooooooooooo`0000;ooooo0ooo0003ooooo`05ool00?oooooooooooooooooo00000oooool0
0ooo003oooooooooo`07ooooo`;o00001Oooool0013ooooo00?o0000ooooooooool00oooool00ooo
003oooooooooo`05ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00002
ooooo`?oo`000oooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_oo
ool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00004ooooo`03
ool00?oooooooooo00?oo`00Q_ooool3ool000?ooooo00Goo`00ooooooooooooooooool00004oooo
o`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000Cooooo00Go
o`00ooooooooooooooooool00002ooooo`?oo`000oooool01Ooo003oooooooooooooooooo`0000?o
oooo00?oo`00ooooooooool02?ooool00ol0003oooooooooo`03ooooo`004?ooool00ol0003ooooo
ooooo`03ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool00_ooool01Ooo003ooooo
ooooooooooooo`0000Sooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo
00;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000_oo
ool3ool000;ooooo0ooo0026ooooo`?oo`0000Coooooool00?oo003oo`000oooool00ooo003ooooo
ooooo`02ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`00
00Cooooo00Goo`00ooooooooooooooooool00008ooooo`05ool00?oooooooooooooooooo00000ooo
ool00ooo003oooooooooo`08ooooo`03o`000?oooooooooo00?ooooo000@ooooo`03o`000?oooooo
oooo00?ooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`02ooooo`05ool00?oooooo
oooooooooooo00002?ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool0
0_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00002oooo
o`?oo`00Soooool3ool000?ooooo00?oo`00ooooooooool00_ooool01Ooo003ooooooooooooooooo
o`0000?ooooo00Goo`00ooooooooooooooooool00004ooooo`05ool00?oooooooooooooooooo0000
2?ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool02?ooool00ol0003o
ooooooooo`03ooooo`004?ooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo00Gooooo
00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000Sooooo00Goo`00oooooooo
ooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003
ooooo`03ool00?oooooooooo00?oo`0000Coooooool00?oo003oo`00Soooool3ool000;ooooo0ooo
0003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000Co
oooo00Goo`00ooooooooooooooooool00008ooooo`05ool00?oooooooooooooooooo00000oooool0
0ooo003oooooooooo`08ooooo`03o`000?oooooooooo00?ooooo000@ooooo`03o`000?oooooooooo
00?ooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooo
oooooooo00002?ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_oo
ool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00ooo002Hooooo`?oo`00
0oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00004oooo
o`05ool00?oooooooooooooooooo00002?ooool01Ooo003oooooooooooooooooo`0000?ooooo00?o
o`00ooooooooool02?ooool00ol0003oooooooooo`03ooooo`004?ooool00ol0003oooooooooo`03
ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool00_ooool01Ooo003ooooooooooooo
ooooo`0000Sooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo
00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00?oo`00V?ooool3ool000?o
oooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00001?ooool0
1Ooo003oooooooooooooooooo`0000Sooooo00Goo`00ooooooooooooooooool00003ooooo`03ool0
0?oooooooooo00Sooooo00?o0000ooooooooool00oooool0013ooooo00?o0000ooooooooool00ooo
ool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00;ooooo00Goo`00oooooooooooooooo
ool00008ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ooooo`05
ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`2Qooooo`05ool00?oooooooooo
oooooooo00000oooool01Ooo003oooooooooooooooooo`0000Cooooo00Goo`00oooooooooooooooo
ool00008ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`08ooooo`03
o`000?oooooooooo00?ooooo000@ooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool0
1?ooool3ool000?ooooo00Goo`00ooooooooooooooooool00008ooooo`05ool00?oooooooooooooo
oooo00000oooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00000_ooool3
ool00:3ooooo0ooo0003ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003ooooooooo
o`02ooooo`05ool00?oooooooooooooooooo00002?ooool01Ooo003oooooooooooooooooo`0000;o
oooo0ooo0009ooooo`03o`000?oooooooooo00?ooooo000@ooooo`;o00001?ooool00ooo003ooooo
ooooo`04ooooo`?oo`000oooool01Ooo003oooooooooooooooooo`0000Sooooo00Goo`00oooooooo
ooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00002
ooooo`?oo`00X?ooool3ool000?ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oo
oooooooo00;ooooo00Goo`00ooooooooooooooooool00008ooooo`05ool00?oooooooooooooooooo
00000_ooool3ool000Sooooo0_l00005ooooo`004?ooool00ol0003oooooooooo`03ooooo`03ool0
0?oooooooooo00Cooooo0ooo0003ooooo`05ool00?oooooooooooooooooo00002?ooool01Ooo003o
ooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_ooool01Ooo003ooooooooooooooooo
o`0000;ooooo0ooo002Pooooo`?oo`000oooool01Ooo003oooooooooooooooooo`0000?ooooo00?o
o`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000Sooooo00Goo`00oooooooooooo
ooooool00002ooooo`?oo`002Oooool00ol0003oooooooooo`03ooooo`004?ooool00ol0003ooooo
ooooo`03ooooo`03ool00?oooooooooo00[ooooo00Goo`00ooooooooooooooooool00008ooooo`05
ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooo
oooooooo0000Zoooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_oo
ool01Ooo003oooooooooooooooooo`0000Sooooo00Goo`00ooooooooooooooooool0000>ooooo`03
o`000?oooooooooo00?ooooo000@ooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool0
2_ooool01Ooo003oooooooooooooooooo`0000Sooooo00Goo`00ooooooooooooooooool00003oooo
o`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool0002[ooooo`05ool00?oooooo
oooooooooooo00000oooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo0000
2?ooool01Ooo003oooooooooooooooooo`0000kooooo00?o0000ooooooooool00oooool0013ooooo
00?o0000ooooooooool00oooool00ooo003oooooooooo`0:ooooo`05ool00?oooooooooooooooooo
00002?ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooool00002ool00:Wooooo0ooo0003ooooo`05ool00?oooooooooooooooooo00001?ooool0
1Ooo003oooooooooooooooooo`0000Sooooo00Goo`00ooooooooooooooooool0000>ooooo`03o`00
0?oooooooooo00?ooooo000@ooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool02_oo
ool01Ooo003oooooooooooooooooo`0000Sooooo00Goo`00ooooooooooooooooool00003ooooo`03
ool00?oooooooooo00;ooooo00?oo`00oooooooo00000_oo002Yooooo`?oo`000oooool01Ooo003o
ooooooooooooooooo`0000Cooooo00Goo`00ooooooooooooooooool00008ooooo`05ool00?oooooo
oooooooooooo00003_ooool00ol0003oooooooooo`03ooooo`004?ooool00ol0003oooooooooo`03
ooooo`03ool00?oooooooooo00[ooooo00Goo`00ooooooooooooooooool00008ooooo`05ool00?oo
oooooooooooooooo00000oooool00ooo003oooooooooo`02ooooo`03ool00?ooooooo`0000;oo`00
ZOooool3ool000?ooooo00Goo`00ooooooooooooooooool00004ooooo`05ool00?oooooooooooooo
oooo00002?ooool01Ooo003oooooooooooooooooo`0000kooooo00?o0000ooooooooool00oooool0
00Go00000oooool2o`0000Kooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`0:oooo
o`05ool00?oooooooooooooooooo00002?ooool01Ooo003oooooooooooooooooo`0000?ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`2aooooo`05ool00?oooooooooooooooooo0000
1?ooool01Ooo003oooooooooooooooooo`0000Sooooo00Goo`00ooooooooooooooooool0000>oooo
o`03o`000?oooooooooo00?ooooo00001Ooooooo0000oooooooooooo000000;ooooo00Co0000oooo
oooooooo00001Oooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo00[ooooo00Goo`00
ooooooooooooooooool00008ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo0;7ooooo00Goo`00ooooooooooooooooool00004ooooo`05
ool00?oooooooooooooooooo00002?ooool01Ooo003oooooooooooooooooo`0000kooooo00?o0000
ooooooooool00oooool000;ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00005
ooooo`;o00001?ooool00ooo003oooooooooo`0:ooooo`05ool00?oooooooooooooooooo00002?oo
ool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`2aooooo`05ool00?oooooooooooooooooo00001?ooool01Ooo003oooooooooooooooooo`00
00Sooooo00Goo`00ooooooooooooooooool0000<ooooo`?o00001Oooool000?ooooo00Go0000oooo
ooooooooooooo`000002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ooo003oooooooooo`0:ooooo`05ool00?oooooooooooooooooo00002?ooool01Ooo003ooooooooo
ooooooooo`0000?ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`2aooooo`05ool0
0?oooooooooooooooooo00001?ooool01Ooo003oooooooooooooooooo`0000Sooooo00Goo`00oooo
ooooooooooooool0000>ooooo`03o`000?oooooooooo00?ooooo00001Ol0003ooooooooooooooooo
000000;ooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`03ooooo`03ool00?oo
oooooooo00[ooooo00Goo`00ooooooooooooooooool00008ooooo`05ool00?oooooooooooooooooo
00000oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo0;7ooooo00Goo`00oooooooo
ooooooooool00004ooooo`05ool00?oooooooooooooooooo00002?ooool01Ooo003ooooooooooooo
ooooo`0000kooooo00?o0000ooooooooool00oooool00005o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool0
2_ooool01Ooo003oooooooooooooooooo`0000Sooooo00Goo`00ooooooooooooooooool00003oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0/Oooool01Ooo003ooooooooooooooooo
o`0000Cooooo00Goo`00ooooooooooooooooool00008ooooo`05ool00?oooooooooooooooooo0000
3_ooool00ol0003oooooooooo`03ooooo`0000Coooooo`000?l0003o00001?ooool2o`0000Kooooo
00?o0000ooooooooool00oooool00ooo003oooooooooo`0:ooooo`05ool00?oooooooooooooooooo
00002?ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00ooo002boooo
o`?oo`000_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00002?ooool0
1Ooo003oooooooooooooooooo`0000kooooo00?o0000ooooooooool00oooool0013ooooo00?o0000
ooooooooool00oooool00ooo003oooooooooo`0:ooooo`05ool00?oooooooooooooooooo00002?oo
ool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00ooo002booooo`?oo`00
0_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00002?ooool01Ooo003o
ooooooooooooooooo`0000kooooo00?o0000ooooooooool00oooool0013ooooo00?o0000oooooooo
ool00oooool00ooo003oooooooooo`0:ooooo`05ool00?oooooooooooooooooo00002?ooool01Ooo
003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00ooo002booooo`?oo`000_ooool0
0ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00002?ooool01Ooo003ooooooooo
ooooooooo`0000kooooo00?o0000ooooooooool00oooool0013ooooo00?o0000ooooooooool00ooo
ool00ooo003oooooooooo`0:ooooo`05ool00?oooooooooooooooooo00002?ooool01Ooo003ooooo
ooooooooooooo`0000?ooooo00?oo`00ooooooooool0^_ooool00ooo003oooooooooo`02ooooo`05
ool00?oooooooooooooooooo00002?ooool01Ooo003oooooooooooooooooo`0000kooooo00?o0000
ooooooooool00oooool0013ooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`0:oooo
o`05ool00?oooooooooooooooooo00002?ooool01Ooo003oooooooooooooooooo`0000?ooooo00?o
o`00ooooooooool0^_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo0000
2?ooool01Ooo003oooooooooooooooooo`0000kooooo00?o0000ooooooooool00oooool0013ooooo
0_l00004ooooo`03ool00?oooooooooo00[ooooo00Goo`00ooooooooooooooooool00008ooooo`05
ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`2jooooo`03ool00?oooooooooo
00;ooooo00Goo`00ooooooooooooooooool00008ooooo`05ool00?oooooooooooooooooo00003Ooo
ool2o`0000Gooooo000@ooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool02_ooool0
1Ooo003oooooooooooooooooo`0000Sooooo00Goo`00ooooooooooooooooool00003ooooo`03ool0
0?oooooooooo0;[ooooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000So
oooo00Goo`00ooooooooooooooooool0000>ooooo`03o`000?oooooooooo00?ooooo000@ooooo`03
o`000?oooooooooo00?ooooo00?oo`00ooooooooool02_ooool01Ooo003oooooooooooooooooo`00
00Sooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo0;[ooooo00?oo`00
ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000Sooooo00Goo`00oooooooooooooooo
ool0000>ooooo`03o`000?oooooooooo00?ooooo000@ooooo`03o`000?oooooooooo00?ooooo00?o
o`00ooooooooool02_ooool01Ooo003oooooooooooooooooo`0000Sooooo00Goo`00oooooooooooo
ooooool00003ooooo`03ool00?oooooooooo0;[ooooo00?oo`00ooooooooool00_ooool01Ooo003o
ooooooooooooooooo`0000Sooooo00Goo`00ooooooooooooooooool0000>ooooo`03o`000?oooooo
oooo00?ooooo000@ooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool02_ooool01Ooo
003oooooooooooooooooo`0000Sooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oo
oooooooo0;[ooooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000Sooooo
00Goo`00ooooooooooooooooool0000>ooooo`03o`000?oooooooooo00?ooooo000@ooooo`03o`00
0?oooooooooo00?ooooo00?oo`00ooooooooool02_ooool01Ooo003oooooooooooooooooo`0000So
oooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo0;[ooooo00?oo`00oooo
ooooool00_ooool01Ooo003oooooooooooooooooo`0000Sooooo00Goo`00ooooooooooooooooool0
000>ooooo`03o`000?oooooooooo00?ooooo000@ooooo`03o`000?oooooooooo00?ooooo00?oo`00
ooooooooool02_ooool01Ooo003oooooooooooooooooo`0000Sooooo00Goo`00oooooooooooooooo
ool00003ooooo`03ool00?oooooooooo0;[ooooo00?oo`00ooooooooool00_ooool01Ooo003ooooo
ooooooooooooo`0000Sooooo00Goo`00ooooooooooooooooool0000>ooooo`03o`000?oooooooooo
00?ooooo000@ooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool02_ooool01Ooo003o
ooooooooooooooooo`0000Sooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooo
oooo0;[ooooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000Sooooo00Go
o`00ooooooooooooooooool0000>ooooo`03o`000?oooooooooo00?ooooo000@ooooo`03o`000?oo
oooooooo00?ooooo00?oo`00ooooooooool02_ooool00ooo003oooooooooo`03ool000Oooooo00Go
o`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo0;[ooooo00?oo`00ooooooooool0
0_ooool01Ooo003oooooooooooooooooo`0000Kooooo0ooo0003ooooo`03ool00?oooooooooo00co
oooo00?o0000ooooooooool00oooool0013ooooo00?o0000ooooooooool00oooool00ooo003ooooo
ooooo`0:ooooo`03ool00?oooooooooo00?oo`001oooool01Ooo003oooooooooooooooooo`0000?o
oooo00?oo`00ooooooooool0^_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooo
oooo00001_ooool3ool000?ooooo00?oo`00ooooooooool03?ooool00ol0003oooooooooo`03oooo
o`004?ooool2o`0000Cooooo00?oo`00ooooooooool02_ooool00ooo003oooooooooo`03ool000Oo
oooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo0;[ooooo00?oo`00oooo
ooooool00_ooool01Ooo003oooooooooooooooooo`0000Kooooo0ooo0003ooooo`03ool00?oooooo
oooo00_ooooo0_l00005ooooo`004?ooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo
00[ooooo00?oo`00ooooooooool02_ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00
ooooooooool0^_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00003?oo
ool00ooo003oooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo000@ooooo`03o`000?oooooo
oooo00?ooooo00?oo`00ooooooooool02_ooool00ooo003oooooooooo`0:ooooo`05ool00?oooooo
oooooooooooo00000oooool00ooo003oooooooooo`2jooooo`03ool00?oooooooooo00;ooooo00Go
o`00ooooooooooooooooool0000<ooooo`03ool00?oooooooooo00cooooo00?o0000ooooooooool0
0oooool0013ooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`0:ooooo`03ool00?oo
oooooooo00[ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo0;[ooooo
00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000cooooo00?oo`00oooooooo
ool03?ooool00ol0003oooooooooo`03ooooo`004?ooool00ol0003oooooooooo`03ooooo`03ool0
0?oooooooooo00[ooooo00?oo`00ooooooooool02_ooool01Ooo003oooooooooooooooooo`0000?o
oooo00?oo`00ooooooooool0^_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooo
oooo00003?ooool00ooo003oooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo000@ooooo`03
o`000?oooooooooo00?ooooo00?oo`00ooooooooool02_ooool00ooo003oooooooooo`0:ooooo`05
ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`2jooooo`03ool00?oooooooooo
00;ooooo00Goo`00ooooooooooooooooool0000<ooooo`03ool00?oooooooooo00cooooo00?o0000
ooooooooool00oooool0013ooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`0:oooo
o`03ool00?oooooooooo00[ooooo00Goo`00ooooooooooooooooool00002ooooo`?oo`00^_ooool3
ool000?ooooo00Goo`00ooooooooooooooooool0000<ooooo`03ool00?oooooooooo00cooooo00?o
0000ooooooooool00oooool0013ooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`0:
ooooo`03ool00?oooooooooo00[ooooo00Goo`00ooooooooooooooooool00002ooooo`?oo`00^_oo
ool3ool000?ooooo00Goo`00ooooooooooooooooool0000<ooooo`03ool00?oooooooooo00cooooo
00?o0000ooooooooool00oooool0013ooooo00?o0000ooooooooool00oooool00ooo003ooooooooo
o`0:ooooo`03ool00?oooooooooo00[ooooo00Goo`00ooooooooooooooooool00002ooooo`?oo`00
^_ooool3ool000?ooooo00Goo`00ooooooooooooooooool0000<ooooo`03ool00?oooooooooo00co
oooo00?o0000ooooooooool00oooool0013ooooo0_l00004ooooo`03ool00?oooooooooo00[ooooo
00?oo`00ooooooooool02_ooool01Ooo003oooooooooooooooooo`000<Gooooo00Goo`00oooooooo
ooooooooool0000<ooooo`03ool00?oooooooooo00_ooooo0_l00005ooooo`004?ooool00ol0003o
ooooooooo`03ooooo`03ool00?oooooooooo00[ooooo00?oo`00ooooooooool02_ooool01Ooo003o
ooooooooooooooooo`000<Gooooo00Goo`00ooooooooooooooooool0000<ooooo`03ool00?oooooo
oooo00cooooo00?o0000ooooooooool00oooool0013ooooo00?o0000ooooooooool00oooool00ooo
003oooooooooo`0:ooooo`03ool00?oooooooooo00[ooooo00Goo`00ooooooooooooooooool00035
ooooo`05ool00?oooooooooooooooooo00003?ooool00ooo003oooooooooo`0<ooooo`03o`000?oo
oooooooo00?ooooo000@ooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool02_ooool0
0ooo003oooooooooo`0:ooooo`05ool00?oooooooooooooooooo0000aOooool01Ooo003ooooooooo
ooooooooo`0000cooooo00?oo`00ooooooooool03?ooool00ol0003oooooooooo`03ooooo`004?oo
ool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo00[ooooo00?oo`00ooooooooool02_oo
ool01Ooo003oooooooooooooooooo`000<Gooooo00Goo`00ooooooooooooooooool0000<ooooo`03
ool00?oooooooooo00cooooo00?o0000ooooooooool00oooool0013ooooo00?o0000ooooooooool0
0oooool00ooo003oooooooooo`0:ooooo`03ool00?oooooooooo00[ooooo00Goo`00oooooooooooo
ooooool00035ooooo`05ool00?oooooooooooooooooo00003?ooool00ooo003oooooooooo`0<oooo
o`03o`000?oooooooooo00?ooooo0002ooooo`?o00000oooool2o`0000Kooooo00?o0000oooooooo
ool00oooool00ooo003oooooooooo`0:ooooo`03ool00?oooooooooo00[ooooo00Goo`00oooooooo
ooooooooool00035ooooo`05ool00?oooooooooooooooooo00003?ooool00ooo003oooooooooo`0<
ooooo`03o`000?oooooooooo00?ooooo0003ooooo`05o`000?ooooooooooooooool000000_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool02_ooool0
0ooo003oooooooooo`0:ooooo`05ool00?oooooooooooooooooo0000aOooool01Ooo003ooooooooo
ooooooooo`0000cooooo00?oo`00ooooooooool03?ooool00ol0003oooooooooo`03ooooo`001Ol0
0002ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00oooool00ooo003ooooo
ooooo`0:ooooo`03ool00?oooooooooo00[ooooo00Goo`00ooooooooooooooooool00035ooooo`05
ool00?oooooooooooooooooo00003?ooool00ooo003oooooooooo`0<ooooo`03o`000?oooooooooo
00?ooooo00001?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000Gooooo0_l00004
ooooo`03ool00?oooooooooo00[ooooo00?oo`00ooooooooool02_ooool01Ooo003ooooooooooooo
ooooo`000<Gooooo00Goo`00ooooooooooooooooool0000<ooooo`03ool00?oooooooooo00[ooooo
0ol00005ooooo`0000Coooooo`000?oooooo00000oooool01?l0003oooooooooool00005ooooo`03
o`000?oooooooooo00?ooooo00?oo`00ooooooooool02_ooool00ooo003oooooooooo`0:ooooo`05
ool00?oooooooooooooooooo0000aOooool01Ooo003oooooooooooooooooo`0000cooooo00?oo`00
ooooooooool03?ooool00ol0003oooooooooo`03ooooo`000_ooool2o`0000?ooooo00Co0000oooo
oooooooo00001Oooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo00[ooooo00?oo`00
ooooooooool02_ooool01Ooo003oooooooooooooooooo`000<Gooooo00Goo`00oooooooooooooooo
ool0000<ooooo`03ool00?oooooooooo00cooooo00?o0000ooooooooool00oooool000?ooooo00?o
0000ooooooooool00_ooool2o`0000Kooooo00?o0000ooooooooool00oooool00ooo003ooooooooo
o`0:ooooo`03ool00?oooooooooo00[ooooo00Goo`00ooooooooooooooooool00035ooooo`05ool0
0?oooooooooooooooooo00003?ooool00ooo003oooooooooo`0<ooooo`03o`000?oooooooooo00?o
oooo000@ooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool02?ooool3ool000cooooo
00Goo`00ooooooooooooooooool00035ooooo`05ool00?oooooooooooooooooo00002_ooool3ool0
00kooooo00?o0000ooooooooool00oooool0013ooooo00?o0000ooooooooool00oooool00ooo003o
ooooooooo`08ooooo`?oo`003?ooool01Ooo003oooooooooooooooooo`000<Gooooo00Goo`00oooo
ooooooooooooool0000:ooooo`?oo`003_ooool00ol0003oooooooooo`03ooooo`004?ooool00ol0
003oooooooooo`03ooooo`03ool00?oooooooooo00Sooooo0ooo000<ooooo`05ool00?oooooooooo
oooooooo0000aOooool01Ooo003oooooooooooooooooo`0000[ooooo0ooo000>ooooo`03o`000?oo
oooooooo00?ooooo000@ooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool05oooool0
1Ooo003oooooooooooooooooo`000<Gooooo00Goo`00ooooooooooooooooool0000Kooooo`03o`00
0?oooooooooo00?ooooo000@ooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool05ooo
ool01Ooo003oooooooooooooooooo`000<Gooooo00Goo`00ooooooooooooooooool0000Kooooo`03
o`000?oooooooooo00?ooooo000@ooooo`;o00001?ooool00ooo003oooooooooo`0Gooooo`05ool0
0?oooooooooooooooooo0000aOooool01Ooo003oooooooooooooooooo`0001[ooooo0_l00005oooo
o`004?ooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo01Oooooo00Goo`00oooooooo
ooooooooool00035ooooo`05ool00?oooooooooooooooooo00006oooool00ol0003oooooooooo`03
ooooo`004?ooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo01Oooooo00Goo`00oooo
ooooooooooooool00035ooooo`05ool00?oooooooooooooooooo00006oooool00ol0003ooooooooo
o`03ooooo`004?ooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo01Oooooo00Goo`00
ooooooooooooooooool00035ooooo`05ool00?oooooooooooooooooo00006oooool00ol0003ooooo
ooooo`03ooooo`004?ooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo01Oooooo00Go
o`00ooooooooooooooooool00035ooooo`05ool00?oooooooooooooooooo00006oooool00ol0003o
ooooooooo`03ooooo`004?ooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo01Oooooo
00Goo`00ooooooooooooooooool00035ooooo`05ool00?oooooooooooooooooo00006oooool00ol0
003oooooooooo`03ooooo`004?ooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo01Oo
oooo00Goo`00ooooooooooooooooool00035ooooo`05ool00?oooooooooooooooooo00006oooool0
0ol0003oooooooooo`03ooooo`004?ooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo
01Oooooo00Goo`00ooooooooooooooooool00035ooooo`05ool00?oooooooooooooooooo00006ooo
ool00ol0003oooooooooo`03ooooo`004?ooool00ol0003oooooooooo`03ooooo`03ool00?oooooo
oooo01Oooooo00Goo`00ooooooooooooooooool00035ooooo`05ool00?oooooooooooooooooo0000
6oooool00ol0003oooooooooo`03ooooo`004?ooool2o`0000Cooooo00?oo`00ooooooooool05ooo
ool01Ooo003oooooooooooooooooo`000<Gooooo00Goo`00ooooooooooooooooool0000Jooooo`;o
00001Oooool0013ooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`0Gooooo`05ool0
0?oooooooooooooooooo0000aOooool01Ooo003oooooooooooooooooo`0001_ooooo00?o0000oooo
ooooool00oooool0013ooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`0Gooooo`05
ool00?oooooooooooooooooo0000aOooool01Ooo003oooooooooooooooooo`0001_ooooo00?o0000
ooooooooool00oooool0013ooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`0Goooo
o`05ool00?oooooooooooooooooo0000aOooool01Ooo003oooooooooooooooooo`0001_ooooo00?o
0000ooooooooool00oooool0013ooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`0G
ooooo`05ool00?oooooooooooooooooo0000aOooool01Ooo003oooooooooooooooooo`0001_ooooo
00?o0000ooooooooool00oooool0013ooooo00?o0000ooooooooool00oooool00ooo003ooooooooo
o`0Gooooo`05ool00?oooooooooooooooooo0000aOooool01Ooo003oooooooooooooooooo`0001_o
oooo00?o0000ooooooooool00oooool0013ooooo00?o0000ooooooooool00oooool00ooo003ooooo
ooooo`0Gooooo`05ool00?oooooooooooooooooo0000aOooool01Ooo003oooooooooooooooooo`00
01_ooooo00?o0000ooooooooool00oooool0013ooooo00?o0000ooooooooool00oooool00ooo003o
ooooooooo`0Gooooo`05ool00?oooooooooooooooooo0000aOooool01Ooo003ooooooooooooooooo
o`0001_ooooo00?o0000ooooooooool00oooool0013ooooo00?o0000ooooooooool00oooool00ooo
003oooooooooo`0Gooooo`05ool00?oooooooooooooooooo0000aOooool01Ooo003ooooooooooooo
ooooo`0001_ooooo00?o0000ooooooooool00oooool0013ooooo0_l00004ooooo`03ool00?oooooo
oooo01Oooooo00Goo`00ooooooooooooooooool00035ooooo`05ool00?oooooooooooooooooo0000
6_ooool2o`0000Gooooo000@ooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool05ooo
ool01Ooo003oooooooooooooooooo`000<Gooooo00Goo`00ooooooooooooooooool0000Kooooo`03
o`000?oooooooooo00?ooooo000@ooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool0
5oooool01Ooo003oooooooooooooooooo`000<Gooooo00Goo`00ooooooooooooooooool0000Koooo
o`03o`000?oooooooooo00?ooooo000@ooooo`03o`000?oooooooooo00?ooooo00?oo`00oooooooo
ool05oooool01Ooo003oooooooooooooooooo`000<Gooooo00Goo`00ooooooooooooooooool0000K
ooooo`03o`000?oooooooooo00?ooooo000@ooooo`03o`000?oooooooooo00?ooooo00?oo`00oooo
ooooool05oooool01Ooo003oooooooooooooooooo`000<Gooooo00Goo`00ooooooooooooooooool0
000Kooooo`03o`000?oooooooooo00?ooooo000@ooooo`03o`000?oooooooooo00?ooooo00?oo`00
ooooooooool05oooool01Ooo003oooooooooooooooooo`000<Gooooo00Goo`00oooooooooooooooo
ool0000Kooooo`03o`000?oooooooooo00?ooooo000@ooooo`03o`000?oooooooooo00?ooooo00?o
o`00ooooooooool05oooool01Ooo003oooooooooooooooooo`000<Gooooo00Goo`00oooooooooooo
ooooool0000Kooooo`03o`000?oooooooooo00?ooooo00001?oooooo0000o`000?l00004ooooo`;o
00001_ooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo01Oooooo00Goo`00oooooooo
ooooooooool00035ooooo`05ool00?oooooooooooooooooo00006oooool00ol0003oooooooooo`03
ooooo`0000Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Gooooo00?o
0000ooooooooool00oooool00ooo003oooooooooo`0Gooooo`05ool00?oooooooooooooooooo0000
aOooool01Ooo003oooooooooooooooooo`0001_ooooo00?o0000ooooooooool00oooool00005o`00
0?ooooooooooooooool000000_ooool01?l0003oooooooooool00005ooooo`;o00001?ooool00ooo
003oooooooooo`0Gooooo`05ool00?oooooooooooooooooo0000aOooool01Ooo003ooooooooooooo
ooooo`0001Wooooo0ol00005ooooo`001?l00003ooooo`04o`000?ooooooooooo`0000Gooooo00?o
0000ooooooooool00oooool00ooo003oooooooooo`0Gooooo`05ool00?oooooooooooooooooo0000
aOooool01Ooo003oooooooooooooooooo`0001_ooooo00?o0000ooooooooool00oooool00003o`00
0?oooooooooo00Cooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`03ooooo`03
ool00?oooooooooo01Oooooo00Goo`00ooooooooooooooooool00035ooooo`05ool00?oooooooooo
oooooooo00006oooool00ol0003oooooooooo`03ooooo`0000?oooooo`000?ooool01?ooool01?l0
003oooooooooool00005ooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool05oooool0
1Ooo003oooooooooooooooooo`000<Gooooo00Goo`00ooooooooooooooooool0000Kooooo`03o`00
0?oooooooooo00?ooooo0002ooooo`;o00001?ooool2o`0000Kooooo00?o0000ooooooooool00ooo
ool00ooo003oooooooooo`0Gooooo`05ool00?oooooooooooooooooo0000aOooool01Ooo003ooooo
ooooooooooooo`0001_ooooo00?o0000ooooooooool00oooool0013ooooo00?o0000ooooooooool0
0oooool00ooo003oooooooooo`0Gooooo`05ool00?oooooooooooooooooo0000aOooool01Ooo003o
ooooooooooooooooo`0001_ooooo00?o0000ooooooooool00oooool0013ooooo00?o0000oooooooo
ool00oooool00ooo003oooooooooo`0Gooooo`05ool00?oooooooooooooooooo0000aOooool01Ooo
003oooooooooooooooooo`0001_ooooo00?o0000ooooooooool00oooool0013ooooo00?o0000oooo
ooooool00oooool00ooo003oooooooooo`0Gooooo`05ool00?oooooooooooooooooo0000aOooool0
1Ooo003oooooooooooooooooo`0001_ooooo00?o0000ooooooooool00oooool0013ooooo00?o0000
ooooooooool00oooool00ooo003oooooooooo`0Eooooo`?oo`000oooool00ooo003oooooooooo`33
ooooo`03ool00?oooooooooo00?oo`006_ooool00ol0003oooooooooo`03ooooo`004?ooool2o`00
00Cooooo00?oo`00ooooooooool05Oooool3ool000?ooooo00?oo`00ooooooooool0`oooool00ooo
003oooooooooo`03ool001Wooooo0_l00005ooooo`004?ooool00ol0003oooooooooo`03ooooo`03
ool00?oooooooooo01Gooooo0ooo0003ooooo`03ool00?oooooooooo0<?ooooo00?oo`00oooooooo
ool00ooo000Jooooo`03o`000?oooooooooo00?ooooo000@ooooo`04o`000?ooooooooooooooo`?o
o`007Oooool00ooo003oooooooooo`33ooooo`03ool00?oooooooooo01gooooo00?o0000oooooooo
ool00oooool0013ooooo00Co0000oooooooooooooooo0ooo000Mooooo`03ool00?oooooooooo0<?o
oooo00?oo`00ooooooooool07Oooool00ol0003oooooooooo`03ooooo`004?ooool01?l0003ooooo
ooooooooool3ool001gooooo00?oo`00ooooooooool0`oooool00ooo003oooooooooo`0Mooooo`03
o`000?oooooooooo00?ooooo000@ooooo`03o`000?oooooooooo027ooooo00?oo`00ooooooooool0
`oooool00ooo003oooooooooo`0Mooooo`03o`000?oooooooooo00?ooooo000@ooooo`03o`000?oo
oooooooo027ooooo00?oo`00ooooooooool0`oooool00ooo003oooooooooo`0Mooooo`03o`000?oo
oooooooo00?ooooo000@ooooo`03o`000?oooooooooo027ooooo00?oo`00ooooooooool0`oooool0
0ooo003oooooooooo`0Mooooo`03o`000?oooooooooo00?ooooo000@ooooo`03o`000?oooooooooo
027ooooo00?oo`00ooooooooool0`oooool00ooo003oooooooooo`0Mooooo`03o`000?oooooooooo
00?ooooo000@ooooo`;o00008_ooool00ooo003oooooooooo`33ooooo`03ool00?oooooooooo01co
oooo0_l00005ooooo`004?ooool00ol0003oooooooooo`0Qooooo`03ool00?oooooooooo0<?ooooo
00?oo`00ooooooooool07Oooool00ol0003oooooooooo`03ooooo`004?ooool00ol0003ooooooooo
o`0Qooooo`03ool00?oooooooooo0<?ooooo00?oo`00ooooooooool07Oooool00ol0003ooooooooo
o`03ooooo`004?ooool00ol0003oooooooooo`0Qooooo`03ool00?oooooooooo0<?ooooo00?oo`00
ooooooooool07Oooool00ol0003oooooooooo`03ooooo`004?ooool00ol0003oooooooooo`0Qoooo
o`03ool00?oooooooooo0<?ooooo00?oo`00ooooooooool07Oooool00ol0003oooooooooo`03oooo
o`004?ooool00ol0003oooooooooo`0Qooooo`03ool00?oooooooooo0<?ooooo00?oo`00oooooooo
ool07Oooool00ol0003oooooooooo`03ooooo`004?ooool00ol0003oooooooooo`0Qooooo`03ool0
0?oooooooooo0<?ooooo00?oo`00ooooooooool07Oooool00ol0003oooooooooo`03ooooo`004?oo
ool00ol0003oooooooooo`0Qooooo`03ool00?oooooooooo0<?ooooo00?oo`00ooooooooool07Ooo
ool00ol0003oooooooooo`03ooooo`004?ooool00ol0003oooooooooo`0Qooooo`03ool00?oooooo
oooo0<?ooooo00?oo`00ooooooooool07Oooool00ol0003oooooooooo`03ooooo`004?ooool00ol0
003oooooooooo`0Qooooo`03ool00?oooooooooo0<?ooooo00?oo`00ooooooooool07Oooool00ol0
003oooooooooo`03ooooo`004?ooool2o`0002;ooooo00?oo`00ooooooooool0`oooool00ooo003o
ooooooooo`0Looooo`;o00001Oooool0013ooooo00?o0000ooooooooool08Oooool00ooo003ooooo
ooooo`33ooooo`03ool00?oooooooooo01gooooo00?o0000ooooooooool00oooool0013ooooo00?o
0000ooooooooool08Oooool00ooo003oooooooooo`33ooooo`03ool00?oooooooooo01gooooo00?o
0000ooooooooool00oooool0013ooooo00?o0000ooooooooool08Oooool00ooo003oooooooooo`33
ooooo`03ool00?oooooooooo01gooooo00?o0000ooooooooool00oooool0013ooooo00?o0000oooo
ooooool08Oooool00ooo003oooooooooo`33ooooo`03ool00?oooooooooo01gooooo00?o0000oooo
ooooool00oooool0013ooooo00?o0000ooooooooool08Oooool00ooo003oooooooooo`33ooooo`03
ool00?oooooooooo01gooooo00?o0000ooooooooool00oooool00004ooooool0003o0000o`0000Co
oooo0_l00006ooooo`03o`000?oooooooooo027ooooo00?oo`00ooooooooool0`oooool00ooo003o
ooooooooo`0Mooooo`03o`000?oooooooooo00?ooooo00001Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`0Qooooo`03ool00?oooooooooo
0<?ooooo00?oo`00ooooooooool07Oooool00ol0003oooooooooo`03ooooo`0000Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool08Oooool0
0ooo003oooooooooo`33ooooo`03ool00?oooooooooo01gooooo00?o0000ooooooooool00oooool0
0004ooooool0003o0000o`0000?ooooo00Co0000oooooooooooo00001Oooool2o`0002;ooooo00?o
o`00ooooooooool0`oooool00ooo003oooooooooo`0Kooooo`?o00001Oooool00005o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo027ooooo
00?oo`00ooooooooool0`oooool00ooo003oooooooooo`0Mooooo`03o`000?oooooooooo00?ooooo
00001Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00001Oooool00ol0003o
ooooooooo`0Qooooo`03ool00?oooooooooo0<?ooooo00?oo`00ooooooooool07Oooool00ol0003o
ooooooooo`03ooooo`0000Coooooo`000?l0003o00001?ooool2o`0000Kooooo00?o0000oooooooo
ool08Oooool00ooo003oooooooooo`33ooooo`03ool00?oooooooooo01gooooo00?o0000oooooooo
ool00oooool0013ooooo00?o0000ooooooooool08Oooool00ooo003oooooooooo`33ooooo`03ool0
0?oooooooooo01gooooo00?o0000ooooooooool00oooool0013ooooo00?o0000ooooooooool08Ooo
ool00ooo003oooooooooo`33ooooo`03ool00?oooooooooo01gooooo00?o0000ooooooooool00ooo
ool0013ooooo00?o0000ooooooooool08Oooool00ooo003oooooooooo`33ooooo`03ool00?oooooo
oooo01gooooo00?o0000ooooooooool00oooool0013ooooo00?o0000ooooooooool08Oooool00ooo
003oooooooooo`33ooooo`03ool00?oooooooooo01gooooo00?o0000ooooooooool00oooool0013o
oooo00?o0000ooooooooool08Oooool00ooo003oooooooooo`33ooooo`03ool00?oooooooooo01go
oooo00?o0000ooooooooool00oooool0013ooooo0_l0000Rooooo`03ool00?oooooooooo0<?ooooo
00?oo`00ooooooooool07?ooool2o`0000Gooooo000@ooooo`03o`000?oooooooooo023ooooo0ooo
0032ooooo`?oo`007oooool00ol0003oooooooooo`03ooooo`004?ooool00ol0003oooooooooo`0P
ooooo`?oo`00`_ooool3ool001oooooo00?o0000ooooooooool00oooool0013ooooo00?o0000oooo
ooooool08?ooool3ool00<;ooooo0ooo000Oooooo`03o`000?oooooooooo00?ooooo000@ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooool000001Oooool0013oooooool0000<o`0000Gooooo
0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-5.20018, -8.90942, \
0.232596, 0.548294}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Rearrange and scale DFT result", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(g5 = 
        DiscreteListPlot[FourierRearrange[Abs[Last\  /@ \ fft], fs], Red, 
          PlotRange \[Rule] All, ImageSize \[Rule] 504, \ 
          Frame \[Rule] True, \ Axes \[Rule] False, \ 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(g6\  = \ Show[g1, g5];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.047619 0.0147151 0.00481352 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .11099 -12 -4.5 ]
[-0.0125 .11099 0 4.5 ]
[-0.0125 .20726 -12 -4.5 ]
[-0.0125 .20726 0 4.5 ]
[-0.0125 .30353 -12 -4.5 ]
[-0.0125 .30353 0 4.5 ]
[-0.0125 .3998 -12 -4.5 ]
[-0.0125 .3998 0 4.5 ]
[-0.0125 .49607 -18 -4.5 ]
[-0.0125 .49607 0 4.5 ]
[-0.0125 .59234 -18 -4.5 ]
[-0.0125 .59234 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .11099 m
.00625 .11099 L
s
[(20)] -0.0125 .11099 1 0 Mshowa
0 .20726 m
.00625 .20726 L
s
[(40)] -0.0125 .20726 1 0 Mshowa
0 .30353 m
.00625 .30353 L
s
[(60)] -0.0125 .30353 1 0 Mshowa
0 .3998 m
.00625 .3998 L
s
[(80)] -0.0125 .3998 1 0 Mshowa
0 .49607 m
.00625 .49607 L
s
[(100)] -0.0125 .49607 1 0 Mshowa
0 .59234 m
.00625 .59234 L
s
[(120)] -0.0125 .59234 1 0 Mshowa
.125 Mabswid
0 .03878 m
.00375 .03878 L
s
0 .06285 m
.00375 .06285 L
s
0 .08692 m
.00375 .08692 L
s
0 .13505 m
.00375 .13505 L
s
0 .15912 m
.00375 .15912 L
s
0 .18319 m
.00375 .18319 L
s
0 .23132 m
.00375 .23132 L
s
0 .25539 m
.00375 .25539 L
s
0 .27946 m
.00375 .27946 L
s
0 .32759 m
.00375 .32759 L
s
0 .35166 m
.00375 .35166 L
s
0 .37573 m
.00375 .37573 L
s
0 .42386 m
.00375 .42386 L
s
0 .44793 m
.00375 .44793 L
s
0 .472 m
.00375 .472 L
s
0 .52013 m
.00375 .52013 L
s
0 .5442 m
.00375 .5442 L
s
0 .56827 m
.00375 .56827 L
s
0 .6164 m
.00375 .6164 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .11099 m
1 .11099 L
s
.99375 .20726 m
1 .20726 L
s
.99375 .30353 m
1 .30353 L
s
.99375 .3998 m
1 .3998 L
s
.99375 .49607 m
1 .49607 L
s
.99375 .59234 m
1 .59234 L
s
.125 Mabswid
.99625 .03878 m
1 .03878 L
s
.99625 .06285 m
1 .06285 L
s
.99625 .08692 m
1 .08692 L
s
.99625 .13505 m
1 .13505 L
s
.99625 .15912 m
1 .15912 L
s
.99625 .18319 m
1 .18319 L
s
.99625 .23132 m
1 .23132 L
s
.99625 .25539 m
1 .25539 L
s
.99625 .27946 m
1 .27946 L
s
.99625 .32759 m
1 .32759 L
s
.99625 .35166 m
1 .35166 L
s
.99625 .37573 m
1 .37573 L
s
.99625 .42386 m
1 .42386 L
s
.99625 .44793 m
1 .44793 L
s
.99625 .472 m
1 .472 L
s
.99625 .52013 m
1 .52013 L
s
.99625 .5442 m
1 .5442 L
s
.99625 .56827 m
1 .56827 L
s
.99625 .6164 m
1 .6164 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
0 0 1 r
.5 Mabswid
[ .01 ] 0 setdash
.02381 .0436 m
.02395 .04359 L
.02408 .04356 L
.02423 .0435 L
.02437 .04342 L
.02462 .04324 L
.02489 .04295 L
.02519 .04255 L
.02551 .04203 L
.02608 .04082 L
.02722 .03748 L
.02847 .03259 L
.02973 .02678 L
.03043 .0235 L
.03077 .02199 L
.03109 .02078 L
.03125 .0203 L
.03139 .01994 L
.03147 .01978 L
.03156 .01965 L
.03171 .01954 L
.03179 .01954 L
.03188 .01958 L
.03197 .01969 L
.03206 .01983 L
.03221 .02019 L
.03238 .02069 L
.03299 .02316 L
.03355 .02577 L
.03476 .03143 L
.03605 .03668 L
.03714 .04015 L
.03777 .04164 L
.03805 .04217 L
.03836 .04267 L
.03863 .04302 L
.03892 .04332 L
.03908 .04344 L
.03923 .04353 L
.03938 .04359 L
.03952 .04363 L
.03965 .04364 L
.03978 .04364 L
.0399 .04362 L
.04003 .04358 L
.04017 .04352 L
.04031 .04343 L
.04058 .04321 L
.04089 .04286 L
.04122 .04236 L
Mistroke
.04183 .04116 L
.04243 .03963 L
.04298 .03792 L
.04525 .02852 L
.04644 .02291 L
.04673 .02167 L
.04705 .02055 L
.04722 .02005 L
.04731 .01987 L
.04739 .01973 L
.04746 .01963 L
.04755 .01956 L
.0477 .01956 L
.04778 .01962 L
.04786 .01973 L
.04802 .02002 L
.04819 .02051 L
.04836 .02107 L
.04905 .02403 L
.05029 .0299 L
.05155 .03536 L
.05217 .03763 L
.05273 .03943 L
.05326 .04087 L
.05383 .04213 L
.05415 .04267 L
.05444 .04308 L
.05472 .04338 L
.05487 .04351 L
.05501 .04361 L
.05517 .0437 L
.05531 .04375 L
.05546 .04378 L
.05555 .04379 L
.05563 .04379 L
.05576 .04377 L
.05591 .04373 L
.05606 .04366 L
.0562 .04357 L
.05653 .04328 L
.05683 .04292 L
.05716 .04241 L
.05751 .04174 L
.05866 .0387 L
.05989 .03416 L
.0621 .02396 L
.0627 .02136 L
.063 .02034 L
.06309 .02012 L
.06318 .01991 L
Mistroke
.06326 .01976 L
.06334 .01966 L
.06342 .01959 L
.06351 .01957 L
.0636 .0196 L
.06369 .01969 L
.06378 .01983 L
.06387 .02 L
.06403 .02043 L
.06434 .02151 L
.06467 .02292 L
.06583 .02842 L
.0671 .03418 L
.06827 .03855 L
.0689 .04048 L
.06951 .04194 L
.06984 .04258 L
.0702 .04315 L
.07052 .04354 L
.07068 .04369 L
.07082 .04381 L
.07096 .04389 L
.07111 .04396 L
.07119 .04399 L
.07127 .04401 L
.07142 .04403 L
.07158 .04402 L
.07172 .04399 L
.0718 .04396 L
.07188 .04393 L
.07205 .04383 L
.0722 .04373 L
.07233 .04361 L
.07264 .04326 L
.07294 .04282 L
.07326 .04225 L
.07437 .03945 L
.07504 .03719 L
.07568 .03471 L
.07688 .02935 L
.07804 .02378 L
.07837 .02228 L
.07868 .02103 L
.07882 .02057 L
.07897 .02016 L
.07912 .01982 L
.07927 .01965 L
.07941 .01961 L
.07954 .01969 L
.07968 .01991 L
Mistroke
.07982 .02022 L
.08006 .02099 L
.08033 .02203 L
.08149 .0275 L
.08262 .03281 L
.08383 .03775 L
.08453 .04005 L
.08517 .04176 L
.08547 .04243 L
.08581 .04306 L
.0861 .04351 L
.08642 .0439 L
.08658 .04405 L
.08674 .04417 L
.08689 .04426 L
.08704 .04433 L
.08718 .04436 L
.08731 .04438 L
.08745 .04437 L
.08761 .04434 L
.08769 .04431 L
.08777 .04427 L
.08795 .04417 L
.08811 .04405 L
.08827 .04389 L
.08856 .04354 L
.08888 .04305 L
.08944 .04192 L
.09006 .04032 L
.09116 .03655 L
.09353 .02574 L
.09418 .02267 L
.09454 .0212 L
.09471 .0206 L
.09487 .02015 L
.09503 .01985 L
.0951 .01975 L
.09519 .01968 L
.09527 .01966 L
.09536 .0197 L
.09545 .01979 L
.09553 .01991 L
.09567 .02023 L
.09583 .02069 L
.09612 .02176 L
.09863 .03366 L
.09972 .03811 L
.1009 .0418 L
.10154 .04322 L
.10182 .0437 L
Mistroke
.10212 .04414 L
.10241 .04446 L
.10255 .04457 L
.10268 .04466 L
.10283 .04474 L
.10297 .04479 L
.10312 .04483 L
.10328 .04483 L
.10343 .04481 L
.10358 .04476 L
.10366 .04472 L
.10374 .04468 L
.10391 .04456 L
.10424 .04424 L
.10459 .04377 L
.10517 .04269 L
.10581 .0411 L
.10705 .03687 L
.10817 .03197 L
.10949 .02551 L
.11007 .02275 L
.11037 .02145 L
.11054 .02083 L
.1107 .02035 L
.11085 .02001 L
.11101 .01979 L
.11115 .01973 L
.11128 .01981 L
.11141 .01999 L
.11155 .0203 L
.11169 .02072 L
.11183 .0212 L
.11302 .02676 L
.11424 .03278 L
.11553 .03828 L
.11669 .04206 L
.11735 .04362 L
.11766 .0442 L
.11796 .04464 L
.11823 .04496 L
.11837 .04509 L
.11852 .04521 L
.11865 .04529 L
.11879 .04535 L
.11892 .04539 L
.11904 .0454 L
.11919 .0454 L
.11933 .04538 L
.11945 .04534 L
.11959 .04527 L
Mistroke
.11974 .04517 L
.1199 .04504 L
.12019 .04473 L
.1205 .04428 L
.12084 .04368 L
.12143 .04231 L
.12207 .04043 L
.12277 .03791 L
.12405 .03235 L
.12521 .02655 L
.12578 .02366 L
.12609 .02225 L
.12641 .02097 L
.12655 .02053 L
.1267 .02016 L
.12678 .02001 L
.12686 .0199 L
.12701 .01982 L
.12714 .01987 L
.12728 .02006 L
.12742 .02039 L
.12756 .0208 L
.1282 .02348 L
.12878 .0264 L
.13008 .03299 L
.13121 .03801 L
.1324 .04219 L
.13302 .04382 L
.13335 .04452 L
.1337 .04513 L
.13403 .04556 L
.13432 .04585 L
.13447 .04595 L
.13462 .04603 L
.13477 .04609 L
.1349 .04611 L
.13506 .04611 L
.13514 .0461 L
.13522 .04608 L
.13538 .04603 L
.13552 .04595 L
.13569 .04583 L
.13584 .04569 L
.13618 .04527 L
.13648 .0448 L
.1368 .04418 L
.13739 .04275 L
.13855 .03885 L
.13963 .03418 L
.14072 .02874 L
Mistroke
.14189 .02279 L
.14223 .02133 L
.1424 .02074 L
.14256 .02031 L
.1427 .02005 L
.14285 .01993 L
.14294 .01993 L
.14302 .01998 L
.14317 .02021 L
.14332 .02056 L
.14347 .02105 L
.14375 .02215 L
.14437 .0252 L
.1456 .03166 L
.14677 .03725 L
.1479 .04172 L
.1484 .04329 L
.14895 .04473 L
.1495 .04581 L
.1498 .04626 L
.15008 .04658 L
.15023 .04671 L
.15038 .04682 L
.15052 .04689 L
.15067 .04694 L
.15082 .04697 L
.15091 .04697 L
.15099 .04696 L
.15115 .04693 L
.1513 .04686 L
.15145 .04677 L
.15161 .04665 L
.15193 .04629 L
.15223 .04585 L
.15251 .04535 L
.15314 .04387 L
.15382 .04179 L
.15504 .03692 L
.15637 .03032 L
.15703 .02681 L
.15765 .02359 L
.15792 .02231 L
.1582 .02116 L
.15835 .02068 L
.15843 .02047 L
.15851 .02029 L
.15866 .02009 L
.1588 .02005 L
.15896 .02018 L
.1591 .02046 L
Mistroke
.15918 .02066 L
.15927 .02092 L
.15944 .02154 L
.16004 .02439 L
.16117 .03052 L
.16249 .03724 L
.1637 .04228 L
.16429 .04422 L
.16484 .04569 L
.16541 .04685 L
.16572 .04731 L
.16604 .04767 L
.16621 .0478 L
.16636 .0479 L
.16645 .04794 L
.16654 .04797 L
.16663 .04799 L
.16672 .048 L
.1668 .048 L
.16688 .04799 L
.16703 .04795 L
.16718 .04789 L
.16727 .04783 L
.16736 .04777 L
.16766 .04749 L
.16794 .04713 L
.16856 .04598 L
.16915 .04446 L
.16977 .04243 L
.17088 .03782 L
.1721 .03167 L
.17277 .02799 L
.1734 .02453 L
.17369 .02305 L
.17399 .02167 L
.17415 .02108 L
.17424 .02081 L
.17433 .02057 L
.17441 .0204 L
.17449 .02028 L
.17464 .02019 L
.17478 .02026 L
.17492 .02047 L
.17506 .02085 L
.17522 .02138 L
.17577 .02393 L
.17799 .0361 L
.17923 .04187 L
.17988 .04433 L
.18057 .04643 L
Mistroke
.18117 .0478 L
.18151 .04838 L
.18168 .04861 L
.18183 .04879 L
.18198 .04893 L
.18213 .04905 L
.18227 .04913 L
.1824 .04918 L
.18254 .04921 L
.18269 .04922 L
.18277 .04921 L
.18285 .0492 L
.183 .04914 L
.18315 .04906 L
.18329 .04895 L
.1836 .04863 L
.18388 .04822 L
.18415 .04774 L
.18476 .04633 L
.18542 .0443 L
.18674 .0388 L
.18796 .03239 L
.18905 .02614 L
.18965 .0229 L
.18995 .02159 L
.19009 .02108 L
.19022 .02072 L
.19038 .02044 L
.19046 .02037 L
.19055 .02035 L
.19063 .0204 L
.19071 .0205 L
.1908 .02067 L
.1909 .0209 L
.19105 .0214 L
.19119 .02197 L
.19151 .02351 L
.19271 .03043 L
.19496 .04237 L
.19558 .0449 L
.19624 .04713 L
.1968 .04863 L
.1971 .04927 L
.19741 .04982 L
.19757 .05004 L
.19774 .05025 L
.1979 .05041 L
.19805 .05052 L
.19813 .05057 L
.19822 .05061 L
Mistroke
.19832 .05065 L
.1984 .05067 L
.19849 .05068 L
.19858 .05068 L
.19874 .05066 L
.19888 .0506 L
.19904 .05051 L
.19919 .05039 L
.19933 .05025 L
.19966 .04982 L
.19998 .04927 L
.20058 .04785 L
.20114 .04613 L
.20241 .04089 L
.20358 .03468 L
.20484 .02714 L
.20543 .02379 L
.20574 .02221 L
.2059 .02157 L
.20604 .0211 L
.20617 .02078 L
.20629 .0206 L
.20642 .02055 L
.20656 .02066 L
.20671 .02094 L
.20686 .02141 L
.20714 .02257 L
.20933 .0356 L
.21054 .0422 L
.21168 .04719 L
.21227 .04916 L
.21258 .05002 L
.21292 .0508 L
.21322 .05139 L
.2135 .05181 L
.21363 .05198 L
.21378 .05213 L
.21391 .05223 L
.21404 .05232 L
.21418 .05238 L
.21431 .05242 L
.21446 .05243 L
.2146 .0524 L
.21475 .05235 L
.2149 .05226 L
.21505 .05214 L
.21519 .052 L
.21544 .05169 L
.2157 .05125 L
.21625 .05005 L
Mistroke
.21684 .04829 L
.21747 .04595 L
.21858 .04064 L
.2198 .03357 L
.22047 .02935 L
.2211 .0254 L
.22139 .02372 L
.2217 .02218 L
.22186 .02155 L
.22195 .02127 L
.22204 .02104 L
.22212 .02089 L
.2222 .0208 L
.22235 .02079 L
.22249 .02098 L
.22263 .02131 L
.22277 .02182 L
.22293 .02251 L
.22348 .0256 L
.2257 .03967 L
.22694 .04628 L
.2276 .04908 L
.22829 .05145 L
.22889 .053 L
.22924 .05364 L
.2294 .05389 L
.22956 .05408 L
.2297 .05423 L
.22985 .05436 L
.22999 .05444 L
.23012 .05449 L
.23026 .05452 L
.23041 .05452 L
.23049 .0545 L
.23057 .05447 L
.23072 .0544 L
.2308 .05434 L
.23088 .05428 L
.23103 .05414 L
.23135 .05371 L
.23163 .05321 L
.23194 .05253 L
.23263 .05051 L
.23327 .04806 L
.23445 .04222 L
.23569 .03457 L
.23683 .02693 L
.23713 .02501 L
.23746 .02312 L
.23761 .02239 L
Mistroke
.23777 .02175 L
.23791 .02134 L
.23806 .02108 L
.23821 .02104 L
.23834 .0212 L
.23849 .02158 L
.23865 .02217 L
.23892 .02349 L
.23921 .02524 L
.24027 .03244 L
.24159 .04124 L
.24283 .04827 L
.24395 .05302 L
.24425 .05402 L
.24458 .05494 L
.24488 .05565 L
.24516 .05618 L
.24529 .05639 L
.24544 .05659 L
.24559 .05675 L
.24572 .05687 L
.24587 .05697 L
.24595 .05701 L
.24603 .05704 L
.24617 .05706 L
.24632 .05706 L
.24645 .05702 L
.24659 .05695 L
.24674 .05684 L
.24688 .0567 L
.24713 .05638 L
.2474 .05592 L
.24772 .05524 L
.24806 .05431 L
.24869 .05216 L
.24986 .04666 L
.25221 .03132 L
.25285 .02675 L
.25318 .02453 L
.25337 .02345 L
.25354 .02258 L
.25369 .02197 L
.25377 .0217 L
.25385 .02152 L
.25393 .02138 L
.25402 .02132 L
.25411 .02135 L
.25419 .02145 L
.25433 .02178 L
.25448 .02233 L
Mistroke
.25479 .02393 L
.25727 .04174 L
.25835 .04865 L
.25953 .05459 L
.26015 .05694 L
.26043 .05778 L
.26073 .05857 L
.261 .05914 L
.26129 .05961 L
.26144 .05982 L
.26159 .05996 L
.26173 .06007 L
.26188 .06015 L
.26203 .06019 L
.26218 .06019 L
.26226 .06018 L
.26234 .06015 L
.2625 .06006 L
.26265 .05994 L
.2628 .05977 L
.26308 .05937 L
.2634 .05873 L
.26371 .05798 L
.2644 .05568 L
.265 .05308 L
.26565 .04963 L
.26684 .04196 L
.26799 .03331 L
.26855 .02892 L
.26907 .02513 L
.26936 .02337 L
.26952 .02258 L
.26967 .02204 L
.26982 .02173 L
.26991 .02167 L
.26999 .0217 L
.27007 .02181 L
.27016 .02202 L
.27024 .02229 L
.27032 .0226 L
.27058 .02398 L
.27086 .0259 L
.27145 .03039 L
.27277 .04103 L
.27398 .04982 L
.27511 .0565 L
.27568 .05915 L
.27631 .06144 L
.27664 .06237 L
.27694 .06305 L
Mistroke
.27711 .06335 L
.27729 .06363 L
.27746 .06383 L
.27761 .06397 L
.27776 .06406 L
.27789 .0641 L
.27804 .06411 L
.27812 .0641 L
.2782 .06408 L
.27835 .064 L
.27844 .06394 L
.27852 .06386 L
.27882 .06348 L
.27898 .06322 L
.27914 .06289 L
.27944 .06218 L
.2801 .05999 L
.28068 .05747 L
.2813 .05409 L
.28355 .03764 L
.28413 .03269 L
.28476 .02741 L
.28505 .02522 L
.28521 .02416 L
.28536 .02331 L
.28548 .02273 L
.28562 .02229 L
.28577 .02208 L
.28591 .02217 L
.28599 .02232 L
.28607 .02258 L
.28622 .02322 L
.28639 .02424 L
.28655 .02534 L
.28723 .03093 L
.28843 .04167 L
.28956 .05099 L
.29075 .05922 L
.29137 .06265 L
.29206 .06564 L
.29236 .06667 L
.29268 .06759 L
.29298 .06826 L
.29313 .06851 L
.29326 .06871 L
.2934 .06889 L
.29354 .06901 L
.29368 .0691 L
.29384 .06915 L
.29398 .06915 L
Mistroke
.29414 .0691 L
.29422 .06906 L
.2943 .06899 L
.29445 .06885 L
.2946 .06866 L
.29475 .06841 L
.29503 .06784 L
.29556 .06632 L
.29619 .06377 L
.29686 .06023 L
.29806 .05192 L
.29929 .04139 L
.30045 .0304 L
.30095 .02597 L
.3011 .02488 L
.30123 .02399 L
.30136 .02333 L
.30149 .02283 L
.30164 .02257 L
.3018 .02268 L
.30193 .02308 L
.30208 .0238 L
.30222 .02466 L
.30236 .02576 L
.30263 .02802 L
.30497 .051 L
.30628 .06198 L
.30749 .06965 L
.30809 .07237 L
.30839 .07348 L
.30872 .07444 L
.30889 .07484 L
.30905 .07515 L
.30921 .07541 L
.30935 .0756 L
.30944 .07569 L
.30952 .07575 L
.3096 .0758 L
.30969 .07584 L
.30978 .07586 L
.30988 .07586 L
.30997 .07584 L
.31005 .0758 L
.31019 .07571 L
.31034 .07555 L
.31049 .07535 L
.31062 .07513 L
.31093 .07443 L
.31123 .07354 L
.31183 .07116 L
Mistroke
.31248 .06767 L
.31373 .05854 L
.31486 .04795 L
.31618 .03385 L
.31676 .02785 L
.31692 .0264 L
.31709 .02503 L
.31717 .02446 L
.31725 .024 L
.31739 .02338 L
.31753 .02313 L
.31767 .02327 L
.3178 .02369 L
.31794 .02445 L
.31808 .02552 L
.31824 .0269 L
.31852 .02977 L
.31972 .04344 L
.32102 .05795 L
.32223 .06947 L
.32345 .07829 L
.32409 .08159 L
.32445 .083 L
.32478 .08399 L
.32493 .08435 L
.32509 .08467 L
.32523 .08489 L
.32538 .08508 L
.32546 .08515 L
.32554 .08521 L
.32563 .08525 L
.32572 .08527 L
.32587 .08525 L
.32595 .08522 L
.32603 .08517 L
.32617 .08504 L
.3263 .08487 L
.32644 .08463 L
.3266 .0843 L
.32691 .08344 L
.3272 .08242 L
.32778 .07974 L
.32839 .07594 L
.32949 .06682 L
.33198 .03779 L
.33258 .03028 L
.33274 .02847 L
.33291 .0267 L
.33307 .02533 L
.33322 .02437 L
Mistroke
.3333 .02402 L
.33339 .02383 L
.33355 .02398 L
.33364 .02433 L
.33374 .02491 L
.33391 .02636 L
.33425 .03009 L
.33455 .03401 L
.33699 .06692 L
.33812 .07984 L
.33931 .09042 L
.33993 .09446 L
.34029 .09625 L
.34062 .09758 L
.34078 .09809 L
.34092 .0985 L
.34106 .09882 L
.3412 .09909 L
.34136 .09931 L
.3415 .09945 L
.34165 .09952 L
.34174 .09952 L
.34182 .09951 L
.34196 .09942 L
.34212 .09926 L
.34226 .09904 L
.34239 .09878 L
.34271 .0979 L
.34301 .09677 L
.34361 .09362 L
.34426 .08892 L
.34542 .07734 L
.34649 .06348 L
.34759 .04695 L
.34819 .03734 L
.34876 .02886 L
.34892 .02699 L
.349 .02613 L
.34908 .02547 L
.34917 .02496 L
.34926 .02466 L
.34935 .02466 L
.34943 .02491 L
.34959 .02596 L
.34967 .02673 L
.34975 .02771 L
.35005 .03184 L
.35125 .0526 L
.35257 .07543 L
.35381 .09451 L
Mistroke
.35493 .10836 L
.35556 .11446 L
.35614 .11886 L
.35641 .12047 L
.3567 .12189 L
.35697 .12292 L
.35709 .12328 L
.35722 .1236 L
.35738 .12388 L
.35752 .12406 L
.3576 .12412 L
.35769 .12416 L
.35784 .12414 L
.35798 .12404 L
.35812 .12386 L
.35827 .12358 L
.35842 .12318 L
.35871 .12217 L
.35902 .12069 L
.35957 .11697 L
.36024 .11083 L
.36084 .10365 L
.36334 .05993 L
.36444 .03614 L
.36474 .03023 L
.36482 .02884 L
.36491 .02757 L
.36506 .026 L
.36521 .02566 L
.36534 .02645 L
.36549 .02832 L
.36565 .03111 L
.36789 .08647 L
.37027 .14067 L
.37151 .16145 L
.3722 .17007 L
.37254 .17328 L
.37285 .17573 L
.37312 .17742 L
.37326 .17812 L
.37341 .17875 L
.3735 .17904 L
.37358 .17927 L
.37373 .17961 L
.37388 .17979 L
.37403 .17984 L
.37411 .1798 L
.37419 .17972 L
.37428 .1796 L
.37437 .17941 L
Mistroke
.37452 .17897 L
.37468 .17832 L
.37499 .17664 L
.37528 .17449 L
.37588 .16811 L
.37654 .15831 L
.37716 .14631 L
.37774 .13289 L
.37998 .06069 L
.38054 .03924 L
.3807 .03352 L
.38085 .02906 L
.38099 .02695 L
.38114 .02797 L
.38129 .03172 L
.38142 .0364 L
.38171 .04879 L
.38223 .07364 L
.38472 .20583 L
.38724 .34453 L
.38955 .45895 L
.39072 .50703 L
.39181 .54423 L
.39295 .57396 L
.39355 .58567 L
.39386 .59061 L
.3942 .59498 L
.3945 .59816 L
.39466 .59954 L
.39483 .60079 L
.39499 .60171 L
.39514 .60237 L
.39528 .60285 L
.39542 .60317 L
.39558 .60332 L
.39567 .60331 L
.39575 .60324 L
.39591 .60296 L
.39606 .6025 L
.39614 .60217 L
.39623 .60174 L
.39639 .60082 L
.39676 .59797 L
.39704 .59495 L
.39735 .59099 L
.39791 .58194 L
.39918 .55284 L
.4004 .51486 L
.40173 .46412 L
.40416 .3548 L
Mistroke
.40673 .23058 L
.40906 .12675 L
.41023 .08208 L
.41085 .06141 L
.41118 .05119 L
.4115 .04258 L
.41179 .03563 L
.41192 .03318 L
.41207 .03108 L
.41222 .02966 L
.41237 .02929 L
.41245 .02951 L
.41254 .03002 L
.41269 .03156 L
.41282 .03328 L
.41296 .03539 L
.41321 .03958 L
.41379 .04926 L
.41435 .05772 L
.41494 .06524 L
.41529 .06879 L
.4156 .07153 L
.41589 .07371 L
.41621 .07556 L
.41636 .07631 L
.41653 .07701 L
.41669 .07755 L
.41684 .07793 L
.41701 .07828 L
.4171 .07842 L
.41719 .07851 L
.41735 .07861 L
.41743 .07861 L
.41752 .07859 L
.41759 .07855 L
.41768 .07847 L
.41783 .07827 L
.41798 .07799 L
.41812 .07766 L
.41843 .07667 L
.41875 .07528 L
.41935 .07189 L
.4199 .06797 L
.42113 .05699 L
.42334 .03383 L
.42392 .02795 L
.42454 .02233 L
.4248 .0204 L
.42494 .01954 L
.42507 .01893 L
Mistroke
.42523 .01857 L
.42537 .01864 L
.4255 .01902 L
.42565 .01966 L
.42816 .03342 L
.42938 .03935 L
.43053 .0472 L
.43117 .0533 L
.43186 .06159 L
.43306 .08023 L
.43546 .13045 L
.438 .19311 L
.4404 .24953 L
.44145 .27049 L
.44258 .28939 L
.44321 .29778 L
.44379 .30411 L
.44435 .3088 L
.44463 .31064 L
.44494 .31226 L
.4451 .31292 L
.44526 .31348 L
.44541 .31386 L
.44556 .31416 L
.44565 .31428 L
.44573 .31436 L
.44582 .31441 L
.44591 .31441 L
.44607 .31434 L
.44616 .31424 L
.44624 .31412 L
.44638 .31383 L
.44652 .31346 L
.44683 .31228 L
.44713 .3107 L
.44746 .3085 L
.44809 .3028 L
.44868 .29588 L
.45001 .27468 L
.45119 .25036 L
.45244 .21975 L
.45485 .15222 L
.45612 .11571 L
.45746 .08 L
.45804 .06668 L
.45836 .06036 L
.45866 .0553 L
.45883 .05293 L
.45902 .05082 L
.4591 .05006 L
Mistroke
.45919 .04938 L
.45934 .04848 L
.4595 .048 L
.45964 .04793 L
.45973 .04804 L
.45981 .04825 L
.45989 .04857 L
.45998 .04902 L
.46012 .04998 L
.46026 .05104 L
.46055 .05398 L
.46109 .0604 L
.4623 .07564 L
.46288 .08203 L
.4635 .08764 L
.46403 .09137 L
.46433 .09303 L
.46461 .09429 L
.46477 .09487 L
.46494 .09539 L
.46508 .09574 L
.46524 .09604 L
.46533 .09617 L
.46541 .09627 L
.46549 .09634 L
.46559 .09639 L
.46567 .09641 L
.46576 .0964 L
.46591 .09632 L
.46606 .09617 L
.46621 .09593 L
.46636 .09562 L
.46649 .09528 L
.46682 .09421 L
.46712 .09288 L
.46768 .08976 L
.46829 .08537 L
.46953 .07425 L
.47067 .06305 L
.47124 .05808 L
.47176 .05438 L
.47204 .05291 L
.4722 .05228 L
.47234 .05185 L
.4725 .05153 L
.47259 .05143 L
.47267 .05138 L
.47282 .0514 L
.47298 .0516 L
.47312 .05189 L
Mistroke
.47326 .05233 L
.47352 .05343 L
.47382 .0552 L
.4741 .05716 L
.47541 .06881 L
.47662 .07976 L
.4772 .08418 L
.47774 .08763 L
.4783 .09036 L
.4786 .09142 L
.47877 .09188 L
.47892 .09223 L
.47907 .09248 L
.47923 .09267 L
.47932 .09274 L
.4794 .09278 L
.47956 .09278 L
.47964 .09275 L
.47973 .09268 L
.47988 .0925 L
.47997 .09237 L
.48005 .09221 L
.48023 .09177 L
.48053 .09077 L
.48081 .08955 L
.48143 .08574 L
.482 .08088 L
.48262 .07437 L
.48372 .05956 L
.4844 .04921 L
.48473 .04422 L
.48504 .04008 L
.48518 .03842 L
.48531 .03713 L
.48545 .03612 L
.48561 .0355 L
.48576 .03549 L
.48591 .03604 L
.48598 .03657 L
.48607 .03733 L
.48622 .03913 L
.48651 .04357 L
.48681 .04956 L
.48736 .06236 L
.48862 .09628 L
.49115 .17173 L
.49353 .2391 L
.49478 .26978 L
.49612 .29686 L
.49679 .30782 L
Mistroke
.49742 .31642 L
.49799 .32263 L
.49828 .32525 L
.4986 .32766 L
.49889 .32938 L
.49919 .3308 L
.49935 .33139 L
.49951 .33181 L
.49966 .33212 L
.4998 .33231 L
.49994 .3324 L
.50008 .33239 L
.5002 .33231 L
.50033 .33214 L
.50048 .33185 L
.50063 .33144 L
.50091 .33039 L
.5012 .32891 L
.50151 .32689 L
.50206 .32212 L
.50272 .31458 L
.50332 .30606 L
.50463 .28239 L
.50587 .25443 L
.51051 .12199 L
.51174 .08612 L
.5129 .05598 L
.51348 .04372 L
.51365 .0409 L
.51381 .03867 L
.51395 .0371 L
.51411 .03595 L
.5142 .03558 L
.51429 .03542 L
.51444 .03565 L
.51453 .03605 L
.51461 .03657 L
.5148 .03821 L
.51511 .042 L
.51544 .04676 L
.51658 .06403 L
.51721 .07237 L
.51781 .07907 L
.51837 .08415 L
.51866 .08636 L
.51897 .08834 L
.51923 .08973 L
.51952 .09095 L
.51964 .09139 L
.51978 .09179 L
Mistroke
.5199 .09211 L
.52002 .09235 L
.52018 .09258 L
.52031 .09272 L
.52046 .09279 L
.52055 .09279 L
.52062 .09277 L
.52075 .09269 L
.52089 .09254 L
.52104 .0923 L
.52118 .09201 L
.5215 .0911 L
.52179 .08999 L
.52244 .08656 L
.52307 .08223 L
.52375 .07659 L
.52499 .06504 L
.52553 .06012 L
.52612 .05558 L
.52646 .05358 L
.5266 .05288 L
.52676 .05225 L
.52692 .05181 L
.52706 .05153 L
.52721 .05138 L
.52729 .05137 L
.52737 .0514 L
.52753 .05158 L
.52761 .05173 L
.52769 .05195 L
.52785 .05246 L
.52799 .05307 L
.52832 .05487 L
.52867 .05736 L
.5299 .06867 L
.53112 .08043 L
.53177 .08584 L
.53245 .09058 L
.53279 .09246 L
.53311 .09392 L
.5334 .09495 L
.53355 .09538 L
.53371 .09577 L
.53386 .09605 L
.534 .09624 L
.53415 .09636 L
.53424 .0964 L
.53432 .09641 L
.53445 .09637 L
.5346 .09625 L
Mistroke
.53474 .09607 L
.53487 .09583 L
.53502 .0955 L
.53517 .09507 L
.53543 .0941 L
.53572 .09276 L
.53604 .09095 L
.5366 .08679 L
.53713 .08195 L
.5384 .06698 L
.53903 .0589 L
.53931 .05555 L
.53961 .05227 L
.53975 .05095 L
.53991 .04974 L
.54005 .04885 L
.54019 .04827 L
.54034 .04794 L
.54042 .04791 L
.5405 .04799 L
.54064 .04841 L
.5408 .04925 L
.54088 .04991 L
.54096 .05062 L
.54114 .0526 L
.54147 .05733 L
.54208 .0692 L
.54432 .12823 L
.54679 .19894 L
.54909 .25651 L
.55023 .27905 L
.55131 .29569 L
.5519 .30273 L
.55221 .30579 L
.55255 .30854 L
.55283 .31045 L
.55313 .31212 L
.55327 .31271 L
.55341 .31325 L
.55355 .31366 L
.55368 .31396 L
.55383 .31422 L
.55397 .31437 L
.55412 .31442 L
.5542 .3144 L
.55428 .31435 L
.55441 .31421 L
.55455 .31396 L
.5547 .3136 L
.55483 .31317 L
Mistroke
.55515 .31184 L
.55544 .31021 L
.5561 .30515 L
.55672 .29855 L
.55741 .28955 L
.55865 .26879 L
.56356 .15404 L
.566 .09812 L
.5672 .07585 L
.56829 .05965 L
.56936 .04816 L
.56989 .04388 L
.57048 .04013 L
.57284 .0285 L
.57348 .02487 L
.57408 .02117 L
.57434 .0197 L
.57447 .0191 L
.57462 .01866 L
.57478 .01857 L
.57492 .01891 L
.57506 .01952 L
.57521 .02041 L
.57588 .0261 L
.57652 .03245 L
.57773 .0452 L
.57889 .05716 L
.58012 .06814 L
.58072 .07237 L
.58102 .0741 L
.58129 .07546 L
.58153 .07649 L
.58179 .0774 L
.58192 .07776 L
.58206 .07807 L
.5822 .07833 L
.58234 .07849 L
.58249 .07859 L
.58257 .07861 L
.58265 .07861 L
.58281 .07852 L
.5829 .07842 L
.58298 .0783 L
.58312 .07804 L
.58327 .07767 L
.58357 .07661 L
.5839 .07496 L
.58426 .07262 L
.5849 .06688 L
.58556 .05902 L
Mistroke
.58618 .04984 L
.58677 .03982 L
.58707 .035 L
.58719 .0331 L
.58733 .0313 L
.58747 .02998 L
.5876 .02934 L
.58775 .02951 L
.58789 .03059 L
.58805 .03272 L
.58819 .03531 L
.58851 .04266 L
.58975 .08142 L
.59197 .17105 L
.59682 .40063 L
.59904 .49467 L
.6003 .53786 L
.60091 .55548 L
.60147 .56933 L
.60203 .58093 L
.60264 .59089 L
.60297 .59515 L
.60328 .59831 L
.60357 .60062 L
.60372 .60151 L
.60389 .60229 L
.60397 .6026 L
.60406 .60287 L
.60414 .60307 L
.60422 .6032 L
.60436 .60332 L
.60452 .60325 L
.60461 .60312 L
.6047 .6029 L
.60479 .60263 L
.60488 .60232 L
.60503 .60158 L
.6052 .60057 L
.6055 .59814 L
.60579 .59518 L
.60643 .58602 L
.60703 .57439 L
.60769 .55852 L
.60888 .52154 L
.61112 .428 L
.61346 .30695 L
.61604 .16395 L
.61721 .10144 L
.61783 .07047 L
.61817 .05445 L
Mistroke
.61848 .04056 L
.61862 .03492 L
.61876 .0304 L
.61891 .02719 L
.61905 .02734 L
.61921 .03067 L
.61935 .03529 L
.61968 .04741 L
.62077 .08811 L
.62186 .1223 L
.62304 .15045 L
.62371 .16238 L
.62432 .17056 L
.62462 .17356 L
.62494 .17617 L
.62509 .17712 L
.62524 .17798 L
.62539 .17863 L
.62552 .17911 L
.62567 .1795 L
.62575 .17965 L
.62584 .17976 L
.62593 .17982 L
.62601 .17984 L
.62617 .17975 L
.62632 .17952 L
.62646 .17918 L
.62661 .17868 L
.62677 .178 L
.6271 .17611 L
.62741 .17376 L
.62811 .16647 L
.62872 .15808 L
.62928 .14889 L
.63055 .12374 L
.63174 .09558 L
.63302 .06312 L
.63365 .04735 L
.63395 .03991 L
.63423 .03354 L
.63449 .02866 L
.63462 .02687 L
.63476 .02576 L
.6349 .0258 L
.63505 .02707 L
.6352 .02913 L
.63533 .03145 L
.63649 .0562 L
.63772 .08089 L
.63886 .09955 L
Mistroke
.63993 .11256 L
.64046 .11721 L
.64102 .1209 L
.64133 .12233 L
.6415 .12293 L
.64165 .12338 L
.64178 .12369 L
.64193 .12393 L
.64209 .1241 L
.64223 .12416 L
.64238 .12413 L
.64246 .12407 L
.64255 .12398 L
.6427 .12374 L
.64285 .12343 L
.64301 .12296 L
.64317 .12243 L
.64352 .12088 L
.64414 .11692 L
.64473 .11184 L
.64589 .0986 L
.64712 .08051 L
.64934 .04212 L
.64994 .03198 L
.65025 .0277 L
.65033 .02675 L
.65042 .02588 L
.6505 .02525 L
.65058 .02485 L
.65067 .02464 L
.65075 .02469 L
.65084 .02501 L
.65094 .02563 L
.65102 .02636 L
.6511 .02718 L
.65128 .02939 L
.65192 .03912 L
.65436 .07471 L
.65554 .08724 L
.65614 .09197 L
.65648 .09418 L
.65679 .09586 L
.65706 .09706 L
.65735 .09809 L
.65751 .09854 L
.65766 .09888 L
.6578 .09914 L
.65795 .09934 L
.65808 .09945 L
.65821 .09952 L
Mistroke
.65834 .09952 L
.65846 .09947 L
.6586 .09936 L
.65875 .09917 L
.65889 .09892 L
.65902 .09864 L
.65934 .09771 L
.65964 .09657 L
.6603 .09306 L
.66089 .08892 L
.6615 .08358 L
.66375 .05738 L
.6649 .04153 L
.66553 .03291 L
.66584 .02903 L
.66597 .0275 L
.66612 .02602 L
.66626 .02491 L
.66639 .02418 L
.66653 .02382 L
.66668 .02396 L
.66676 .02424 L
.66684 .02469 L
.667 .02583 L
.66728 .02872 L
.66834 .04189 L
.66956 .05679 L
.67071 .06863 L
.67135 .07397 L
.67203 .07866 L
.67234 .08034 L
.67266 .08186 L
.67294 .08295 L
.67324 .08389 L
.6734 .08429 L
.67354 .0846 L
.67368 .08484 L
.67383 .08504 L
.67397 .08517 L
.6741 .08524 L
.67423 .08527 L
.67438 .08524 L
.67453 .08516 L
.67461 .08508 L
.67469 .085 L
.67485 .08477 L
.67502 .08446 L
.67533 .0837 L
.6756 .08279 L
.67615 .08045 L
Mistroke
.67674 .07711 L
.67781 .06907 L
.68016 .0448 L
.68141 .03048 L
.68177 .02684 L
.68194 .02532 L
.68203 .02468 L
.68211 .02418 L
.68226 .02347 L
.68241 .02314 L
.6825 .02315 L
.68259 .02332 L
.68267 .0236 L
.68275 .02397 L
.68289 .02486 L
.68304 .02604 L
.68332 .02858 L
.68394 .03517 L
.6852 .04857 L
.68639 .05958 L
.6875 .06754 L
.68809 .0708 L
.68873 .0734 L
.68905 .07439 L
.68936 .07509 L
.68954 .07539 L
.6897 .0756 L
.68978 .07568 L
.68988 .07576 L
.68997 .07582 L
.69006 .07585 L
.69021 .07586 L
.6903 .07584 L
.69038 .07581 L
.69052 .07572 L
.69068 .07557 L
.69082 .07538 L
.69094 .07517 L
.69124 .07455 L
.69155 .07366 L
.69184 .07266 L
.69249 .06975 L
.69368 .06226 L
.69479 .0532 L
.69608 .04084 L
.69671 .03446 L
.69729 .02878 L
.69756 .02637 L
.69781 .02444 L
.69794 .02366 L
Mistroke
.69808 .02303 L
.69823 .02263 L
.69837 .02258 L
.69852 .02286 L
.69866 .0234 L
.69881 .02425 L
.69897 .02537 L
.69954 .03024 L
.70073 .04155 L
.70202 .05255 L
.70265 .05713 L
.70325 .06087 L
.70383 .06388 L
.70437 .06609 L
.70489 .06764 L
.70517 .06827 L
.70543 .0687 L
.70558 .06888 L
.70571 .06901 L
.70586 .0691 L
.70602 .06915 L
.70616 .06915 L
.70629 .06911 L
.70643 .06903 L
.70658 .0689 L
.70673 .06873 L
.70689 .06849 L
.70722 .06783 L
.70752 .06703 L
.70781 .06612 L
.70845 .0635 L
.70914 .05985 L
.71157 .04165 L
.71282 .03048 L
.71314 .02779 L
.71343 .02546 L
.7137 .02369 L
.71385 .02291 L
.71399 .0224 L
.71412 .02213 L
.71427 .02211 L
.71443 .02242 L
.71457 .02298 L
.71473 .02381 L
.71488 .02472 L
.7152 .02713 L
.71653 .03833 L
.71764 .04711 L
.71883 .05484 L
.71951 .05834 L
Mistroke
.72012 .06082 L
.72042 .06178 L
.72074 .06264 L
.72105 .06327 L
.72133 .06369 L
.72148 .06386 L
.72162 .06399 L
.72175 .06406 L
.7219 .06411 L
.72205 .06411 L
.72213 .0641 L
.72221 .06407 L
.72236 .06399 L
.7225 .06387 L
.72264 .06372 L
.72278 .06353 L
.72303 .0631 L
.72331 .06251 L
.7236 .06171 L
.72423 .05952 L
.72489 .05647 L
.7261 .04934 L
.7285 .03081 L
.72916 .02572 L
.72949 .02356 L
.72958 .02307 L
.72968 .0226 L
.72977 .02224 L
.72986 .02198 L
.72994 .0218 L
.73002 .0217 L
.7301 .02167 L
.73019 .02175 L
.73027 .02189 L
.73036 .02212 L
.73051 .02272 L
.73066 .02349 L
.73082 .02444 L
.73111 .02638 L
.73232 .03567 L
.73361 .04503 L
.73483 .0522 L
.73537 .05471 L
.73594 .05688 L
.73622 .05775 L
.73652 .05857 L
.73681 .05917 L
.73707 .0596 L
.73721 .05979 L
.73737 .05996 L
Mistroke
.73746 .06003 L
.73754 .06009 L
.73762 .06013 L
.7377 .06016 L
.73778 .06018 L
.73786 .06019 L
.73801 .06018 L
.73816 .06013 L
.7383 .06005 L
.73843 .05995 L
.73856 .05981 L
.73881 .05946 L
.73911 .05892 L
.73938 .05829 L
.73997 .05653 L
.74053 .05436 L
.74169 .04841 L
.74293 .04037 L
.74409 .03185 L
.7446 .02808 L
.74489 .02604 L
.74515 .02429 L
.7453 .02342 L
.74544 .02269 L
.74558 .0221 L
.7457 .02168 L
.74584 .02141 L
.74598 .02133 L
.74613 .02148 L
.74628 .02188 L
.74643 .02243 L
.74658 .02319 L
.74686 .02484 L
.7475 .02922 L
.74971 .04422 L
.75093 .05059 L
.75162 .05331 L
.75195 .05435 L
.75226 .05519 L
.75256 .05584 L
.75288 .0564 L
.75302 .05659 L
.75317 .05676 L
.7533 .05687 L
.75344 .05697 L
.75352 .05701 L
.7536 .05704 L
.75375 .05707 L
.75383 .05706 L
.75391 .05705 L
Mistroke
.754 .05703 L
.75409 .057 L
.75423 .05691 L
.75437 .05679 L
.75453 .05663 L
.75469 .05642 L
.75499 .0559 L
.75532 .0552 L
.75591 .05352 L
.7566 .05088 L
.75724 .04794 L
.75966 .03294 L
.76079 .02524 L
.76106 .02359 L
.76136 .02213 L
.76144 .02179 L
.76152 .02152 L
.76168 .02116 L
.76182 .02103 L
.76198 .02112 L
.76214 .02145 L
.76223 .02173 L
.76231 .02205 L
.76266 .02378 L
.76329 .02772 L
.76449 .03575 L
.76568 .04289 L
.76632 .04621 L
.76692 .04885 L
.76748 .05088 L
.76799 .05235 L
.76826 .05299 L
.76855 .05355 L
.76871 .05381 L
.76886 .05401 L
.769 .05417 L
.76915 .05431 L
.76931 .05441 L
.76945 .05448 L
.76959 .05452 L
.76972 .05452 L
.76987 .0545 L
.77001 .05444 L
.77009 .0544 L
.77017 .05434 L
.77032 .05421 L
.7706 .05389 L
.77089 .05342 L
.77142 .05227 L
.77203 .05044 L
Mistroke
.7726 .04828 L
.77391 .04194 L
.77616 .02789 L
.77677 .02407 L
.77711 .02232 L
.77728 .02163 L
.77743 .02116 L
.77756 .02089 L
.7777 .02077 L
.77784 .02083 L
.77799 .02109 L
.77814 .02155 L
.77831 .02221 L
.7786 .02369 L
.77995 .032 L
.78117 .0393 L
.78243 .04552 L
.78299 .0477 L
.7836 .04964 L
.78388 .05037 L
.78418 .05103 L
.78444 .0515 L
.78472 .05191 L
.78489 .05209 L
.78504 .05222 L
.78519 .05232 L
.78534 .05239 L
.78548 .05242 L
.78561 .05243 L
.78576 .0524 L
.78591 .05234 L
.78607 .05225 L
.78622 .05213 L
.78655 .05174 L
.78687 .05122 L
.78722 .0505 L
.78785 .04878 L
.78842 .04678 L
.78962 .04139 L
.79073 .03524 L
.79203 .02731 L
.79266 .02361 L
.79294 .02223 L
.79308 .02162 L
.79324 .02109 L
.79339 .02073 L
.79353 .02056 L
.79367 .02056 L
.7938 .02072 L
.79393 .02101 L
Mistroke
.79405 .02139 L
.79433 .02254 L
.7955 .02921 L
.79679 .03672 L
.79799 .0427 L
.79908 .04686 L
.7997 .04856 L
.80026 .04969 L
.80058 .05014 L
.80073 .05031 L
.80087 .05044 L
.80102 .05055 L
.80111 .0506 L
.80119 .05063 L
.80128 .05066 L
.80137 .05068 L
.80145 .05068 L
.80154 .05068 L
.8017 .05065 L
.80184 .05058 L
.80192 .05054 L
.80201 .05048 L
.80217 .05034 L
.80247 .04999 L
.80275 .04956 L
.80331 .04837 L
.80392 .04665 L
.80501 .04247 L
.8075 .02916 L
.8081 .02569 L
.80873 .02235 L
.80891 .02156 L
.809 .02122 L
.80909 .02095 L
.80925 .02057 L
.80933 .02044 L
.80942 .02037 L
.80957 .02039 L
.80972 .0206 L
.80981 .02079 L
.80988 .02101 L
.81006 .02161 L
.81065 .0245 L
.8113 .02818 L
.81248 .03484 L
.81372 .04089 L
.81487 .04526 L
.81545 .04688 L
.81575 .04755 L
.81608 .04816 L
Mistroke
.81626 .04845 L
.81643 .04867 L
.81661 .04886 L
.81677 .049 L
.81693 .04911 L
.81708 .04918 L
.81724 .04921 L
.81733 .04922 L
.81741 .04922 L
.81756 .04919 L
.8177 .04914 L
.81783 .04907 L
.81797 .04897 L
.81829 .04865 L
.81858 .04823 L
.81911 .04721 L
.81968 .04575 L
.82086 .04151 L
.82217 .03531 L
.8233 .02906 L
.82392 .02557 L
.8245 .02257 L
.8248 .02129 L
.82497 .02075 L
.82512 .02039 L
.82521 .02027 L
.82529 .0202 L
.82538 .02019 L
.82548 .02024 L
.82564 .02049 L
.82573 .02071 L
.82581 .02096 L
.82611 .02212 L
.82639 .02343 L
.82701 .02676 L
.82822 .03335 L
.8295 .03953 L
.83012 .04203 L
.83071 .04403 L
.83123 .04548 L
.83153 .04616 L
.83181 .04671 L
.8321 .04718 L
.83237 .04752 L
.8325 .04766 L
.83265 .04778 L
.83281 .04788 L
.83296 .04795 L
.83309 .04798 L
.83323 .048 L
Mistroke
.83337 .04799 L
.83351 .04795 L
.83364 .0479 L
.83376 .04783 L
.83402 .04761 L
.83431 .04727 L
.83458 .04687 L
.83519 .04562 L
.83578 .044 L
.83642 .04185 L
.83882 .03056 L
.84008 .02375 L
.84039 .02227 L
.84072 .02096 L
.84082 .02066 L
.84091 .02042 L
.84099 .02026 L
.84108 .02013 L
.84117 .02006 L
.84126 .02005 L
.84135 .02009 L
.84142 .02018 L
.84158 .02049 L
.84166 .0207 L
.84175 .02097 L
.84205 .02214 L
.84272 .02546 L
.84393 .03194 L
.84512 .03766 L
.84625 .04203 L
.84684 .04383 L
.84715 .04462 L
.84748 .04534 L
.84776 .04584 L
.84807 .04629 L
.84835 .0466 L
.84848 .04672 L
.84861 .04681 L
.84876 .04689 L
.84885 .04693 L
.84893 .04695 L
.84902 .04697 L
.8491 .04697 L
.84924 .04696 L
.84939 .04693 L
.84952 .04687 L
.84967 .04679 L
.84983 .04667 L
.85015 .04633 L
.85045 .0459 L
Mistroke
.85113 .04453 L
.85174 .04288 L
.85239 .04067 L
.85359 .03564 L
.85583 .02418 L
.85637 .02165 L
.85652 .02108 L
.85668 .02057 L
.85681 .02024 L
.85696 .02 L
.85704 .01994 L
.85712 .01992 L
.85721 .01996 L
.85729 .02004 L
.85744 .02031 L
.85753 .02053 L
.8576 .02076 L
.85821 .02325 L
.85952 .02997 L
.86074 .0359 L
.86193 .04061 L
.86244 .04227 L
.86301 .04375 L
.86333 .04444 L
.86362 .04497 L
.86392 .04542 L
.86421 .04573 L
.86436 .04587 L
.86453 .04598 L
.86469 .04606 L
.86483 .0461 L
.86499 .04612 L
.86507 .04611 L
.86515 .0461 L
.86524 .04608 L
.86532 .04606 L
.86541 .04602 L
.8655 .04597 L
.86563 .04588 L
.86578 .04576 L
.86605 .04547 L
.86637 .04501 L
.86666 .0445 L
.86727 .04313 L
.8679 .04127 L
.86896 .03731 L
.87012 .03199 L
.87134 .02577 L
.87194 .02282 L
.87221 .02167 L
Mistroke
.87249 .02063 L
.87257 .02041 L
.87265 .02021 L
.8728 .01994 L
.87289 .01985 L
.87297 .01982 L
.87313 .01989 L
.87321 .02 L
.8733 .02016 L
.87346 .02056 L
.87363 .02112 L
.87382 .02186 L
.87502 .02771 L
.87625 .03375 L
.87755 .03912 L
.87865 .04253 L
.87896 .04325 L
.87928 .04391 L
.87957 .04439 L
.87987 .0448 L
.88002 .04496 L
.88018 .04511 L
.88033 .04522 L
.88047 .0453 L
.88055 .04534 L
.88063 .04537 L
.88071 .04539 L
.88081 .0454 L
.88088 .04541 L
.88097 .0454 L
.88112 .04538 L
.88128 .04532 L
.88136 .04528 L
.88144 .04523 L
.88174 .04498 L
.88202 .04467 L
.88231 .04425 L
.88286 .04319 L
.88337 .04191 L
.88453 .03806 L
.88678 .02779 L
.88739 .02469 L
.88773 .02307 L
.88805 .02168 L
.88832 .0207 L
.88847 .02026 L
.88861 .01996 L
.88875 .01978 L
.88891 .01974 L
.88899 .01978 L
Mistroke
.88907 .01988 L
.88922 .02016 L
.88931 .02037 L
.88939 .02063 L
.88955 .02117 L
.88991 .02266 L
.89057 .02579 L
.89179 .03178 L
.89296 .03688 L
.8936 .03925 L
.89421 .04115 L
.8948 .04263 L
.89512 .04327 L
.89545 .04383 L
.89575 .04424 L
.89603 .04452 L
.89617 .04462 L
.89631 .04471 L
.89645 .04477 L
.89657 .04481 L
.8967 .04483 L
.89684 .04483 L
.89697 .04481 L
.89709 .04478 L
.89723 .04472 L
.89738 .04463 L
.89765 .0444 L
.89794 .04406 L
.89824 .04361 L
.89878 .04256 L
.89938 .04105 L
.89992 .03938 L
.90114 .03468 L
.90334 .02417 L
.90392 .0216 L
.90408 .02097 L
.90424 .02047 L
.90438 .0201 L
.90453 .01982 L
.90466 .01969 L
.90481 .01968 L
.90496 .01983 L
.9051 .02009 L
.90524 .02044 L
.90536 .02083 L
.90563 .02186 L
.90813 .03362 L
.90925 .03806 L
.90986 .04006 L
.91043 .04162 L
Mistroke
.91105 .04293 L
.91138 .04345 L
.91173 .04389 L
.91204 .04416 L
.91219 .04425 L
.91228 .04429 L
.91236 .04433 L
.9125 .04436 L
.91266 .04438 L
.9128 .04436 L
.91294 .04433 L
.91307 .04428 L
.91322 .0442 L
.91336 .0441 L
.91349 .04398 L
.91381 .04363 L
.91411 .0432 L
.9147 .04206 L
.91535 .0404 L
.9165 .03649 L
.91757 .03195 L
.91885 .02584 L
.91948 .02288 L
.91975 .0217 L
.92005 .0206 L
.92018 .02022 L
.92032 .0199 L
.92046 .0197 L
.92058 .01962 L
.92071 .01964 L
.92086 .0198 L
.921 .02008 L
.92113 .02042 L
.9214 .02134 L
.9217 .02256 L
.9223 .02536 L
.92353 .03125 L
.92483 .0367 L
.92594 .04033 L
.92657 .04188 L
.92715 .04295 L
.92744 .04336 L
.9276 .04353 L
.92776 .04369 L
.9279 .0438 L
.92806 .0439 L
.9282 .04396 L
.92833 .04401 L
.92847 .04403 L
.9286 .04403 L
Mistroke
.92872 .04401 L
.92885 .04398 L
.92899 .04392 L
.92914 .04383 L
.92941 .04361 L
.92969 .0433 L
.93 .04286 L
.93055 .04181 L
.93121 .04015 L
.93182 .03827 L
.93429 .02783 L
.93491 .02485 L
.9355 .02218 L
.93575 .02116 L
.93602 .02027 L
.93616 .01993 L
.93632 .01968 L
.93646 .01957 L
.93659 .0196 L
.93673 .01975 L
.93688 .02003 L
.93702 .0204 L
.93715 .02082 L
.93766 .02288 L
.93881 .02831 L
.93995 .03348 L
.94118 .03818 L
.94185 .04019 L
.94246 .04167 L
.94304 .04274 L
.94334 .04313 L
.9435 .04332 L
.94366 .04346 L
.9438 .04357 L
.94395 .04366 L
.94409 .04373 L
.94422 .04376 L
.94436 .04378 L
.94451 .04378 L
.94459 .04377 L
.94467 .04375 L
.94482 .0437 L
.94495 .04364 L
.94509 .04354 L
.94538 .04328 L
.94565 .04296 L
.9459 .04259 L
.94651 .04142 L
.94717 .03973 L
.94837 .03566 L
Mistroke
.95061 .02562 L
.95116 .02305 L
.95147 .02175 L
.95175 .02068 L
.95192 .0202 L
.952 .01998 L
.95209 .0198 L
.95218 .01967 L
.95225 .01959 L
.9524 .01955 L
.95255 .01965 L
.95264 .01977 L
.95271 .01991 L
.95286 .02026 L
.95301 .02072 L
.95422 .026 L
.95555 .03217 L
.95676 .03702 L
.9579 .04053 L
.95854 .04194 L
.9589 .04255 L
.95923 .043 L
.9595 .04329 L
.95966 .04341 L
.95981 .04351 L
.95997 .04358 L
.96011 .04362 L
.96026 .04364 L
.96034 .04364 L
.96043 .04364 L
.96051 .04362 L
.96059 .0436 L
.96074 .04354 L
.96089 .04345 L
.96107 .04333 L
.96138 .04301 L
.96167 .04263 L
.96222 .04167 L
.9628 .0403 L
.96412 .03605 L
.96533 .03103 L
.96644 .0258 L
.96705 .02296 L
.96735 .02169 L
.96763 .02068 L
.96777 .02025 L
.96792 .01987 L
.96808 .01963 L
.96817 .01956 L
.96824 .01953 L
Mistroke
.96833 .01955 L
.96842 .01962 L
.96857 .01986 L
.96866 .02006 L
.96874 .02027 L
.96893 .02084 L
.97013 .02612 L
.97131 .03162 L
.97258 .03677 L
.9732 .03883 L
.97378 .04047 L
.97435 .04176 L
.97488 .04266 L
.97518 .04304 L
.97534 .0432 L
.97551 .04334 L
.9756 .04341 L
.97569 .04346 L
.97577 .0435 L
.97587 .04354 L
.97602 .04358 L
.97611 .04359 L
.97619 .0436 L
Mfstroke
1 0 0 r
[ ] 0 setdash
.03968 .01472 m
.03968 .04364 L
s
.05556 .01472 m
.05556 .04379 L
s
.07143 .01472 m
.07143 .04403 L
s
.0873 .01472 m
.0873 .04437 L
s
.10317 .01472 m
.10317 .04483 L
s
.11905 .01472 m
.11905 .04541 L
s
.13492 .01472 m
.13492 .04611 L
s
.15079 .01472 m
.15079 .04697 L
s
.16667 .01472 m
.16667 .04799 L
s
.18254 .01472 m
.18254 .04922 L
s
.19841 .01472 m
.19841 .05067 L
s
.21429 .01472 m
.21429 .05241 L
s
.23016 .01472 m
.23016 .0545 L
s
.24603 .01472 m
.24603 .05704 L
s
.2619 .01472 m
.2619 .06016 L
s
.27778 .01472 m
.27778 .06407 L
s
.29365 .01472 m
.29365 .06908 L
s
.30952 .01472 m
.30952 .07576 L
s
.3254 .01472 m
.3254 .08509 L
s
.34127 .01472 m
.34127 .0992 L
s
.35714 .01472 m
.35714 .12341 L
s
.37302 .01472 m
.37302 .17683 L
s
.38889 .01472 m
.38889 .42846 L
s
.40476 .01472 m
.40476 .32573 L
s
.42063 .01472 m
.42063 .0617 L
s
.43651 .01472 m
.43651 .15573 L
s
.45238 .01472 m
.45238 .22118 L
s
.46825 .01472 m
.46825 .08568 L
s
.48413 .01472 m
.48413 .05342 L
s
.5 .01472 m
.5 .33241 L
s
.51587 .01472 m
.51587 .05342 L
s
.53175 .01472 m
.53175 .08568 L
s
.54762 .01472 m
.54762 .22118 L
s
.56349 .01472 m
.56349 .15573 L
s
.57937 .01472 m
.57937 .0617 L
s
.59524 .01472 m
.59524 .32573 L
s
.61111 .01472 m
.61111 .42846 L
s
.62698 .01472 m
.62698 .17683 L
s
.64286 .01472 m
.64286 .12341 L
s
.65873 .01472 m
.65873 .0992 L
s
.6746 .01472 m
.6746 .08509 L
s
.69048 .01472 m
.69048 .07576 L
s
.70635 .01472 m
.70635 .06908 L
s
.72222 .01472 m
.72222 .06407 L
s
.7381 .01472 m
.7381 .06016 L
s
.75397 .01472 m
.75397 .05704 L
s
.76984 .01472 m
.76984 .0545 L
s
.78571 .01472 m
.78571 .05241 L
s
.80159 .01472 m
.80159 .05067 L
s
.81746 .01472 m
.81746 .04922 L
s
.83333 .01472 m
.83333 .04799 L
s
.84921 .01472 m
.84921 .04697 L
s
.86508 .01472 m
.86508 .04611 L
s
.88095 .01472 m
.88095 .04541 L
s
.89683 .01472 m
.89683 .04483 L
s
.9127 .01472 m
.9127 .04437 L
s
.92857 .01472 m
.92857 .04403 L
s
.94444 .01472 m
.94444 .04379 L
s
.96032 .01472 m
.96032 .04364 L
s
.97619 .01472 m
.97619 .0436 L
s
.015 w
.03968 .04364 Mdot
.05556 .04379 Mdot
.07143 .04403 Mdot
.0873 .04437 Mdot
.10317 .04483 Mdot
.11905 .04541 Mdot
.13492 .04611 Mdot
.15079 .04697 Mdot
.16667 .04799 Mdot
.18254 .04922 Mdot
.19841 .05067 Mdot
.21429 .05241 Mdot
.23016 .0545 Mdot
.24603 .05704 Mdot
.2619 .06016 Mdot
.27778 .06407 Mdot
.29365 .06908 Mdot
.30952 .07576 Mdot
.3254 .08509 Mdot
.34127 .0992 Mdot
.35714 .12341 Mdot
.37302 .17683 Mdot
.38889 .42846 Mdot
.40476 .32573 Mdot
.42063 .0617 Mdot
.43651 .15573 Mdot
.45238 .22118 Mdot
.46825 .08568 Mdot
.48413 .05342 Mdot
.5 .33241 Mdot
.51587 .05342 Mdot
.53175 .08568 Mdot
.54762 .22118 Mdot
.56349 .15573 Mdot
.57937 .0617 Mdot
.59524 .32573 Mdot
.61111 .42846 Mdot
.62698 .17683 Mdot
.64286 .12341 Mdot
.65873 .0992 Mdot
.6746 .08509 Mdot
.69048 .07576 Mdot
.70635 .06908 Mdot
.72222 .06407 Mdot
.7381 .06016 Mdot
.75397 .05704 Mdot
.76984 .0545 Mdot
.78571 .05241 Mdot
.80159 .05067 Mdot
.81746 .04922 Mdot
.83333 .04799 Mdot
.84921 .04697 Mdot
.86508 .04611 Mdot
.88095 .04541 Mdot
.89683 .04483 Mdot
.9127 .04437 Mdot
.92857 .04403 Mdot
.94444 .04379 Mdot
.96032 .04364 Mdot
.97619 .0436 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`006Oooool3o`0000Cooooo0_l0000iooooo`?o0000>oooool2o`0003cooooo0ol0000ioooo
o`?o00001?ooool2o`0000Cooooo000Jooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo0000=oooool01Ol0003ooooooooooooooooo000003Wooooo00Co0000oooooooooooo0000>_oo
ool01Ol0003ooooooooooooooooo000003Wooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00003ooooo`004_ooool5o`0000?ooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool0000aooooo`Go00001Oooool00ol0003oooooooooo`0gooooo`04o`000?ooooooooooo`00
03kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000?ooooo000Jooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000>oooool0
0ol0003oooooooooo`0gooooo`04o`000?ooooooooooo`0003kooooo00?o0000ooooooooool0=ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo000Jooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo0000=oooool4o`0003[ooooo00Co0000oooooooooooo
0000>_ooool4o`0003[ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003oooo
o`006Oooool2o`0000Cooooo00Co0000oooooooooooo0000=oooool00ol0003oooooooooo`0koooo
o`04o`000?ooooooooooo`0003[ooooo00?o0000ooooooooool0>_ooool2o`0000Cooooo00Co0000
oooooooooooo00000oooool001[ooooo00?o0000ooooooooool00oooool2o`0003Sooooo1Ol0000j
ooooo`;o0000>oooool5o`0003Wooooo00?o0000ooooooooool00oooool2o`0000Cooooo003ooooo
ob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Eoooooooo00002ol00001
ooooo`005Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`03ooooo`7o00000Oooool000kooooo0_l00005ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0mooooo`03
o`000?oooooooooo03cooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`03ooooo`7o
00000Oooool000gooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`22ooooo`03
o`000?oooooooooo087ooooo0Ol00001ooooo`003Oooool01?l0003oooooooooool00004ooooo`;o
00002?ooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo
003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_ooool01Ooo003ooooooooooooo
ooooo`0000?ooooo00Goo`00ooooooooooooooooool00004ooooo`05ool00?oooooooooooooooooo
00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_ooool01Ooo
003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oo
oooooooo00;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo
00001?ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003
ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oo
oooooooooooooooo00000oooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo
00000oooool01Ooo003oooooooooooooooooo`0000Cooooo00Goo`00ooooooooooooooooool00003
ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ooooo`05ool00?oo
oooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00oooooooo
ool00_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00004
ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo
00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00oooooooo
ool00_ooool2o`00007ooooo000=ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool01Oooool00ol00?ooooooool00004ooooo`09ool00?oooooo003ooooooooo003oooooo`00oooo
ooooo`0000?ooooo00Koo`00ooooool00?oo003oool00?ooool2o`00o`03oooooooo003ooooo00;o
oooo00Woo`00ooooool00?ooooooool00?oooooo003ooooooooo00000_ooool00ol00?ooooooool0
0003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000Co
oooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool0
0ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooo
ooooooooo`0000Cooooo00Goo`00o`00ooooooooooooool00003ooooo`05ool00?oooooooooooooo
oooo00000oooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00000oooool0
1Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_ooool01Ooo003ooooooooo
ooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00004ooooo`05ool00?oooooooooooooo
oooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_ooool0
1Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool0
0?oooooooooo00;ooooo00Woo`00ooooooooooooooooool00?oooooo003ooooooooo00000_ooool0
0ol00?ooo`00ooooo`03ooooo`0=ool00?oooooooooooooooooo003oooooo`00ooooooooo`00oooo
ool00?ooooooool00003ooooo`03ool00?oooooooooo00;ooooo00Woo`00ooooooooooooooooool0
0?oooooo003ooooooooo00001Oooool1o`00007ooooo000=ooooo`04o`000?ooooooooooo`0000Co
oooo00?o0000ooooooooool01Oooool2o`00o`03ool00?oooooo003o00;ooooo01;oo`00o`00ool0
0?ooooooool00?oooooo003ooooooooo003oooooo`00ooooooooo`00ooooool00?ooooooool00?oo
ool2o`00o`0@oooooooo003oooooo`00ooooooooo`00ooooool00?ooooooool00?oooooo003ooooo
oooo003oooooo`00o`;ooooo00Goo`00ooooool00?ooooooool00003ooooo`0:ool00?oooooo003o
oooooooo003oooooo`00ooooooooo`00ooooo`;o003o00Koooooool00?oooooo003ooooooooo0003
ooooo`09ool00?oooooo003ooooooooo003oooooo`00ooooooooo`0000Cooooo00Goo`00oooooooo
ooooooooool00003ooooo`05ool00?oooooooooooooooooo00001?ooool01Ooo003o003ooooooooo
ooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo
00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool01_oo
003ooooooooooooooooo003oool000?ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool0
0?oooooooooo00;ooooo00Woo`00ooooooooooooooooool00?oooooo003ooooooooo00000oooool0
1_oo003oooooo`00ooooooooo`00ooooo`;o003o00[oooooool00?oooooo003ooooooooo003ooooo
o`00ooooooooo`000oooool01_oo003oooooo`00ool00?ooo`00ooooo`;o003o00koooooool00?oo
oooo003ooooooooo003oooooo`00ooooooooo`00ooooool00?ooooooool000;ooooo00Co003ooooo
oooo003o003o0_ooool03ooo003oooooo`00ooooooooo`00ooooool00?ooooooool00?oooooo003o
oooooooo003oooooo`00o`02ooooo`09ool00?l00?oo003ooooooooo003oooooo`00ooooooooo`00
00Gooooo0Ol00001ooooo`003Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo
00Kooooo00?o003oool00?ooool00_l00?l00oooooooo`00o`00o`02ooooo`0=ool00?oooooo003o
oooooooo003oooooo`00ooooooooo`00ooooool00?ooooooool00002ooooo`0Ao`00ooooooooo`00
ooooool00?ooooooool00?oooooo003ooooooooo003oooooo`00ooooooooo`00ooooool00?l00_oo
ool04Ooo003o003oo`00ooooooooo`00ooooool00?ooooooool00?oooooo003ooooooooo003ooooo
o`00ooooooooo`0000;ooooo01?o003ooooooooo003oooooo`00ooooooooo`00ooooool00?oooooo
ool00?oooooo003ooooooooo003oooooo`00ooooooooo`0000Cooooo00Goo`00oooooooooooooooo
ool00003ooooo`05ool00?oooooooooooooooooo00001?ooool01Ooo003oooooooooooooooooo`00
00?ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00Goo`00
ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003ooooo
ooooo`02o`00o`05ool00?oooooooooooooooooo00000oooool01ooo003oooooooooooooooooo`00
ooooool00?l00_ooool04_oo003o003oo`00ooooooooo`00ooooool00?ooooooool00?oooooo003o
oooooooo003oooooo`00ooooooooo`00ooooo`;o003o00?oooooool00?l00?l00_ooool01_oo003o
ooooo`00ooooooooo`00ooooo`;o003o00Koo`00ooooool00?oo003oool00?ooool2o`00o`03oooo
oooo003o003o00;ooooo00Goo`00ooooool00?ooooooool00002ooooo`08o`00oooo003ooooooooo
ool00?ooooooool00?l00?l2ooooo`0:ool00?l00?oooooooooooooo003oooooo`00ooooooooo`00
ooooo`;o003o00Koo`00ooooool00?oo003ooooooooo0002o`00o`06oooooooo003oooooo`00oooo
ooooo`001Oooool1o`00007ooooo000>ooooo`;o00001Oooool00ol0003oooooooooo`05ooooo`;o
003o00Koo`00ooooool00?oo003ooooooooo0003ooooo`06ool00?l00?oooooooooooooo003ooooo
0_l00?l01ooo003oooooo`00ool00?ooo`00ooooool00?l00_ooool03_oo003o003oo`00oooooooo
o`00o`00oooooooo003oool00?oooooo003ooooooooo003ooooo0_l00?l01_ooooooo`00o`00ool0
0?ooooooool000;o003o00Ooooooool00?oooooo003ooooooooo003ooooo00;o003o01?oo`00oooo
oooooooo003ooooooooo003oooooo`00ooooooooo`00ooooool00?ooooooool00?oooooo003ooooo
oooo003ooooo00;o003o00koo`00ooooool00?oo003ooooooooo003oooooo`00ooooooooo`00oooo
ool00?ooooooool000?ooooo00?oo`00ooooool00?l00_ooool01Ooo003oooooooooooooooooo`00
00?ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00Goo`00
ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003ooooo
ooooo`02o`00o`05ool00?oooooo003ooooooooo00000oooool01Ooo003oooooo`00ooooooooo`00
00;ooooo00Co003ooooooooo003o003o0_ooool02Ooo003oooooo`00ooooooooo`00ooooool00?oo
ooooool00003ooooo`03ool00?oooooo003o00;ooooo00Goo`00o`00ool00?ooooooool00002o`00
o`03oooooooo003ooooo00;o003o00Ooo`00ooooooooooooooooool00?oooooo003o00;ooooo00Go
o`00o`00ool00?ooooooool00003ooooo`06ool00?oooooo003oo`00oooo003ooooo0_l00?l01_oo
ooooo`00o`00ool00?ooooooool000?ooooo00Koo`00o`00oooooooo003oool00?ooool2o`00o`06
ool00?oooooo003oo`00ooooooooo`000_l00?l01_ooooooo`00ooooool00?ooooooool000Gooooo
0Ol00001ooooo`005Oooool00ol0003oooooooooo`04ooooo`09o`00ooooooooooooool00?l00?oo
ooooo`00ooooooooo`0000;ooooo00?o003oool00?l00?l00_ooool01Ooo003o003oooooool00?oo
o`0000;ooooo00Co003oool00?oooooo003o0_ooool01Ooo003o003oo`00ooooooooo`0000;ooooo
00Ko003oool00?ooooooooooo`00oooo0002ooooo`03o`00ooooooooo`0000;o003o00Koooooool0
0?l00?ooooooo`00oooo0003ooooo`07ool00?oooooo003ooooooooo003oooooo`00o`02ooooo`05
ool00?l00?oooooooooooooo00000_l00?l00oooooooo`00ooooo`02ooooo`06ool00?oooooo003o
o`00oooo003ooooo0_l00?l02_ooooooo`00ooooool00?ooooooool00?oooooo003ooooooooo0003
ooooo`03ool00?oooooo003o00;ooooo00Goo`00o`00ool00?ooooooool00003ooooo`05ool00?oo
oooooooooooooooo00000oooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo
00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00[oo`00oooooooooooo003ooooooooo
003oooooo`00ooooooooo`000oooool01Ooo003oooooo`00ooooooooo`0000;ooooo00?o003ooooo
oooo00000_l00?l00oooooooo`00ooooo`02ooooo`06ool00?oooooo003ooooooooo003ooooo0_l0
0?l00ooo003oooooooooo`02ooooo`05ool00?l00?oo003ooooooooo00000_l00?l00oooooooo`00
o`00o`02o`00o`06ool00?oooooo003ooooooooo003ooooo0_l00?l01oooooooo`00oooooooooooo
003oool00?l00?l00_ooool01ooo003oooooo`00ooooooooo`00ooooool00?l00_ooool01Ooo003o
003oooooool00?ooo`0000;ooooo00?o003oool00?l00?l00_ooool01_oo003o003oooooool00?oo
o`00ooooo`;o003o00[oooooool00?ooooooooooo`00oooo003o003oooooool00?ooo`001Oooool1
o`00007ooooo000Eooooo`;o00001Oooool01?l00?oooooooooooooo0004ooooo`0:ool00?l00?oo
ooooo`00oooo003o003oooooool00?ooo`00o`00o`;ooooo00Koo`00ooooooooooooooooool00?l0
0?l2ooooo`06o`00oooo003o003oooooool00?ooo`000_ooool01_l00?ooo`00o`00oooooooo003o
ool000;ooooo00Co003ooooooooo003o003o0_ooool02_oo003oooooooooool00?ooo`00o`00oooo
oooo003oool00?l00?l2ooooo`03ool00?oooooo003o00;ooooo00Woo`00o`00ooooooooooooool0
0?oooooo003ooooooooo00000_ooool01ol00?ooo`00ooooool00?ooooooool00?ooool00_l00?l0
2_ooooooo`00ooooool00?ooooooool00?oooooo003ooooooooo0003ooooo`03ool00?oooooo003o
00;ooooo00Goo`00ooooool00?ooooooool00003ooooo`05ool00?oooooooooooooooooo00000ooo
ool00ooo003o003oooooo`02ooooo`05ool00?ooooooooooo`00oooo00000oooool01Ooo003ooooo
ooooooooooooo`0000?ooooo00Koo`00oooooooooooo003ooooooooo0003ooooo`0:ool00?oooooo
oooooooooooo003oooooo`00ooooooooo`00ooooo`;o003o00ooooooool00?l00?oo003ooooooooo
003oooooo`00ooooooooo`00ooooool00?ooooooool00?ooool00_l00?l02ooo003oooooo`00ool0
0?ooooooool00?oooooo003ooooooooo003o003o00;ooooo00Koo`00oooooooooooo003oool00?oo
ool2o`00o`06ool00?ooooooooooo`00ooooooooo`000_ooool01ol00?ooo`00o`00oooooooo003o
ool00?l00?l00_ooool00ooo003o003oooooo`02ooooo`0=ool00?ooooooooooo`00oooo003o003o
ooooool00?ooo`00o`00oooooooo003oool00003ooooo`0;ool00?ooooooooooooooool00?ooo`00
o`00oooooooo003oool00?l00?l00_ooool00ooo003oooooooooo`02ooooo`;o00000Oooool001Go
oooo00?o0000ooooooooool01_ooool3ool00005oooooooo003oo`00ool00?ooool00ooo0002oooo
o`?oo`0000Coooooool00?oo003oo`000_ooool01_oo003o003ooooooooooooo003oool000?ooooo
00koo`00o`00oooooooo003oool00?l00?ooooooo`00oooo003o003oooooool00?ooooooool000?o
oooo00koo`00ooooooooooooooooool00?l00?ooooooo`00oooo003o003oooooool00?ooo`00oooo
o`;o003o00_oooooool00?l00?oo003ooooooooo003oooooo`00ooooooooo`00ooooo`02o`00o`06
ool00?ooooooooooo`00oooo003ooooo0_l00?l02_ooooooo`00o`00ool00?ooooooool00?oooooo
003ooooooooo0003ooooo`0:ool00?ooooooooooo`00ooooooooo`00ooooool00?ooooooool000?o
oooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?l00?oooooo00;ooooo00Goo`00oooo
ooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool01_oo003ooooooooo
oooooooo003oool000?ooooo00_oo`00ooooooooooooooooool00?oooooo003ooooooooo003ooooo
o`00o`02ooooo`05ool00?oooooo003ooooooooo00000_l00?l01oooooooo`00oooooooooooo003o
ool00?ooool00_l00?l01_oo003oooooo`00ool00?ooooooool000;o003o00Koooooool00?l00?oo
ooooo`00oooo0003ooooo`0Bool00?l00?ooooooo`00oooo003oooooo`00oooooooo003oool00?l0
0?ooooooo`00oooo003o003oooooool00?ooo`000_ooool00ol00?ooo`00ooooo`02ooooo`03o`00
oooo003ooooo00;ooooo00?oo`00ooooooooool00ooo00001Oooooooo`00ool00?oo003ooooo00?o
o`0000Goooooool00?oo003oo`00ooooo`03ool000;ooooo0ooo0004ooooo`7o00000Oooool001Go
oooo00?o0000ooooooooool01_ooool3ool00005oooooooo003oo`00ool00?ooool00ooo0002oooo
o`?oo`0000Goooooool00?oo003oo`00ooooo`03ool00005oooooooo003oo`00ool00?ooool00ooo
0002ooooo`?oo`000_ooool00ooo003o003oooooo`02ooooo`0=ool00?ooooooooooo`00oooo003o
003oooooool00?ooo`00o`00oooooooo003oool00002ooooo`03o`00oooo003ooooo00;o003o00Oo
ooooool00?l00?oo003ooooooooo003o003o00;ooooo00Koo`00ooooool00?oo003oool00?ooool2
o`00o`03ool00?oooooooooo00;ooooo00Woo`00ooooooooooooooooool00?oooooo003ooooooooo
00000oooool02_oo003oooooo`00ool00?ooooooool00?oooooo003ooooooooo0003ooooo`05ool0
0?oooooooooooooooooo00000oooool00ooo003o003oooooo`02ooooo`05ool00?ooooooooooo`00
oooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00[oo`00ooooool00?ooooooo`00
oooo003oooooo`00ooooooooo`000oooool01_oo003oooooo`00ooooooooo`00ooooo`;o003o00?o
ooooool00?l00?l00_ooool01Ooo003o003oo`00ooooooooo`0000?ooooo00Koo`00ooooool00?oo
ooooool00?ooool2o`00o`03oooooooo003o003o00;ooooo00Koo`00oooooooooooo003oool00?l0
0?l2ooooo`0;ool00?l00?oooooooooooooo003oooooo`00oooooooo003oool00?l00?l00_ooool0
0ooo003oooooooooo`03ool00005oooooooo003oo`00ool00?ooool00ooo00001?ooooooo`00ool0
0?oo0002ooooo`?oo`0000Goooooool00?oo003oo`00ooooo`03ool00005oooooooo003oo`00ool0
0?ooool00ooo0002ooooo`?oo`001?ooool1o`00007ooooo000Eooooo`03o`000?oooooooooo00Ko
oooo0ooo00001Oooooooo`00ool00?oo003ooooo00?oo`000_ooool3ool00005oooooooo003oo`00
ool00?ooool00ooo00001Oooooooo`00ool00?oo003ooooo00?oo`000_ooool3ool00005oooooooo
003oo`00ool00?ooool00ooo00001?ooooooo`00ool00?oo0002ooooo`0:o`00oooo003ooooooooo
ool00?ooo`00o`00oooooooo003oool000?ooooo00_o003oool00?ooooooooooo`00oooo003o003o
ooooool00?ooo`00o`00o`02ooooo`06ool00?oooooo003oo`00oooo003ooooo0_l00?l02_oooooo
o`00ooooool00?ooooooool00?oooooo003ooooooooo0003ooooo`06ool00?oooooo003oo`00oooo
ooooo`000oooool02Ooo003oooooooooooooooooo`00ooooool00?ooooooool00003ooooo`03ool0
0?l00?oooooo00;ooooo00Goo`00oooooooooooo003oool00003ooooo`05ool00?oooooooooooooo
oooo00000oooool01_oo003oooooo`00oooooooo003oool000;o003o00?oooooool00?ooool00_oo
ool01Ooo003oooooo`00ooooooooo`0000;ooooo00Co003ooooooooo003o003o0_ooool02Ooo003o
003oooooooooooooo`00o`00oooooooo003oool00003ooooo`03ool00?oooooo003o00;ooooo00go
o`00o`00ooooooooooooool00?l00?ooooooo`00oooo003o003oooooool00?ooo`0000;ooooo0ooo
00001Oooooooo`00ool00?oo003ooooo00?oo`000_ooool3ool00005oooooooo003oo`00ool00?oo
ool00ooo00001?ooooooo`00ool00?oo0002ooooo`?oo`0000Goooooool00?oo003oo`00ooooo`03
ool00005oooooooo003oo`00ool00?ooool00ooo0002ooooo`?oo`001?ooool1o`00007ooooo000E
ooooo`03o`000?oooooooooo01_ooooo0ooo00001Oooooooo`00ool00?oo003ooooo00?oo`000_oo
ool3ool00005oooooooo003oo`00ool00?ooool00ooo00001?ooooooo`00ool00?oo0002ooooo`?o
o`000_ooool01_oo003o003oooooooooooooo`00o`00o`?ooooo00Woo`00o`00ooooooooooooool0
0?l00?ooooooo`00oooo00000oooool01_oo003oooooo`00ool00?ooo`00ooooo`;o003o00[ooooo
ool00?l00?oo003ooooooooo003oooooo`00ooooooooo`000oooool02_oo003oooooo`00ool00?oo
ooooool00?oooooo003ooooooooo0003ooooo`05ool00?oooooo003ooooooooo00000_l00?l3ool0
00?ooooo00?oo`00oooooooo00000_oo0002ooooo`03o`00oooo003ooooo00;o003o00[oo`00oooo
ooooooooooooool00?oooooo003oooooool00?ooo`000_l00?l00oooooooo`00ooooo`02ooooo`05
ool00?oooooo003ooooooooo00000_ooool00ol00?ooooooool00002o`00o`03oooooooo003o003o
00;ooooo00Goo`00o`00oooooooo003oool00002ooooo`03o`00oooo003ooooo00?ooooo00_oo`00
o`00oooooooo003oool00?l00?ooooooo`00oooo003o003oooooo`03ool00005oooooooo003oo`00
ool00?ooool00ooo00001?ooooooo`00ool00?oo0002ooooo`?oo`0000Goooooool00?oo003oo`00
ooooo`03ool00004oooooooo003oo`00ool001kooooo0Ol00001ooooo`005Oooool00ol0003ooooo
ooooo`0/ooooo`?oo`0000Goooooool00?oo003oo`00ooooo`03ool000;ooooo0ooo00001?oooooo
o`00ool00?oo0002ooooo`03ool00?l00?oooooo00;ooooo00Woo`00ooooooooooooooooool00?l0
0?ooooooo`00oooo00000_ooool01ol00?ooo`00ooooool00?ooooooool00?ooool00_l00?l02_oo
ooooo`00o`00ool00?ooooooool00?oooooo003ooooooooo0003ooooo`03ool00?oooooo003o00;o
oooo00Goo`00ooooool00?ooooooool00003ooooo`07ool00?oooooo003ooooooooo003oooooo`00
o`03ool000?ooooo00?oo`00oooooooo00000_oo0002ooooo`03o`00oooo003ooooo00;o003o00Oo
o`00ooooooooooooooooool00?oooooo003o00;ooooo00Goo`00o`00ooooooooooooool00003oooo
o`06ool00?oooooo003ooooooooo003ooooo0_l00?l01_ooooooo`00o`00ool00?ooooooool000;o
oooo00[o003oool00?l00?ooooooo`00oooo003o003oooooool00?ooo`000oooool01_l00?ooo`00
oooooooooooo003oool000;ooooo0ooo00001Oooooooo`00ool00?oo003ooooo00?oo`0000Gooooo
ool00?oo003oo`00ooooo`03ool002oooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`0i
ooooo`?oo`0000Goooooool00?oo003oo`00ooooo`03ool000;ooooo00Ko003oool00?oooooooooo
o`00oooo0002ooooo`06o`00oooo003o003oooooool00?ooo`000_ooool00ol00?ooo`00ooooo`02
o`00o`0:oooooooo003o003oo`00ooooooooo`00ooooool00?ooooooool000?ooooo00?oo`00oooo
ooooool00ooo0002ooooo`03o`00oooo003ooooo00;ooooo00Ooo`00ooooooooooooooooool00?oo
oooo003o00?oo`000oooool00ooo003oooooool00002ool00005ooooool00?oo003oool00?ooool0
0_l00?l01Ooo003oooooooooooooooooo`0000;ooooo0ooo0003ooooo`0;ool00?oooooooooooooo
oooo003oooooo`00ooooooooo`00ooooool00?l00_ooool02Ooo003oooooo`00ooooooooo`00o`00
oooooooo003oool00002ooooo`03o`00oooo003o003o00;ooooo00Ooo`00o`00ooooooooooooo`00
oooo003ooooo00?oo`000_ooool3ool00004oooooooo003oo`00ool003_ooooo0Ol00001ooooo`00
5Oooool2o`0003kooooo0ooo00001Oooooooo`00ool00?oo003ooooo00?oo`000_ooool00ol00?oo
o`00ooooo`02ooooo`05ool00?l00?ooooooo`00oooo00000_ooool00ol00?ooo`00ooooo`03oooo
o`09ool00?oooooooooooooooooo003oooooo`00ooooooooo`0000?ooooo00?oo`00ooooooooool0
0ooo0002ooooo`03o`00oooo003ooooo00;ooooo00Goo`00ooooool00?ooooooool00002o`00o`03
ooooool00?oo003o00?ooooo00?oo`00ooooooooool00_l00?l2ooooo`06o`00oooo003ooooooooo
ool00?ooo`000oooool00ooo003oooooo`00o`03ool00004ooooool00?ooooooool000?ooooo00Ko
o`00ooooool00?ooooooool00?ooool2o`00o`0:oooooooo003oooooo`00ooooooooo`00o`00oooo
oooo003oool000?ooooo00Ooo`00o`00ooooooooooooool00?l00?oooooo00?oo`0000Coooooool0
0?oo003oo`000_ooool3ool003kooooo0_l00001ooooo`005Oooool00ol0003oooooooooo`11oooo
o`?oo`0000Goooooool00?oo003oo`00ooooo`03ool000?ooooo00Woo`00o`00oooooooo003oool0
0?l00?ooooooo`00oooo00001?ooool01Ooo003oooooooooooooooooo`0000?ooooo00Ooo`00oooo
ooooooooooooool00?oooooo003o00?oo`000oooool01Ooo003oooooooooooooooooo`0000;o003o
00Goooooool00?l00?oo003oooooo`02o`00o`?ooooo00?oo`00ooooooooool00_l00?l3ooooo`05
ool00?oooooooooooooooooo00000oooool00ooo003oooooo`00o`03ool000;o003o00?oooooool0
0?ooool00_ooool01_oo003oooooooooooooooooo`00ooooo`;o003o00?oooooool00?l00?l00_oo
ool02Ooo003o003oooooool00?ooo`00o`00oooooooo003oool00002ooooo`?oo`0000Goooooool0
0?oo003oo`00ooooo`03ool004Cooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`15oooo
o`?oo`0000Coooooool00?oo003oo`000_ooool00ol00?ooo`00o`00o`02ooooo`06ool00?l00?oo
ooooo`00oooo003ooooo0_l00?l02_ooooooo`00o`00ool00?ooooooool00?oooooo003ooooooooo
0003ooooo`03ool00?oooooo003o00;o003o1?ooool02_oo003oooooooooooooooooo`00o`00oooo
oooo003oool00?l00?l2ooooo`;o003o0oooool01?oo003oooooooooool00?l2ooooo`07o`00oooo
ooooo`00ooooool00?ooooooool00003ooooo`03ool00?l00?oooooo00;ooooo0ol00?l00ooooooo
o`00ooooo`02ooooo`05ool00?oooooooooooooooooo00000_ooool02?l00?ooooooool00?l00?oo
ooooo`00oooo003o003o0_ooool01Ooo003o003oooooooooooooo`0000;ooooo0ooo00001?oooooo
o`00ool00?oo0018ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0BOooool3ool000;o
oooo0ooo0002ooooo`06ool00?l00?oooooooooooooo003ooooo0_l00?l02_ooooooo`00o`00ool0
0?ooooooool00?oooooo003ooooooooo0003ooooo`05ool00?oooooo003oooooool00?l00oooool0
0ol00?ooo`00ooooo`02ooooo`07ool00?l00?oooooooooooooo003oooooo`00o`06ooooo`03ool0
0?oooooooooo00;o003o00Goooooo`00ooooooooo`00ooooo`02o`00o`06ool00?oooooooooooooo
oooo003o003o1?ooool2o`00o`03oooooooo003ooooo00;ooooo00Koo`00ooooool00?oo003oool0
0?ooool2o`00o`06oooooooo003o003oooooool00?ooo`000_ooool01?l00?ooo`00o`00ooooool3
ool00004oooooooo003oo`00ool004cooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`1>
ooooo`?oo`000_ooool01Ooo003oooooooooooooooooo`0000;o003o00?oooooo`00oooo00000_l0
0?l01_ooooooo`00ooooool00?ooooooool000?ooooo00?oo`00ooooooooool01Oooool00ol00?oo
o`00ooooo`02ooooo`07ool00?l00?oooooooooooooo003oooooo`00o`02ooooo`05o`00oooooooo
oooooooooooo00000oooool02Ol00?ooooooo`00ooooooooo`00o`00oooooooo003oool00003oooo
o`03ool00?oooooooooo00?ooooo00Co003oooooooooooooo`000oooool01ooo003oooooo`00ool0
0?ooo`00ooooool00?l00_ooool01Ooo003oooooooooool00?ooo`0000;ooooo00Co003oool00?oo
oooooooo0ooo001@ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0C_ooool3ool00004
oooooooo003oo`00ool000;ooooo00?oo`00ooooooooool00_ooool02Ooo003o003ooooooooooooo
o`00ooooool00?ooooooool00003ooooo`03ool00?oooooooooo00Gooooo00?o003oool00?ooool0
0_ooool00ooo003oooooooooo`03ool00004ooooool00?oo003oo`00o`?ooooo00Ooo`00oooooooo
ooooooooo`00oooooooo003o00?oo`0000?oooooo`00oooo00000oooool00ooo003oooooooooo`04
ooooo`03o`00ooooooooo`0000?ooooo00Ooo`00ooooool00?oo003oool00?oooooo003o00;ooooo
00Goo`00oooooooooooo003oool00002ooooo`?oo`0000Coooooool00?oo003oo`00D?ooool1o`00
007ooooo000Eooooo`;o0000Doooool3ool000;ooooo00?oo`00ooooooooool00_ooool02Ooo003o
ooooooooooooooooo`00ooooool00?ooooooool00003ooooo`03ool00?oooooo003o00Kooooo00Oo
o`00ooooooooooooooooool00?l00?oooooo00?oo`0000Coooooo`00ool00?oo003o0oooool00ooo
003oooooooooo`02o`00o`;ooooo0ooo0002ooooo`06ool00?oooooooooooooooooo003o003o1Ooo
ool00ol00?ooooooool00003ooooo`06ool00?ooooooooooo`00oooo003ooooo0_l00?l00ooooooo
o`00o`00o`02ooooo`03ool00?oooooooooo00?oo`00Doooool2o`00007ooooo000Eooooo`03o`00
0?oooooooooo05;ooooo0ooo0002ooooo`0>ool00?l00?ooooooooooool00?ooo`00o`00oooooooo
003oool00?oooooo003ooooooooo0003ooooo`03ool00?oooooo003o00Kooooo00Ooo`00oooooooo
ooooooooool00?l00?oooooo00?oo`0000Coooooo`00ool00?oo003o0oooool01Ooo003ooooooooo
ool00?oooooo00;o003o0ooo0002ooooo`06ool00?oooooooooooooooooo003o003o1Oooool00ol0
0?ooooooool00003ooooo`05ool00?oooooooooooooooooo00000_ooool01?l00?ooooooool00?l0
0?l2ooooo`03ool00?oooooooooo00?oo`00E?ooool1o`00007ooooo000Eooooo`03o`000?oooooo
oooo05Oooooo00[oo`00o`00ooooooooooooo`00oooo003o003oooooool00?ooo`000_l00?l00ooo
ooooo`00ooooo`02ooooo`03ool00?oooooo003o00Gooooo00?o003oool00?ooool00_ooool01?oo
003o003oooooool00?l9ooooo`06ool00?ooooooooooo`00oooooooo003o0oooool01?l00?oooooo
o`00oooo0003ooooo`03ool00?l00?oooooo00Cooooo00?o003ooooooooo00000oooool01Ooo003o
ooooo`00ool00?ooo`0000;ooooo00?o003ooooooooo00000_ooool00ol00?ooo`00ooooo`1Hoooo
o`7o00000Oooool001Gooooo00?o0000ooooooooool0E_ooool3ool000;ooooo00Ko003oool00?l0
0?ooooooo`00oooo0002o`00o`03oooooooo003ooooo00;ooooo00?oo`00ooooool00?l01Oooool0
0ol00?ooo`00ooooo`02ooooo`03ool00?l00?oooooo00Oooooo00Co003oooooooooooooo`002?oo
ool01?l00?ooooooo`00oooo0003ooooo`03ool00?oooooooooo00Kooooo00Koo`00oooooooooooo
ooooool00?ooool2o`00o`03ool00?oooooo003o00;ooooo00?oo`00oooooooo00000_oo001Ioooo
o`7o00000Oooool000Kooooo1Ol00003ooooo`;o00001Oooool00ol0003oooooooooo`1Fooooo`?o
o`000oooool01_oo003o003oooooool00?ooo`00o`00o`;ooooo00Goo`00ooooooooooooooooool0
0007ooooo`03o`00oooo003ooooo00;ooooo00?oo`00ooooooooool01oooool01?l00?oooooooooo
oooo000:ooooo`03o`00oooo003ooooo00;ooooo00?oo`00ooooooooool01_ooool01_oo003ooooo
ooooooooooooo`00ooooo`;o003o00Ooo`00ooooool00?oo003ooooooooo003ooooo00?oo`00FOoo
ool1o`00007ooooo0007ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`1Fooooo`?oo`000oooool01_oo003oooooooooooooooooo`00o`00
o`;ooooo00Ooo`00ooooooooooooooooool00?oooooo003o00Gooooo00?o003oool00?ooool00_oo
ool00ooo003oooooooooo`07ooooo`04o`00ooooooooooooool000;ooooo00?o003oooooooooool0
1Oooool00ol00?ooo`00ooooo`02ooooo`03ool00?l00?oooooo00Gooooo00?o003oool00?ooool0
0_ooool01_oo003oooooo`00ool00?ooo`00o`00o`;ooooo00?o003oool00?ooool00ooo001Ioooo
o`7o00000Oooool000Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00004oooo
o`03o`000?oooooooooo05_ooooo00[o003oool00?ooooooooooo`00oooo003oooooo`00oooooooo
o`000oooool00ooo003oooooo`00o`06ooooo`06ool00?oooooooooooooooooo003o003o2?ooool0
1?l00?oooooooooooooo0002ooooo`03o`00oooooooooooo00Kooooo00Koo`00oooooooooooooooo
ool00?l00?l6ooooo`03o`00oooo003ooooo00;ooooo00Goo`00ooooooooooooooooool00004oooo
o`03ool00?oooooooooo05_ooooo0Ol00001ooooo`002Oooool01Ol0003ooooooooooooooooo0000
00;ooooo00?o0000ooooooooool00_ooool2o`0005cooooo00[o003oool00?ooooooooooo`00oooo
003oooooo`00ooooooooo`000oooool00ooo003oooooo`00o`05ooooo`03o`00oooo003ooooo00;o
oooo00?oo`00o`00ooooool02_ooool00ooo003oooooo`00o`08ooooo`03o`00oooo003ooooo00;o
oooo00?oo`00o`00ooooool01Oooool00ol00?ooo`00ooooo`02ooooo`05ool00?oooooo003ooooo
oooo00000oooool00ol00?ooo`00ooooo`1Kooooo`;o00000Oooool000Kooooo00Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0Foooool0
2_l00?ooo`00oooooooooooo003oool00?l00?ooooooo`00oooo0003ooooo`03ool00?oooooo003o
00Gooooo00?o003oool00?ooool00_ooool00ooo003o003oooooo`0:ooooo`03ool00?oooooooooo
00Sooooo00?o003oool00?ooool00_ooool00ooo003o003oooooo`06ooooo`06ool00?oooooooooo
oooooooo003ooooo0_l00?l01_oo003o003ooooooooooooo003oool005gooooo0Ol00001ooooo`00
1_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00001?ooool00ol0
003oooooooooo`1Jooooo`?oo`000_ooool01_l00?ooo`00o`00oooooooo003oool000?ooooo00?o
o`00ooooooooool01Oooool00ol00?ooo`00ooooo`02ooooo`03ool00?oooooooooo00Oooooo00Co
003oooooooooooooo`002_ooool00ol00?ooo`00ooooo`02ooooo`03ool00?oooooooooo00Kooooo
00Koo`00ooooooooooooooooool00?ooool2o`00o`03ool00?l00?oooooo00?oo`00GOooool1o`00
007ooooo0007ooooo`?o00001?ooool2o`0000Gooooo00?o0000ooooooooool0F_ooool3ool000?o
oooo00Goo`00o`00ooooooooooooool00003ooooo`03ool00?oooooooooo00Gooooo00?o003oool0
0?ooool00_ooool00ooo003oooooooooo`07ooooo`06o`00ooooooooooooool00?oooooo003o2?oo
ool00ol00?ooo`00ooooo`02ooooo`03ool00?l00?oooooo00Gooooo00?o003oool00?ooool00_oo
ool01ooo003oooooo`00ool00?ooo`00o`00ooooool00ooo001Mooooo`7o00000Oooool001Gooooo
00?o0000ooooooooool0F_ooool3ool000?ooooo00Goo`00oooooooooooo003oool00003ooooo`03
ool00?l00?oooooo00Kooooo00Koo`00ooooooooooooooooool00?l00?l8ooooo`06o`00oooooooo
ooooool00?oooooo003o2Oooool01_oo003oooooooooooooooooo`00o`00o`Kooooo00?o003oool0
0?ooool00_ooool01ooo003oooooooooooooooooo`00o`00ooooool00ooo001Mooooo`7o00000Ooo
ool001Gooooo00?o0000ooooooooool0Goooool01_l00?ooo`00oooooooooooo003oool000?ooooo
00?oo`00o`00ooooool01_ooool01_oo003oooooooooooooooooo`00o`00o`_ooooo00?oo`00oooo
ool00?l02Oooool01_oo003oooooooooooooooooo`00o`00o`Kooooo00?o003oool00?ooool00_oo
ool01Ooo003oooooooooooooooooo`0006;ooooo0Ol00001ooooo`005Oooool2o`00063ooooo00Ko
003oool00?l00?ooooooo`00oooo0003ooooo`03ool00?l00?oooooo00Gooooo00?o003oool00?oo
ool00_ooool00ooo003o003oooooo`0:ooooo`03ool00?oooooo003o00Sooooo00?o003oool00?oo
ool00_ooool00ooo003o003oooooo`05ooooo`03o`00oooo003ooooo00;ooooo00Koo`00ooooool0
0?oo003oool00?l00?mPooooo`;o00000Oooool001Gooooo00?o0000ooooooooool0Goooool01_l0
0?ooo`00o`00oooooooo003oool000?ooooo00?oo`00ooooooooool01Oooool00ol00?ooo`00oooo
o`02ooooo`03ool00?l00?oooooo00Oooooo00Co003oooooooooooooo`002_ooool00ol00?ooo`00
ooooo`02ooooo`03ool00?oooooooooo00Kooooo00Koo`00ooooooooooooooooool00?ooool2o`00
o`03ool00?l00?oooooo063ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`1Pooooo`05
ool00?l00?oooooooooooooo00000oooool00ooo003oooooooooo`06ooooo`05ool00?oooooooooo
oooooooo00002Oooool01_l00?oooooooooooooo003oooooo`00o`Sooooo00?o003oool00?ooool0
0_ooool00ooo003oooooooooo`05ooooo`03o`00oooo003ooooo00;ooooo00Koo`00o`00oooooooo
003oool00?l00?mQooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0H?ooool01Ooo003o
003oooooooooooooo`0000?ooooo00?oo`00o`00ooooool01_ooool01_oo003ooooooooooooooooo
o`00o`00o`Sooooo00Ko003oooooooooooooo`00ooooool00?l9ooooo`06ool00?oooooooooooooo
oooo003o003o1_ooool00ol00?ooo`00ooooo`02ooooo`06ool00?ooooooooooo`00oooo003o003o
HOooool1o`00007ooooo000Eooooo`03o`000?oooooooooo05oooooo00Ko003oool00?oooooooooo
o`00oooo0003ooooo`03ool00?l00?oooooo00Kooooo00Koo`00ooooooooooooooooool00?l00?l8
ooooo`06o`00ooooooooooooool00?oooooo003o2Oooool01_oo003oooooooooooooooooo`00o`00
o`Kooooo00?o003oool00?ooool00_ooool01Ooo003oooooooooooooooooo`0006;ooooo0Ol00001
ooooo`005Oooool00ol0003oooooooooo`1Oooooo`06o`00oooo003o003oooooool00?ooo`000ooo
ool00ooo003o003oooooo`04ooooo`?oo`000oooool00ooo003o003oooooo`0:ooooo`03ool00?oo
oooo003o00Wooooo00?oo`00ooooooooool00ooo0006ooooo`03o`00oooo003ooooo00;ooooo00Go
o`00o`00oooooooo003oool0001Rooooo`7o00000Oooool001Gooooo0_l0001Pooooo`06o`00oooo
003o003oooooool00?ooo`000oooool00ooo003o003oooooo`04ooooo`?oo`000oooool00ooo003o
003oooooo`07ooooo`04o`00ooooooooooooool000_ooooo00?oo`00ooooooooool00ooo0007oooo
o`0:ool00?oooooooooooooooooo003o003oooooool00?ooo`00o`00of3ooooo0_l00001ooooo`00
5Oooool00ol0003oooooooooo`1Oooooo`03o`00oooo003o003o00;ooooo00Goo`00oooooooooooo
ooooool00006ooooo`?oo`000oooool00ooo003oooooooooo`07ooooo`04o`00ooooooooooooool0
00_ooooo00?oo`00ooooooooool00ooo0007ooooo`0:ool00?oooooooooooooooooo003o003ooooo
ool00?ooo`00o`00of7ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`1Pooooo`05ool0
0?l00?oooooooooooooo00000oooool00ooo003o003oooooo`0:ooooo`03ool00?oooooooooo00Oo
oooo00Ko003oooooooooooooo`00ooooool00?l9ooooo`05ool00?ooooooooooooooool00?l01ooo
ool00ol00?ooo`00ooooo`02ooooo`06ool00?l00?ooooooo`00oooo003o003oHOooool1o`00007o
oooo000Eooooo`03o`000?oooooooooo063ooooo00Goo`00oooooooooooo003oool00003ooooo`03
ool00?l00?oooooo00[ooooo00?oo`00ooooooooool01oooool01_l00?oooooooooooooo003ooooo
o`00o`Wooooo00Goo`00ooooooooooooooooo`00o`07ooooo`03o`00oooo003ooooo00;ooooo00Go
o`00ooooooooooooooooool0001Rooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0H?oo
ool01Ooo003o003oooooool00?ooo`0000?ooooo00?oo`00o`00ooooool01_ooool01Ol00?oooooo
ooooooooooooo`0000cooooo00?oo`00ooooool00?l02Oooool01Ooo003ooooooooooooooooo003o
00Oooooo00?o003oool00?ooool00_ooool01Ooo003o003oooooooooooooo`0006;ooooo0Ol00001
ooooo`005Oooool00ol0003oooooooooo`1Nooooo`?oo`000_ooool00ol00?ooo`00ooooo`02oooo
o`03ool00?l00?oooooo00Kooooo00Go003oooooooooooooooooool0000<ooooo`03ool00?oooooo
oooo00Wooooo00Goo`00ooooooooooooooooo`00o`08ooooo`07ool00?oooooooooooooooooo003o
003oooooo`03ool0067ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`1Nooooo`?oo`00
0_ooool00ol00?ooo`00ooooo`02ooooo`03ool00?oooooooooo00Kooooo00Go003ooooooooooooo
ooooool00009ooooo`04o`00ooooooooooooool000_ooooo00?oo`00ooooooooool02_ooool01ooo
003oooooooooooooooooo`00o`00ooooool00ooo001Qooooo`7o00000Oooool001Gooooo0_l0001O
ooooo`?oo`000oooool01Ooo003oooooooooooooooooo`0000Sooooo00Go003ooooooooooooooooo
ool00009ooooo`06o`00ooooooooooooool00?oooooo003o2Oooool01Ooo003ooooooooooooooooo
003o00Oooooo00?o003oool00?ooool00_ooool00ooo003o003oooooo`03ool0063ooooo0_l00001
ooooo`005Oooool00ol0003oooooooooo`1Sooooo`03o`00oooo003ooooo00;ooooo00?oo`00o`00
ooooool02_ooool00ooo003oooooooooo`07ooooo`06o`00ooooooooooooool00?oooooo003o2Ooo
ool01Ooo003ooooooooooooooooo003o00Oooooo00?o003oool00?ooool00_ooool00ooo003ooooo
ooooo`1Tooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0Hoooool00ol00?ooo`00oooo
o`02ooooo`03ool00?l00?oooooo00Kooooo00Go003oooooooooooooooooool0000<ooooo`03ool0
0?oooooo003o00Wooooo00Goo`00ooooooooooooooooo`00o`07ooooo`03o`00oooo003ooooo00;o
oooo00?oo`00ooooooooool0I?ooool1o`00007ooooo000Eooooo`03o`000?oooooooooo06?ooooo
00?o003oool00?ooool00_ooool00ooo003o003oooooo`06ooooo`05o`00oooooooooooooooooooo
00003?ooool00ooo003oooooo`00o`09ooooo`05ool00?ooooooooooooooool00?l01oooool00ol0
0?ooo`00ooooo`02ooooo`03ool00?l00?oooooo06Cooooo0Ol00001ooooo`002?ooool3o`0000?o
oooo0_l00005ooooo`03o`000?oooooooooo06?ooooo00?o003oool00?ooool00_ooool00ooo003o
ooooooooo`06ooooo`05o`00oooooooooooooooooooo00002Oooool01?l00?oooooooooooooo000;
ooooo`03ool00?oooooooooo00[ooooo00Koo`00ooooooooooooooooool00?l00?mUooooo`7o0000
0Oooool000Wooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0I?ooool01Ooo003oooooooooooooooooo`0000Sooooo00Go003ooooooooo
ooooooooool00009ooooo`06o`00ooooooooooooool00?oooooo003o2Oooool00ooo003ooooooooo
o`09ooooo`03o`00oooo003ooooo00;ooooo00?oo`00o`00ooooool0I?ooool1o`00007ooooo0006
ooooo`Go00000_ooool01?l0003oooooooooool00004ooooo`;o0000IOooool01_oo003ooooooooo
ooooooooo`00o`00o`_ooooo00?oo`00ooooooooool02?ooool01Ol00?ooooooool00?oooooo003o
00Wooooo00Goo`00ooooooooooooooooo`00o`07ooooo`03o`00oooo003ooooo00;ooooo00?oo`00
ooooooooool0Hoooool2o`00007ooooo0006ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`1Sooooo`03o`00oooo003ooooo00;ooooo00?o
o`00o`00ooooool02_ooool00ooo003oooooooooo`08ooooo`05o`00ooooooooo`00ooooool00?l0
2Oooool01Ooo003ooooooooooooooooo003o00Oooooo00?o003oool00?ooool00_ooool00ooo003o
ooooooooo`1Tooooo`7o00000Oooool000Oooooo00?o0000ooooool000000oooool01?l0003ooooo
ooooool00004ooooo`03o`000?oooooooooo06?ooooo00?o003oool00?ooool00_ooool00ooo003o
003oooooo`06ooooo`05o`00oooooooooooooooooooo00003?ooool00ooo003oooooo`00o`09oooo
o`05ool00?ooooooooooooooool00?l01oooool00ol00?ooo`00ooooo`02ooooo`03ool00?l00?oo
oooo06Cooooo0Ol00001ooooo`002?ooool2o`0000?ooooo00Co0000oooooooooooo00001?ooool0
0ol0003oooooooooo`1Sooooo`03o`00oooo003ooooo00;ooooo00?oo`00o`00ooooool01_ooool0
0ol00?ooooooooooo`03ool000Wooooo00?o003ooooooooo00002_ooool3ool000_ooooo00Koo`00
ooooooooooooooooool00?l00?mUooooo`7o00000Oooool000Wooooo00?o0000ooooooooool00_oo
ool2o`0000Gooooo00?o0000ooooooooool0I?ooool01Ooo003oooooooooooooooooo`0000Sooooo
00?o003oooooooooool00ooo0009ooooo`03o`00ooooooooo`0000[ooooo0ooo000;ooooo`06ool0
0?oooooooooooooooooo003o003oIOooool1o`00007ooooo000Eooooo`03o`000?oooooooooo06Co
oooo00Koo`00ooooooooooooooooool00?l00?l:ooooo`?oo`002Oooool01?l00?ooooooool00?l0
0?l9ooooo`?oo`000_ooool00ol00?ooooooooooo`05ooooo`03o`00oooo003ooooo00;ooooo00?o
o`00o`00ooooool0I?ooool1o`00007ooooo000Eooooo`03o`000?oooooooooo06?ooooo00?o003o
ool00?ooool00_ooool00ooo003o003oooooo`0:ooooo`03o`00oooooooooooo00Sooooo00Co003o
oooooooo003o003o3_ooool00ol00?ooooooooooo`05ooooo`03o`00oooo003ooooo00;ooooo00?o
o`00ooooooooool0I?ooool1o`00007ooooo000Eooooo`;o0000I?ooool00ol00?ooo`00ooooo`02
ooooo`03ool00?l00?oooooo00Oooooo00Co003ooooooooooooo003o3?ooool00ooo003o003ooooo
o`09ooooo`05o`00ooooooooooooooooool00?l01oooool00ol00?ooo`00ooooo`02ooooo`03ool0
0?l00?oooooo06?ooooo0_l00001ooooo`005Oooool00ol0003oooooooooo`1Sooooo`03o`00oooo
003ooooo00;ooooo00?oo`00o`00ooooool01oooool01?l00?ooooooooooool00?l<ooooo`03ool0
0?oooooooooo00Wooooo00Go003oooooooooooooooooo`00o`08ooooo`06ool00?oooooooooooooo
oooo003o003oIOooool1o`00007ooooo000Eooooo`03o`000?oooooooooo06?ooooo00?o003oool0
0?ooool00_ooool00ooo003oooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00?o003ooooo
oooo00002oooool00ol00?ooooooooooo`0:ooooo`06ool00?oooooooooooooooooo003o003oIOoo
ool1o`00007ooooo000Eooooo`03o`000?oooooooooo06Cooooo00Koo`00ooooooooooooooooool0
0?l00?l8ooooo`03o`00oooooooooooo00_ooooo00Co003ooooooooo003o003o2_ooool01?l00?oo
ooooooooool00?l8ooooo`03o`00oooo003ooooo00;ooooo00?oo`00o`00ooooool0I?ooool1o`00
007ooooo000Eooooo`03o`000?oooooooooo06?ooooo00?o003oool00?ooool00_ooool00ooo003o
003oooooo`0:ooooo`03o`00oooooooooooo00Sooooo00Co003ooooooooo003o003o3Oooool00ol0
0?ooooooooooo`06ooooo`03o`00oooo003ooooo00;ooooo00?oo`00ooooooooool0I?ooool1o`00
007ooooo000Eooooo`03o`000?oooooooooo06?ooooo00?o003oool00?ooool00_ooool00ooo003o
003oooooo`07ooooo`04o`00ooooooooooooo`00o`cooooo00?oo`00o`00ooooool03?ooool00ol0
0?ooooooooooo`06ooooo`03o`00oooo003ooooo00;ooooo00?oo`00ooooooooool0I?ooool1o`00
007ooooo000Eooooo`;o0000I?ooool00ol00?ooo`00ooooo`02ooooo`03ool00?l00?oooooo00Oo
oooo00Co003ooooooooooooo003o3?ooool00ooo003o003oooooo`0:ooooo`03o`00oooooooo003o
00Sooooo00?o003oool00?ooool00_ooool00ooo003o003oooooo`1Sooooo`;o00000Oooool001Go
oooo00?o0000ooooooooool0Hoooool00ol00?ooo`00ooooo`02ooooo`03ool00?oooooooooo00Oo
oooo00?o003oooooooooool02oooool00ol00?ooooooool0000<ooooo`03o`00oooooooooooo00Wo
oooo00Koo`00ooooooooooooooooool00?l00?mUooooo`7o00000Oooool001Gooooo00?o0000oooo
ooooool0I?ooool01Ooo003oooooooooooooooooo`0000Wooooo00?o003oooooooooool02oooool0
1?l00?ooooooool00?l00?l;ooooo`03o`00oooooooooooo00Wooooo00Koo`00oooooooooooooooo
ool00?l00?mUooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0I?ooool01_oo003ooooo
ooooooooooooo`00o`00o`[ooooo00?o003oooooooooool02Oooool01?l00?ooooooool00?l00?l=
ooooo`03o`00oooooooooooo00Oooooo00Goo`00ooooooooooooooooool0001Vooooo`7o00000Ooo
ool001Gooooo00?o0000ooooooooool0Hoooool00ol00?ooo`00ooooo`02ooooo`03ool00?l00?oo
oooo00Wooooo00?o003oooooooooool02Oooool01?l00?ooooooool00?l00?l=ooooo`03o`00oooo
oooooooo00Oooooo00Goo`00ooooooooooooooooool0001Vooooo`7o00000Oooool001Gooooo00?o
0000ooooooooool0Hoooool00ol00?ooo`00ooooo`02ooooo`03ool00?l00?oooooo00Oooooo00?o
003oooooool00?l03Oooool00ooo003o003oooooo`0:ooooo`03o`00oooooooo003o00Wooooo00Ko
o`00ooooooooooooooooool00?l00?mUooooo`7o00000Oooool001Gooooo0_l0001Tooooo`03o`00
oooo003ooooo00;ooooo00?oo`00ooooooooool01oooool00ol00?ooooooo`00o`0;ooooo`03o`00
ooooooooo`0000cooooo00?o003oooooooooool02Oooool01_oo003oooooooooooooooooo`00o`00
ofCooooo0_l00001ooooo`005Oooool00ol0003oooooooooo`1Tooooo`05ool00?oooooooooooooo
oooo00002Oooool00ol00?ooooooooooo`0;ooooo`03o`00ooooooooo`0000cooooo00?o003ooooo
ooooool02Oooool01_oo003oooooooooooooooooo`00o`00ofGooooo0Ol00001ooooo`005Oooool0
0ol0003oooooooooo`1Tooooo`06ool00?oooooooooooooooooo003o003o2_ooool00ol00?oooooo
ooooo`09ooooo`04o`00ooooooooo`00o`00o`_ooooo00?o003oooooool00?l02Oooool01_oo003o
ooooooooooooooooo`00o`00ofGooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`1Soooo
o`03o`00oooo003ooooo00;ooooo00?oo`00o`00ooooool02Oooool00ol00?ooooooooooo`09oooo
o`04o`00ooooooooo`00o`00o`gooooo00?o003oooooooooool01oooool01Ooo003ooooooooooooo
ooooo`0006Kooooo0Ol00001ooooo`001oooool3o`0000Cooooo0_l00005ooooo`03o`000?oooooo
oooo06?ooooo00?o003oool00?ooool00_ooool00ooo003oooooooooo`07ooooo`03o`00oooooooo
003o00gooooo00?oo`00o`00ooooool02_ooool00ol00?ooooooo`00o`09ooooo`06ool00?oooooo
oooooooooooo003o003oIOooool1o`00007ooooo0006ooooo`05o`000?ooooooooooooooool00000
0_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo06?ooooo00?o003oool00?oo
ool00_ooool00ooo003oooooooooo`08ooooo`;o003o3Oooool00ooo003oooooooooo`0:ooooo`03
o`00oooooooo003o00Wooooo00Koo`00ooooooooooooooooool00?l00?mUooooo`7o00000Oooool0
00Kooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooooooool0Hoooool00ol00?ooo`00ooooo`02ooooo`03ool00?oooooooooo00Sooooo00?o
003oooooooooool02oooool00ol00?ooo`00ooooo`0;ooooo`03o`00oooooooooooo00Wooooo00Ko
o`00ooooooooooooooooool00?l00?mUooooo`7o00000Oooool000Kooooo1?l00003ooooo`04o`00
0?ooooooooooo`0000Cooooo0_l0001Uooooo`05ool00?oooooooooooooooooo00002_ooool00ol0
0?ooooooooooo`0;ooooo`03o`00oooo003ooooo00_ooooo0ol00?l9ooooo`06ool00?oooooooooo
oooooooo003o003oI?ooool2o`00007ooooo0006ooooo`03o`000?oooooooooo00Cooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`1Sooooo`03o`00oooo003ooooo00;ooooo00?o
o`00ooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooo003ooooo00cooooo00?o
003oooooooooool02?ooool01Ooo003oooooooooooooooooo`0006Kooooo0Ol00001ooooo`001ooo
ool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0
Hoooool00ol00?ooo`00ooooo`02ooooo`03ool00?oooooooooo00Sooooo0_l00?l<ooooo`03o`00
oooo003ooooo00cooooo00?o003oooooooooool02?ooool01Ooo003oooooooooooooooooo`0006Ko
oooo0Ol00001ooooo`002?ooool2o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo06Cooooo
00Goo`00ooooooooooooooooool0000:ooooo`03o`00oooooooooooo00_ooooo00?o003oool00?oo
ool03?ooool00ol00?ooooooooooo`08ooooo`06ool00?oooooooooooooooooo003o003oIOooool1
o`00007ooooo000Eooooo`03o`000?oooooooooo06Cooooo00Goo`00ooooooooooooooooool0000H
ooooo`03o`00oooo003ooooo01Oooooo00Koo`00ooooooooooooooooool00?l00?mUooooo`7o0000
0Oooool001Gooooo00?o0000ooooooooool0I?ooool00ooo003oooooooooo`03ool001Oooooo00?o
003oool00?ooool05Oooool3ool000?ooooo00?oo`00o`00ooooool0I?ooool1o`00007ooooo000E
ooooo`;o0000IOooool00ooo003oooooooooo`03ool001Sooooo00?oo`00ooooooooool05?ooool3
ool000?ooooo00?oo`00ooooooooool0Hoooool2o`00007ooooo000Eooooo`03o`000?oooooooooo
06Cooooo00?oo`00ooooooooool00ooo000Fooooo`?oo`005_ooool3ool000?ooooo00?oo`00oooo
ooooool0I?ooool1o`00007ooooo000Eooooo`03o`000?oooooooooo06Cooooo00Goo`00oooooooo
ooooooooo`00o`0Gooooo`?oo`006?ooool01_l00?ooooooooooooooooooo`00o`00ofGooooo0Ol0
0001ooooo`005Oooool00ol0003oooooooooo`1Tooooo`03ool00?oooooooooo01Wooooo0ooo000L
ooooo`03ool00?l00?oooooo06Cooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`1Toooo
o`03ool00?oooooooooo01_ooooo00?o0000ooooooooool05_ooool01Ol00?oooooooooooooooooo
o`0006Kooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`1Tooooo`05ool00?oooooooooo
ooooool00?l06Oooool00ol0003oooooooooo`0Fooooo`05o`00oooooooooooooooooooo0000I_oo
ool1o`00007ooooo000Eooooo`03o`000?oooooooooo06Cooooo00Goo`00ooooooooooooooooo`00
o`0Iooooo`03o`000?oooooooooo01Kooooo00Go003oooooooooooooooooool0001Vooooo`7o0000
0Oooool001Gooooo0_l0001Uooooo`05ool00?ooooooooooooooool00?l06Oooool00ol0003ooooo
ooooo`0Fooooo`05o`00oooooooooooooooooooo0000IOooool2o`00007ooooo000Eooooo`03o`00
0?oooooooooo06Cooooo00Goo`00ooooooooooooooooo`00o`0Iooooo`03o`000?oooooooooo01[o
oooo00?oo`00ooooooooool0I?ooool1o`00007ooooo000Eooooo`03o`000?oooooooooo06Cooooo
00?oo`00ooooooooool06oooool00ol0003oooooooooo`0Jooooo`03ool00?oooooooooo06Cooooo
0Ol00001ooooo`005Oooool00ol0003oooooooooo`1Tooooo`03ool00?oooooooooo01_ooooo00?o
0000ooooooooool05_ooool01Ol00?ooooooooooooooooooo`0006Kooooo0Ol00001ooooo`005Ooo
ool00ol0003oooooooooo`1Tooooo`05ool00?ooooooooooooooool00?l06Oooool00ol0003ooooo
ooooo`0Fooooo`05o`00oooooooooooooooooooo0000I_ooool1o`00007ooooo000Eooooo`03o`00
0?oooooooooo06Cooooo00Goo`00ooooooooooooooooo`00o`0Iooooo`03o`000?oooooooooo01Ko
oooo00Go003oooooooooooooooooool0001Vooooo`7o00000Oooool001Gooooo0_l0001Uooooo`05
ool00?ooooooooooooooool00?l06Oooool00ol0003oooooooooo`0Jooooo`03ool00?oooooooooo
06?ooooo0_l00001ooooo`005Oooool00ol0003oooooooooo`1Tooooo`05ool00?oooooooooooooo
ool00?l06Oooool00ol0003oooooooooo`0Jooooo`03ool00?oooooooooo06Cooooo0Ol00001oooo
o`005Oooool00ol0003oooooooooo`1Tooooo`03ool00?oooooooooo01_ooooo00?o0000oooooooo
ool05_ooool01Ol00?ooooooooooooooooooo`0006Kooooo0Ol00001ooooo`005Oooool00ol0003o
ooooooooo`1Tooooo`05ool00?ooooooooooooooool00?l06Oooool00ol0003oooooooooo`0Foooo
o`05o`00oooooooooooooooooooo0000I_ooool1o`00007ooooo0007ooooo`?o00001?ooool2o`00
00Gooooo00?o0000ooooooooool0I?ooool01Ooo003ooooooooooooooooo003o01Wooooo00?o0000
ooooooooool05_ooool01Ol00?ooooooooooooooooooo`0006Kooooo0Ol00001ooooo`001_ooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
ooooo`1Tooooo`05ool00?ooooooooooooooool00?l06Oooool00ol0003oooooooooo`0Fooooo`05
o`00oooooooooooooooooooo0000I_ooool1o`00007ooooo0006ooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00004ooooo`;o0000IOooool01Ooo003ooooooooooooo
oooo003o01Wooooo00?o0000ooooooooool06_ooool00ooo003oooooooooo`1Sooooo`;o00000Ooo
ool000Oooooo0ol00003ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0I?oo
ool00ooo003oooooooooo`0Kooooo`03o`000?oooooooooo01Kooooo00Go003ooooooooooooooooo
ool0001Vooooo`7o00000Oooool000Kooooo00Go0000ooooooooooooooooo`000002ooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool0I?ooool00ooo003oooooooooo`0Kooooo`03
o`000?oooooooooo01Kooooo00Go003oooooooooooooooooool0001Vooooo`7o00000Oooool000Ko
oooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000
ooooooooool0I?ooool01Ooo003ooooooooooooooooo003o01Wooooo00?o0000ooooooooool05_oo
ool01Ol00?ooooooooooooooooooo`0006Kooooo0Ol00001ooooo`001oooool3o`0000Cooooo0_l0
0005ooooo`03o`000?oooooooooo06Cooooo00Goo`00ooooooooooooooooo`00o`0Iooooo`03o`00
0?oooooooooo01Kooooo00Go003oooooooooooooooooool0001Vooooo`7o00000Oooool001Gooooo
00?o0000ooooooooool0I?ooool01Ooo003ooooooooooooooooo003o01Wooooo00?o0000oooooooo
ool06_ooool00ooo003oooooooooo`1Tooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0
I?ooool00ooo003oooooooooo`0Kooooo`03o`000?oooooooooo01[ooooo00?oo`00ooooooooool0
I?ooool1o`00007ooooo000Eooooo`;o0000I?ooool3ool001cooooo00?o0000ooooooooool05_oo
ool00ol00?ooooooooooo`03ool006Cooooo0_l00001ooooo`005Oooool00ol0003oooooooooo`1S
ooooo`?oo`000_ooool00ol00?ooooooooooo`0Gooooo`03o`000?oooooooooo01Kooooo00?o003o
ooooooooool00ooo001Uooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0Hoooool3ool0
00;ooooo00?o003oooooooooool05oooool00ol0003oooooooooo`0Fooooo`03o`00oooooooooooo
00?oo`00IOooool1o`00007ooooo000Eooooo`03o`000?oooooooooo06Cooooo00Go003ooooooooo
ooooooooo`00o`0Iooooo`03o`000?oooooooooo01[ooooo00?o003oooooooooool0I?ooool1o`00
007ooooo000Eooooo`03o`000?oooooooooo06Cooooo00Go003oooooooooooooooooo`00o`0Ioooo
o`03o`000?oooooooooo01[ooooo00?o003oooooooooool0I?ooool1o`00007ooooo000Eooooo`03
o`000?oooooooooo08;ooooo00?o0000ooooooooool05oooool01?l00?ooooooooooool00?mVoooo
o`7o00000Oooool001Gooooo0_l0001Uooooo`05o`00ooooooooooooooooool00?l06Oooool00ol0
003oooooooooo`0Gooooo`03o`00oooooooooooo06Kooooo0_l00001ooooo`005Oooool00ol0003o
ooooooooo`1Tooooo`05o`00ooooooooooooooooool00?l06Oooool00ol0003oooooooooo`0Goooo
o`03o`00oooooooooooo06Oooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`1Tooooo`05
o`00ooooooooooooooooool00?l06Oooool00ol0003oooooooooo`0Gooooo`04o`00oooooooooooo
o`00ofKooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`1Tooooo`05o`00oooooooooooo
ooooool00?l06Oooool00ol0003oooooooooo`0Jooooo`03o`00oooooooooooo06Cooooo0Ol00001
ooooo`005Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo01Oooooo00Co003ooooo
oooooooo003oI_ooool1o`00007ooooo000Eooooo`03o`000?oooooooooo08;ooooo00?o0000oooo
ooooool05oooool00ol00?ooooooooooo`1Wooooo`7o00000Oooool001Gooooo0_l0001Uooooo`04
o`00ooooooooooooo`00oa[ooooo00?o0000ooooooooool05oooool00ol00?ooooooooooo`1Voooo
o`;o00000Oooool001Gooooo00?o0000ooooooooool0I?ooool01?l00?ooooooooooool00?lJoooo
o`03o`000?oooooooooo01Oooooo00Co003ooooooooooooo003oI_ooool1o`00007ooooo000Eoooo
o`03o`000?oooooooooo06Cooooo00Co003ooooooooooooo003o6_ooool00ol0003oooooooooo`0J
ooooo`03o`00oooooooooooo06Cooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`22oooo
o`03o`000?oooooooooo01[ooooo00?o003oooooooooool0I?ooool1o`00007ooooo00001?oooooo
0000o`000?l00004ooooo`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool0P_ooool00ol0
003oooooooooo`0Gooooo`04o`00ooooooooooooo`00ofKooooo0Ol00001ooooo`000_ooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?oo
ool00ol0003oooooooooo`1Tooooo`04o`00ooooooooooooo`00oa[ooooo00?o0000ooooooooool0
5oooool00ol00?ooooooooooo`1Wooooo`7o00000Oooool000;ooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool0I?ooool01?l00?ooooooooooool00?lJooooo`03o`000?oooooooooo01Oooooo00Co003ooooo
oooooooo003oI_ooool1o`00007ooooo0002ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00004ooooo`;o0000I_ooool00ol00?ooooooo`00
o`0Jooooo`03o`000?oooooooooo01[ooooo00?o003oooooooooool0Hoooool2o`00007ooooo0002
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo06Gooooo00?o003oooooool00?l06_ooool00ol0003ooooo
ooooo`0Jooooo`03o`00oooooooooooo06Cooooo0Ol00001ooooo`0000?oooooo`000?l000001?oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool0P_ooool00ol0003oooooooooo`0Gooooo`04o`00ooooooooooooo`00ofKooooo0Ol00001oooo
o`000_ooool00ol0003oooooooooo`03ooooo`;o00001?ooool2o`0000Gooooo00?o0000oooooooo
ool0IOooool00ol00?ooooooo`00o`0Jooooo`03o`000?oooooooooo01Oooooo00?o003ooooooooo
ool0Ioooool1o`00007ooooo000Eooooo`03o`000?oooooooooo06Gooooo00?o003oooooool00?l0
6_ooool00ol0003oooooooooo`0Gooooo`03o`00oooooooooooo06Oooooo0Ol00001ooooo`005Ooo
ool00ol0003oooooooooo`1Uooooo`03o`00oooooooo003o01[ooooo00?o0000ooooooooool05ooo
ool01?l00?ooooooooooool00?mVooooo`7o00000Oooool001Gooooo0_l0001Vooooo`03o`00oooo
oooo003o01[ooooo00?o0000ooooooooool06_ooool00ol00?ooooooooooo`1Sooooo`;o00000Ooo
ool001Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`0Gooooo`04o`00oooooooo
003oo`00ofKooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`1Wooooo`03o`00oooooooo
oooo01Sooooo00?o0000ooooooooool05oooool00ol00?ooooooooooo`1Wooooo`7o00000Oooool0
01Gooooo00?o0000ooooooooool0IOooool00ol00?ooooooo`00o`0Jooooo`03o`000?oooooooooo
01Oooooo00?o003oooooooooool0Ioooool1o`00007ooooo000Eooooo`03o`000?oooooooooo06Go
oooo00?o003oooooool00?l06_ooool00ol0003oooooooooo`0Gooooo`03o`00oooooooo003o06Oo
oooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`1Uooooo`03o`00oooooooo003o01[ooooo
00?o0000ooooooooool06Oooool00ol00?ooooooooooo`1Uooooo`7o00000Oooool001Gooooo00?o
0000ooooooooool0P_ooool00ol0003oooooooooo`0Iooooo`03o`00oooooooooooo06Gooooo0Ol0
0001ooooo`005Oooool2o`0008?ooooo00?o0000ooooooooool05oooool00ol00?ooooooo`00o`1V
ooooo`;o00000Oooool001Gooooo00?o0000ooooooooool0IOooool00ol00?ooooooo`00o`0Joooo
o`03o`000?oooooooooo01Oooooo00?o003oooooooooool0Ioooool1o`00007ooooo000Eooooo`03
o`000?oooooooooo06Gooooo00?o003oooooool00?l06_ooool00ol0003oooooooooo`0Gooooo`03
o`00oooooooo003o06Oooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`1Uooooo`03o`00
oooooooo003o01[ooooo00?o0000ooooooooool06Oooool00ol00?ooooooooooo`1Uooooo`7o0000
0Oooool001Gooooo00?o0000ooooooooool0IOooool00ol00?ooooooooooo`0Jooooo`03o`000?oo
oooooooo01Wooooo00?o003oooooooooool0IOooool1o`00007ooooo000Eooooo`03o`000?oooooo
oooo08;ooooo00?o0000ooooooooool05oooool00ol00?ooooooo`00o`1Wooooo`7o00000Oooool0
01Gooooo0_l0001Vooooo`03o`00oooooooo003o01[ooooo00?o0000ooooooooool06?ooool00ol0
0?ooooooooooo`1Uooooo`;o00000Oooool001Gooooo00?o0000ooooooooool0IOooool00ol00?oo
ooooo`00o`0Jooooo`03o`000?oooooooooo01Sooooo00?o003oooooooooool0I_ooool1o`00007o
oooo000Eooooo`03o`000?oooooooooo06Gooooo0_l00?lKooooo`03o`000?oooooooooo01Wooooo
00?o003oooooooooool0IOooool1o`00007ooooo000Eooooo`03o`000?oooooooooo06Gooooo0_l0
0?lKooooo`03o`000?oooooooooo01Wooooo00?o003oooooooooool0IOooool1o`00007ooooo0000
1?oooooo0000o`000?l00002ooooo`Go00000oooool2o`0000Gooooo00?o0000ooooooooool0P_oo
ool00ol0003oooooooooo`0Hooooo`;o003oIoooool1o`00007ooooo0002ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`00
0?oooooooooo06Kooooo00?o003oooooooooool06Oooool00ol0003oooooooooo`0Hooooo`03o`00
oooooooooooo06Kooooo0Ol00001ooooo`000_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo00001?ooool2o`0006Kooooo0_l00?lKooooo`03o`00
0?oooooooooo01Sooooo00?o003oooooooooool0IOooool2o`00007ooooo0002ooooo`03o`000?oo
oooooooo00Cooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0I_ooool00ol00?ooooooooooo`0Iooooo`03o`000?oooooooooo01Sooooo
0_l00?mWooooo`7o00000Oooool000;ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`00
0?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Vooooo`03
o`00oooooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol00?ooooooooooo`1Uooooo`7o
00000Oooool00003ooooool0003o000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`0Hoooo
o`;o003oIoooool1o`00007ooooo0002ooooo`03o`000?oooooooooo00;ooooo0ol00004ooooo`;o
00001Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`00
5Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`005Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`03ooooo`7o00000Oooool001Goooooool0000;o`00007ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-12.1861, -12.8898, \
0.0790804, 0.782323}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Show both", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(gw1 = 
        Show[GraphicsArray[{{g1, g5, \ g6}}], \ 
          ImageSize \[Rule] 504*1.5];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .19314 
%%ImageSize: 756 146.011 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.00459847 0.31746 [
[ 0 0 0 0 ]
[ 1 .19314 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .19314 L
0 .19314 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00459847 0.321429 0.188537 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.047619 0.0108341 0.00484525 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01083 -6 -4.5 ]
[-0.0125 .01083 0 4.5 ]
[-0.0125 .10774 -12 -4.5 ]
[-0.0125 .10774 0 4.5 ]
[-0.0125 .20464 -12 -4.5 ]
[-0.0125 .20464 0 4.5 ]
[-0.0125 .30155 -12 -4.5 ]
[-0.0125 .30155 0 4.5 ]
[-0.0125 .39845 -12 -4.5 ]
[-0.0125 .39845 0 4.5 ]
[-0.0125 .49536 -18 -4.5 ]
[-0.0125 .49536 0 4.5 ]
[-0.0125 .59226 -18 -4.5 ]
[-0.0125 .59226 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01083 m
.00625 .01083 L
s
[(0)] -0.0125 .01083 1 0 Mshowa
0 .10774 m
.00625 .10774 L
s
[(20)] -0.0125 .10774 1 0 Mshowa
0 .20464 m
.00625 .20464 L
s
[(40)] -0.0125 .20464 1 0 Mshowa
0 .30155 m
.00625 .30155 L
s
[(60)] -0.0125 .30155 1 0 Mshowa
0 .39845 m
.00625 .39845 L
s
[(80)] -0.0125 .39845 1 0 Mshowa
0 .49536 m
.00625 .49536 L
s
[(100)] -0.0125 .49536 1 0 Mshowa
0 .59226 m
.00625 .59226 L
s
[(120)] -0.0125 .59226 1 0 Mshowa
.125 Mabswid
0 .03506 m
.00375 .03506 L
s
0 .05929 m
.00375 .05929 L
s
0 .08351 m
.00375 .08351 L
s
0 .13197 m
.00375 .13197 L
s
0 .15619 m
.00375 .15619 L
s
0 .18042 m
.00375 .18042 L
s
0 .22887 m
.00375 .22887 L
s
0 .2531 m
.00375 .2531 L
s
0 .27732 m
.00375 .27732 L
s
0 .32578 m
.00375 .32578 L
s
0 .35 m
.00375 .35 L
s
0 .37423 m
.00375 .37423 L
s
0 .42268 m
.00375 .42268 L
s
0 .44691 m
.00375 .44691 L
s
0 .47113 m
.00375 .47113 L
s
0 .51959 m
.00375 .51959 L
s
0 .54381 m
.00375 .54381 L
s
0 .56804 m
.00375 .56804 L
s
0 .61649 m
.00375 .61649 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01083 m
1 .01083 L
s
.99375 .10774 m
1 .10774 L
s
.99375 .20464 m
1 .20464 L
s
.99375 .30155 m
1 .30155 L
s
.99375 .39845 m
1 .39845 L
s
.99375 .49536 m
1 .49536 L
s
.99375 .59226 m
1 .59226 L
s
.125 Mabswid
.99625 .03506 m
1 .03506 L
s
.99625 .05929 m
1 .05929 L
s
.99625 .08351 m
1 .08351 L
s
.99625 .13197 m
1 .13197 L
s
.99625 .15619 m
1 .15619 L
s
.99625 .18042 m
1 .18042 L
s
.99625 .22887 m
1 .22887 L
s
.99625 .2531 m
1 .2531 L
s
.99625 .27732 m
1 .27732 L
s
.99625 .32578 m
1 .32578 L
s
.99625 .35 m
1 .35 L
s
.99625 .37423 m
1 .37423 L
s
.99625 .42268 m
1 .42268 L
s
.99625 .44691 m
1 .44691 L
s
.99625 .47113 m
1 .47113 L
s
.99625 .51959 m
1 .51959 L
s
.99625 .54381 m
1 .54381 L
s
.99625 .56804 m
1 .56804 L
s
.99625 .61649 m
1 .61649 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
0 0 1 r
.5 Mabswid
[ .01 ] 0 setdash
.02381 .03991 m
.02395 .03989 L
.02408 .03987 L
.02423 .03981 L
.02437 .03973 L
.02462 .03954 L
.02489 .03926 L
.02519 .03886 L
.02551 .03833 L
.02608 .03711 L
.02722 .03375 L
.02847 .02882 L
.02973 .02297 L
.03043 .01967 L
.03077 .01816 L
.03109 .01694 L
.03125 .01645 L
.03139 .01609 L
.03147 .01593 L
.03156 .0158 L
.03171 .01569 L
.03179 .01569 L
.03188 .01574 L
.03197 .01584 L
.03206 .01598 L
.03221 .01634 L
.03238 .01685 L
.03299 .01933 L
.03355 .02196 L
.03476 .02765 L
.03605 .03294 L
.03714 .03644 L
.03777 .03793 L
.03805 .03847 L
.03836 .03897 L
.03863 .03933 L
.03892 .03963 L
.03908 .03975 L
.03923 .03984 L
.03938 .0399 L
.03952 .03994 L
.03965 .03995 L
.03978 .03995 L
.0399 .03993 L
.04003 .03989 L
.04017 .03983 L
.04031 .03974 L
.04058 .03952 L
.04089 .03917 L
.04122 .03867 L
Mistroke
.04183 .03745 L
.04243 .03592 L
.04298 .0342 L
.04525 .02473 L
.04644 .01908 L
.04673 .01784 L
.04705 .01671 L
.04722 .0162 L
.04731 .01602 L
.04739 .01588 L
.04746 .01578 L
.04755 .01571 L
.0477 .01571 L
.04778 .01577 L
.04786 .01588 L
.04802 .01618 L
.04819 .01667 L
.04836 .01723 L
.04905 .02021 L
.05029 .02612 L
.05155 .03161 L
.05217 .0339 L
.05273 .03571 L
.05326 .03716 L
.05383 .03843 L
.05415 .03897 L
.05444 .03938 L
.05472 .03969 L
.05487 .03982 L
.05501 .03992 L
.05517 .04001 L
.05531 .04006 L
.05546 .04009 L
.05555 .0401 L
.05563 .0401 L
.05576 .04008 L
.05591 .04004 L
.05606 .03997 L
.0562 .03988 L
.05653 .03959 L
.05683 .03922 L
.05716 .03871 L
.05751 .03804 L
.05866 .03497 L
.05989 .03041 L
.0621 .02014 L
.0627 .01752 L
.063 .01649 L
.06309 .01627 L
.06318 .01607 L
Mistroke
.06326 .01592 L
.06334 .01581 L
.06342 .01574 L
.06351 .01572 L
.0636 .01575 L
.06369 .01584 L
.06378 .01598 L
.06387 .01616 L
.06403 .01658 L
.06434 .01767 L
.06467 .01909 L
.06583 .02463 L
.0671 .03043 L
.06827 .03483 L
.0689 .03677 L
.06951 .03824 L
.06984 .03889 L
.0702 .03946 L
.07052 .03985 L
.07068 .04 L
.07082 .04012 L
.07096 .0402 L
.07111 .04027 L
.07119 .0403 L
.07127 .04032 L
.07142 .04034 L
.07158 .04033 L
.07172 .0403 L
.0718 .04027 L
.07188 .04024 L
.07205 .04015 L
.0722 .04004 L
.07233 .03992 L
.07264 .03957 L
.07294 .03913 L
.07326 .03855 L
.07437 .03573 L
.07504 .03346 L
.07568 .03096 L
.07688 .02557 L
.07804 .01996 L
.07837 .01845 L
.07868 .01719 L
.07882 .01672 L
.07897 .01631 L
.07912 .01598 L
.07927 .0158 L
.07941 .01576 L
.07954 .01584 L
.07968 .01606 L
Mistroke
.07982 .01638 L
.08006 .01715 L
.08033 .0182 L
.08149 .0237 L
.08262 .02905 L
.08383 .03402 L
.08453 .03633 L
.08517 .03805 L
.08547 .03874 L
.08581 .03937 L
.0861 .03982 L
.08642 .04021 L
.08658 .04037 L
.08674 .04048 L
.08689 .04057 L
.08704 .04064 L
.08718 .04068 L
.08731 .04069 L
.08745 .04068 L
.08761 .04065 L
.08769 .04062 L
.08777 .04059 L
.08795 .04048 L
.08811 .04036 L
.08827 .0402 L
.08856 .03985 L
.08888 .03936 L
.08944 .03821 L
.09006 .03661 L
.09116 .03281 L
.09353 .02194 L
.09418 .01884 L
.09454 .01736 L
.09471 .01675 L
.09487 .0163 L
.09503 .016 L
.0951 .0159 L
.09519 .01583 L
.09527 .01582 L
.09536 .01585 L
.09545 .01594 L
.09553 .01606 L
.09567 .01638 L
.09583 .01685 L
.09612 .01793 L
.09863 .02991 L
.09972 .03438 L
.1009 .03809 L
.10154 .03952 L
.10182 .04001 L
Mistroke
.10212 .04045 L
.10241 .04077 L
.10255 .04089 L
.10268 .04098 L
.10283 .04106 L
.10297 .04111 L
.10312 .04114 L
.10328 .04115 L
.10343 .04112 L
.10358 .04108 L
.10366 .04104 L
.10374 .041 L
.10391 .04088 L
.10424 .04055 L
.10459 .04008 L
.10517 .03899 L
.10581 .03739 L
.10705 .03313 L
.10817 .0282 L
.10949 .0217 L
.11007 .01892 L
.11037 .01761 L
.11054 .01699 L
.1107 .0165 L
.11085 .01617 L
.11101 .01594 L
.11115 .01589 L
.11128 .01596 L
.11141 .01615 L
.11155 .01646 L
.11169 .01688 L
.11183 .01736 L
.11302 .02296 L
.11424 .02902 L
.11553 .03456 L
.11669 .03836 L
.11735 .03993 L
.11766 .04051 L
.11796 .04096 L
.11823 .04128 L
.11837 .04141 L
.11852 .04153 L
.11865 .04161 L
.11879 .04167 L
.11892 .04171 L
.11904 .04173 L
.11919 .04173 L
.11933 .0417 L
.11945 .04166 L
.11959 .04159 L
Mistroke
.11974 .04149 L
.1199 .04136 L
.12019 .04104 L
.1205 .04059 L
.12084 .03999 L
.12143 .03861 L
.12207 .03672 L
.12277 .03418 L
.12405 .02858 L
.12521 .02275 L
.12578 .01984 L
.12609 .01842 L
.12641 .01713 L
.12655 .01669 L
.1267 .01632 L
.12678 .01616 L
.12686 .01606 L
.12701 .01597 L
.12714 .01603 L
.12728 .01622 L
.12742 .01655 L
.12756 .01696 L
.1282 .01966 L
.12878 .0226 L
.13008 .02923 L
.13121 .03428 L
.1324 .03849 L
.13302 .04013 L
.13335 .04083 L
.1337 .04145 L
.13403 .04188 L
.13432 .04217 L
.13447 .04227 L
.13462 .04236 L
.13477 .04241 L
.1349 .04244 L
.13506 .04244 L
.13514 .04243 L
.13522 .04241 L
.13538 .04235 L
.13552 .04228 L
.13569 .04215 L
.13584 .04201 L
.13618 .04159 L
.13648 .04112 L
.1368 .04049 L
.13739 .03906 L
.13855 .03513 L
.13963 .03043 L
.14072 .02495 L
Mistroke
.14189 .01896 L
.14223 .01749 L
.1424 .0169 L
.14256 .01647 L
.1427 .01621 L
.14285 .01608 L
.14294 .01608 L
.14302 .01614 L
.14317 .01636 L
.14332 .01672 L
.14347 .01721 L
.14375 .01832 L
.14437 .02139 L
.1456 .02789 L
.14677 .03352 L
.1479 .03801 L
.1484 .0396 L
.14895 .04104 L
.1495 .04213 L
.1498 .04258 L
.15008 .04291 L
.15023 .04304 L
.15038 .04315 L
.15052 .04322 L
.15067 .04328 L
.15082 .0433 L
.15091 .0433 L
.15099 .0433 L
.15115 .04326 L
.1513 .04319 L
.15145 .0431 L
.15161 .04298 L
.15193 .04262 L
.15223 .04218 L
.15251 .04167 L
.15314 .04018 L
.15382 .03809 L
.15504 .03318 L
.15637 .02654 L
.15703 .02301 L
.15765 .01977 L
.15792 .01848 L
.1582 .01732 L
.15835 .01684 L
.15843 .01663 L
.15851 .01644 L
.15866 .01624 L
.1588 .0162 L
.15896 .01633 L
.1591 .01662 L
Mistroke
.15918 .01682 L
.15927 .01708 L
.15944 .01771 L
.16004 .02057 L
.16117 .02674 L
.16249 .03351 L
.1637 .03858 L
.16429 .04054 L
.16484 .04202 L
.16541 .04318 L
.16572 .04364 L
.16604 .044 L
.16621 .04414 L
.16636 .04424 L
.16645 .04427 L
.16654 .0443 L
.16663 .04433 L
.16672 .04434 L
.1668 .04434 L
.16688 .04433 L
.16703 .04429 L
.16718 .04422 L
.16727 .04417 L
.16736 .04411 L
.16766 .04382 L
.16794 .04346 L
.16856 .04231 L
.16915 .04077 L
.16977 .03873 L
.17088 .03409 L
.1721 .0279 L
.17277 .0242 L
.1734 .02071 L
.17369 .01923 L
.17399 .01783 L
.17415 .01724 L
.17424 .01697 L
.17433 .01673 L
.17441 .01655 L
.17449 .01644 L
.17464 .01634 L
.17478 .01642 L
.17492 .01663 L
.17506 .01701 L
.17522 .01754 L
.17577 .02011 L
.17799 .03236 L
.17923 .03817 L
.17988 .04064 L
.18057 .04275 L
Mistroke
.18117 .04414 L
.18151 .04472 L
.18168 .04495 L
.18183 .04513 L
.18198 .04527 L
.18213 .04539 L
.18227 .04547 L
.1824 .04553 L
.18254 .04556 L
.18269 .04557 L
.18277 .04556 L
.18285 .04554 L
.183 .04549 L
.18315 .0454 L
.18329 .0453 L
.1836 .04498 L
.18388 .04456 L
.18415 .04408 L
.18476 .04266 L
.18542 .04062 L
.18674 .03508 L
.18796 .02863 L
.18905 .02233 L
.18965 .01908 L
.18995 .01775 L
.19009 .01724 L
.19022 .01687 L
.19038 .01659 L
.19046 .01652 L
.19055 .01651 L
.19063 .01656 L
.19071 .01666 L
.1908 .01683 L
.1909 .01706 L
.19105 .01757 L
.19119 .01814 L
.19151 .01969 L
.19271 .02665 L
.19496 .03867 L
.19558 .04122 L
.19624 .04347 L
.1968 .04497 L
.1971 .04562 L
.19741 .04617 L
.19757 .0464 L
.19774 .04661 L
.1979 .04676 L
.19805 .04687 L
.19813 .04693 L
.19822 .04697 L
Mistroke
.19832 .047 L
.1984 .04703 L
.19849 .04704 L
.19858 .04704 L
.19874 .04701 L
.19888 .04696 L
.19904 .04686 L
.19919 .04674 L
.19933 .04661 L
.19966 .04617 L
.19998 .04561 L
.20058 .04419 L
.20114 .04245 L
.20241 .03718 L
.20358 .03093 L
.20484 .02334 L
.20543 .01996 L
.20574 .01838 L
.2059 .01773 L
.20604 .01726 L
.20617 .01694 L
.20629 .01675 L
.20642 .0167 L
.20656 .01682 L
.20671 .0171 L
.20686 .01758 L
.20714 .01875 L
.20933 .03186 L
.21054 .0385 L
.21168 .04352 L
.21227 .04551 L
.21258 .04638 L
.21292 .04716 L
.21322 .04775 L
.2135 .04818 L
.21363 .04834 L
.21378 .04849 L
.21391 .0486 L
.21404 .04869 L
.21418 .04875 L
.21431 .04878 L
.21446 .04879 L
.2146 .04877 L
.21475 .04872 L
.2149 .04863 L
.21505 .04851 L
.21519 .04837 L
.21544 .04806 L
.2157 .04761 L
.21625 .04641 L
Mistroke
.21684 .04463 L
.21747 .04227 L
.21858 .03693 L
.2198 .02981 L
.22047 .02556 L
.2211 .02159 L
.22139 .0199 L
.2217 .01835 L
.22186 .01771 L
.22195 .01744 L
.22204 .0172 L
.22212 .01704 L
.2222 .01696 L
.22235 .01695 L
.22249 .01714 L
.22263 .01747 L
.22277 .01799 L
.22293 .01868 L
.22348 .02179 L
.2257 .03596 L
.22694 .0426 L
.2276 .04542 L
.22829 .04781 L
.22889 .04937 L
.22924 .05002 L
.2294 .05026 L
.22956 .05046 L
.2297 .05061 L
.22985 .05074 L
.22999 .05082 L
.23012 .05087 L
.23026 .0509 L
.23041 .0509 L
.23049 .05088 L
.23057 .05085 L
.23072 .05078 L
.2308 .05072 L
.23088 .05066 L
.23103 .05052 L
.23135 .05009 L
.23163 .04958 L
.23194 .0489 L
.23263 .04686 L
.23327 .0444 L
.23445 .03852 L
.23569 .03082 L
.23683 .02313 L
.23713 .02119 L
.23746 .0193 L
.23761 .01856 L
Mistroke
.23777 .01791 L
.23791 .0175 L
.23806 .01724 L
.23821 .0172 L
.23834 .01736 L
.23849 .01774 L
.23865 .01834 L
.23892 .01967 L
.23921 .02143 L
.24027 .02867 L
.24159 .03753 L
.24283 .04461 L
.24395 .04939 L
.24425 .0504 L
.24458 .05132 L
.24488 .05204 L
.24516 .05257 L
.24529 .05279 L
.24544 .05299 L
.24559 .05315 L
.24572 .05327 L
.24587 .05337 L
.24595 .05341 L
.24603 .05344 L
.24617 .05346 L
.24632 .05346 L
.24645 .05342 L
.24659 .05335 L
.24674 .05324 L
.24688 .0531 L
.24713 .05277 L
.2474 .05232 L
.24772 .05162 L
.24806 .05069 L
.24869 .04853 L
.24986 .04299 L
.25221 .02755 L
.25285 .02295 L
.25318 .02072 L
.25337 .01963 L
.25354 .01875 L
.25369 .01813 L
.25377 .01787 L
.25385 .01768 L
.25393 .01755 L
.25402 .01749 L
.25411 .01752 L
.25419 .01761 L
.25433 .01794 L
.25448 .0185 L
Mistroke
.25479 .02011 L
.25727 .03804 L
.25835 .04499 L
.25953 .05097 L
.26015 .05334 L
.26043 .05419 L
.26073 .05498 L
.261 .05555 L
.26129 .05603 L
.26144 .05623 L
.26159 .05638 L
.26173 .05649 L
.26188 .05657 L
.26203 .05661 L
.26218 .05661 L
.26226 .05659 L
.26234 .05656 L
.2625 .05648 L
.26265 .05636 L
.2628 .05619 L
.26308 .05578 L
.2634 .05514 L
.26371 .05438 L
.2644 .05207 L
.265 .04945 L
.26565 .04598 L
.26684 .03826 L
.26799 .02955 L
.26855 .02513 L
.26907 .02131 L
.26936 .01955 L
.26952 .01875 L
.26967 .0182 L
.26982 .01789 L
.26991 .01784 L
.26999 .01787 L
.27007 .01798 L
.27016 .01818 L
.27024 .01846 L
.27032 .01877 L
.27058 .02016 L
.27086 .0221 L
.27145 .02662 L
.27277 .03732 L
.27398 .04617 L
.27511 .0529 L
.27568 .05556 L
.27631 .05786 L
.27664 .0588 L
.27694 .05948 L
Mistroke
.27711 .05979 L
.27729 .06007 L
.27746 .06027 L
.27761 .06041 L
.27776 .0605 L
.27789 .06055 L
.27804 .06056 L
.27812 .06055 L
.2782 .06052 L
.27835 .06044 L
.27844 .06038 L
.27852 .06031 L
.27882 .05992 L
.27898 .05965 L
.27914 .05932 L
.27944 .05861 L
.2801 .05641 L
.28068 .05387 L
.2813 .05046 L
.28355 .03391 L
.28413 .02893 L
.28476 .02361 L
.28505 .02141 L
.28521 .02034 L
.28536 .01948 L
.28548 .0189 L
.28562 .01846 L
.28577 .01825 L
.28591 .01833 L
.28599 .01849 L
.28607 .01875 L
.28622 .01939 L
.28639 .02042 L
.28655 .02153 L
.28723 .02716 L
.28843 .03797 L
.28956 .04735 L
.29075 .05563 L
.29137 .05908 L
.29206 .06209 L
.29236 .06313 L
.29268 .06405 L
.29298 .06473 L
.29313 .06499 L
.29326 .06519 L
.2934 .06536 L
.29354 .06548 L
.29368 .06558 L
.29384 .06563 L
.29398 .06563 L
Mistroke
.29414 .06558 L
.29422 .06553 L
.2943 .06547 L
.29445 .06532 L
.2946 .06514 L
.29475 .06489 L
.29503 .06431 L
.29556 .06278 L
.29619 .06021 L
.29686 .05664 L
.29806 .04829 L
.29929 .03768 L
.30045 .02662 L
.30095 .02217 L
.3011 .02107 L
.30123 .02017 L
.30136 .01951 L
.30149 .019 L
.30164 .01874 L
.3018 .01885 L
.30193 .01925 L
.30208 .01997 L
.30222 .02085 L
.30236 .02195 L
.30263 .02423 L
.30497 .04736 L
.30628 .05841 L
.30749 .06613 L
.30809 .06887 L
.30839 .06998 L
.30872 .07095 L
.30889 .07136 L
.30905 .07167 L
.30921 .07193 L
.30935 .07212 L
.30944 .07221 L
.30952 .07227 L
.3096 .07233 L
.30969 .07237 L
.30978 .07238 L
.30988 .07238 L
.30997 .07236 L
.31005 .07232 L
.31019 .07223 L
.31034 .07207 L
.31049 .07187 L
.31062 .07165 L
.31093 .07094 L
.31123 .07005 L
.31183 .06765 L
Mistroke
.31248 .06414 L
.31373 .05495 L
.31486 .04428 L
.31618 .0301 L
.31676 .02406 L
.31692 .02259 L
.31709 .02122 L
.31717 .02065 L
.31725 .02018 L
.31739 .01956 L
.31753 .01931 L
.31767 .01944 L
.3178 .01987 L
.31794 .02063 L
.31808 .02171 L
.31824 .0231 L
.31852 .02598 L
.31972 .03975 L
.32102 .05436 L
.32223 .06595 L
.32345 .07482 L
.32409 .07815 L
.32445 .07957 L
.32478 .08056 L
.32493 .08093 L
.32509 .08125 L
.32523 .08148 L
.32538 .08166 L
.32546 .08174 L
.32554 .08179 L
.32563 .08183 L
.32572 .08185 L
.32587 .08184 L
.32595 .0818 L
.32603 .08175 L
.32617 .08162 L
.3263 .08145 L
.32644 .08121 L
.3266 .08088 L
.32691 .08002 L
.3272 .07898 L
.32778 .07629 L
.32839 .07246 L
.32949 .06328 L
.33198 .03406 L
.33258 .02651 L
.33274 .02468 L
.33291 .0229 L
.33307 .02152 L
.33322 .02055 L
Mistroke
.3333 .0202 L
.33339 .02001 L
.33355 .02016 L
.33364 .02052 L
.33374 .0211 L
.33391 .02256 L
.33425 .02631 L
.33455 .03026 L
.33699 .06338 L
.33812 .07639 L
.33931 .08704 L
.33993 .09111 L
.34029 .09291 L
.34062 .09425 L
.34078 .09476 L
.34092 .09518 L
.34106 .09549 L
.3412 .09577 L
.34136 .09599 L
.3415 .09612 L
.34165 .0962 L
.34174 .0962 L
.34182 .09618 L
.34196 .0961 L
.34212 .09594 L
.34226 .09571 L
.34239 .09545 L
.34271 .09457 L
.34301 .09343 L
.34361 .09026 L
.34426 .08553 L
.34542 .07387 L
.34649 .05993 L
.34759 .04328 L
.34819 .03361 L
.34876 .02508 L
.34892 .02319 L
.349 .02232 L
.34908 .02166 L
.34917 .02114 L
.34926 .02085 L
.34935 .02084 L
.34943 .0211 L
.34959 .02215 L
.34967 .02293 L
.34975 .02392 L
.35005 .02807 L
.35125 .04897 L
.35257 .07195 L
.35381 .09115 L
Mistroke
.35493 .10509 L
.35556 .11124 L
.35614 .11566 L
.35641 .11729 L
.3567 .11872 L
.35697 .11975 L
.35709 .12012 L
.35722 .12043 L
.35738 .12072 L
.35752 .1209 L
.3576 .12096 L
.35769 .121 L
.35784 .12098 L
.35798 .12088 L
.35812 .1207 L
.35827 .12042 L
.35842 .12002 L
.35871 .119 L
.35902 .1175 L
.35957 .11376 L
.36024 .10758 L
.36084 .10035 L
.36334 .05634 L
.36444 .0324 L
.36474 .02645 L
.36482 .02505 L
.36491 .02377 L
.36506 .0222 L
.36521 .02186 L
.36534 .02264 L
.36549 .02453 L
.36565 .02734 L
.36789 .08306 L
.37027 .13762 L
.37151 .15854 L
.3722 .16721 L
.37254 .17044 L
.37285 .17291 L
.37312 .17461 L
.37326 .17531 L
.37341 .17595 L
.3735 .17624 L
.37358 .17648 L
.37373 .17682 L
.37388 .177 L
.37403 .17705 L
.37411 .17701 L
.37419 .17693 L
.37428 .1768 L
.37437 .17661 L
Mistroke
.37452 .17618 L
.37468 .17552 L
.37499 .17382 L
.37528 .17167 L
.37588 .16524 L
.37654 .15538 L
.37716 .1433 L
.37774 .12979 L
.37998 .05711 L
.38054 .03552 L
.3807 .02977 L
.38085 .02527 L
.38099 .02315 L
.38114 .02418 L
.38129 .02795 L
.38142 .03267 L
.38171 .04513 L
.38223 .07015 L
.38472 .20321 L
.38724 .34282 L
.38955 .458 L
.39072 .5064 L
.39181 .54384 L
.39295 .57377 L
.39355 .58556 L
.39386 .59053 L
.3942 .59493 L
.3945 .59812 L
.39466 .59951 L
.39483 .60077 L
.39499 .6017 L
.39514 .60237 L
.39528 .60284 L
.39542 .60317 L
.39558 .60332 L
.39567 .60331 L
.39575 .60324 L
.39591 .60296 L
.39606 .6025 L
.39614 .60216 L
.39623 .60173 L
.39639 .6008 L
.39676 .59793 L
.39704 .5949 L
.39735 .5909 L
.39791 .5818 L
.39918 .55251 L
.4004 .51427 L
.40173 .4632 L
.40416 .35316 L
Mistroke
.40673 .22812 L
.40906 .12361 L
.41023 .07864 L
.41085 .05783 L
.41118 .04755 L
.4115 .03888 L
.41179 .03189 L
.41192 .02942 L
.41207 .02731 L
.41222 .02587 L
.41237 .02551 L
.41245 .02572 L
.41254 .02624 L
.41269 .02779 L
.41282 .02952 L
.41296 .03165 L
.41321 .03586 L
.41379 .04561 L
.41435 .05412 L
.41494 .06169 L
.41529 .06527 L
.4156 .06803 L
.41589 .07021 L
.41621 .07208 L
.41636 .07284 L
.41653 .07354 L
.41669 .07408 L
.41684 .07447 L
.41701 .07482 L
.4171 .07496 L
.41719 .07505 L
.41735 .07515 L
.41743 .07515 L
.41752 .07513 L
.41759 .07509 L
.41768 .07501 L
.41783 .07481 L
.41798 .07453 L
.41812 .0742 L
.41843 .0732 L
.41875 .0718 L
.41935 .06838 L
.4199 .06444 L
.42113 .05339 L
.42334 .03007 L
.42392 .02415 L
.42454 .01849 L
.4248 .01656 L
.42494 .01569 L
.42507 .01507 L
Mistroke
.42523 .01472 L
.42537 .01479 L
.4255 .01516 L
.42565 .01581 L
.42816 .02967 L
.42938 .03563 L
.43053 .04353 L
.43117 .04968 L
.43186 .05802 L
.43306 .07678 L
.43546 .12734 L
.438 .19041 L
.4404 .2472 L
.44145 .26829 L
.44258 .28733 L
.44321 .29577 L
.44379 .30214 L
.44435 .30686 L
.44463 .30871 L
.44494 .31034 L
.4451 .311 L
.44526 .31157 L
.44541 .31195 L
.44556 .31226 L
.44565 .31238 L
.44573 .31245 L
.44582 .3125 L
.44591 .31251 L
.44607 .31243 L
.44616 .31234 L
.44624 .31222 L
.44638 .31192 L
.44652 .31155 L
.44683 .31037 L
.44713 .30877 L
.44746 .30656 L
.44809 .30082 L
.44868 .29385 L
.45001 .27252 L
.45119 .24803 L
.45244 .21722 L
.45485 .14924 L
.45612 .1125 L
.45746 .07655 L
.45804 .06314 L
.45836 .05678 L
.45866 .05169 L
.45883 .0493 L
.45902 .04718 L
.4591 .04642 L
Mistroke
.45919 .04573 L
.45934 .04482 L
.4595 .04434 L
.45964 .04426 L
.45973 .04438 L
.45981 .04459 L
.45989 .04492 L
.45998 .04537 L
.46012 .04633 L
.46026 .0474 L
.46055 .05036 L
.46109 .05682 L
.4623 .07216 L
.46288 .07859 L
.4635 .08424 L
.46403 .08799 L
.46433 .08966 L
.46461 .09094 L
.46477 .09152 L
.46494 .09204 L
.46508 .09239 L
.46524 .0927 L
.46533 .09283 L
.46541 .09292 L
.46549 .093 L
.46559 .09305 L
.46567 .09307 L
.46576 .09306 L
.46591 .09298 L
.46606 .09283 L
.46621 .09258 L
.46636 .09228 L
.46649 .09193 L
.46682 .09085 L
.46712 .08951 L
.46768 .08637 L
.46829 .08196 L
.46953 .07076 L
.47067 .05949 L
.47124 .05449 L
.47176 .05076 L
.47204 .04928 L
.4722 .04865 L
.47234 .04822 L
.4725 .04789 L
.47259 .04779 L
.47267 .04774 L
.47282 .04776 L
.47298 .04796 L
.47312 .04826 L
Mistroke
.47326 .0487 L
.47352 .04981 L
.47382 .05158 L
.4741 .05356 L
.47541 .06529 L
.47662 .07631 L
.4772 .08076 L
.47774 .08423 L
.4783 .08698 L
.4786 .08804 L
.47877 .08851 L
.47892 .08886 L
.47907 .08912 L
.47923 .0893 L
.47932 .08937 L
.4794 .08941 L
.47956 .08941 L
.47964 .08938 L
.47973 .08932 L
.47988 .08914 L
.47997 .089 L
.48005 .08884 L
.48023 .0884 L
.48053 .08739 L
.48081 .08616 L
.48143 .08233 L
.482 .07744 L
.48262 .07088 L
.48372 .05597 L
.4844 .04556 L
.48473 .04054 L
.48504 .03637 L
.48518 .0347 L
.48531 .03339 L
.48545 .03238 L
.48561 .03176 L
.48576 .03174 L
.48591 .0323 L
.48598 .03284 L
.48607 .0336 L
.48622 .03541 L
.48651 .03988 L
.48681 .04591 L
.48736 .0588 L
.48862 .09294 L
.49115 .16889 L
.49353 .2367 L
.49478 .26758 L
.49612 .29484 L
.49679 .30588 L
Mistroke
.49742 .31453 L
.49799 .32078 L
.49828 .32341 L
.4986 .32585 L
.49889 .32757 L
.49919 .329 L
.49935 .3296 L
.49951 .33002 L
.49966 .33034 L
.4998 .33053 L
.49994 .33061 L
.50008 .33061 L
.5002 .33052 L
.50033 .33035 L
.50048 .33006 L
.50063 .32965 L
.50091 .32859 L
.5012 .32711 L
.50151 .32507 L
.50206 .32026 L
.50272 .31268 L
.50332 .3041 L
.50463 .28028 L
.50587 .25212 L
.51051 .11881 L
.51174 .08271 L
.5129 .05237 L
.51348 .04003 L
.51365 .0372 L
.51381 .03495 L
.51395 .03337 L
.51411 .03221 L
.5142 .03183 L
.51429 .03168 L
.51444 .03191 L
.51453 .03231 L
.51461 .03283 L
.5148 .03448 L
.51511 .0383 L
.51544 .04309 L
.51658 .06047 L
.51721 .06887 L
.51781 .07561 L
.51837 .08072 L
.51866 .08295 L
.51897 .08495 L
.51923 .08634 L
.51952 .08758 L
.51964 .08802 L
.51978 .08842 L
Mistroke
.5199 .08874 L
.52002 .08898 L
.52018 .08921 L
.52031 .08935 L
.52046 .08942 L
.52055 .08942 L
.52062 .0894 L
.52075 .08932 L
.52089 .08917 L
.52104 .08893 L
.52118 .08864 L
.5215 .08773 L
.52179 .0866 L
.52244 .08316 L
.52307 .0788 L
.52375 .07312 L
.52499 .06149 L
.52553 .05654 L
.52612 .05197 L
.52646 .04995 L
.5266 .04925 L
.52676 .04862 L
.52692 .04817 L
.52706 .04789 L
.52721 .04775 L
.52729 .04773 L
.52737 .04776 L
.52753 .04794 L
.52761 .0481 L
.52769 .04832 L
.52785 .04883 L
.52799 .04944 L
.52832 .05125 L
.52867 .05376 L
.5299 .06515 L
.53112 .07698 L
.53177 .08242 L
.53245 .0872 L
.53279 .08909 L
.53311 .09056 L
.5334 .0916 L
.53355 .09203 L
.53371 .09242 L
.53386 .09271 L
.534 .0929 L
.53415 .09302 L
.53424 .09306 L
.53432 .09307 L
.53445 .09303 L
.5346 .09291 L
Mistroke
.53474 .09272 L
.53487 .09248 L
.53502 .09215 L
.53517 .09172 L
.53543 .09075 L
.53572 .0894 L
.53604 .08757 L
.5366 .08339 L
.53713 .07851 L
.5384 .06344 L
.53903 .05531 L
.53931 .05194 L
.53961 .04864 L
.53975 .04731 L
.53991 .04609 L
.54005 .04519 L
.54019 .04461 L
.54034 .04428 L
.54042 .04425 L
.5405 .04433 L
.54064 .04475 L
.5408 .0456 L
.54088 .04626 L
.54096 .04698 L
.54114 .04897 L
.54147 .05373 L
.54208 .06568 L
.54432 .12509 L
.54679 .19627 L
.54909 .25422 L
.55023 .27691 L
.55131 .29366 L
.5519 .30075 L
.55221 .30383 L
.55255 .3066 L
.55283 .30852 L
.55313 .3102 L
.55327 .31079 L
.55341 .31133 L
.55355 .31175 L
.55368 .31205 L
.55383 .31232 L
.55397 .31246 L
.55412 .31251 L
.5542 .31249 L
.55428 .31245 L
.55441 .3123 L
.55455 .31205 L
.5547 .31169 L
.55483 .31126 L
Mistroke
.55515 .30992 L
.55544 .30828 L
.5561 .30318 L
.55672 .29654 L
.55741 .28748 L
.55865 .26659 L
.56356 .15107 L
.566 .09479 L
.5672 .07238 L
.56829 .05606 L
.56936 .0445 L
.56989 .04019 L
.57048 .03641 L
.57284 .02471 L
.57348 .02105 L
.57408 .01733 L
.57434 .01585 L
.57447 .01525 L
.57462 .01481 L
.57478 .01472 L
.57492 .01505 L
.57506 .01567 L
.57521 .01657 L
.57588 .02229 L
.57652 .02869 L
.57773 .04152 L
.57889 .05356 L
.58012 .06462 L
.58072 .06887 L
.58102 .07061 L
.58129 .07198 L
.58153 .07302 L
.58179 .07394 L
.58192 .07429 L
.58206 .07461 L
.5822 .07486 L
.58234 .07503 L
.58249 .07513 L
.58257 .07515 L
.58265 .07515 L
.58281 .07506 L
.5829 .07496 L
.58298 .07484 L
.58312 .07458 L
.58327 .0742 L
.58357 .07313 L
.5839 .07147 L
.58426 .06912 L
.5849 .06335 L
.58556 .05543 L
Mistroke
.58618 .04619 L
.58677 .03611 L
.58707 .03126 L
.58719 .02934 L
.58733 .02753 L
.58747 .0262 L
.5876 .02556 L
.58775 .02573 L
.58789 .02681 L
.58805 .02895 L
.58819 .03156 L
.58851 .03896 L
.58975 .07798 L
.59197 .1682 L
.59682 .39929 L
.59904 .49395 L
.6003 .53743 L
.60091 .55517 L
.60147 .5691 L
.60203 .58078 L
.60264 .59081 L
.60297 .5951 L
.60328 .59828 L
.60357 .6006 L
.60372 .6015 L
.60389 .60229 L
.60397 .6026 L
.60406 .60287 L
.60414 .60307 L
.60422 .6032 L
.60436 .60332 L
.60452 .60325 L
.60461 .60311 L
.6047 .6029 L
.60479 .60263 L
.60488 .60232 L
.60503 .60157 L
.6052 .60055 L
.6055 .5981 L
.60579 .59513 L
.60643 .5859 L
.60703 .5742 L
.60769 .55823 L
.60888 .521 L
.61112 .42685 L
.61346 .305 L
.61604 .16105 L
.61721 .09813 L
.61783 .06695 L
.61817 .05083 L
Mistroke
.61848 .03685 L
.61862 .03117 L
.61876 .02663 L
.61891 .0234 L
.61905 .02354 L
.61921 .0269 L
.61935 .03154 L
.61968 .04374 L
.62077 .08471 L
.62186 .11912 L
.62304 .14747 L
.62371 .15947 L
.62432 .1677 L
.62462 .17073 L
.62494 .17335 L
.62509 .17431 L
.62524 .17518 L
.62539 .17583 L
.62552 .17631 L
.62567 .17671 L
.62575 .17685 L
.62584 .17697 L
.62593 .17703 L
.62601 .17705 L
.62617 .17695 L
.62632 .17672 L
.62646 .17638 L
.62661 .17588 L
.62677 .17519 L
.6271 .17329 L
.62741 .17093 L
.62811 .16359 L
.62872 .15514 L
.62928 .14589 L
.63055 .12058 L
.63174 .09223 L
.63302 .05956 L
.63365 .04368 L
.63395 .0362 L
.63423 .02978 L
.63449 .02487 L
.63462 .02307 L
.63476 .02196 L
.6349 .02199 L
.63505 .02327 L
.6352 .02534 L
.63533 .02767 L
.63649 .0526 L
.63772 .07745 L
.63886 .09622 L
Mistroke
.63993 .10933 L
.64046 .11401 L
.64102 .11772 L
.64133 .11915 L
.6415 .11976 L
.64165 .12022 L
.64178 .12053 L
.64193 .12077 L
.64209 .12094 L
.64223 .121 L
.64238 .12097 L
.64246 .12091 L
.64255 .12082 L
.6427 .12058 L
.64285 .12027 L
.64301 .11979 L
.64317 .11926 L
.64352 .1177 L
.64414 .11371 L
.64473 .1086 L
.64589 .09527 L
.64712 .07706 L
.64934 .03842 L
.64994 .02822 L
.65025 .02391 L
.65033 .02295 L
.65042 .02208 L
.6505 .02144 L
.65058 .02104 L
.65067 .02082 L
.65075 .02088 L
.65084 .0212 L
.65094 .02183 L
.65102 .02256 L
.6511 .02338 L
.65128 .02561 L
.65192 .0354 L
.65436 .07122 L
.65554 .08383 L
.65614 .0886 L
.65648 .09082 L
.65679 .09251 L
.65706 .09372 L
.65735 .09476 L
.65751 .09521 L
.65766 .09555 L
.6578 .09581 L
.65795 .09602 L
.65808 .09613 L
.65821 .09619 L
Mistroke
.65834 .0962 L
.65846 .09615 L
.6586 .09604 L
.65875 .09585 L
.65889 .0956 L
.65902 .09531 L
.65934 .09437 L
.65964 .09323 L
.6603 .0897 L
.66089 .08553 L
.6615 .08015 L
.66375 .05378 L
.6649 .03782 L
.66553 .02915 L
.66584 .02525 L
.66597 .02371 L
.66612 .02221 L
.66626 .02109 L
.66639 .02036 L
.66653 .02 L
.66668 .02014 L
.66676 .02042 L
.66684 .02088 L
.667 .02202 L
.66728 .02493 L
.66834 .03819 L
.66956 .05318 L
.67071 .0651 L
.67135 .07048 L
.67203 .0752 L
.67234 .0769 L
.67266 .07843 L
.67294 .07952 L
.67324 .08047 L
.6734 .08087 L
.67354 .08118 L
.67368 .08142 L
.67383 .08163 L
.67397 .08175 L
.6741 .08183 L
.67423 .08185 L
.67438 .08183 L
.67453 .08174 L
.67461 .08167 L
.67469 .08158 L
.67485 .08135 L
.67502 .08104 L
.67533 .08027 L
.6756 .07936 L
.67615 .07701 L
Mistroke
.67674 .07364 L
.67781 .06554 L
.68016 .04112 L
.68141 .0267 L
.68177 .02303 L
.68194 .0215 L
.68203 .02087 L
.68211 .02036 L
.68226 .01965 L
.68241 .01931 L
.6825 .01933 L
.68259 .01949 L
.68267 .01978 L
.68275 .02015 L
.68289 .02104 L
.68304 .02224 L
.68332 .02479 L
.68394 .03142 L
.6852 .04491 L
.68639 .05599 L
.6875 .06401 L
.68809 .06729 L
.68873 .06991 L
.68905 .0709 L
.68936 .0716 L
.68954 .07191 L
.6897 .07212 L
.68978 .07221 L
.68988 .07228 L
.68997 .07234 L
.69006 .07237 L
.69021 .07238 L
.6903 .07237 L
.69038 .07234 L
.69052 .07224 L
.69068 .07209 L
.69082 .0719 L
.69094 .07169 L
.69124 .07106 L
.69155 .07017 L
.69184 .06916 L
.69249 .06623 L
.69368 .05869 L
.69479 .04958 L
.69608 .03713 L
.69671 .03071 L
.69729 .02499 L
.69756 .02256 L
.69781 .02063 L
.69794 .01984 L
Mistroke
.69808 .01921 L
.69823 .0188 L
.69837 .01875 L
.69852 .01903 L
.69866 .01958 L
.69881 .02043 L
.69897 .02156 L
.69954 .02646 L
.70073 .03784 L
.70202 .04892 L
.70265 .05353 L
.70325 .05729 L
.70383 .06032 L
.70437 .06255 L
.70489 .06411 L
.70517 .06475 L
.70543 .06517 L
.70558 .06536 L
.70571 .06548 L
.70586 .06558 L
.70602 .06563 L
.70616 .06563 L
.70629 .06559 L
.70643 .06551 L
.70658 .06538 L
.70673 .0652 L
.70689 .06496 L
.70722 .0643 L
.70752 .0635 L
.70781 .06258 L
.70845 .05994 L
.70914 .05626 L
.71157 .03795 L
.71282 .0267 L
.71314 .024 L
.71343 .02165 L
.7137 .01986 L
.71385 .01909 L
.71399 .01857 L
.71412 .01829 L
.71427 .01828 L
.71443 .01859 L
.71457 .01915 L
.71473 .01999 L
.71488 .02091 L
.7152 .02333 L
.71653 .0346 L
.71764 .04344 L
.71883 .05122 L
.71951 .05474 L
Mistroke
.72012 .05725 L
.72042 .05821 L
.72074 .05907 L
.72105 .05971 L
.72133 .06014 L
.72148 .06031 L
.72162 .06043 L
.72175 .0605 L
.7219 .06055 L
.72205 .06056 L
.72213 .06054 L
.72221 .06051 L
.72236 .06043 L
.7225 .06031 L
.72264 .06017 L
.72278 .05997 L
.72303 .05954 L
.72331 .05894 L
.7236 .05814 L
.72423 .05593 L
.72489 .05286 L
.7261 .04569 L
.7285 .02704 L
.72916 .02191 L
.72949 .01974 L
.72958 .01924 L
.72968 .01877 L
.72977 .01841 L
.72986 .01814 L
.72994 .01797 L
.73002 .01786 L
.7301 .01784 L
.73019 .01791 L
.73027 .01806 L
.73036 .01829 L
.73051 .01889 L
.73066 .01966 L
.73082 .02062 L
.73111 .02258 L
.73232 .03193 L
.73361 .04135 L
.73483 .04857 L
.73537 .05109 L
.73594 .05328 L
.73622 .05416 L
.73652 .05497 L
.73681 .05558 L
.73707 .05602 L
.73721 .05621 L
.73737 .05638 L
Mistroke
.73746 .05645 L
.73754 .05651 L
.73762 .05655 L
.7377 .05658 L
.73778 .0566 L
.73786 .05661 L
.73801 .0566 L
.73816 .05655 L
.7383 .05647 L
.73843 .05637 L
.73856 .05622 L
.73881 .05588 L
.73911 .05533 L
.73938 .0547 L
.73997 .05292 L
.74053 .05074 L
.74169 .04475 L
.74293 .03666 L
.74409 .02808 L
.7446 .02429 L
.74489 .02224 L
.74515 .02047 L
.7453 .01959 L
.74544 .01886 L
.74558 .01827 L
.7457 .01785 L
.74584 .01757 L
.74598 .01749 L
.74613 .01764 L
.74628 .01804 L
.74643 .0186 L
.74658 .01936 L
.74686 .02102 L
.7475 .02544 L
.74971 .04054 L
.75093 .04695 L
.75162 .04968 L
.75195 .05073 L
.75226 .05157 L
.75256 .05224 L
.75288 .05279 L
.75302 .05298 L
.75317 .05315 L
.7533 .05327 L
.75344 .05336 L
.75352 .05341 L
.7536 .05344 L
.75375 .05346 L
.75383 .05346 L
.75391 .05345 L
Mistroke
.754 .05343 L
.75409 .05339 L
.75423 .0533 L
.75437 .05319 L
.75453 .05303 L
.75469 .05281 L
.75499 .05229 L
.75532 .05158 L
.75591 .04989 L
.7566 .04724 L
.75724 .04427 L
.75966 .02918 L
.76079 .02142 L
.76106 .01977 L
.76136 .0183 L
.76144 .01795 L
.76152 .01768 L
.76168 .01732 L
.76182 .01719 L
.76198 .01728 L
.76214 .01762 L
.76223 .0179 L
.76231 .01822 L
.76266 .01996 L
.76329 .02392 L
.76449 .03201 L
.76568 .03919 L
.76632 .04253 L
.76692 .04519 L
.76748 .04724 L
.76799 .04872 L
.76826 .04936 L
.76855 .04993 L
.76871 .05019 L
.76886 .05039 L
.769 .05055 L
.76915 .05069 L
.76931 .0508 L
.76945 .05086 L
.76959 .0509 L
.76972 .0509 L
.76987 .05088 L
.77001 .05082 L
.77009 .05078 L
.77017 .05072 L
.77032 .05059 L
.7706 .05026 L
.77089 .04979 L
.77142 .04864 L
.77203 .04679 L
Mistroke
.7726 .04462 L
.77391 .03824 L
.77616 .02409 L
.77677 .02025 L
.77711 .01849 L
.77728 .0178 L
.77743 .01732 L
.77756 .01705 L
.7777 .01693 L
.77784 .01699 L
.77799 .01725 L
.77814 .01772 L
.77831 .01837 L
.7786 .01987 L
.77995 .02823 L
.78117 .03558 L
.78243 .04185 L
.78299 .04403 L
.7836 .04599 L
.78388 .04672 L
.78418 .04739 L
.78444 .04786 L
.78472 .04827 L
.78489 .04845 L
.78504 .04859 L
.78519 .04869 L
.78534 .04876 L
.78548 .04879 L
.78561 .04879 L
.78576 .04877 L
.78591 .04871 L
.78607 .04862 L
.78622 .0485 L
.78655 .04811 L
.78687 .04758 L
.78722 .04685 L
.78785 .04512 L
.78842 .04312 L
.78962 .03768 L
.79073 .0315 L
.79203 .02351 L
.79266 .01979 L
.79294 .0184 L
.79308 .01778 L
.79324 .01725 L
.79339 .01689 L
.79353 .01672 L
.79367 .01672 L
.7938 .01688 L
.79393 .01717 L
Mistroke
.79405 .01756 L
.79433 .01871 L
.7955 .02542 L
.79679 .03298 L
.79799 .039 L
.79908 .04319 L
.7997 .0449 L
.80026 .04604 L
.80058 .0465 L
.80073 .04667 L
.80087 .0468 L
.80102 .04691 L
.80111 .04695 L
.80119 .04699 L
.80128 .04702 L
.80137 .04703 L
.80145 .04704 L
.80154 .04703 L
.8017 .047 L
.80184 .04694 L
.80192 .04689 L
.80201 .04683 L
.80217 .0467 L
.80247 .04634 L
.80275 .0459 L
.80331 .04471 L
.80392 .04298 L
.80501 .03877 L
.8075 .02537 L
.8081 .02188 L
.80873 .01852 L
.80891 .01772 L
.809 .01738 L
.80909 .01711 L
.80925 .01673 L
.80933 .0166 L
.80942 .01652 L
.80957 .01655 L
.80972 .01676 L
.80981 .01695 L
.80988 .01717 L
.81006 .01778 L
.81065 .02069 L
.8113 .02439 L
.81248 .03109 L
.81372 .03718 L
.81487 .04158 L
.81545 .04321 L
.81575 .04389 L
.81608 .0445 L
Mistroke
.81626 .04479 L
.81643 .04502 L
.81661 .04521 L
.81677 .04535 L
.81693 .04545 L
.81708 .04552 L
.81724 .04556 L
.81733 .04557 L
.81741 .04557 L
.81756 .04554 L
.8177 .04549 L
.81783 .04542 L
.81797 .04531 L
.81829 .04499 L
.81858 .04457 L
.81911 .04354 L
.81968 .04207 L
.82086 .03781 L
.82217 .03156 L
.8233 .02527 L
.82392 .02176 L
.8245 .01875 L
.8248 .01746 L
.82497 .0169 L
.82512 .01655 L
.82521 .01642 L
.82529 .01636 L
.82538 .01634 L
.82548 .0164 L
.82564 .01665 L
.82573 .01687 L
.82581 .01712 L
.82611 .01829 L
.82639 .01961 L
.82701 .02296 L
.82822 .02959 L
.8295 .03582 L
.83012 .03833 L
.83071 .04034 L
.83123 .0418 L
.83153 .04249 L
.83181 .04304 L
.8321 .04351 L
.83237 .04386 L
.8325 .04399 L
.83265 .04412 L
.83281 .04422 L
.83296 .04429 L
.83309 .04432 L
.83323 .04434 L
Mistroke
.83337 .04433 L
.83351 .04429 L
.83364 .04423 L
.83376 .04417 L
.83402 .04395 L
.83431 .04361 L
.83458 .0432 L
.83519 .04195 L
.83578 .04031 L
.83642 .03814 L
.83882 .02678 L
.84008 .01992 L
.84039 .01844 L
.84072 .01712 L
.84082 .01682 L
.84091 .01658 L
.84099 .01641 L
.84108 .01628 L
.84117 .01621 L
.84126 .0162 L
.84135 .01625 L
.84142 .01634 L
.84158 .01665 L
.84166 .01686 L
.84175 .01714 L
.84205 .01831 L
.84272 .02165 L
.84393 .02817 L
.84512 .03393 L
.84625 .03833 L
.84684 .04014 L
.84715 .04093 L
.84748 .04166 L
.84776 .04217 L
.84807 .04262 L
.84835 .04293 L
.84848 .04305 L
.84861 .04314 L
.84876 .04322 L
.84885 .04326 L
.84893 .04328 L
.84902 .0433 L
.8491 .0433 L
.84924 .04329 L
.84939 .04326 L
.84952 .0432 L
.84967 .04312 L
.84983 .043 L
.85015 .04266 L
.85045 .04222 L
Mistroke
.85113 .04084 L
.85174 .03919 L
.85239 .03696 L
.85359 .0319 L
.85583 .02036 L
.85637 .01781 L
.85652 .01724 L
.85668 .01673 L
.85681 .0164 L
.85696 .01616 L
.85704 .01609 L
.85712 .01608 L
.85721 .01611 L
.85729 .0162 L
.85744 .01647 L
.85753 .01668 L
.8576 .01691 L
.85821 .01943 L
.85952 .02619 L
.86074 .03216 L
.86193 .0369 L
.86244 .03857 L
.86301 .04006 L
.86333 .04075 L
.86362 .04129 L
.86392 .04174 L
.86421 .04206 L
.86436 .04219 L
.86453 .04231 L
.86469 .04238 L
.86483 .04242 L
.86499 .04244 L
.86507 .04244 L
.86515 .04243 L
.86524 .04241 L
.86532 .04238 L
.86541 .04234 L
.8655 .0423 L
.86563 .04221 L
.86578 .04208 L
.86605 .04179 L
.86637 .04133 L
.86666 .04081 L
.86727 .03943 L
.8679 .03756 L
.86896 .03357 L
.87012 .02822 L
.87134 .02196 L
.87194 .01899 L
.87221 .01784 L
Mistroke
.87249 .01679 L
.87257 .01657 L
.87265 .01636 L
.8728 .01609 L
.87289 .01601 L
.87297 .01597 L
.87313 .01604 L
.87321 .01615 L
.8733 .01631 L
.87346 .01672 L
.87363 .01729 L
.87382 .01803 L
.87502 .02392 L
.87625 .02999 L
.87755 .0354 L
.87865 .03883 L
.87896 .03956 L
.87928 .04022 L
.87957 .0407 L
.87987 .04111 L
.88002 .04128 L
.88018 .04143 L
.88033 .04154 L
.88047 .04162 L
.88055 .04166 L
.88063 .04169 L
.88071 .04171 L
.88081 .04172 L
.88088 .04173 L
.88097 .04173 L
.88112 .0417 L
.88128 .04164 L
.88136 .0416 L
.88144 .04155 L
.88174 .0413 L
.88202 .04099 L
.88231 .04056 L
.88286 .0395 L
.88337 .03821 L
.88453 .03434 L
.88678 .02399 L
.88739 .02088 L
.88773 .01925 L
.88805 .01785 L
.88832 .01685 L
.88847 .01642 L
.88861 .01612 L
.88875 .01593 L
.88891 .01589 L
.88899 .01594 L
Mistroke
.88907 .01603 L
.88922 .01631 L
.88931 .01653 L
.88939 .01679 L
.88955 .01734 L
.88991 .01883 L
.89057 .02198 L
.89179 .02801 L
.89296 .03314 L
.8936 .03553 L
.89421 .03744 L
.8948 .03893 L
.89512 .03957 L
.89545 .04014 L
.89575 .04055 L
.89603 .04083 L
.89617 .04094 L
.89631 .04103 L
.89645 .04109 L
.89657 .04113 L
.8967 .04115 L
.89684 .04115 L
.89697 .04113 L
.89709 .04109 L
.89723 .04103 L
.89738 .04094 L
.89765 .04071 L
.89794 .04038 L
.89824 .03992 L
.89878 .03886 L
.89938 .03735 L
.89992 .03566 L
.90114 .03094 L
.90334 .02035 L
.90392 .01776 L
.90408 .01713 L
.90424 .01662 L
.90438 .01625 L
.90453 .01597 L
.90466 .01584 L
.90481 .01583 L
.90496 .01598 L
.9051 .01625 L
.90524 .0166 L
.90536 .01699 L
.90563 .01803 L
.90813 .02987 L
.90925 .03434 L
.90986 .03635 L
.91043 .03792 L
Mistroke
.91105 .03923 L
.91138 .03976 L
.91173 .0402 L
.91204 .04047 L
.91219 .04057 L
.91228 .04061 L
.91236 .04064 L
.9125 .04068 L
.91266 .04069 L
.9128 .04068 L
.91294 .04065 L
.91307 .04059 L
.91322 .04051 L
.91336 .04041 L
.91349 .0403 L
.91381 .03994 L
.91411 .03951 L
.9147 .03836 L
.91535 .03669 L
.9165 .03275 L
.91757 .02818 L
.91885 .02203 L
.91948 .01905 L
.91975 .01787 L
.92005 .01676 L
.92018 .01637 L
.92032 .01605 L
.92046 .01585 L
.92058 .01577 L
.92071 .01579 L
.92086 .01595 L
.921 .01623 L
.92113 .01657 L
.9214 .0175 L
.9217 .01873 L
.9223 .02155 L
.92353 .02748 L
.92483 .03297 L
.92594 .03662 L
.92657 .03818 L
.92715 .03926 L
.92744 .03967 L
.9276 .03984 L
.92776 .04 L
.9279 .04011 L
.92806 .04021 L
.9282 .04028 L
.92833 .04032 L
.92847 .04034 L
.9286 .04034 L
Mistroke
.92872 .04032 L
.92885 .04029 L
.92899 .04023 L
.92914 .04014 L
.92941 .03992 L
.92969 .0396 L
.93 .03916 L
.93055 .0381 L
.93121 .03644 L
.93182 .03455 L
.93429 .02404 L
.93491 .02104 L
.9355 .01835 L
.93575 .01732 L
.93602 .01643 L
.93616 .01608 L
.93632 .01583 L
.93646 .01573 L
.93659 .01575 L
.93673 .0159 L
.93688 .01619 L
.93702 .01656 L
.93715 .01698 L
.93766 .01905 L
.93881 .02452 L
.93995 .02973 L
.94118 .03446 L
.94185 .03648 L
.94246 .03797 L
.94304 .03904 L
.94334 .03944 L
.9435 .03962 L
.94366 .03977 L
.9438 .03988 L
.94395 .03997 L
.94409 .04004 L
.94422 .04007 L
.94436 .0401 L
.94451 .04009 L
.94459 .04008 L
.94467 .04007 L
.94482 .04001 L
.94495 .03994 L
.94509 .03985 L
.94538 .03959 L
.94565 .03926 L
.9459 .03889 L
.94651 .03771 L
.94717 .03601 L
.94837 .03192 L
Mistroke
.95061 .02181 L
.95116 .01923 L
.95147 .01792 L
.95175 .01684 L
.95192 .01635 L
.952 .01614 L
.95209 .01595 L
.95218 .01582 L
.95225 .01574 L
.9524 .0157 L
.95255 .0158 L
.95264 .01592 L
.95271 .01607 L
.95286 .01642 L
.95301 .01688 L
.95422 .02219 L
.95555 .0284 L
.95676 .03328 L
.9579 .03682 L
.95854 .03824 L
.9589 .03886 L
.95923 .03931 L
.9595 .0396 L
.95966 .03972 L
.95981 .03982 L
.95997 .03989 L
.96011 .03993 L
.96026 .03995 L
.96034 .03995 L
.96043 .03995 L
.96051 .03993 L
.96059 .03991 L
.96074 .03985 L
.96089 .03976 L
.96107 .03963 L
.96138 .03932 L
.96167 .03893 L
.96222 .03796 L
.9628 .03659 L
.96412 .03231 L
.96533 .02725 L
.96644 .022 L
.96705 .01914 L
.96735 .01785 L
.96763 .01683 L
.96777 .0164 L
.96792 .01603 L
.96808 .01578 L
.96817 .01571 L
.96824 .01568 L
Mistroke
.96833 .0157 L
.96842 .01577 L
.96857 .01601 L
.96866 .01621 L
.96874 .01642 L
.96893 .017 L
.97013 .02232 L
.97131 .02785 L
.97258 .03304 L
.9732 .03511 L
.97378 .03676 L
.97435 .03806 L
.97488 .03896 L
.97518 .03935 L
.97534 .0395 L
.97551 .03965 L
.9756 .03971 L
.97569 .03977 L
.97577 .03981 L
.97587 .03985 L
.97602 .03989 L
.97611 .0399 L
.97619 .03991 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.00459847 0.64881 0.188537 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.491929 0.0484262 0.0147151 0.00684776 [
[.00767 -0.0125 -9 -9 ]
[.00767 -0.0125 9 0 ]
[.2498 -0.0125 -6 -9 ]
[.2498 -0.0125 6 0 ]
[.49193 -0.0125 -3 -9 ]
[.49193 -0.0125 3 0 ]
[.73406 -0.0125 -3 -9 ]
[.73406 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .15167 -12 -4.5 ]
[-0.0125 .15167 0 4.5 ]
[-0.0125 .28863 -12 -4.5 ]
[-0.0125 .28863 0 4.5 ]
[-0.0125 .42558 -12 -4.5 ]
[-0.0125 .42558 0 4.5 ]
[-0.0125 .56254 -12 -4.5 ]
[-0.0125 .56254 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.00767 0 m
.00767 .00625 L
s
[(-10)] .00767 -0.0125 0 1 Mshowa
.2498 0 m
.2498 .00625 L
s
[(-5)] .2498 -0.0125 0 1 Mshowa
.49193 0 m
.49193 .00625 L
s
[(0)] .49193 -0.0125 0 1 Mshowa
.73406 0 m
.73406 .00625 L
s
[(5)] .73406 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05609 0 m
.05609 .00375 L
s
.10452 0 m
.10452 .00375 L
s
.15295 0 m
.15295 .00375 L
s
.20137 0 m
.20137 .00375 L
s
.29822 0 m
.29822 .00375 L
s
.34665 0 m
.34665 .00375 L
s
.39508 0 m
.39508 .00375 L
s
.4435 0 m
.4435 .00375 L
s
.54036 0 m
.54036 .00375 L
s
.58878 0 m
.58878 .00375 L
s
.63721 0 m
.63721 .00375 L
s
.68563 0 m
.68563 .00375 L
s
.78249 0 m
.78249 .00375 L
s
.83091 0 m
.83091 .00375 L
s
.87934 0 m
.87934 .00375 L
s
.92776 0 m
.92776 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .15167 m
.00625 .15167 L
s
[(20)] -0.0125 .15167 1 0 Mshowa
0 .28863 m
.00625 .28863 L
s
[(40)] -0.0125 .28863 1 0 Mshowa
0 .42558 m
.00625 .42558 L
s
[(60)] -0.0125 .42558 1 0 Mshowa
0 .56254 m
.00625 .56254 L
s
[(80)] -0.0125 .56254 1 0 Mshowa
.125 Mabswid
0 .04895 m
.00375 .04895 L
s
0 .08319 m
.00375 .08319 L
s
0 .11743 m
.00375 .11743 L
s
0 .18591 m
.00375 .18591 L
s
0 .22015 m
.00375 .22015 L
s
0 .25439 m
.00375 .25439 L
s
0 .32286 m
.00375 .32286 L
s
0 .3571 m
.00375 .3571 L
s
0 .39134 m
.00375 .39134 L
s
0 .45982 m
.00375 .45982 L
s
0 .49406 m
.00375 .49406 L
s
0 .5283 m
.00375 .5283 L
s
0 .59677 m
.00375 .59677 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.00767 .61178 m
.00767 .61803 L
s
.2498 .61178 m
.2498 .61803 L
s
.49193 .61178 m
.49193 .61803 L
s
.73406 .61178 m
.73406 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.05609 .61428 m
.05609 .61803 L
s
.10452 .61428 m
.10452 .61803 L
s
.15295 .61428 m
.15295 .61803 L
s
.20137 .61428 m
.20137 .61803 L
s
.29822 .61428 m
.29822 .61803 L
s
.34665 .61428 m
.34665 .61803 L
s
.39508 .61428 m
.39508 .61803 L
s
.4435 .61428 m
.4435 .61803 L
s
.54036 .61428 m
.54036 .61803 L
s
.58878 .61428 m
.58878 .61803 L
s
.63721 .61428 m
.63721 .61803 L
s
.68563 .61428 m
.68563 .61803 L
s
.78249 .61428 m
.78249 .61803 L
s
.83091 .61428 m
.83091 .61803 L
s
.87934 .61428 m
.87934 .61803 L
s
.92776 .61428 m
.92776 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .15167 m
1 .15167 L
s
.99375 .28863 m
1 .28863 L
s
.99375 .42558 m
1 .42558 L
s
.99375 .56254 m
1 .56254 L
s
.125 Mabswid
.99625 .04895 m
1 .04895 L
s
.99625 .08319 m
1 .08319 L
s
.99625 .11743 m
1 .11743 L
s
.99625 .18591 m
1 .18591 L
s
.99625 .22015 m
1 .22015 L
s
.99625 .25439 m
1 .25439 L
s
.99625 .32286 m
1 .32286 L
s
.99625 .3571 m
1 .3571 L
s
.99625 .39134 m
1 .39134 L
s
.99625 .45982 m
1 .45982 L
s
.99625 .49406 m
1 .49406 L
s
.99625 .5283 m
1 .5283 L
s
.99625 .59677 m
1 .59677 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .01472 m
.02381 .05587 L
s
.03995 .01472 m
.03995 .05607 L
s
.05609 .01472 m
.05609 .05642 L
s
.07224 .01472 m
.07224 .05691 L
s
.08838 .01472 m
.08838 .05756 L
s
.10452 .01472 m
.10452 .05838 L
s
.12066 .01472 m
.12066 .05938 L
s
.1368 .01472 m
.1368 .0606 L
s
.15295 .01472 m
.15295 .06206 L
s
.16909 .01472 m
.16909 .0638 L
s
.18523 .01472 m
.18523 .06587 L
s
.20137 .01472 m
.20137 .06834 L
s
.21751 .01472 m
.21751 .07132 L
s
.23366 .01472 m
.23366 .07493 L
s
.2498 .01472 m
.2498 .07937 L
s
.26594 .01472 m
.26594 .08492 L
s
.28208 .01472 m
.28208 .09206 L
s
.29822 .01472 m
.29822 .10155 L
s
.31437 .01472 m
.31437 .11484 L
s
.33051 .01472 m
.33051 .1349 L
s
.34665 .01472 m
.34665 .16934 L
s
.36279 .01472 m
.36279 .24534 L
s
.37893 .01472 m
.37893 .60332 L
s
.39508 .01472 m
.39508 .45716 L
s
.41122 .01472 m
.41122 .08156 L
s
.42736 .01472 m
.42736 .21533 L
s
.4435 .01472 m
.4435 .30844 L
s
.45964 .01472 m
.45964 .11568 L
s
.47579 .01472 m
.47579 .06978 L
s
.49193 .01472 m
.49193 .46667 L
s
.50807 .01472 m
.50807 .06978 L
s
.52421 .01472 m
.52421 .11568 L
s
.54036 .01472 m
.54036 .30844 L
s
.5565 .01472 m
.5565 .21533 L
s
.57264 .01472 m
.57264 .08156 L
s
.58878 .01472 m
.58878 .45716 L
s
.60492 .01472 m
.60492 .60332 L
s
.62107 .01472 m
.62107 .24534 L
s
.63721 .01472 m
.63721 .16934 L
s
.65335 .01472 m
.65335 .1349 L
s
.66949 .01472 m
.66949 .11484 L
s
.68563 .01472 m
.68563 .10155 L
s
.70178 .01472 m
.70178 .09206 L
s
.71792 .01472 m
.71792 .08492 L
s
.73406 .01472 m
.73406 .07937 L
s
.7502 .01472 m
.7502 .07493 L
s
.76634 .01472 m
.76634 .07132 L
s
.78249 .01472 m
.78249 .06834 L
s
.79863 .01472 m
.79863 .06587 L
s
.81477 .01472 m
.81477 .0638 L
s
.83091 .01472 m
.83091 .06206 L
s
.84705 .01472 m
.84705 .0606 L
s
.8632 .01472 m
.8632 .05938 L
s
.87934 .01472 m
.87934 .05838 L
s
.89548 .01472 m
.89548 .05756 L
s
.91162 .01472 m
.91162 .05691 L
s
.92776 .01472 m
.92776 .05642 L
s
.94391 .01472 m
.94391 .05607 L
s
.96005 .01472 m
.96005 .05587 L
s
.97619 .01472 m
.97619 .0558 L
s
.015 w
.02381 .05587 Mdot
.03995 .05607 Mdot
.05609 .05642 Mdot
.07224 .05691 Mdot
.08838 .05756 Mdot
.10452 .05838 Mdot
.12066 .05938 Mdot
.1368 .0606 Mdot
.15295 .06206 Mdot
.16909 .0638 Mdot
.18523 .06587 Mdot
.20137 .06834 Mdot
.21751 .07132 Mdot
.23366 .07493 Mdot
.2498 .07937 Mdot
.26594 .08492 Mdot
.28208 .09206 Mdot
.29822 .10155 Mdot
.31437 .11484 Mdot
.33051 .1349 Mdot
.34665 .16934 Mdot
.36279 .24534 Mdot
.37893 .60332 Mdot
.39508 .45716 Mdot
.41122 .08156 Mdot
.42736 .21533 Mdot
.4435 .30844 Mdot
.45964 .11568 Mdot
.47579 .06978 Mdot
.49193 .46667 Mdot
.50807 .06978 Mdot
.52421 .11568 Mdot
.54036 .30844 Mdot
.5565 .21533 Mdot
.57264 .08156 Mdot
.58878 .45716 Mdot
.60492 .60332 Mdot
.62107 .24534 Mdot
.63721 .16934 Mdot
.65335 .1349 Mdot
.66949 .11484 Mdot
.68563 .10155 Mdot
.70178 .09206 Mdot
.71792 .08492 Mdot
.73406 .07937 Mdot
.7502 .07493 Mdot
.76634 .07132 Mdot
.78249 .06834 Mdot
.79863 .06587 Mdot
.81477 .0638 Mdot
.83091 .06206 Mdot
.84705 .0606 Mdot
.8632 .05938 Mdot
.87934 .05838 Mdot
.89548 .05756 Mdot
.91162 .05691 Mdot
.92776 .05642 Mdot
.94391 .05607 Mdot
.96005 .05587 Mdot
.97619 .0558 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.00459847 0.97619 0.188537 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.047619 0.0147151 0.00481352 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .11099 -12 -4.5 ]
[-0.0125 .11099 0 4.5 ]
[-0.0125 .20726 -12 -4.5 ]
[-0.0125 .20726 0 4.5 ]
[-0.0125 .30353 -12 -4.5 ]
[-0.0125 .30353 0 4.5 ]
[-0.0125 .3998 -12 -4.5 ]
[-0.0125 .3998 0 4.5 ]
[-0.0125 .49607 -18 -4.5 ]
[-0.0125 .49607 0 4.5 ]
[-0.0125 .59234 -18 -4.5 ]
[-0.0125 .59234 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .11099 m
.00625 .11099 L
s
[(20)] -0.0125 .11099 1 0 Mshowa
0 .20726 m
.00625 .20726 L
s
[(40)] -0.0125 .20726 1 0 Mshowa
0 .30353 m
.00625 .30353 L
s
[(60)] -0.0125 .30353 1 0 Mshowa
0 .3998 m
.00625 .3998 L
s
[(80)] -0.0125 .3998 1 0 Mshowa
0 .49607 m
.00625 .49607 L
s
[(100)] -0.0125 .49607 1 0 Mshowa
0 .59234 m
.00625 .59234 L
s
[(120)] -0.0125 .59234 1 0 Mshowa
.125 Mabswid
0 .03878 m
.00375 .03878 L
s
0 .06285 m
.00375 .06285 L
s
0 .08692 m
.00375 .08692 L
s
0 .13505 m
.00375 .13505 L
s
0 .15912 m
.00375 .15912 L
s
0 .18319 m
.00375 .18319 L
s
0 .23132 m
.00375 .23132 L
s
0 .25539 m
.00375 .25539 L
s
0 .27946 m
.00375 .27946 L
s
0 .32759 m
.00375 .32759 L
s
0 .35166 m
.00375 .35166 L
s
0 .37573 m
.00375 .37573 L
s
0 .42386 m
.00375 .42386 L
s
0 .44793 m
.00375 .44793 L
s
0 .472 m
.00375 .472 L
s
0 .52013 m
.00375 .52013 L
s
0 .5442 m
.00375 .5442 L
s
0 .56827 m
.00375 .56827 L
s
0 .6164 m
.00375 .6164 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .11099 m
1 .11099 L
s
.99375 .20726 m
1 .20726 L
s
.99375 .30353 m
1 .30353 L
s
.99375 .3998 m
1 .3998 L
s
.99375 .49607 m
1 .49607 L
s
.99375 .59234 m
1 .59234 L
s
.125 Mabswid
.99625 .03878 m
1 .03878 L
s
.99625 .06285 m
1 .06285 L
s
.99625 .08692 m
1 .08692 L
s
.99625 .13505 m
1 .13505 L
s
.99625 .15912 m
1 .15912 L
s
.99625 .18319 m
1 .18319 L
s
.99625 .23132 m
1 .23132 L
s
.99625 .25539 m
1 .25539 L
s
.99625 .27946 m
1 .27946 L
s
.99625 .32759 m
1 .32759 L
s
.99625 .35166 m
1 .35166 L
s
.99625 .37573 m
1 .37573 L
s
.99625 .42386 m
1 .42386 L
s
.99625 .44793 m
1 .44793 L
s
.99625 .472 m
1 .472 L
s
.99625 .52013 m
1 .52013 L
s
.99625 .5442 m
1 .5442 L
s
.99625 .56827 m
1 .56827 L
s
.99625 .6164 m
1 .6164 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
0 0 1 r
.5 Mabswid
[ .01 ] 0 setdash
.02381 .0436 m
.02395 .04359 L
.02408 .04356 L
.02423 .0435 L
.02437 .04342 L
.02462 .04324 L
.02489 .04295 L
.02519 .04255 L
.02551 .04203 L
.02608 .04082 L
.02722 .03748 L
.02847 .03259 L
.02973 .02678 L
.03043 .0235 L
.03077 .02199 L
.03109 .02078 L
.03125 .0203 L
.03139 .01994 L
.03147 .01978 L
.03156 .01965 L
.03171 .01954 L
.03179 .01954 L
.03188 .01958 L
.03197 .01969 L
.03206 .01983 L
.03221 .02019 L
.03238 .02069 L
.03299 .02316 L
.03355 .02577 L
.03476 .03143 L
.03605 .03668 L
.03714 .04015 L
.03777 .04164 L
.03805 .04217 L
.03836 .04267 L
.03863 .04302 L
.03892 .04332 L
.03908 .04344 L
.03923 .04353 L
.03938 .04359 L
.03952 .04363 L
.03965 .04364 L
.03978 .04364 L
.0399 .04362 L
.04003 .04358 L
.04017 .04352 L
.04031 .04343 L
.04058 .04321 L
.04089 .04286 L
.04122 .04236 L
Mistroke
.04183 .04116 L
.04243 .03963 L
.04298 .03792 L
.04525 .02852 L
.04644 .02291 L
.04673 .02167 L
.04705 .02055 L
.04722 .02005 L
.04731 .01987 L
.04739 .01973 L
.04746 .01963 L
.04755 .01956 L
.0477 .01956 L
.04778 .01962 L
.04786 .01973 L
.04802 .02002 L
.04819 .02051 L
.04836 .02107 L
.04905 .02403 L
.05029 .0299 L
.05155 .03536 L
.05217 .03763 L
.05273 .03943 L
.05326 .04087 L
.05383 .04213 L
.05415 .04267 L
.05444 .04308 L
.05472 .04338 L
.05487 .04351 L
.05501 .04361 L
.05517 .0437 L
.05531 .04375 L
.05546 .04378 L
.05555 .04379 L
.05563 .04379 L
.05576 .04377 L
.05591 .04373 L
.05606 .04366 L
.0562 .04357 L
.05653 .04328 L
.05683 .04292 L
.05716 .04241 L
.05751 .04174 L
.05866 .0387 L
.05989 .03416 L
.0621 .02396 L
.0627 .02136 L
.063 .02034 L
.06309 .02012 L
.06318 .01991 L
Mistroke
.06326 .01976 L
.06334 .01966 L
.06342 .01959 L
.06351 .01957 L
.0636 .0196 L
.06369 .01969 L
.06378 .01983 L
.06387 .02 L
.06403 .02043 L
.06434 .02151 L
.06467 .02292 L
.06583 .02842 L
.0671 .03418 L
.06827 .03855 L
.0689 .04048 L
.06951 .04194 L
.06984 .04258 L
.0702 .04315 L
.07052 .04354 L
.07068 .04369 L
.07082 .04381 L
.07096 .04389 L
.07111 .04396 L
.07119 .04399 L
.07127 .04401 L
.07142 .04403 L
.07158 .04402 L
.07172 .04399 L
.0718 .04396 L
.07188 .04393 L
.07205 .04383 L
.0722 .04373 L
.07233 .04361 L
.07264 .04326 L
.07294 .04282 L
.07326 .04225 L
.07437 .03945 L
.07504 .03719 L
.07568 .03471 L
.07688 .02935 L
.07804 .02378 L
.07837 .02228 L
.07868 .02103 L
.07882 .02057 L
.07897 .02016 L
.07912 .01982 L
.07927 .01965 L
.07941 .01961 L
.07954 .01969 L
.07968 .01991 L
Mistroke
.07982 .02022 L
.08006 .02099 L
.08033 .02203 L
.08149 .0275 L
.08262 .03281 L
.08383 .03775 L
.08453 .04005 L
.08517 .04176 L
.08547 .04243 L
.08581 .04306 L
.0861 .04351 L
.08642 .0439 L
.08658 .04405 L
.08674 .04417 L
.08689 .04426 L
.08704 .04433 L
.08718 .04436 L
.08731 .04438 L
.08745 .04437 L
.08761 .04434 L
.08769 .04431 L
.08777 .04427 L
.08795 .04417 L
.08811 .04405 L
.08827 .04389 L
.08856 .04354 L
.08888 .04305 L
.08944 .04192 L
.09006 .04032 L
.09116 .03655 L
.09353 .02574 L
.09418 .02267 L
.09454 .0212 L
.09471 .0206 L
.09487 .02015 L
.09503 .01985 L
.0951 .01975 L
.09519 .01968 L
.09527 .01966 L
.09536 .0197 L
.09545 .01979 L
.09553 .01991 L
.09567 .02023 L
.09583 .02069 L
.09612 .02176 L
.09863 .03366 L
.09972 .03811 L
.1009 .0418 L
.10154 .04322 L
.10182 .0437 L
Mistroke
.10212 .04414 L
.10241 .04446 L
.10255 .04457 L
.10268 .04466 L
.10283 .04474 L
.10297 .04479 L
.10312 .04483 L
.10328 .04483 L
.10343 .04481 L
.10358 .04476 L
.10366 .04472 L
.10374 .04468 L
.10391 .04456 L
.10424 .04424 L
.10459 .04377 L
.10517 .04269 L
.10581 .0411 L
.10705 .03687 L
.10817 .03197 L
.10949 .02551 L
.11007 .02275 L
.11037 .02145 L
.11054 .02083 L
.1107 .02035 L
.11085 .02001 L
.11101 .01979 L
.11115 .01973 L
.11128 .01981 L
.11141 .01999 L
.11155 .0203 L
.11169 .02072 L
.11183 .0212 L
.11302 .02676 L
.11424 .03278 L
.11553 .03828 L
.11669 .04206 L
.11735 .04362 L
.11766 .0442 L
.11796 .04464 L
.11823 .04496 L
.11837 .04509 L
.11852 .04521 L
.11865 .04529 L
.11879 .04535 L
.11892 .04539 L
.11904 .0454 L
.11919 .0454 L
.11933 .04538 L
.11945 .04534 L
.11959 .04527 L
Mistroke
.11974 .04517 L
.1199 .04504 L
.12019 .04473 L
.1205 .04428 L
.12084 .04368 L
.12143 .04231 L
.12207 .04043 L
.12277 .03791 L
.12405 .03235 L
.12521 .02655 L
.12578 .02366 L
.12609 .02225 L
.12641 .02097 L
.12655 .02053 L
.1267 .02016 L
.12678 .02001 L
.12686 .0199 L
.12701 .01982 L
.12714 .01987 L
.12728 .02006 L
.12742 .02039 L
.12756 .0208 L
.1282 .02348 L
.12878 .0264 L
.13008 .03299 L
.13121 .03801 L
.1324 .04219 L
.13302 .04382 L
.13335 .04452 L
.1337 .04513 L
.13403 .04556 L
.13432 .04585 L
.13447 .04595 L
.13462 .04603 L
.13477 .04609 L
.1349 .04611 L
.13506 .04611 L
.13514 .0461 L
.13522 .04608 L
.13538 .04603 L
.13552 .04595 L
.13569 .04583 L
.13584 .04569 L
.13618 .04527 L
.13648 .0448 L
.1368 .04418 L
.13739 .04275 L
.13855 .03885 L
.13963 .03418 L
.14072 .02874 L
Mistroke
.14189 .02279 L
.14223 .02133 L
.1424 .02074 L
.14256 .02031 L
.1427 .02005 L
.14285 .01993 L
.14294 .01993 L
.14302 .01998 L
.14317 .02021 L
.14332 .02056 L
.14347 .02105 L
.14375 .02215 L
.14437 .0252 L
.1456 .03166 L
.14677 .03725 L
.1479 .04172 L
.1484 .04329 L
.14895 .04473 L
.1495 .04581 L
.1498 .04626 L
.15008 .04658 L
.15023 .04671 L
.15038 .04682 L
.15052 .04689 L
.15067 .04694 L
.15082 .04697 L
.15091 .04697 L
.15099 .04696 L
.15115 .04693 L
.1513 .04686 L
.15145 .04677 L
.15161 .04665 L
.15193 .04629 L
.15223 .04585 L
.15251 .04535 L
.15314 .04387 L
.15382 .04179 L
.15504 .03692 L
.15637 .03032 L
.15703 .02681 L
.15765 .02359 L
.15792 .02231 L
.1582 .02116 L
.15835 .02068 L
.15843 .02047 L
.15851 .02029 L
.15866 .02009 L
.1588 .02005 L
.15896 .02018 L
.1591 .02046 L
Mistroke
.15918 .02066 L
.15927 .02092 L
.15944 .02154 L
.16004 .02439 L
.16117 .03052 L
.16249 .03724 L
.1637 .04228 L
.16429 .04422 L
.16484 .04569 L
.16541 .04685 L
.16572 .04731 L
.16604 .04767 L
.16621 .0478 L
.16636 .0479 L
.16645 .04794 L
.16654 .04797 L
.16663 .04799 L
.16672 .048 L
.1668 .048 L
.16688 .04799 L
.16703 .04795 L
.16718 .04789 L
.16727 .04783 L
.16736 .04777 L
.16766 .04749 L
.16794 .04713 L
.16856 .04598 L
.16915 .04446 L
.16977 .04243 L
.17088 .03782 L
.1721 .03167 L
.17277 .02799 L
.1734 .02453 L
.17369 .02305 L
.17399 .02167 L
.17415 .02108 L
.17424 .02081 L
.17433 .02057 L
.17441 .0204 L
.17449 .02028 L
.17464 .02019 L
.17478 .02026 L
.17492 .02047 L
.17506 .02085 L
.17522 .02138 L
.17577 .02393 L
.17799 .0361 L
.17923 .04187 L
.17988 .04433 L
.18057 .04643 L
Mistroke
.18117 .0478 L
.18151 .04838 L
.18168 .04861 L
.18183 .04879 L
.18198 .04893 L
.18213 .04905 L
.18227 .04913 L
.1824 .04918 L
.18254 .04921 L
.18269 .04922 L
.18277 .04921 L
.18285 .0492 L
.183 .04914 L
.18315 .04906 L
.18329 .04895 L
.1836 .04863 L
.18388 .04822 L
.18415 .04774 L
.18476 .04633 L
.18542 .0443 L
.18674 .0388 L
.18796 .03239 L
.18905 .02614 L
.18965 .0229 L
.18995 .02159 L
.19009 .02108 L
.19022 .02072 L
.19038 .02044 L
.19046 .02037 L
.19055 .02035 L
.19063 .0204 L
.19071 .0205 L
.1908 .02067 L
.1909 .0209 L
.19105 .0214 L
.19119 .02197 L
.19151 .02351 L
.19271 .03043 L
.19496 .04237 L
.19558 .0449 L
.19624 .04713 L
.1968 .04863 L
.1971 .04927 L
.19741 .04982 L
.19757 .05004 L
.19774 .05025 L
.1979 .05041 L
.19805 .05052 L
.19813 .05057 L
.19822 .05061 L
Mistroke
.19832 .05065 L
.1984 .05067 L
.19849 .05068 L
.19858 .05068 L
.19874 .05066 L
.19888 .0506 L
.19904 .05051 L
.19919 .05039 L
.19933 .05025 L
.19966 .04982 L
.19998 .04927 L
.20058 .04785 L
.20114 .04613 L
.20241 .04089 L
.20358 .03468 L
.20484 .02714 L
.20543 .02379 L
.20574 .02221 L
.2059 .02157 L
.20604 .0211 L
.20617 .02078 L
.20629 .0206 L
.20642 .02055 L
.20656 .02066 L
.20671 .02094 L
.20686 .02141 L
.20714 .02257 L
.20933 .0356 L
.21054 .0422 L
.21168 .04719 L
.21227 .04916 L
.21258 .05002 L
.21292 .0508 L
.21322 .05139 L
.2135 .05181 L
.21363 .05198 L
.21378 .05213 L
.21391 .05223 L
.21404 .05232 L
.21418 .05238 L
.21431 .05242 L
.21446 .05243 L
.2146 .0524 L
.21475 .05235 L
.2149 .05226 L
.21505 .05214 L
.21519 .052 L
.21544 .05169 L
.2157 .05125 L
.21625 .05005 L
Mistroke
.21684 .04829 L
.21747 .04595 L
.21858 .04064 L
.2198 .03357 L
.22047 .02935 L
.2211 .0254 L
.22139 .02372 L
.2217 .02218 L
.22186 .02155 L
.22195 .02127 L
.22204 .02104 L
.22212 .02089 L
.2222 .0208 L
.22235 .02079 L
.22249 .02098 L
.22263 .02131 L
.22277 .02182 L
.22293 .02251 L
.22348 .0256 L
.2257 .03967 L
.22694 .04628 L
.2276 .04908 L
.22829 .05145 L
.22889 .053 L
.22924 .05364 L
.2294 .05389 L
.22956 .05408 L
.2297 .05423 L
.22985 .05436 L
.22999 .05444 L
.23012 .05449 L
.23026 .05452 L
.23041 .05452 L
.23049 .0545 L
.23057 .05447 L
.23072 .0544 L
.2308 .05434 L
.23088 .05428 L
.23103 .05414 L
.23135 .05371 L
.23163 .05321 L
.23194 .05253 L
.23263 .05051 L
.23327 .04806 L
.23445 .04222 L
.23569 .03457 L
.23683 .02693 L
.23713 .02501 L
.23746 .02312 L
.23761 .02239 L
Mistroke
.23777 .02175 L
.23791 .02134 L
.23806 .02108 L
.23821 .02104 L
.23834 .0212 L
.23849 .02158 L
.23865 .02217 L
.23892 .02349 L
.23921 .02524 L
.24027 .03244 L
.24159 .04124 L
.24283 .04827 L
.24395 .05302 L
.24425 .05402 L
.24458 .05494 L
.24488 .05565 L
.24516 .05618 L
.24529 .05639 L
.24544 .05659 L
.24559 .05675 L
.24572 .05687 L
.24587 .05697 L
.24595 .05701 L
.24603 .05704 L
.24617 .05706 L
.24632 .05706 L
.24645 .05702 L
.24659 .05695 L
.24674 .05684 L
.24688 .0567 L
.24713 .05638 L
.2474 .05592 L
.24772 .05524 L
.24806 .05431 L
.24869 .05216 L
.24986 .04666 L
.25221 .03132 L
.25285 .02675 L
.25318 .02453 L
.25337 .02345 L
.25354 .02258 L
.25369 .02197 L
.25377 .0217 L
.25385 .02152 L
.25393 .02138 L
.25402 .02132 L
.25411 .02135 L
.25419 .02145 L
.25433 .02178 L
.25448 .02233 L
Mistroke
.25479 .02393 L
.25727 .04174 L
.25835 .04865 L
.25953 .05459 L
.26015 .05694 L
.26043 .05778 L
.26073 .05857 L
.261 .05914 L
.26129 .05961 L
.26144 .05982 L
.26159 .05996 L
.26173 .06007 L
.26188 .06015 L
.26203 .06019 L
.26218 .06019 L
.26226 .06018 L
.26234 .06015 L
.2625 .06006 L
.26265 .05994 L
.2628 .05977 L
.26308 .05937 L
.2634 .05873 L
.26371 .05798 L
.2644 .05568 L
.265 .05308 L
.26565 .04963 L
.26684 .04196 L
.26799 .03331 L
.26855 .02892 L
.26907 .02513 L
.26936 .02337 L
.26952 .02258 L
.26967 .02204 L
.26982 .02173 L
.26991 .02167 L
.26999 .0217 L
.27007 .02181 L
.27016 .02202 L
.27024 .02229 L
.27032 .0226 L
.27058 .02398 L
.27086 .0259 L
.27145 .03039 L
.27277 .04103 L
.27398 .04982 L
.27511 .0565 L
.27568 .05915 L
.27631 .06144 L
.27664 .06237 L
.27694 .06305 L
Mistroke
.27711 .06335 L
.27729 .06363 L
.27746 .06383 L
.27761 .06397 L
.27776 .06406 L
.27789 .0641 L
.27804 .06411 L
.27812 .0641 L
.2782 .06408 L
.27835 .064 L
.27844 .06394 L
.27852 .06386 L
.27882 .06348 L
.27898 .06322 L
.27914 .06289 L
.27944 .06218 L
.2801 .05999 L
.28068 .05747 L
.2813 .05409 L
.28355 .03764 L
.28413 .03269 L
.28476 .02741 L
.28505 .02522 L
.28521 .02416 L
.28536 .02331 L
.28548 .02273 L
.28562 .02229 L
.28577 .02208 L
.28591 .02217 L
.28599 .02232 L
.28607 .02258 L
.28622 .02322 L
.28639 .02424 L
.28655 .02534 L
.28723 .03093 L
.28843 .04167 L
.28956 .05099 L
.29075 .05922 L
.29137 .06265 L
.29206 .06564 L
.29236 .06667 L
.29268 .06759 L
.29298 .06826 L
.29313 .06851 L
.29326 .06871 L
.2934 .06889 L
.29354 .06901 L
.29368 .0691 L
.29384 .06915 L
.29398 .06915 L
Mistroke
.29414 .0691 L
.29422 .06906 L
.2943 .06899 L
.29445 .06885 L
.2946 .06866 L
.29475 .06841 L
.29503 .06784 L
.29556 .06632 L
.29619 .06377 L
.29686 .06023 L
.29806 .05192 L
.29929 .04139 L
.30045 .0304 L
.30095 .02597 L
.3011 .02488 L
.30123 .02399 L
.30136 .02333 L
.30149 .02283 L
.30164 .02257 L
.3018 .02268 L
.30193 .02308 L
.30208 .0238 L
.30222 .02466 L
.30236 .02576 L
.30263 .02802 L
.30497 .051 L
.30628 .06198 L
.30749 .06965 L
.30809 .07237 L
.30839 .07348 L
.30872 .07444 L
.30889 .07484 L
.30905 .07515 L
.30921 .07541 L
.30935 .0756 L
.30944 .07569 L
.30952 .07575 L
.3096 .0758 L
.30969 .07584 L
.30978 .07586 L
.30988 .07586 L
.30997 .07584 L
.31005 .0758 L
.31019 .07571 L
.31034 .07555 L
.31049 .07535 L
.31062 .07513 L
.31093 .07443 L
.31123 .07354 L
.31183 .07116 L
Mistroke
.31248 .06767 L
.31373 .05854 L
.31486 .04795 L
.31618 .03385 L
.31676 .02785 L
.31692 .0264 L
.31709 .02503 L
.31717 .02446 L
.31725 .024 L
.31739 .02338 L
.31753 .02313 L
.31767 .02327 L
.3178 .02369 L
.31794 .02445 L
.31808 .02552 L
.31824 .0269 L
.31852 .02977 L
.31972 .04344 L
.32102 .05795 L
.32223 .06947 L
.32345 .07829 L
.32409 .08159 L
.32445 .083 L
.32478 .08399 L
.32493 .08435 L
.32509 .08467 L
.32523 .08489 L
.32538 .08508 L
.32546 .08515 L
.32554 .08521 L
.32563 .08525 L
.32572 .08527 L
.32587 .08525 L
.32595 .08522 L
.32603 .08517 L
.32617 .08504 L
.3263 .08487 L
.32644 .08463 L
.3266 .0843 L
.32691 .08344 L
.3272 .08242 L
.32778 .07974 L
.32839 .07594 L
.32949 .06682 L
.33198 .03779 L
.33258 .03028 L
.33274 .02847 L
.33291 .0267 L
.33307 .02533 L
.33322 .02437 L
Mistroke
.3333 .02402 L
.33339 .02383 L
.33355 .02398 L
.33364 .02433 L
.33374 .02491 L
.33391 .02636 L
.33425 .03009 L
.33455 .03401 L
.33699 .06692 L
.33812 .07984 L
.33931 .09042 L
.33993 .09446 L
.34029 .09625 L
.34062 .09758 L
.34078 .09809 L
.34092 .0985 L
.34106 .09882 L
.3412 .09909 L
.34136 .09931 L
.3415 .09945 L
.34165 .09952 L
.34174 .09952 L
.34182 .09951 L
.34196 .09942 L
.34212 .09926 L
.34226 .09904 L
.34239 .09878 L
.34271 .0979 L
.34301 .09677 L
.34361 .09362 L
.34426 .08892 L
.34542 .07734 L
.34649 .06348 L
.34759 .04695 L
.34819 .03734 L
.34876 .02886 L
.34892 .02699 L
.349 .02613 L
.34908 .02547 L
.34917 .02496 L
.34926 .02466 L
.34935 .02466 L
.34943 .02491 L
.34959 .02596 L
.34967 .02673 L
.34975 .02771 L
.35005 .03184 L
.35125 .0526 L
.35257 .07543 L
.35381 .09451 L
Mistroke
.35493 .10836 L
.35556 .11446 L
.35614 .11886 L
.35641 .12047 L
.3567 .12189 L
.35697 .12292 L
.35709 .12328 L
.35722 .1236 L
.35738 .12388 L
.35752 .12406 L
.3576 .12412 L
.35769 .12416 L
.35784 .12414 L
.35798 .12404 L
.35812 .12386 L
.35827 .12358 L
.35842 .12318 L
.35871 .12217 L
.35902 .12069 L
.35957 .11697 L
.36024 .11083 L
.36084 .10365 L
.36334 .05993 L
.36444 .03614 L
.36474 .03023 L
.36482 .02884 L
.36491 .02757 L
.36506 .026 L
.36521 .02566 L
.36534 .02645 L
.36549 .02832 L
.36565 .03111 L
.36789 .08647 L
.37027 .14067 L
.37151 .16145 L
.3722 .17007 L
.37254 .17328 L
.37285 .17573 L
.37312 .17742 L
.37326 .17812 L
.37341 .17875 L
.3735 .17904 L
.37358 .17927 L
.37373 .17961 L
.37388 .17979 L
.37403 .17984 L
.37411 .1798 L
.37419 .17972 L
.37428 .1796 L
.37437 .17941 L
Mistroke
.37452 .17897 L
.37468 .17832 L
.37499 .17664 L
.37528 .17449 L
.37588 .16811 L
.37654 .15831 L
.37716 .14631 L
.37774 .13289 L
.37998 .06069 L
.38054 .03924 L
.3807 .03352 L
.38085 .02906 L
.38099 .02695 L
.38114 .02797 L
.38129 .03172 L
.38142 .0364 L
.38171 .04879 L
.38223 .07364 L
.38472 .20583 L
.38724 .34453 L
.38955 .45895 L
.39072 .50703 L
.39181 .54423 L
.39295 .57396 L
.39355 .58567 L
.39386 .59061 L
.3942 .59498 L
.3945 .59816 L
.39466 .59954 L
.39483 .60079 L
.39499 .60171 L
.39514 .60237 L
.39528 .60285 L
.39542 .60317 L
.39558 .60332 L
.39567 .60331 L
.39575 .60324 L
.39591 .60296 L
.39606 .6025 L
.39614 .60217 L
.39623 .60174 L
.39639 .60082 L
.39676 .59797 L
.39704 .59495 L
.39735 .59099 L
.39791 .58194 L
.39918 .55284 L
.4004 .51486 L
.40173 .46412 L
.40416 .3548 L
Mistroke
.40673 .23058 L
.40906 .12675 L
.41023 .08208 L
.41085 .06141 L
.41118 .05119 L
.4115 .04258 L
.41179 .03563 L
.41192 .03318 L
.41207 .03108 L
.41222 .02966 L
.41237 .02929 L
.41245 .02951 L
.41254 .03002 L
.41269 .03156 L
.41282 .03328 L
.41296 .03539 L
.41321 .03958 L
.41379 .04926 L
.41435 .05772 L
.41494 .06524 L
.41529 .06879 L
.4156 .07153 L
.41589 .07371 L
.41621 .07556 L
.41636 .07631 L
.41653 .07701 L
.41669 .07755 L
.41684 .07793 L
.41701 .07828 L
.4171 .07842 L
.41719 .07851 L
.41735 .07861 L
.41743 .07861 L
.41752 .07859 L
.41759 .07855 L
.41768 .07847 L
.41783 .07827 L
.41798 .07799 L
.41812 .07766 L
.41843 .07667 L
.41875 .07528 L
.41935 .07189 L
.4199 .06797 L
.42113 .05699 L
.42334 .03383 L
.42392 .02795 L
.42454 .02233 L
.4248 .0204 L
.42494 .01954 L
.42507 .01893 L
Mistroke
.42523 .01857 L
.42537 .01864 L
.4255 .01902 L
.42565 .01966 L
.42816 .03342 L
.42938 .03935 L
.43053 .0472 L
.43117 .0533 L
.43186 .06159 L
.43306 .08023 L
.43546 .13045 L
.438 .19311 L
.4404 .24953 L
.44145 .27049 L
.44258 .28939 L
.44321 .29778 L
.44379 .30411 L
.44435 .3088 L
.44463 .31064 L
.44494 .31226 L
.4451 .31292 L
.44526 .31348 L
.44541 .31386 L
.44556 .31416 L
.44565 .31428 L
.44573 .31436 L
.44582 .31441 L
.44591 .31441 L
.44607 .31434 L
.44616 .31424 L
.44624 .31412 L
.44638 .31383 L
.44652 .31346 L
.44683 .31228 L
.44713 .3107 L
.44746 .3085 L
.44809 .3028 L
.44868 .29588 L
.45001 .27468 L
.45119 .25036 L
.45244 .21975 L
.45485 .15222 L
.45612 .11571 L
.45746 .08 L
.45804 .06668 L
.45836 .06036 L
.45866 .0553 L
.45883 .05293 L
.45902 .05082 L
.4591 .05006 L
Mistroke
.45919 .04938 L
.45934 .04848 L
.4595 .048 L
.45964 .04793 L
.45973 .04804 L
.45981 .04825 L
.45989 .04857 L
.45998 .04902 L
.46012 .04998 L
.46026 .05104 L
.46055 .05398 L
.46109 .0604 L
.4623 .07564 L
.46288 .08203 L
.4635 .08764 L
.46403 .09137 L
.46433 .09303 L
.46461 .09429 L
.46477 .09487 L
.46494 .09539 L
.46508 .09574 L
.46524 .09604 L
.46533 .09617 L
.46541 .09627 L
.46549 .09634 L
.46559 .09639 L
.46567 .09641 L
.46576 .0964 L
.46591 .09632 L
.46606 .09617 L
.46621 .09593 L
.46636 .09562 L
.46649 .09528 L
.46682 .09421 L
.46712 .09288 L
.46768 .08976 L
.46829 .08537 L
.46953 .07425 L
.47067 .06305 L
.47124 .05808 L
.47176 .05438 L
.47204 .05291 L
.4722 .05228 L
.47234 .05185 L
.4725 .05153 L
.47259 .05143 L
.47267 .05138 L
.47282 .0514 L
.47298 .0516 L
.47312 .05189 L
Mistroke
.47326 .05233 L
.47352 .05343 L
.47382 .0552 L
.4741 .05716 L
.47541 .06881 L
.47662 .07976 L
.4772 .08418 L
.47774 .08763 L
.4783 .09036 L
.4786 .09142 L
.47877 .09188 L
.47892 .09223 L
.47907 .09248 L
.47923 .09267 L
.47932 .09274 L
.4794 .09278 L
.47956 .09278 L
.47964 .09275 L
.47973 .09268 L
.47988 .0925 L
.47997 .09237 L
.48005 .09221 L
.48023 .09177 L
.48053 .09077 L
.48081 .08955 L
.48143 .08574 L
.482 .08088 L
.48262 .07437 L
.48372 .05956 L
.4844 .04921 L
.48473 .04422 L
.48504 .04008 L
.48518 .03842 L
.48531 .03713 L
.48545 .03612 L
.48561 .0355 L
.48576 .03549 L
.48591 .03604 L
.48598 .03657 L
.48607 .03733 L
.48622 .03913 L
.48651 .04357 L
.48681 .04956 L
.48736 .06236 L
.48862 .09628 L
.49115 .17173 L
.49353 .2391 L
.49478 .26978 L
.49612 .29686 L
.49679 .30782 L
Mistroke
.49742 .31642 L
.49799 .32263 L
.49828 .32525 L
.4986 .32766 L
.49889 .32938 L
.49919 .3308 L
.49935 .33139 L
.49951 .33181 L
.49966 .33212 L
.4998 .33231 L
.49994 .3324 L
.50008 .33239 L
.5002 .33231 L
.50033 .33214 L
.50048 .33185 L
.50063 .33144 L
.50091 .33039 L
.5012 .32891 L
.50151 .32689 L
.50206 .32212 L
.50272 .31458 L
.50332 .30606 L
.50463 .28239 L
.50587 .25443 L
.51051 .12199 L
.51174 .08612 L
.5129 .05598 L
.51348 .04372 L
.51365 .0409 L
.51381 .03867 L
.51395 .0371 L
.51411 .03595 L
.5142 .03558 L
.51429 .03542 L
.51444 .03565 L
.51453 .03605 L
.51461 .03657 L
.5148 .03821 L
.51511 .042 L
.51544 .04676 L
.51658 .06403 L
.51721 .07237 L
.51781 .07907 L
.51837 .08415 L
.51866 .08636 L
.51897 .08834 L
.51923 .08973 L
.51952 .09095 L
.51964 .09139 L
.51978 .09179 L
Mistroke
.5199 .09211 L
.52002 .09235 L
.52018 .09258 L
.52031 .09272 L
.52046 .09279 L
.52055 .09279 L
.52062 .09277 L
.52075 .09269 L
.52089 .09254 L
.52104 .0923 L
.52118 .09201 L
.5215 .0911 L
.52179 .08999 L
.52244 .08656 L
.52307 .08223 L
.52375 .07659 L
.52499 .06504 L
.52553 .06012 L
.52612 .05558 L
.52646 .05358 L
.5266 .05288 L
.52676 .05225 L
.52692 .05181 L
.52706 .05153 L
.52721 .05138 L
.52729 .05137 L
.52737 .0514 L
.52753 .05158 L
.52761 .05173 L
.52769 .05195 L
.52785 .05246 L
.52799 .05307 L
.52832 .05487 L
.52867 .05736 L
.5299 .06867 L
.53112 .08043 L
.53177 .08584 L
.53245 .09058 L
.53279 .09246 L
.53311 .09392 L
.5334 .09495 L
.53355 .09538 L
.53371 .09577 L
.53386 .09605 L
.534 .09624 L
.53415 .09636 L
.53424 .0964 L
.53432 .09641 L
.53445 .09637 L
.5346 .09625 L
Mistroke
.53474 .09607 L
.53487 .09583 L
.53502 .0955 L
.53517 .09507 L
.53543 .0941 L
.53572 .09276 L
.53604 .09095 L
.5366 .08679 L
.53713 .08195 L
.5384 .06698 L
.53903 .0589 L
.53931 .05555 L
.53961 .05227 L
.53975 .05095 L
.53991 .04974 L
.54005 .04885 L
.54019 .04827 L
.54034 .04794 L
.54042 .04791 L
.5405 .04799 L
.54064 .04841 L
.5408 .04925 L
.54088 .04991 L
.54096 .05062 L
.54114 .0526 L
.54147 .05733 L
.54208 .0692 L
.54432 .12823 L
.54679 .19894 L
.54909 .25651 L
.55023 .27905 L
.55131 .29569 L
.5519 .30273 L
.55221 .30579 L
.55255 .30854 L
.55283 .31045 L
.55313 .31212 L
.55327 .31271 L
.55341 .31325 L
.55355 .31366 L
.55368 .31396 L
.55383 .31422 L
.55397 .31437 L
.55412 .31442 L
.5542 .3144 L
.55428 .31435 L
.55441 .31421 L
.55455 .31396 L
.5547 .3136 L
.55483 .31317 L
Mistroke
.55515 .31184 L
.55544 .31021 L
.5561 .30515 L
.55672 .29855 L
.55741 .28955 L
.55865 .26879 L
.56356 .15404 L
.566 .09812 L
.5672 .07585 L
.56829 .05965 L
.56936 .04816 L
.56989 .04388 L
.57048 .04013 L
.57284 .0285 L
.57348 .02487 L
.57408 .02117 L
.57434 .0197 L
.57447 .0191 L
.57462 .01866 L
.57478 .01857 L
.57492 .01891 L
.57506 .01952 L
.57521 .02041 L
.57588 .0261 L
.57652 .03245 L
.57773 .0452 L
.57889 .05716 L
.58012 .06814 L
.58072 .07237 L
.58102 .0741 L
.58129 .07546 L
.58153 .07649 L
.58179 .0774 L
.58192 .07776 L
.58206 .07807 L
.5822 .07833 L
.58234 .07849 L
.58249 .07859 L
.58257 .07861 L
.58265 .07861 L
.58281 .07852 L
.5829 .07842 L
.58298 .0783 L
.58312 .07804 L
.58327 .07767 L
.58357 .07661 L
.5839 .07496 L
.58426 .07262 L
.5849 .06688 L
.58556 .05902 L
Mistroke
.58618 .04984 L
.58677 .03982 L
.58707 .035 L
.58719 .0331 L
.58733 .0313 L
.58747 .02998 L
.5876 .02934 L
.58775 .02951 L
.58789 .03059 L
.58805 .03272 L
.58819 .03531 L
.58851 .04266 L
.58975 .08142 L
.59197 .17105 L
.59682 .40063 L
.59904 .49467 L
.6003 .53786 L
.60091 .55548 L
.60147 .56933 L
.60203 .58093 L
.60264 .59089 L
.60297 .59515 L
.60328 .59831 L
.60357 .60062 L
.60372 .60151 L
.60389 .60229 L
.60397 .6026 L
.60406 .60287 L
.60414 .60307 L
.60422 .6032 L
.60436 .60332 L
.60452 .60325 L
.60461 .60312 L
.6047 .6029 L
.60479 .60263 L
.60488 .60232 L
.60503 .60158 L
.6052 .60057 L
.6055 .59814 L
.60579 .59518 L
.60643 .58602 L
.60703 .57439 L
.60769 .55852 L
.60888 .52154 L
.61112 .428 L
.61346 .30695 L
.61604 .16395 L
.61721 .10144 L
.61783 .07047 L
.61817 .05445 L
Mistroke
.61848 .04056 L
.61862 .03492 L
.61876 .0304 L
.61891 .02719 L
.61905 .02734 L
.61921 .03067 L
.61935 .03529 L
.61968 .04741 L
.62077 .08811 L
.62186 .1223 L
.62304 .15045 L
.62371 .16238 L
.62432 .17056 L
.62462 .17356 L
.62494 .17617 L
.62509 .17712 L
.62524 .17798 L
.62539 .17863 L
.62552 .17911 L
.62567 .1795 L
.62575 .17965 L
.62584 .17976 L
.62593 .17982 L
.62601 .17984 L
.62617 .17975 L
.62632 .17952 L
.62646 .17918 L
.62661 .17868 L
.62677 .178 L
.6271 .17611 L
.62741 .17376 L
.62811 .16647 L
.62872 .15808 L
.62928 .14889 L
.63055 .12374 L
.63174 .09558 L
.63302 .06312 L
.63365 .04735 L
.63395 .03991 L
.63423 .03354 L
.63449 .02866 L
.63462 .02687 L
.63476 .02576 L
.6349 .0258 L
.63505 .02707 L
.6352 .02913 L
.63533 .03145 L
.63649 .0562 L
.63772 .08089 L
.63886 .09955 L
Mistroke
.63993 .11256 L
.64046 .11721 L
.64102 .1209 L
.64133 .12233 L
.6415 .12293 L
.64165 .12338 L
.64178 .12369 L
.64193 .12393 L
.64209 .1241 L
.64223 .12416 L
.64238 .12413 L
.64246 .12407 L
.64255 .12398 L
.6427 .12374 L
.64285 .12343 L
.64301 .12296 L
.64317 .12243 L
.64352 .12088 L
.64414 .11692 L
.64473 .11184 L
.64589 .0986 L
.64712 .08051 L
.64934 .04212 L
.64994 .03198 L
.65025 .0277 L
.65033 .02675 L
.65042 .02588 L
.6505 .02525 L
.65058 .02485 L
.65067 .02464 L
.65075 .02469 L
.65084 .02501 L
.65094 .02563 L
.65102 .02636 L
.6511 .02718 L
.65128 .02939 L
.65192 .03912 L
.65436 .07471 L
.65554 .08724 L
.65614 .09197 L
.65648 .09418 L
.65679 .09586 L
.65706 .09706 L
.65735 .09809 L
.65751 .09854 L
.65766 .09888 L
.6578 .09914 L
.65795 .09934 L
.65808 .09945 L
.65821 .09952 L
Mistroke
.65834 .09952 L
.65846 .09947 L
.6586 .09936 L
.65875 .09917 L
.65889 .09892 L
.65902 .09864 L
.65934 .09771 L
.65964 .09657 L
.6603 .09306 L
.66089 .08892 L
.6615 .08358 L
.66375 .05738 L
.6649 .04153 L
.66553 .03291 L
.66584 .02903 L
.66597 .0275 L
.66612 .02602 L
.66626 .02491 L
.66639 .02418 L
.66653 .02382 L
.66668 .02396 L
.66676 .02424 L
.66684 .02469 L
.667 .02583 L
.66728 .02872 L
.66834 .04189 L
.66956 .05679 L
.67071 .06863 L
.67135 .07397 L
.67203 .07866 L
.67234 .08034 L
.67266 .08186 L
.67294 .08295 L
.67324 .08389 L
.6734 .08429 L
.67354 .0846 L
.67368 .08484 L
.67383 .08504 L
.67397 .08517 L
.6741 .08524 L
.67423 .08527 L
.67438 .08524 L
.67453 .08516 L
.67461 .08508 L
.67469 .085 L
.67485 .08477 L
.67502 .08446 L
.67533 .0837 L
.6756 .08279 L
.67615 .08045 L
Mistroke
.67674 .07711 L
.67781 .06907 L
.68016 .0448 L
.68141 .03048 L
.68177 .02684 L
.68194 .02532 L
.68203 .02468 L
.68211 .02418 L
.68226 .02347 L
.68241 .02314 L
.6825 .02315 L
.68259 .02332 L
.68267 .0236 L
.68275 .02397 L
.68289 .02486 L
.68304 .02604 L
.68332 .02858 L
.68394 .03517 L
.6852 .04857 L
.68639 .05958 L
.6875 .06754 L
.68809 .0708 L
.68873 .0734 L
.68905 .07439 L
.68936 .07509 L
.68954 .07539 L
.6897 .0756 L
.68978 .07568 L
.68988 .07576 L
.68997 .07582 L
.69006 .07585 L
.69021 .07586 L
.6903 .07584 L
.69038 .07581 L
.69052 .07572 L
.69068 .07557 L
.69082 .07538 L
.69094 .07517 L
.69124 .07455 L
.69155 .07366 L
.69184 .07266 L
.69249 .06975 L
.69368 .06226 L
.69479 .0532 L
.69608 .04084 L
.69671 .03446 L
.69729 .02878 L
.69756 .02637 L
.69781 .02444 L
.69794 .02366 L
Mistroke
.69808 .02303 L
.69823 .02263 L
.69837 .02258 L
.69852 .02286 L
.69866 .0234 L
.69881 .02425 L
.69897 .02537 L
.69954 .03024 L
.70073 .04155 L
.70202 .05255 L
.70265 .05713 L
.70325 .06087 L
.70383 .06388 L
.70437 .06609 L
.70489 .06764 L
.70517 .06827 L
.70543 .0687 L
.70558 .06888 L
.70571 .06901 L
.70586 .0691 L
.70602 .06915 L
.70616 .06915 L
.70629 .06911 L
.70643 .06903 L
.70658 .0689 L
.70673 .06873 L
.70689 .06849 L
.70722 .06783 L
.70752 .06703 L
.70781 .06612 L
.70845 .0635 L
.70914 .05985 L
.71157 .04165 L
.71282 .03048 L
.71314 .02779 L
.71343 .02546 L
.7137 .02369 L
.71385 .02291 L
.71399 .0224 L
.71412 .02213 L
.71427 .02211 L
.71443 .02242 L
.71457 .02298 L
.71473 .02381 L
.71488 .02472 L
.7152 .02713 L
.71653 .03833 L
.71764 .04711 L
.71883 .05484 L
.71951 .05834 L
Mistroke
.72012 .06082 L
.72042 .06178 L
.72074 .06264 L
.72105 .06327 L
.72133 .06369 L
.72148 .06386 L
.72162 .06399 L
.72175 .06406 L
.7219 .06411 L
.72205 .06411 L
.72213 .0641 L
.72221 .06407 L
.72236 .06399 L
.7225 .06387 L
.72264 .06372 L
.72278 .06353 L
.72303 .0631 L
.72331 .06251 L
.7236 .06171 L
.72423 .05952 L
.72489 .05647 L
.7261 .04934 L
.7285 .03081 L
.72916 .02572 L
.72949 .02356 L
.72958 .02307 L
.72968 .0226 L
.72977 .02224 L
.72986 .02198 L
.72994 .0218 L
.73002 .0217 L
.7301 .02167 L
.73019 .02175 L
.73027 .02189 L
.73036 .02212 L
.73051 .02272 L
.73066 .02349 L
.73082 .02444 L
.73111 .02638 L
.73232 .03567 L
.73361 .04503 L
.73483 .0522 L
.73537 .05471 L
.73594 .05688 L
.73622 .05775 L
.73652 .05857 L
.73681 .05917 L
.73707 .0596 L
.73721 .05979 L
.73737 .05996 L
Mistroke
.73746 .06003 L
.73754 .06009 L
.73762 .06013 L
.7377 .06016 L
.73778 .06018 L
.73786 .06019 L
.73801 .06018 L
.73816 .06013 L
.7383 .06005 L
.73843 .05995 L
.73856 .05981 L
.73881 .05946 L
.73911 .05892 L
.73938 .05829 L
.73997 .05653 L
.74053 .05436 L
.74169 .04841 L
.74293 .04037 L
.74409 .03185 L
.7446 .02808 L
.74489 .02604 L
.74515 .02429 L
.7453 .02342 L
.74544 .02269 L
.74558 .0221 L
.7457 .02168 L
.74584 .02141 L
.74598 .02133 L
.74613 .02148 L
.74628 .02188 L
.74643 .02243 L
.74658 .02319 L
.74686 .02484 L
.7475 .02922 L
.74971 .04422 L
.75093 .05059 L
.75162 .05331 L
.75195 .05435 L
.75226 .05519 L
.75256 .05584 L
.75288 .0564 L
.75302 .05659 L
.75317 .05676 L
.7533 .05687 L
.75344 .05697 L
.75352 .05701 L
.7536 .05704 L
.75375 .05707 L
.75383 .05706 L
.75391 .05705 L
Mistroke
.754 .05703 L
.75409 .057 L
.75423 .05691 L
.75437 .05679 L
.75453 .05663 L
.75469 .05642 L
.75499 .0559 L
.75532 .0552 L
.75591 .05352 L
.7566 .05088 L
.75724 .04794 L
.75966 .03294 L
.76079 .02524 L
.76106 .02359 L
.76136 .02213 L
.76144 .02179 L
.76152 .02152 L
.76168 .02116 L
.76182 .02103 L
.76198 .02112 L
.76214 .02145 L
.76223 .02173 L
.76231 .02205 L
.76266 .02378 L
.76329 .02772 L
.76449 .03575 L
.76568 .04289 L
.76632 .04621 L
.76692 .04885 L
.76748 .05088 L
.76799 .05235 L
.76826 .05299 L
.76855 .05355 L
.76871 .05381 L
.76886 .05401 L
.769 .05417 L
.76915 .05431 L
.76931 .05441 L
.76945 .05448 L
.76959 .05452 L
.76972 .05452 L
.76987 .0545 L
.77001 .05444 L
.77009 .0544 L
.77017 .05434 L
.77032 .05421 L
.7706 .05389 L
.77089 .05342 L
.77142 .05227 L
.77203 .05044 L
Mistroke
.7726 .04828 L
.77391 .04194 L
.77616 .02789 L
.77677 .02407 L
.77711 .02232 L
.77728 .02163 L
.77743 .02116 L
.77756 .02089 L
.7777 .02077 L
.77784 .02083 L
.77799 .02109 L
.77814 .02155 L
.77831 .02221 L
.7786 .02369 L
.77995 .032 L
.78117 .0393 L
.78243 .04552 L
.78299 .0477 L
.7836 .04964 L
.78388 .05037 L
.78418 .05103 L
.78444 .0515 L
.78472 .05191 L
.78489 .05209 L
.78504 .05222 L
.78519 .05232 L
.78534 .05239 L
.78548 .05242 L
.78561 .05243 L
.78576 .0524 L
.78591 .05234 L
.78607 .05225 L
.78622 .05213 L
.78655 .05174 L
.78687 .05122 L
.78722 .0505 L
.78785 .04878 L
.78842 .04678 L
.78962 .04139 L
.79073 .03524 L
.79203 .02731 L
.79266 .02361 L
.79294 .02223 L
.79308 .02162 L
.79324 .02109 L
.79339 .02073 L
.79353 .02056 L
.79367 .02056 L
.7938 .02072 L
.79393 .02101 L
Mistroke
.79405 .02139 L
.79433 .02254 L
.7955 .02921 L
.79679 .03672 L
.79799 .0427 L
.79908 .04686 L
.7997 .04856 L
.80026 .04969 L
.80058 .05014 L
.80073 .05031 L
.80087 .05044 L
.80102 .05055 L
.80111 .0506 L
.80119 .05063 L
.80128 .05066 L
.80137 .05068 L
.80145 .05068 L
.80154 .05068 L
.8017 .05065 L
.80184 .05058 L
.80192 .05054 L
.80201 .05048 L
.80217 .05034 L
.80247 .04999 L
.80275 .04956 L
.80331 .04837 L
.80392 .04665 L
.80501 .04247 L
.8075 .02916 L
.8081 .02569 L
.80873 .02235 L
.80891 .02156 L
.809 .02122 L
.80909 .02095 L
.80925 .02057 L
.80933 .02044 L
.80942 .02037 L
.80957 .02039 L
.80972 .0206 L
.80981 .02079 L
.80988 .02101 L
.81006 .02161 L
.81065 .0245 L
.8113 .02818 L
.81248 .03484 L
.81372 .04089 L
.81487 .04526 L
.81545 .04688 L
.81575 .04755 L
.81608 .04816 L
Mistroke
.81626 .04845 L
.81643 .04867 L
.81661 .04886 L
.81677 .049 L
.81693 .04911 L
.81708 .04918 L
.81724 .04921 L
.81733 .04922 L
.81741 .04922 L
.81756 .04919 L
.8177 .04914 L
.81783 .04907 L
.81797 .04897 L
.81829 .04865 L
.81858 .04823 L
.81911 .04721 L
.81968 .04575 L
.82086 .04151 L
.82217 .03531 L
.8233 .02906 L
.82392 .02557 L
.8245 .02257 L
.8248 .02129 L
.82497 .02075 L
.82512 .02039 L
.82521 .02027 L
.82529 .0202 L
.82538 .02019 L
.82548 .02024 L
.82564 .02049 L
.82573 .02071 L
.82581 .02096 L
.82611 .02212 L
.82639 .02343 L
.82701 .02676 L
.82822 .03335 L
.8295 .03953 L
.83012 .04203 L
.83071 .04403 L
.83123 .04548 L
.83153 .04616 L
.83181 .04671 L
.8321 .04718 L
.83237 .04752 L
.8325 .04766 L
.83265 .04778 L
.83281 .04788 L
.83296 .04795 L
.83309 .04798 L
.83323 .048 L
Mistroke
.83337 .04799 L
.83351 .04795 L
.83364 .0479 L
.83376 .04783 L
.83402 .04761 L
.83431 .04727 L
.83458 .04687 L
.83519 .04562 L
.83578 .044 L
.83642 .04185 L
.83882 .03056 L
.84008 .02375 L
.84039 .02227 L
.84072 .02096 L
.84082 .02066 L
.84091 .02042 L
.84099 .02026 L
.84108 .02013 L
.84117 .02006 L
.84126 .02005 L
.84135 .02009 L
.84142 .02018 L
.84158 .02049 L
.84166 .0207 L
.84175 .02097 L
.84205 .02214 L
.84272 .02546 L
.84393 .03194 L
.84512 .03766 L
.84625 .04203 L
.84684 .04383 L
.84715 .04462 L
.84748 .04534 L
.84776 .04584 L
.84807 .04629 L
.84835 .0466 L
.84848 .04672 L
.84861 .04681 L
.84876 .04689 L
.84885 .04693 L
.84893 .04695 L
.84902 .04697 L
.8491 .04697 L
.84924 .04696 L
.84939 .04693 L
.84952 .04687 L
.84967 .04679 L
.84983 .04667 L
.85015 .04633 L
.85045 .0459 L
Mistroke
.85113 .04453 L
.85174 .04288 L
.85239 .04067 L
.85359 .03564 L
.85583 .02418 L
.85637 .02165 L
.85652 .02108 L
.85668 .02057 L
.85681 .02024 L
.85696 .02 L
.85704 .01994 L
.85712 .01992 L
.85721 .01996 L
.85729 .02004 L
.85744 .02031 L
.85753 .02053 L
.8576 .02076 L
.85821 .02325 L
.85952 .02997 L
.86074 .0359 L
.86193 .04061 L
.86244 .04227 L
.86301 .04375 L
.86333 .04444 L
.86362 .04497 L
.86392 .04542 L
.86421 .04573 L
.86436 .04587 L
.86453 .04598 L
.86469 .04606 L
.86483 .0461 L
.86499 .04612 L
.86507 .04611 L
.86515 .0461 L
.86524 .04608 L
.86532 .04606 L
.86541 .04602 L
.8655 .04597 L
.86563 .04588 L
.86578 .04576 L
.86605 .04547 L
.86637 .04501 L
.86666 .0445 L
.86727 .04313 L
.8679 .04127 L
.86896 .03731 L
.87012 .03199 L
.87134 .02577 L
.87194 .02282 L
.87221 .02167 L
Mistroke
.87249 .02063 L
.87257 .02041 L
.87265 .02021 L
.8728 .01994 L
.87289 .01985 L
.87297 .01982 L
.87313 .01989 L
.87321 .02 L
.8733 .02016 L
.87346 .02056 L
.87363 .02112 L
.87382 .02186 L
.87502 .02771 L
.87625 .03375 L
.87755 .03912 L
.87865 .04253 L
.87896 .04325 L
.87928 .04391 L
.87957 .04439 L
.87987 .0448 L
.88002 .04496 L
.88018 .04511 L
.88033 .04522 L
.88047 .0453 L
.88055 .04534 L
.88063 .04537 L
.88071 .04539 L
.88081 .0454 L
.88088 .04541 L
.88097 .0454 L
.88112 .04538 L
.88128 .04532 L
.88136 .04528 L
.88144 .04523 L
.88174 .04498 L
.88202 .04467 L
.88231 .04425 L
.88286 .04319 L
.88337 .04191 L
.88453 .03806 L
.88678 .02779 L
.88739 .02469 L
.88773 .02307 L
.88805 .02168 L
.88832 .0207 L
.88847 .02026 L
.88861 .01996 L
.88875 .01978 L
.88891 .01974 L
.88899 .01978 L
Mistroke
.88907 .01988 L
.88922 .02016 L
.88931 .02037 L
.88939 .02063 L
.88955 .02117 L
.88991 .02266 L
.89057 .02579 L
.89179 .03178 L
.89296 .03688 L
.8936 .03925 L
.89421 .04115 L
.8948 .04263 L
.89512 .04327 L
.89545 .04383 L
.89575 .04424 L
.89603 .04452 L
.89617 .04462 L
.89631 .04471 L
.89645 .04477 L
.89657 .04481 L
.8967 .04483 L
.89684 .04483 L
.89697 .04481 L
.89709 .04478 L
.89723 .04472 L
.89738 .04463 L
.89765 .0444 L
.89794 .04406 L
.89824 .04361 L
.89878 .04256 L
.89938 .04105 L
.89992 .03938 L
.90114 .03468 L
.90334 .02417 L
.90392 .0216 L
.90408 .02097 L
.90424 .02047 L
.90438 .0201 L
.90453 .01982 L
.90466 .01969 L
.90481 .01968 L
.90496 .01983 L
.9051 .02009 L
.90524 .02044 L
.90536 .02083 L
.90563 .02186 L
.90813 .03362 L
.90925 .03806 L
.90986 .04006 L
.91043 .04162 L
Mistroke
.91105 .04293 L
.91138 .04345 L
.91173 .04389 L
.91204 .04416 L
.91219 .04425 L
.91228 .04429 L
.91236 .04433 L
.9125 .04436 L
.91266 .04438 L
.9128 .04436 L
.91294 .04433 L
.91307 .04428 L
.91322 .0442 L
.91336 .0441 L
.91349 .04398 L
.91381 .04363 L
.91411 .0432 L
.9147 .04206 L
.91535 .0404 L
.9165 .03649 L
.91757 .03195 L
.91885 .02584 L
.91948 .02288 L
.91975 .0217 L
.92005 .0206 L
.92018 .02022 L
.92032 .0199 L
.92046 .0197 L
.92058 .01962 L
.92071 .01964 L
.92086 .0198 L
.921 .02008 L
.92113 .02042 L
.9214 .02134 L
.9217 .02256 L
.9223 .02536 L
.92353 .03125 L
.92483 .0367 L
.92594 .04033 L
.92657 .04188 L
.92715 .04295 L
.92744 .04336 L
.9276 .04353 L
.92776 .04369 L
.9279 .0438 L
.92806 .0439 L
.9282 .04396 L
.92833 .04401 L
.92847 .04403 L
.9286 .04403 L
Mistroke
.92872 .04401 L
.92885 .04398 L
.92899 .04392 L
.92914 .04383 L
.92941 .04361 L
.92969 .0433 L
.93 .04286 L
.93055 .04181 L
.93121 .04015 L
.93182 .03827 L
.93429 .02783 L
.93491 .02485 L
.9355 .02218 L
.93575 .02116 L
.93602 .02027 L
.93616 .01993 L
.93632 .01968 L
.93646 .01957 L
.93659 .0196 L
.93673 .01975 L
.93688 .02003 L
.93702 .0204 L
.93715 .02082 L
.93766 .02288 L
.93881 .02831 L
.93995 .03348 L
.94118 .03818 L
.94185 .04019 L
.94246 .04167 L
.94304 .04274 L
.94334 .04313 L
.9435 .04332 L
.94366 .04346 L
.9438 .04357 L
.94395 .04366 L
.94409 .04373 L
.94422 .04376 L
.94436 .04378 L
.94451 .04378 L
.94459 .04377 L
.94467 .04375 L
.94482 .0437 L
.94495 .04364 L
.94509 .04354 L
.94538 .04328 L
.94565 .04296 L
.9459 .04259 L
.94651 .04142 L
.94717 .03973 L
.94837 .03566 L
Mistroke
.95061 .02562 L
.95116 .02305 L
.95147 .02175 L
.95175 .02068 L
.95192 .0202 L
.952 .01998 L
.95209 .0198 L
.95218 .01967 L
.95225 .01959 L
.9524 .01955 L
.95255 .01965 L
.95264 .01977 L
.95271 .01991 L
.95286 .02026 L
.95301 .02072 L
.95422 .026 L
.95555 .03217 L
.95676 .03702 L
.9579 .04053 L
.95854 .04194 L
.9589 .04255 L
.95923 .043 L
.9595 .04329 L
.95966 .04341 L
.95981 .04351 L
.95997 .04358 L
.96011 .04362 L
.96026 .04364 L
.96034 .04364 L
.96043 .04364 L
.96051 .04362 L
.96059 .0436 L
.96074 .04354 L
.96089 .04345 L
.96107 .04333 L
.96138 .04301 L
.96167 .04263 L
.96222 .04167 L
.9628 .0403 L
.96412 .03605 L
.96533 .03103 L
.96644 .0258 L
.96705 .02296 L
.96735 .02169 L
.96763 .02068 L
.96777 .02025 L
.96792 .01987 L
.96808 .01963 L
.96817 .01956 L
.96824 .01953 L
Mistroke
.96833 .01955 L
.96842 .01962 L
.96857 .01986 L
.96866 .02006 L
.96874 .02027 L
.96893 .02084 L
.97013 .02612 L
.97131 .03162 L
.97258 .03677 L
.9732 .03883 L
.97378 .04047 L
.97435 .04176 L
.97488 .04266 L
.97518 .04304 L
.97534 .0432 L
.97551 .04334 L
.9756 .04341 L
.97569 .04346 L
.97577 .0435 L
.97587 .04354 L
.97602 .04358 L
.97611 .04359 L
.97619 .0436 L
Mfstroke
1 0 0 r
[ ] 0 setdash
.03968 .01472 m
.03968 .04364 L
s
.05556 .01472 m
.05556 .04379 L
s
.07143 .01472 m
.07143 .04403 L
s
.0873 .01472 m
.0873 .04437 L
s
.10317 .01472 m
.10317 .04483 L
s
.11905 .01472 m
.11905 .04541 L
s
.13492 .01472 m
.13492 .04611 L
s
.15079 .01472 m
.15079 .04697 L
s
.16667 .01472 m
.16667 .04799 L
s
.18254 .01472 m
.18254 .04922 L
s
.19841 .01472 m
.19841 .05067 L
s
.21429 .01472 m
.21429 .05241 L
s
.23016 .01472 m
.23016 .0545 L
s
.24603 .01472 m
.24603 .05704 L
s
.2619 .01472 m
.2619 .06016 L
s
.27778 .01472 m
.27778 .06407 L
s
.29365 .01472 m
.29365 .06908 L
s
.30952 .01472 m
.30952 .07576 L
s
.3254 .01472 m
.3254 .08509 L
s
.34127 .01472 m
.34127 .0992 L
s
.35714 .01472 m
.35714 .12341 L
s
.37302 .01472 m
.37302 .17683 L
s
.38889 .01472 m
.38889 .42846 L
s
.40476 .01472 m
.40476 .32573 L
s
.42063 .01472 m
.42063 .0617 L
s
.43651 .01472 m
.43651 .15573 L
s
.45238 .01472 m
.45238 .22118 L
s
.46825 .01472 m
.46825 .08568 L
s
.48413 .01472 m
.48413 .05342 L
s
.5 .01472 m
.5 .33241 L
s
.51587 .01472 m
.51587 .05342 L
s
.53175 .01472 m
.53175 .08568 L
s
.54762 .01472 m
.54762 .22118 L
s
.56349 .01472 m
.56349 .15573 L
s
.57937 .01472 m
.57937 .0617 L
s
.59524 .01472 m
.59524 .32573 L
s
.61111 .01472 m
.61111 .42846 L
s
.62698 .01472 m
.62698 .17683 L
s
.64286 .01472 m
.64286 .12341 L
s
.65873 .01472 m
.65873 .0992 L
s
.6746 .01472 m
.6746 .08509 L
s
.69048 .01472 m
.69048 .07576 L
s
.70635 .01472 m
.70635 .06908 L
s
.72222 .01472 m
.72222 .06407 L
s
.7381 .01472 m
.7381 .06016 L
s
.75397 .01472 m
.75397 .05704 L
s
.76984 .01472 m
.76984 .0545 L
s
.78571 .01472 m
.78571 .05241 L
s
.80159 .01472 m
.80159 .05067 L
s
.81746 .01472 m
.81746 .04922 L
s
.83333 .01472 m
.83333 .04799 L
s
.84921 .01472 m
.84921 .04697 L
s
.86508 .01472 m
.86508 .04611 L
s
.88095 .01472 m
.88095 .04541 L
s
.89683 .01472 m
.89683 .04483 L
s
.9127 .01472 m
.9127 .04437 L
s
.92857 .01472 m
.92857 .04403 L
s
.94444 .01472 m
.94444 .04379 L
s
.96032 .01472 m
.96032 .04364 L
s
.97619 .01472 m
.97619 .0436 L
s
.015 w
.03968 .04364 Mdot
.05556 .04379 Mdot
.07143 .04403 Mdot
.0873 .04437 Mdot
.10317 .04483 Mdot
.11905 .04541 Mdot
.13492 .04611 Mdot
.15079 .04697 Mdot
.16667 .04799 Mdot
.18254 .04922 Mdot
.19841 .05067 Mdot
.21429 .05241 Mdot
.23016 .0545 Mdot
.24603 .05704 Mdot
.2619 .06016 Mdot
.27778 .06407 Mdot
.29365 .06908 Mdot
.30952 .07576 Mdot
.3254 .08509 Mdot
.34127 .0992 Mdot
.35714 .12341 Mdot
.37302 .17683 Mdot
.38889 .42846 Mdot
.40476 .32573 Mdot
.42063 .0617 Mdot
.43651 .15573 Mdot
.45238 .22118 Mdot
.46825 .08568 Mdot
.48413 .05342 Mdot
.5 .33241 Mdot
.51587 .05342 Mdot
.53175 .08568 Mdot
.54762 .22118 Mdot
.56349 .15573 Mdot
.57937 .0617 Mdot
.59524 .32573 Mdot
.61111 .42846 Mdot
.62698 .17683 Mdot
.64286 .12341 Mdot
.65873 .0992 Mdot
.6746 .08509 Mdot
.69048 .07576 Mdot
.70635 .06908 Mdot
.72222 .06407 Mdot
.7381 .06016 Mdot
.75397 .05704 Mdot
.76984 .0545 Mdot
.78571 .05241 Mdot
.80159 .05067 Mdot
.81746 .04922 Mdot
.83333 .04799 Mdot
.84921 .04697 Mdot
.86508 .04611 Mdot
.88095 .04541 Mdot
.89683 .04483 Mdot
.9127 .04437 Mdot
.92857 .04403 Mdot
.94444 .04379 Mdot
.96032 .04364 Mdot
.97619 .0436 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{756, 146},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000;d0000TR000`400?l00000o`00003ooooooooo
ooooooKooooo003ooooooooooooom_ooool00?ooooooooooooofooooo`00ooooooooooooooKooooo
003ooooooooooooom_ooool00?oooooo6_ooool3o`0000Cooooo0_l0000[ooooo`?o0000;Oooool2
o`0002oooooo0ol0000[ooooo`?o00001?ooool2o`000?oooooo4?ooool002_ooooo0ol00004oooo
o`;o0000:_ooool3o`0002_ooooo0_l0000]ooooo`?o0000:_ooool3o`0000Cooooo0_l0000Yoooo
o`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000:Oooool01Ol0003ooooooooooooo
oooo000002_ooooo00Co0000oooooooooooo0000;Oooool01Ol0003ooooooooooooooooo000002_o
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000`ooooo`?o00001?ooool2o`00
02[ooooo0ol0000[ooooo`;o0000;Oooool3o`0002[ooooo0ol00004ooooo`;o00006?ooool002co
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Xooooo`05o`000?oooooooooo
ooooool00000:Oooool01?l0003oooooooooool0000[ooooo`05o`000?ooooooooooooooool00000
:_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00023ooooo1Ol00003ooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00008oooool5o`0000Gooooo00?o0000oooo
ooooool0:Oooool01?l0003oooooooooool0000aooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool0000aooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo0000:?ooool01Ol0003ooooooooooooooooo000002Wooooo00Co0000oooooooo
oooo0000:oooool01Ol0003ooooooooooooooooo000002[ooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool0000Gooooo`009?ooool5o`0000?ooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool0000Rooooo`Go00001Oooool00ol0003oooooooooo`0Wooooo`04o`000?oo
ooooooooo`0002oooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0002Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000]oooo
o`03o`000?oooooooooo02Wooooo00Co0000oooooooooooo0000<Oooool00ol0003oooooooooo`0Y
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000:Oooool5o`0000?ooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool0000Rooooo`Go00001Oooool00ol0003ooooo
ooooo`0Wooooo`04o`000?ooooooooooo`0002oooooo00?o0000ooooooooool0:?ooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0001Oooooo000/ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo0000;?ooool00ol0003oooooooooo`0Wooooo`04o`000?oooooooooo
o`0002oooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0002Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Yooooo`Co0000
;?ooool01?l0003oooooooooool0000]ooooo`Co0000;?ooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`00037ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000/
ooooo`03o`000?oooooooooo02Oooooo00Co0000oooooooooooo0000;oooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00005oooool002cooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool0000Xooooo`Co0000:_ooool01?l0003ooooo
ooooool0000[ooooo`Co0000:oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
02Oooooo0_l00004ooooo`04o`000?ooooooooooo`0002Wooooo00?o0000ooooooooool0;Oooool0
1?l0003oooooooooool0000]ooooo`03o`000?oooooooooo02cooooo0_l00004ooooo`04o`000?oo
ooooooooo`00037ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Xooooo`Co
0000:_ooool01?l0003oooooooooool0000[ooooo`Co0000:oooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0001Oooooo000[ooooo`;o00001?ooool01?l0003oooooooooool0000X
ooooo`03o`000?oooooooooo02_ooooo00Co0000oooooooooooo0000:oooool00ol0003ooooooooo
o`0[ooooo`;o00001?ooool01?l0003oooooooooool0000Xooooo`03o`000?oooooooooo00?ooooo
0_l0000Zooooo`Go0000;?ooool2o`0002kooooo1Ol0000[ooooo`03o`000?oooooooooo00?ooooo
0_l0000aooooo`;o00001?ooool01?l0003oooooooooool0000Xooooo`03o`000?oooooooooo02_o
oooo00Co0000oooooooooooo0000:oooool00ol0003oooooooooo`0[ooooo`;o00001?ooool01?l0
003oooooooooool0000Gooooo`00;?ooool00ol0003oooooooooo`03ooooo`;o0000:Oooool5o`00
02[ooooo0_l0000/ooooo`Go0000:_ooool00ol0003oooooooooo`03ooooo`;o0000oooooolWoooo
o`03o`000?oooooooooo00?ooooo0_l0000Yooooo`Go0000:_ooool2o`0002cooooo1Ol0000Zoooo
o`03o`000?oooooooooo00?ooooo0_l0000Hooooo`00ooooooooooooooKooooo003ooooooooooooo
m_ooool00?ooooooooooooofooooo`008_ooool2o`0000Cooooobol0000Pooooo`;o00001?ooooo>
o`0002gooooob_l0000Fooooo`008Oooool01?l0003oooooooooool00003ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool07Oooool01?l0003oooooooooool00003ooooo`03o`000?oo
oooo0000033ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0_ooooo`03o`000?oo
oooooooo02kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Tooooo`;o00001Ooo
ool01Ol0003ooooooooooooooooo000000Wooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo01Cooooo000Qooooo`04o`000?ooooooooooo`0000?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02gooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool07Oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo0<[o
oooo00?o0000ooooooooool08oooool01?l0003oooooooooool00004ooooo`05o`000?oooooooooo
ooooool00000;oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02gooooo00?o0000
ooooooooool0;Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Cooooo000Qoooo
o`04o`000?ooooooooooo`0000?ooooo0_l0001Dooooo`03o`00oooooooooooo00cooooo00?o0000
ooooooooool0H?ooool3o`0001oooooo00Co0000oooooooooooo00000oooool3o`0000;ooooo00Go
o`00ooooooooooooooooool00002ooooo`04ool00?ooooooooooool000;ooooo00Goo`00oooooooo
ooooooooool00002ooooo`04ool00?ooooooooooool000?ooooo00Coo`00ooooooooooooo`000_oo
ool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`000_ooool01Ooo003o
ooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`000oooool01?oo003ooooooooooooo
0002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo0003ooooo`04
ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000oooool01?oo003ooooooooooooo
0002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo0003ooooo`04
ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000oooool01?oo003ooooooooooooo
0002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo0003ooooo`04
ool00?ooooooooooool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?oooooo
ooooool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?ooooooooooool000?o
oooo00Coo`00ooooooooooooo`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00
ooooooooooooo`000oooool2o`0002Gooooo00Co0000oooooooooooo00001?ooool2o`0000Kooooo
00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`05ool00?oooooooooo
oooooooo00000_ooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000?ooooo
00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`05ool00?oooooooooo
oooooooo00000_ooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000?ooooo
00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`05ool00?oooooooooo
oooooooo00000_ooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000?ooooo
00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`05ool00?oooooooooo
oooooooo00000_ooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000?ooooo
00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`05ool00?oooooooooo
oooooooo00000_ooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000?ooooo
00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`05ool00?oooooooooo
oooooooo00000_ooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000?ooooo
0_l0000Fooooo`008Oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00?ooooo
0_l00?l2ooooo`04o`00ooooooooooooo`00o`;ooooo00Co003ooooooooooooo003o0_ooool00ol0
0?ooooooooooo`02o`00o`Gooooo00Co003ooooooooooooo003o1_ooool01?l00?ooooooooooool0
0?l2ooooo`04o`00ooooooooooooo`00o`;ooooo0_l00?l2ooooo`04o`00ooooooooooooo`00oaSo
oooo00?o003oooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`00oooooooooooo00oo
oooo00Go003oooooooooooooooooo`00o`02ooooo`04o`00ooooooooooooo`00o`;ooooo00?o003o
ooooooooool01?ooool01?l00?ooooooooooool00?l2ooooo`04o`00ooooooooooooo`00o`;ooooo
0_l00?l2ooooo`04o`00ooooooooooooo`00o`;ooooo00Co003ooooooooooooo003o0_ooool2o`00
o`;ooooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooooooo`04ooooo`03o`000?oooooo
oooo01gooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`02ooooo`05ool00?oo
oooooooooooooooo00000_ooool01?oo003ooooooooooooo0002ooooo`05ool00?oooooooooooooo
oooo00000_ooool01?oo003ooooooooooooo0003ooooo`04ool00?ooooooooooool000;ooooo00Go
o`00ooooooooooooooooool00002ooooo`04ool00?ooooooooooool000;ooooo00Goo`00oooooooo
ooooooooool00002ooooo`04ool00?ooooooooooool000?ooooo00Coo`00ooooooooooooo`000_oo
ool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`000oooool01?oo003o
oooooooooooo0002ooooo`04ool00?ooooooooooool000?ooooo00Coo`00ooooooooooooo`000_oo
ool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`000oooool01?oo003o
oooooooooooo0002ooooo`04ool00?ooooooooooool000?ooooo00Coo`00ooooooooooooo`000_oo
ool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`000oooool01?oo003o
oooooooooooo0002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo
0002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo0003ooooo`04
ool00?ooooooooooool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?oooooo
ooooool000Cooooo00?o0000ooooooooool08oooool01?l0003oooooooooool00004ooooo`03o`00
0?oooooooooo00?ooooo00?o003ooooooooo00000_ooool01ooo003o003ooooooooo003oooooo`00
oooo00000_ooool02?oo003oooooooooooooooooo`00o`00ooooooooo`000_ooool01ooo003ooooo
oooooooo003oooooo`00oooo00000oooool01?oo003ooooooooooooo0002ooooo`04ool00?oooooo
ooooool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?ooooooooooool000;o
oooo00Coo`00ooooooooooooo`000oooool01?oo003ooooooooooooo0002ooooo`04ool00?oooooo
ooooool000;ooooo00Goo`00o`00ooooooooooooool00002ooooo`04ool00?ooooooooooool000;o
oooo00Coo`00ooooooooooooo`000oooool01?oo003ooooooooooooo0002ooooo`07ool00?oooooo
ooooool00?oooooo003oool00003ooooo`04ool00?ooooooooooool000;ooooo00Coo`00oooooooo
ooooo`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`000_oo
ool01?oo003ooooooooooooo0003ooooo`07ool00?ooooooooooool00?oooooo003oool00002oooo
o`04ool00?ooooooooooool000?ooooo00Ooo`00ooooooooooooo`00o`00ooooooooo`0000;ooooo
00_oo`00ooooooooooooo`00ooooool00?ooooooool00?l00?ooooooool00002o`00o`07ool00?oo
oooo003oool00?oooooo003oool00004ooooo`03o`000?oooooooooo01Cooooo000Qooooo`04o`00
0?ooooooooooo`0000?ooooo00?o0000ooooooooool01?ooool01Ol00?ooooooo`00ool00?oooooo
00;o003o0_ooool01?l00?ooooooooooool00?l2ooooo`;o003o00Coooooo`00ool00?oooooo0_l0
0?l2ooooo`04o`00ooooooooooooo`00o`;ooooo0_l00?l2ooooo`04o`00ooooooooooooo`00o`;o
oooo00Co003ooooooooooooo003o0_ooool00ol00?ooooooooooo`02o`00o`;ooooo00Co003ooooo
oooooooo003o0_ooool00ol00?ooooooooooo`02o`00o`;ooooo00Co003ooooooooooooo003o2?oo
ool00ol00?ooooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o003oooooooooool01_oo
ool01?l00?ooooooooooool00?l2ooooo`03o`00oooooooooooo00;o003o0_ooool01?l00?oooooo
ooooool00?l2ooooo`04o`00ooooooooooooo`00o`;ooooo0_l00?l00ooooooo003oooooo`02oooo
o`04o`00ooooooooooooo`00o`;ooooo00Go003oooooooooooooooooo`00o`02ooooo`04o`00oooo
oooo003oo`00o`;ooooo0_l00?l00ooooooo003oooooo`02ooooo`05o`00oooooooo003oo`00oooo
ool00_l00?l2ooooo`;o003o00?oooooo`00ool00?l01Oooool00ol0003oooooooooo`0Mooooo`04
o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_ooool01Ooo003ooooooooooooooooo
o`0000;ooooo00Coo`00ooooooooooooo`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo
00Coo`00ooooooooooooo`000oooool01?oo003ooooooooooooo0002ooooo`05ool00?oooooooooo
oooooooo00000_ooool01?oo003ooooooooooooo0002ooooo`05ool00?oooooooooooooooooo0000
0_ooool01?oo003ooooooooooooo0003ooooo`04ool00?ooooooooooool000;ooooo00Goo`00oooo
ooooooooooooool00002ooooo`04ool00?ooooooooooool000?ooooo00Coo`00ooooooooooooo`00
0_ooool01?oo003ooooooooooooo0003ooooo`04ool00?ooooooooooool000;ooooo00Goo`00oooo
ooooooooooooool00002ooooo`04ool00?ooooooooooool000?ooooo00Coo`00ooooooooooooo`00
0_ooool01?oo003ooooooooooooo0003ooooo`04ool00?ooooooooooool000;ooooo00Goo`00oooo
ooooooooooooool00002ooooo`04ool00?ooooooooooool000?ooooo00Coo`00ooooooooooooo`00
0_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`000_ooool01Ooo
003oooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`000oooool01?oo003ooooooooo
oooo0002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo0004oooo
o`03o`000?oooooooooo02?ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`03
ooooo`06o`00ooooooooo`00o`00ooooooooo`000_l00?l04Ooo003oooooo`00oooo003oooooo`00
oooo003oooooo`00ooooooooo`00o`00ooooooooo`00o`00ooooooooo`0000;o003o00koo`00oooo
ool00?ooo`00ooooool00?ooooooool00?l00?ooooooool00?oooooo003oool000;o003o00_oo`00
ooooool00?ooo`00ooooool00?ooooooool00?l00?ooooooool00002ooooo`07ool00?oooooo003o
ool00?oooooo003oool00003ooooo`04ool00?ooooooooooool000;ooooo00Coo`00oooooooooooo
o`000_ooool01Ooo003o003oooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`000_ooool0
1?oo003ooooooooooooo0003ooooo`04ool00?ooooooooooool000;ooooo00Coo`00oooooooooooo
o`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`000_ooool0
1?oo003ooooooooooooo0003ooooo`0:ool00?ooooooooooool00?l00?ooooooool00?oooooo003o
ool000;ooooo00_oo`00ooooool00?ooooooool00?l00?ooooooool00?l00?ooooooool00002oooo
o`0;ool00?oooooo003oool00?oooooo003ooooooooo003o003ooooooooo00000_l00?l05ooo003o
ooooo`00oooo003oooooo`00oooo003oooooo`00ooooooooo`00o`00ooooooooo`00ooooool00?oo
o`00ooooool00?ooo`00ooooool00?ooo`0000Cooooo00?o0000ooooooooool05?ooool002;ooooo
0_l00004ooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool00_l00?l2ooooo`04o`00
ooooooooooooo`00o`;ooooo0_l00?l00ooooooo003oo`00o`04ooooo`;o003o00Goooooo`00ool0
0?oo003oooooo`02o`00o`05ooooool00?oo003oooooool00?l00_ooool2o`00o`;ooooo00Ko003o
ooooooooooooooooo`00ooooool2o`00o`03ooooool00?oo003o00;ooooo00Co003ooooooooooooo
003o0_ooool01?l00?ooooooooooool00?l3ooooo`04o`00ooooooooooooo`00o`Gooooo00Co003o
ooooool00?oo003o3_ooool00ol0003oooooooooo`0<ooooo`04o`00oooooooo003oo`00o`Gooooo
00Co003ooooooooooooo003o0_ooool01ol00?oooooooooooooooooo003oooooool00?l00oooool0
1?l00?ooooooooooool00?l5ooooo`;o003o00Goooooo`00ool00?ooooooo`00o`03ooooo`03o`00
oooooooooooo00;o003o00Coooooo`00ool00?oooooo0_l00?l00ooooooo003oo`00o`02ooooo`;o
003o0_ooool00ol00?ooooooo`00o`02ooooo`;o003o00Goooooo`00oooooooo003oooooo`02o`00
o`;ooooo00?o003oooooooooool00oooool00ol0003oooooooooo`0Nooooo`;o00001?ooool00ol0
003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo
0002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo0003ooooo`04
ool00?ooooooooooool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?oooooo
ooooool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?ooooooooooool000?o
oooo00Coo`00ooooooooooooo`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00
ooooooooooooo`000oooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000?o
oooo00Coo`00ooooooooooooo`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00
ooooooooooooo`000oooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000?o
oooo00Coo`00ooooooooooooo`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00
ooooooooooooo`000oooool01?oo003ooooooooooooo0002ooooo`05ool00?oooooooooooooooooo
00000_ooool01?oo003ooooooooooooo0002ooooo`05ool00?oooooooooooooooooo00000_ooool0
1?oo003ooooooooooooo0003ooooo`04ool00?ooooooooooool000;ooooo00Goo`00oooooooooooo
ooooool00002ooooo`04ool00?ooooooooooool000Cooooo00?o0000ooooooooool08oooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo00?ooooo00Wo003ooooooooo003o003ooooo
oooo003o003ooooooooo00000_l00?l02ooo003o003oo`00oooo003oooooo`00ooooooooo`00oooo
ool00?ooo`0000;o003o00koo`00o`00ool00?ooo`00o`00ooooooooo`00ooooool00?ooooooool0
0?l00?ooooooool000;o003o00koo`00o`00ool00?ooo`00ooooool00?ooo`00ooooool00?oooooo
ool00?l00?ooooooool000;o003o017oo`00o`00ool00?ooo`00ooooool00?ooo`00ooooool00?oo
ooooool00?l00?ooooooool00?l00?ooooooool00002ooooo`04ool00?oooooo003oool000?ooooo
00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`05ool00?oooooooooo
oooooooo00000_ooool01?oo003ooooooooooooo0002ooooo`08ool00?oooooo003oool00?oooooo
003ooooooooo0002ooooo`04ool00?ooooooooooool000;o003o00_oo`00ooooool00?ooo`00oooo
ool00?ooooooool00?l00?ooooooool00002o`00o`0;ool00?l00?ooooooool00?oooooo003oool0
0?oooooo003ooooooooo00000_l00?l01?oo003o003ooooooooo0002o`00o`0Aool00?l00?oo003o
ool00?oooooo003ooooooooo003o003ooooooooo003oooooo`00oooo003oooooo`00oooo00000_l0
0?l02?oo003oooooo`00ooooooooo`00ooooool00?ooo`000_l00?l01?oo003o003oo`00oooo0002
o`00o`03ool00?oooooooooo00;ooooo00?o0000ooooooooool05?ooool002Sooooo00?o0000oooo
ooooool00oooool2o`00o`06ooooool00?ooooooooooool00?oooooo0_l00?l00ooooooo003oo`00
o`04ooooo`08o`00oooooooo003oo`00oooooooo003oooooool00?l2ooooo`05o`00oooooooooooo
o`00ooooool00_l00?l01Ooooooo003oo`00oooooooo003o00?ooooo00?o003oooooooooool00_l0
0?l2ooooo`04o`00ooooooooooooo`00o`;ooooo00Co003ooooooooooooo003o0_ooool2o`00o`;o
oooo00Co003oooooool00?oo003o0_ooool00ol00?ooooooooooo`03ooooo`04o`00oooooooo003o
o`00o`_ooooo00Co003ooooooooooooo00003Oooool00ol00?ooooooooooo`02o`00o`Gooooo00Co
003ooooooooooooo003o0_ooool01?l00?ooooooooooool00?l3ooooo`04o`00oooooooo003oo`00
o`;ooooo00?o003oooooooooool00_l00?l00ooooooo003oo`00o`02ooooo`05o`00oooooooo003o
ooooool00?l00_ooool01_l00?ooooooooooool00?ooooooo`00o`;ooooo00Co003ooooooooooooo
003o0_ooool00ol00?ooooooo`00o`03o`00o`05ooooool00?oo003oooooool00?l01?ooool2o`00
o`;ooooo00?o003oooooooooool01Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
00;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?ooooooooooool000;ooooo00Go
o`00ooooooooooooooooool00002ooooo`04ool00?ooooooooooool000?ooooo00Coo`00oooooooo
ooooo`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`000_oo
ool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`000oooool01?oo003o
oooooooooooo0002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo
0003ooooo`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000oooool01?oo003o
oooooooooooo0002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo
0003ooooo`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000oooool01?oo003o
oooooooooooo0002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo
0003ooooo`04ool00?ooooooooooool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04
ool00?ooooooooooool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?oooooo
ooooool000?ooooo00Coo`00ooooooooooooo`000_ooool01Ooo003oooooooooooooooooo`0000;o
oooo00Coo`00ooooooooooooo`001?ooool00ol0003oooooooooo`0Tooooo`;o00001Oooool00ol0
003oooooooooo`02ooooo`0=o`00ooooooooooooool00?oooooo003oool00?oooooo003oool00?l0
0?ooooooool00002o`00o`08ool00?l00?ooooooo`00oooo003o003ooooooooo0002o`00o`07ool0
0?l00?oo003oool00?oooooo003oool00002o`00o`05oooooooo003o003oo`00oooo00000_l00?l0
1ooo003ooooooooooooo003o003ooooooooo00000oooool01?oo003ooooooooooooo0002o`00o`0A
ool00?l00?oo003oool00?oooooo003oool00?oooooo003ooooooooo003o003ooooooooo003o003o
oooooooo00000_ooool01?oo003oooooo`00oooo0002o`00o`05oooooooo003ooooooooooooo0000
0_ooool01?oo003ooooooooooooo0002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo
003ooooooooooooo0002ooooo`08ool00?oooooo003oool00?oooooo003ooooooooo0002ooooo`0D
ool00?l00?ooooooool00?oooooo003oool00?oooooo003oool00?oooooo003ooooooooo003o003o
oooooooo003oooooo`00oooo0002o`00o`08ool00?l00?oo003oool00?oooooo003ooooooooo0002
o`00o`04ool00?l00?oo003oool000;o003o00Coo`00o`00ool00?ooo`000_ooool01Ol00?ooo`00
ooooool00?ooo`0000;o003o00Coo`00o`00ool00?ooo`000_l00?l04Ooo003oooooooooool00?oo
o`00o`00ooooooooo`00o`00ooooooooo`00o`00ooooooooo`00o`00ooooooooo`0000Cooooo00?o
0000ooooooooool05?ooool002Sooooo0_l00003ooooo`03o`00oooooooooooo00;o003o00Cooooo
o`00ool00?oooooo0_l00?l01?oooooo003oooooooooool3o`00o`;ooooo00Co003oooooool00?oo
003o0_ooool01?l00?ooooooooooool00?l6ooooo`;o003o00?oooooo`00ooooool00_l00?l00ooo
oooo003oooooo`02o`00o`04ooooool00?oo003oooooo`;o003o00?oooooo`00ool00?l00_ooool0
0ol00?ooooooooooo`02o`00o`03ooooool00?oo003o00;ooooo00Co003ooooooooooooo003o1Ooo
ool00ol00?ooooooo`00o`0<ooooo`04o`00ooooooooooooo`0000;ooooo00?o003oooooooooool0
2Oooool01?l00?ooooooo`00ool00?l5ooooo`04o`00ooooooooooooo`00o`;ooooo0_l00?l01?oo
oooo003oo`00ooooool2o`00o`;ooooo00?o003oooooooooool00_l00?l00ooooooo003oo`00o`04
ooooo`;o003o00?oooooo`00ooooool00_l00?l00ooooooo003oo`00o`02o`00o`07ooooool00?oo
003oooooool00?ooooooo`00o`02ooooo`06o`00ooooooooooooooooool00?oooooo0ol00?l01?oo
oooo003oo`00ooooool2o`00o`;ooooo00Go003oooooool00?oo003oooooo`02o`00o`?ooooo0_l0
000Vooooo`03o`000?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool0
0?ooooooooooool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?oooooooooo
ool000?ooooo00Coo`00ooooooooooooo`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo
00Coo`00ooooooooooooo`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00oooo
ooooooooo`000oooool01?oo003ooooooooooooo0002ooooo`05ool00?oooooooooooooooooo0000
0_ooool01?oo003ooooooooooooo0003ooooo`04ool00?ooooooooooool000;ooooo00Coo`00oooo
ooooooooo`000oooool01?oo003ooooooooooooo0002ooooo`05ool00?oooooooooooooooooo0000
0_ooool01?oo003ooooooooooooo0003ooooo`04ool00?ooooooooooool000;ooooo00Coo`00oooo
ooooooooo`000oooool01?oo003ooooooooooooo0002ooooo`05ool00?oooooooooooooooooo0000
0_ooool01?oo003ooooooooooooo0003ooooo`04ool00?ooooooooooool000;ooooo00Goo`00oooo
ooooooooooooool00002ooooo`04ool00?ooooooooooool000;ooooo00Goo`00oooooooooooooooo
ool00002ooooo`04ool00?ooooooooooool000?ooooo00Coo`00ooooooooooooo`000_ooool01Ooo
003oooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`001?ooool00ol0003ooooooooo
o`0[ooooo`03o`000?oooooooooo00;ooooo00?o003ooooooooo00002ooo00002Oooooooo`00oooo
oooooooo003oool00?oooooo003oool00002o`00o`04ool00?oooooo003oool000;o003o00Goo`00
oooooooooooo003oool00002ooooo`04ool00?l00?ooooooool000;o003o00Soo`00o`00ool00?oo
o`00ooooool00?ooooooool000;o003o00Ooo`00o`00ool00?ooo`00ooooool00?ooo`0000;o003o
00_oo`00ooooool00?ooooooool00?l00?ooooooool00?l00?ooooooool00002ooooo`04ool00?oo
oooo003oool000;o003o00Goooooool00?ooooooooooool00002ooooo`07ool00?ooooooooooool0
0?l00?ooooooool00002ooooo`05o`00oooo003ooooooooooooo00000_ooool02ooo003ooooooooo
oooo003oooooo`00oooo003oooooo`00ooooooooo`0000;ooooo00koo`00o`00ooooooooo`00o`00
ooooooooo`00ooooool00?ooo`00ooooool00?ooooooool000;o003o00Ooo`00o`00ool00?ooo`00
ooooool00?ooo`0000;o003o00_oo`00ooooool00?oo003oool00?l00?ooooooool00?oooooo003o
ool00002o`00o`08ool00?l00?ooooooool00?l00?ooooooo`00oooo0002o`00o`07ool00?l00?oo
003oool00?l00?ooooooool00002ooooo`03ool00?l00?oooooo00ooo`000_ooool2o`0001Kooooo
000Xooooo`03o`000?oooooooooo00Gooooo00Co003ooooooooooooo003o1Oooool01Ol00?oooooo
oooooooooooo003o00;ooooo00Co003ooooooooooooo003o0_ooool2o`00o`03ooooool00?oo003o
00;ooooo00Co003oooooool00?oo003o0_ooool00ol00?ooooooooooo`02o`00o`;ooooo00Go003o
ooooooooooooooooo`00o`02ooooo`03o`00oooooooooooo00;o003o0oooool00ol00?ooooooo`00
o`02ooooo`;o003o00?oooooo`00ool00?l00_ooool00ol00?ooooooooooo`03ooooo`05o`00oooo
ooooooooooooool00?l02_ooool01?l00?ooooooooooool00002ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool00oooool01Ol00?ooooooo`00oooooooo003o00Gooooo00Co003ooooo
oooooooo003o0_ooool2o`00o`04ooooool00?oo003oooooo`;o003o0_ooool01_l00?ooooooo`00
oooooooo003oooooo`;o003o00Goooooo`00ool00?ooooooo`00o`04ooooo`;o003o00?oooooo`00
ool00?l00_ooool01?l00?ooooooooooool00?l2ooooo`;o003o00?oooooo`00ool00?l00_ooool0
0ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00;o003o00?oooooo`00ool00?l00_ooool0
1?l00?ooooooooooool00?l4ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool00_oo
ool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`000_ooool01Ooo003o
ooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`000oooool01?oo003ooooooooooooo
0002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo0002ooooo`05
ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo0003ooooo`04ool00?oooooo
ooooool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?ooooooooooool000?o
oooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0003ooooo`04ool00?oooooo
ooooool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?ooooooooooool000?o
oooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0003ooooo`04ool00?oooooo
ooooool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?ooooooooooool000?o
oooo00Coo`00ooooooooooooo`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00
ooooooooooooo`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00oooooooooooo
o`000oooool01?oo003ooooooooooooo0002ooooo`05ool00?oooooooooooooooooo00000_ooool0
1?oo003ooooooooooooo0004ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool00_oo
ool00ol00?ooooooool0000>ool00003oooooooo003oo`0000goo`000_ooool01ooo003oooooo`00
oooo003oooooo`00oooo00000_l00?l02?oo003o003oo`00oooo003o003oooooool00?ooo`000_l0
0?l01?oo003ooooooooooooo0002o`00o`0>ool00?oooooo003oool00?oooooo003ooooooooo003o
003ooooooooo003o003ooooooooo0002ooooo`04ool00?oooooo003oool000;o003o00Goooooool0
0?ooooooooooool00002ooooo`07ool00?ooooooooooool00?l00?ooooooool00002ooooo`05o`00
oooo003ooooooooooooo00000_ooool01?oo003ooooooooooooo0002ooooo`05ool00?oooooo003o
oooooooo00000_ooool01?oo003o003ooooooooo0002o`00o`0>ool00?oooooo003oool00?oooooo
003ooooooooo003o003ooooooooo003o003ooooooooo0002o`00o`0;ool00?ooooooooooool00?l0
0?ooooooo`00oooo003oooooo`00oooo00000_l00?l01Ooo003ooooooooooooo003ooooo00?oo`00
00?oooooool00?oo00003Ooo00000oooooooo`00ool0000=ool000?ooooo00?o0000ooooooooool0
5?ooool002Sooooo00?o0000ooooooooool08_ooool01?l00?ooooooooooool00?l3ooooo`06o`00
oooooooo003oo`00oooooooo003o0_ooool4o`00o`03ooooool00?oo003o00;ooooo00Go003ooooo
ool00?ooooooo`00o`02ooooo`03o`00oooooooo003o00;ooooo00Go003oooooooooooooooooo`00
o`05ooooo`05o`00oooooooo003oooooool00?l01oooool01?l00?ooooooooooool00?l2ooooo`05
o`000?ooooooooooo`00ooooool00_l00?l00ooooooo003oooooo`04ooooo`04o`00oooooooo003o
o`00o`Kooooo00Co003ooooooooooooo003o0oooool01_l00?ooooooooooool00?ooooooo`00o`;o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`Co003o00?oooooo`00ool0
0?l00_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo02;ooooo00?o0000oooooooo
ool09?ooool2o`0000;ooooo0ooo00000oooooooo`00ool0000:ool000;ooooo00Coo`00oooooooo
ooooo`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`000ooo
ool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000?ooooo00Coo`00oooooooo
ooooo`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`000ooo
ool01?oo003ooooooooooooo0002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003o
oooooooooooo0002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo
0003ooooo`04ool00?ooooooooooool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04
ool00?ooooooooooool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?oooooo
ooooool000?ooooo00Coo`00ooooooooooooo`000_ooool01Ooo003oooooooooooooooooo`0000;o
oooo00Coo`00ooooooooooooo`000oooool01?oo003ooooooooooooo0002ooooo`04ool00?oooooo
ooooool000?ooooo00Coo`00ooooooooooooo`000_ooool00ooo003oooooooooo`09ool00003oooo
oooo003oo`0000Ooo`000_ooool2o`0002gooooo00?o0000ooooooooool01?ooool?ool00003oooo
oooo003oo`0000goo`0000?oooooool00?oo00001ooo00003?l00?ooo`00ooooooooooooo`00o`00
oooooooo003oool00?oooooo003oool000;o003o00koo`00o`00ooooooooo`00ooooool00?ooo`00
ooooool00?ooooooool00?l00?ooooooool000;o003o00Ooo`00ooooooooooooo`00ooooool00?oo
o`0000?ooooo00Soo`00ooooooooooooo`00o`00ooooooooo`00ooooo`?oo`0000Coooooool00?oo
oooooooo0ooo00001Oooooooo`00ooooooooooooo`0000;ooooo00Soo`00o`00ooooooooo`00oooo
ool00?ooooooool000;ooooo00Coo`00ooooooooooooo`000_l00?l02ooo003oooooo`00oooo003o
ooooo`00ooooooooo`00ooooool00?ooo`0000;o003o00Ooo`00o`00ooooooooo`00o`00oooooooo
o`0000;ooooo00?o003oool00?ooool03?oo00000oooooooo`00ool0000=ool00003oooooooo003o
o`0000goo`000oooool00ol0003oooooooooo`0Dooooo`00:?ooool00ol0003oooooooooo`0^oooo
o`;o003o00?oooooo`00ool00?l00_ooool01Ol00?ooooooo`00oooooooo003o00;ooooo00Co003o
ooooool00?oooooo0_l00?l2ooooo`04o`00oooooooo003oo`00o`;ooooo00?o003oooooooooool0
0oooool3o`00o`03ooooool00?oooooo00Cooooo00Ko003oooooool00?oo003oooooool00?l2oooo
o`03o`000?oooooooooo00;ooooo0_l00?l00ooooooo003oooooo`04ooooo`03o`00oooooooooooo
00;o003o1Oooool01?l00?ooooooooooool00?l2ooooo`04o`00ooooooooooooo`00o`?ooooo00Co
003oooooool00?oooooo0_l00?l2ooooo`04o`00oooooooo003oo`00o`;ooooo00Co003ooooooooo
oooo003o;_ooool00ol0003oooooooooo`0Tooooo`04o`000?ooooooooooooooo`?oo`0000?ooooo
ool00?oo00002_oo00000oooooooo`00ool00007ool00006oooooooo003oo`00ool00?ooooooo`00
0_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`000_ooool01Ooo
003oooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`000oooool01?oo003ooooooooo
oooo0002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo0003oooo
o`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000oooool01?oo003ooooooooo
oooo0002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo0003oooo
o`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000oooool01?oo003ooooooooo
oooo0002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo0003oooo
o`04ool00?ooooooooooool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`05ool00?oo
ooooooooool00?ooool00ooo00000oooooooo`00ool00007ool00003oooooooo003oo`0000Ooo`00
00?oooooool00?oo00001ooo0003ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0
4?ooool3ool00003oooooooo003oo`0000goo`0000?oooooool00?oo00002_oo00000oooooooo`00
o`00o`02ooooo`04ool00?ooooooooooool000;o003o017oo`00o`00ool00?ooo`00o`00oooooooo
o`00ooooool00?ooooooool00?l00?ooooooool00?oooooo003oool00002ooooo`04ool00?oooooo
003oool000?o003o00Soo`00ooooooooooooo`00o`00ooooooooo`00o`00o`?oo`0000Coooooool0
0?oooooooooo0ooo00001Oooooooo`00ooooool00?ooo`0000;ooooo00Soo`00o`00ooooooooo`00
ooooool00?ooooooool000;ooooo00Ooo`00o`00ool00?ooo`00ooooool00?ooo`0000;o003o00Go
o`00ooooool00?ooooooool00002o`00o`04ool00?oooooo003oool000;o003o00Koo`00o`00oooo
ooooo`00o`00ooooool?ool00003oooooooo003oo`0000goo`004oooool00ol0003oooooooooo`0D
ooooo`00:?ooool2o`0003?ooooo00Co003ooooooooooooo003o0_ooool2o`00o`03ooooool00?oo
003o00?ooooo0_l00?l00ooooooo003oo`00o`02ooooo`04o`00ooooooooooooo`00o`Gooooo0ol0
0?l6ooooo`;o003o00Goooooo`00ooooooooooooo`00o`02ooooo`04o`000?oooooo003oo`00o`Co
oooo00?o003oooooooooool01Oooool3o`00o`Gooooo00Co003ooooooooooooo003o0_ooool2o`00
o`04ooooool00?oo003oooooo`;o003o00?oooooo`00ooooool00_l00?l00ooooooo003oo`00o`02
ooooo`03o`00oooooooooooo037ooooo0_l0000Vooooo`04o`000?ooooooooooooooo`?oo`0000?o
ooooool00?oo00002_oo00000oooooooo`00ool00007ool00003oooooooo003oo`0000Ooo`000_oo
ool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000?ooooo00Coo`00oooooooo
ooooo`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`000ooo
ool01?oo003ooooooooooooo0002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003o
oooooooooooo0002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo
0003ooooo`04ool00?ooooooooooool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04
ool00?ooooooooooool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?oooooo
ooooool000?ooooo00Coo`00ooooooooooooo`000_ooool01Ooo003oooooooooooooooooo`0000;o
oooo00Coo`00ooooooooooooo`000oooool00ooo003oooooool00008ool00003oooooooo003oo`00
00Ooo`0000?oooooool00?oo00001ooo00000oooooooo`00ool00007ool000?ooooo00?o0000oooo
ooooool0:oooool00ol0003oooooooooo`0Tooooo`ooo`0000Koooooool00?oo003oo`00o`00oooo
0002o`00o`04ool00?oooooo003oool000;o003o00Goo`00ooooool00?ooooooool00002o`00o`04
ool00?l00?oo003oool000;ooooo00?oo`00o`00oooo00000_oo00000ooooooo003oool00002oooo
o`05ool00?l00?oo003oool00?l00?l00ooo00001?ooooooo`00ooooooooool3ool00005o`00oooo
003o003oo`00oooo00000_ooool00ooo003o003oool00002ool00003o`00ooooooooo`0000;ooooo
00Ooo`00o`00ool00?ooo`00o`00ooooooooo`0000;o003o00Goo`00o`00oooooooo003oool00002
o`00o`05ool00?l00?oo003oool00?ooool01_oo00000oooooooo`00ool0000:ool002Kooooo00?o
0000ooooooooool05?ooool002Sooooo00?o0000ooooooooool0=Oooool01ol00?oooooooooooooo
oooo003oooooool00?l00_ooool2o`00o`?ooooo0_l00?l00ooooooo003oo`00o`02ooooo`03o`00
oooooooooooo00Cooooo00Co003ooooooooooooo003o1?ooool2o`00o`;ooooo00?o003oooooool0
0?l00_ooool01Ol0003oooooo`00ool00?oooooo00;o003o00?oooooo`00ooooool01?ooool01Ol0
0?ooooooo`00oooooooo003o00Gooooo00Co003ooooooooooooo003o0_ooool2o`00o`07ooooool0
0?oo003oooooool00?ooooooo`00o`02ooooo`;o003o00?oooooo`00ool00?l0=oooool00ol0003o
ooooooooo`0Tooooo`03o`000?oooooooooo01;ooooo2Ooo00000oooooooo`00ool00007ool00003
oooooooo003oo`0000Coo`0000Goooooool00?ooooooooooool00003ooooo`04ool00?oooooooooo
ool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?ooooooooooool000?ooooo
00Coo`00ooooooooooooo`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00oooo
ooooooooo`000_ooool00ooo003oooooooooo`03ool00003oooooooo003ooooo00?oo`000_ooool0
1?oo003ooooooooooooo0002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooo
oooooooo0002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo0003
ooooo`04ool00?ooooooooooool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`03ool0
0?ooooooo`0000;oo`0000?oooooool00?oo00002_oo00000oooooooo`00ool00007ool001Oooooo
00?o0000ooooooooool0:oooool00ol0003oooooooooo`0]ooooo`Koo`0000?oooooool00?oo0000
1?oo00001Oooooooo`00o`00ool00?ooo`0000;o003o00_oo`00o`00ooooooooooooool00?l00?oo
ooooool00?l00?ooooooool00002ooooo`03ool00?ooooooo`0000;oo`0000?oooooo`00oooo0000
0_ooool01_oo003o003oo`00oooo003o003oooooo`;o003o00?oooooool00?ooool00_ooool01?l0
0?ooooooo`00oooo0002o`00o`05ool00?ooooooooooool00?ooool00ooo00000ol00?ooooooool0
0002ooooo`04ool00?l00?oo003oool000;o003o00Coo`00o`00ooooooooo`000_ooool01_l00?oo
o`00ooooooooooooo`00ooooo`Woo`0000Coooooool00?oo003oo`00;_ooool2o`0001Kooooo000X
ooooo`03o`000?oooooooooo03_ooooo0_l00?l01ooooooo003ooooooooooooo003oooooool00?l0
0_ooool01Ol00?oooooooooooooooooo003o00Gooooo00Go003oooooool00?ooooooo`00o`04oooo
o`03o`00oooooooooooo00Co003o0_ooool01Ol0003oooooo`00ool00?oooooo00;o003o00?ooooo
o`00ooooool01?ooool01?l00?ooooooo`00ool00?l6ooooo`04o`00ooooooooooooo`00o`?ooooo
00Ko003ooooooooooooo003oooooool00?l2ooooo`03o`00oooooooooooo03_ooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`0Oooooo`Koo`0000?oooooool00?oo00001ooo00000ooo
ooooo`00ooooo`02ooooo`04ool00?ooooooooooool000;ooooo00Goo`00ooooooooooooooooool0
0002ooooo`04ool00?ooooooooooool000?ooooo00Coo`00ooooooooooooo`000_ooool01Ooo003o
ooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`000_ooool00ooo003oooooooooo`03
ool00003oooooooo003ooooo00?oo`000_ooool01?oo003ooooooooooooo0002ooooo`05ool00?oo
oooooooooooooooo00000_ooool01?oo003ooooooooooooo0002ooooo`05ool00?oooooooooooooo
oooo00000_ooool01?oo003ooooooooooooo0003ooooo`04ool00?ooooooooooool000;ooooo00Ko
o`00ooooooooooooooooool00?ooool6ool00003oooooooo003oo`0000Ooo`009?ooool00ol0003o
ooooooooo`0[ooooo`03o`000?oooooooooo033ooooo0ooo00000oooooooo`00ool00004ool00005
o`00oooo003o003ooooooooo00000_ooool02?oo003oooooooooool00?ooo`00ooooool00?ooo`00
0_l00?l01Ooo003ooooooooooooo003ooooo00?oo`000_ooool01ooo003ooooooooooooo003ooooo
o`00oooo00000_ooool2o`00o`06oooooooo003oooooooooool00?oooooo0_l00?l01?oo003o003o
oooooooo0002ooooo`03ool00?l00?ooo`0000;oo`0000?o003ooooooooo00000_ooool01?oo003o
003ooooooooo0002o`00o`05ool00?oooooo003oool00?l00?l00_ooool01Ooo003oooooo`00oooo
003ooooo00Woo`00<oooool00ol0003oooooooooo`0Dooooo`00:?ooool00ol0003oooooooooo`0l
ooooo`06o`00oooooooo003oo`00oooooooo003o0_ooool01?l00?ooooooo`00ool00?l2ooooo`03
o`00oooooooooooo00?ooooo0_l00?l2ooooo`03o`00oooooooooooo00?ooooo00?o003oooooool0
0?l00ol00?l2ooooo`03o`000?oooooooooo00;ooooo1?l00?l4ooooo`04o`00oooooooooooooooo
o`;o003o1Oooool00ol00?ooooooooooo`02o`00o`05ooooool00?ooooooooooool00?l01?ooool2
o`00ocgooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Vooooo`coo`000_ooool0
1?oo003ooooooooooooo0002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooo
oooooooo0003ooooo`04ool00?ooooooooooool000;ooooo00?oo`00ooooooooool00ooo00001Ooo
ooooo`00ooooooooooooo`0000;ooooo00?oo`00ooooooooool00ooo00000oooooooo`00ooooo`03
ool000;ooooo00Coo`00ooooooooooooo`000_ooool00ooo003oooooooooo`03ool00005oooooooo
003ooooooooooooo00000_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00oooooooo
ooooo`000oooool01?oo003ooooooooooooo0002ooooo`03ool00?oooooooooo00Woo`0000Cooooo
ool00?oo003oo`00:_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo03Oooooo1_oo
00002Oooooooo`00o`00ooooooooo`00o`00oooooooo003oool00002o`00o`04ool00?oooooo003o
ool000;ooooo00Coo`00o`00oooooooo003o0_ooool02Ol00?ooo`00ooooooooooooo`00o`00oooo
ooooo`00ooooo`02o`00o`;ooooo00?oo`00ooooooooool00_l00?l2ooooo`04ool00?oooooo003o
ool000;ooooo00Coo`00o`00oooooooooooo0_l00?l02oooooooo`00ooooooooooooo`00ooooool0
0?ooo`00ooooool00?ooo`0000;o003o00Koo`00o`00oooooooo003oool00?ooool6ool003Wooooo
00?o0000ooooooooool05?ooool002Sooooo00?o0000ooooooooool0?oooool01?l00?ooooooo`00
ooooool2o`00o`;ooooo00Co003ooooooooooooo003o1Oooool2o`00o`Oooooo0_l00?l01?oooooo
003oooooool00?l3ooooo`04o`000?oooooo003oo`00o`Cooooo00?o003oooooooooool01_ooool2
o`00o`Gooooo00Ko003oooooooooooooooooo`00ooooool2o`00o`04ooooool00?ooooooo`00od7o
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0/ooooo`Koo`0000Koooooool00?oo
003oo`00oooooooo0002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooo
oooo0003ooooo`04ool00?ooooooooooool000;ooooo00?oo`00ooooooooool00ooo00001Ooooooo
o`00ooooooooooooo`0000;ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04oooo
o`04ool00?ooooooooooool000;ooooo00?oo`00ooooooooool00ooo00001Oooooooo`00oooooooo
ooooo`0000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?ooooooooooool000?o
oooo00Goo`00ooooooooooooo`00ooooo`03ool00003oooooooo003oo`0000Coo`00<Oooool00ol0
003oooooooooo`0[ooooo`03o`000?oooooooooo03[ooooo0ooo00002Oooooooo`00o`00oooooooo
o`00o`00oooooooo003oool00002o`00o`04ool00?l00?oo003oool000;ooooo00Coo`00o`00oooo
oooo003o0_ooool01Ol00?ooo`00ooooooooooooo`0000;o003o00Ooo`00ooooool00?ooooooo`00
ooooooooo`0000;ooooo0ol00?l01Oooooooo`00o`00ool00?ooo`0000;ooooo00Goo`00o`00oooo
ooooooooo`00o`02ooooo`04ool00?ooooooooooool000;o003o00coo`00o`00ooooooooo`00o`00
ooooooooo`00o`00oooooooo003oool00?ooool3ool003cooooo00?o0000ooooooooool05?ooool0
02Sooooo0_l00010ooooo`04o`00ooooooooooooooooo`;o003o00Coooooo`00ool00?oooooo0_l0
0?l9ooooo`03o`00oooooooooooo00;ooooo0_l00?l2ooooo`03o`00oooooooooooo00;ooooo00Ko
0000ooooool00?ooooooo`00ooooool3o`00o`Cooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooooooo00?o003o00?oooooo`00ool00?l00_ooool00ol00?oo
ooooooooo`0nooooo`;o00009_ooool2o`00033ooooo0ooo00000oooooooo`00ool00004ool00003
oooooooo003ooooo00;ooooo00Coo`00ooooooooooooo`000_ooool01Ooo003ooooooooooooooooo
o`0000;ooooo00Coo`00ooooooooooooo`000_ooool3ool00005oooooooo003ooooooooooooo0000
0_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00Coo`00oooooooooooo
o`000_ooool00ooo003oooooooooo`03ool00005oooooooo003ooooooooooooo00000_ooool01Ooo
003oooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`000oooool00ooo003oooooool0
0005ool00004oooooooo003oo`00ool003?ooooo0_l0000]ooooo`03o`000?oooooooooo03[ooooo
1_oo00000oooooooo`00o`00o`02ooooo`07ool00?l00?ooooooool00?l00?ooooooool00002oooo
o`03ool00?l00?oooooo00?ooooo00Ko003oool00?ooooooooooool00?l00?l3ool00005o`00oooo
oooo003ooooooooo00000oooool2o`00o`?oo`0000Go003oool00?ooooooooooool00004ooooo`;o
003o00Coo`00ooooooooooooo`000_l00?l01ooo003o003oo`00oooo003o003ooooooooo00000_oo
ool6ool003cooooo00?o0000ooooooooool05?ooool002Sooooo00?o0000ooooooooool0@Oooool2
o`00o`?ooooo00Go003oooooooooooooooooo`00o`05ooooo`05o`00ooooooooooooooooool00?l0
1?ooool00ol00?ooooooo`00o`02ooooo`0:o`00oooooooo003oooooool0003oooooo`00oooooooo
003oooooo`?o003o1?ooool00ol00?ooooooooooo`08ooooo`04o`00ooooooooooooo`00o`?ooooo
00?o003oooooooooool0@oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo03?ooooo
1_oo00000oooooooo`00ooooo`02ooooo`04ool00?ooooooooooool000;ooooo00Goo`00oooooooo
ooooooooool00002ooooo`04ool00?ooooooooooool000Kooooo00Coo`00ooooooooooooo`000_oo
ool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00Coo`00ooooooooooooo`00
0_ooool00ooo003oooooooooo`04ooooo`04ool00?ooooooooooool000;ooooo00Goo`00oooooooo
ooooooooool00002ooooo`04ool00?ooooooooooool000?ooooo00?oo`00oooooooo00001Ooo000h
ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0?Oooool3ool00009oooooooo003o
ooooooooool00?ooo`00ooooool00?ooo`0000;o003o00Coo`00ooooooooooooo`001_ooool01Ooo
003ooooooooooooo003ooooo00?oo`0000Goooooo`00ool00?ooooooool00002ooooo`03o`00oooo
oooo003o00?oo`0000Koooooool00?ooooooooooool00?l00?l4ooooo`08o`00oooo003ooooooooo
oooo003o003ooooooooo0002o`00o`06ool00?ooooooooooool00?l00?oooooo0ooo000nooooo`;o
00005_ooool002Sooooo00?o0000ooooooooool0@_ooool01?l00?ooooooo`00ooooool2o`00o`03
ooooool00?oo003o00Gooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`03ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooool000001_ooool00ol00?ooooooooooo`03ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool00oooool01?l00?ooooooo`00ooooool2o`00
o`;ooooo00?o003oooooooooool0@_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
03Kooooo1_oo0002ooooo`04ool00?ooooooooooool000;ooooo00Goo`00ooooooooooooooooool0
0002ooooo`04ool00?ooooooooooool000Kooooo00Coo`00ooooooooooooo`000_ooool00ooo003o
ooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00Coo`00ooooooooooooo`000_ooool00ooo
003oooooooooo`04ooooo`04ool00?ooooooooooool000;ooooo00Goo`00ooooooooooooooooool0
0002ooooo`04ool00?ooooooooooool000;ooooo1_oo000kooooo`03o`000?oooooooooo02_ooooo
00?o0000ooooooooool0?Oooool6ool00009ooooool00?ooo`00ooooool00?ooo`00ooooool00?oo
o`0000;ooooo00?oo`00o`00ooooool00oooool01_l00?ooo`00ooooooooooooo`00o`00o`?oo`00
0_l00?l2ooooo`03ool00?oooooooooo00;o003o00Koooooool00?oo003oo`00o`00oooo0002oooo
o`03ool00?l00?oooooo00?ooooo00co003oool00?ooooooooooool00?oooooo003oool00?oooooo
003oool00?l00?l3ool00004oooooooo003oo`00ool003oooooo00?o0000ooooooooool05?ooool0
01[ooooo1Ol00003ooooo`;o00001?ooool00ol0003oooooooooo`12ooooo`03o`00oooooooo003o
00;ooooo00?o003oooooool00?l01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
00Cooooo00Go003oooooool0003oooooo`00o`06ooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool00oooool01?l00?ooooooooooooooool2o`00o`;ooooo00?o003oooooooooool0@_oo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo03Wooooo0ooo0002ooooo`04ool00?oo
ooooooooool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?ooooooooooool0
00Kooooo00Coo`00ooooooooooooo`000_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooo
oooo00Cooooo00Coo`00ooooooooooooo`000_ooool00ooo003oooooooooo`04ooooo`04ool00?oo
ooooooooool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?ooooooooooool0
00;ooooo0ooo000nooooo`03o`000?oooooooooo01cooooo1Ol00003ooooo`;o00001Oooool00ol0
003oooooooooo`10ooooo`?oo`0000Koooooo`00oooo003oooooo`00oooo0002o`00o`05ool00?oo
ooooooooool00?l00?l01?ooool02?l00?ooo`00ooooooooooooo`00o`00oooooooo003o0oooool0
0ol00?ooooooool00002ooooo`04o`00ooooooooooooooooo`?o003o00Goo`00ooooooooooooo`00
o`00o`05ooooo`04ool00?ooooooooooool000;o003o00Goo`00o`00ooooooooo`00o`00o`03ool0
04?ooooo00?o0000ooooooooool05?ooool001_ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00003ooooo`03o`000?oooooooooo04Gooooo0ol00?l00ooooooo003oo`00o`0:
ooooo`05o`00ooooooooooooooooool00?l02?ooool00ol0003oooooo`00o`06ooooo`05o`00oooo
ooooooooooooool00?l01?ooool00ol00?ooooooooooo`03ooooo`04o`00oooooooo003oooooo`;o
003oAoooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo03Wooooo0ooo0002ooooo`04
ool00?ooooooooooool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?oooooo
ooooool000Kooooo00Coo`00ooooooooooooo`000_ooool00ooo003oooooooooo`04ooooo`03ool0
0?oooooooooo00Cooooo00Coo`00ooooooooooooo`000_ooool00ooo003oooooooooo`04ooooo`04
ool00?ooooooooooool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?oooooo
ooooool000;ooooo0ooo000nooooo`03o`000?oooooooooo01gooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo043ooooo0ooo0002ooooo`07
ool00?ooooooooooool00?l00?ooooooool00002ooooo`03ool00?l00?oooooo00?ooooo00Ko003o
ool00?ooooooooooool00?l00?l5ooooo`03o`00ooooooooo`0000Sooooo00Go003oool00?oooooo
ooooool00005ooooo`05o`00oooo003ooooooooooooo00000_l00?l01Ooo003o003oo`00oooo003o
003o00?oo`00@oooool00ol0003oooooooooo`0Dooooo`007?ooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0000?ooooo0_l00017ooooo`05o`00ooooooooooooooooool00?l01Ooo
ool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l01_ooool01Ol00?oooooo
o`000?oooooo003o00Kooooo00Go003oooooooooooooooooo`00o`09ooooo`;o003o00Coooooo`00
oooooooo003oA_ooool3o`0002Kooooo00?o0000ooooooooool0?Oooool3ool00005oooooooo003o
oooooooooooo00000oooool01?oo003ooooooooooooo0002ooooo`03ool00?oooooooooo00Cooooo
00Goo`00ooooooooooooo`00ooooo`03ool000Gooooo00?oo`00ooooooooool00oooool3ool00005
oooooooo003ooooooooooooo00001_ooool01?oo003ooooooooooooo0002ooooo`05ool00?oooooo
oooooooooooo00000_ooool00ooo003oooooool00002ool004;ooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0
A?ooool01Ol00?ooo`00ooooool00?ooo`0000;o003o00Coo`00ooooooooooooo`001_ooool01?oo
003ooooooooooooo0006ooooo`03o`00ooooooooo`0000;ooooo00?o003oooooooooool01?ooool0
1Ooo003ooooooooooooo003o003o00Cooooo00_o003oool00?ooooooooooool00?l00?ooooooool0
0?l00?ooooooool00017ooooo`03o`000?oooooooooo01Cooooo000Mooooo`05o`000?oooooooooo
ooooool000000_ooool01Ol0003ooooooooooooooooo000004Oooooo0ol00?l00ooooooo003oo`00
o`05ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool02?ooool00ol00?ooooooo`00
000<ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool2o`00o`03ooooool0
0?oooooo00;o003oAoooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo03gooooo0ooo
00001Oooooooo`00ooooooooooooo`0000?ooooo00Coo`00ooooooooooooo`000_ooool00ooo003o
ooooooooo`04ooooo`05ool00?ooooooooooool00?ooool00ooo0005ooooo`03ool00?oooooooooo
00?ooooo0ooo00001Oooooooo`00ooooooooooooo`0000Kooooo00Coo`00ooooooooooooo`000_oo
ool01Ooo003oooooooooooooooooo`0000;ooooo00?oo`00oooooooo00000_oo0012ooooo`03o`00
0?oooooooooo01oooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00;o
oooo0_l00015ooooo`08o`00oooo003oooooo`00oooo003oooooo`00oooo0002ooooo`03ool00?l0
0?oooooo00?ooooo00Ko003oool00?ooooooooooool00?l00?l7ooooo`04ool00?ooooooooooo`00
o`Gooooo00Ko003oool00?ooooooooooool00?l00?l4ooooo`08o`00oooo003ooooooooooooo003o
ooooo`00oooo0002ooooo`03ool00?l00?oooooo04Cooooo0_l0000Fooooo`006_ooool01Ol0003o
oooooooooooooooo000000;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`15
ooooo`05o`00oooooooo003oooooool00?l01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo00Cooooo00Go003oooooool0003oooooo`00o`06ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo04Gooooo
00?o0000ooooooooool09?ooool2o`0003kooooo0ooo00001Oooooooo`00ooooooooooooo`0000?o
oooo00Coo`00ooooooooooooo`000_ooool00ooo003oooooooooo`04ooooo`05ool00?oooooooooo
ool00?ooool00ooo0005ooooo`03ool00?oooooooooo00?ooooo0ooo00001Oooooooo`00oooooooo
ooooo`0000Kooooo00Coo`00ooooooooooooo`000_ooool01Ooo003oooooooooooooooooo`0000;o
oooo00?oo`00oooooooo00000_oo0011ooooo`;o00007_ooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`14ooooo`?oo`0000Go003o
ool00?l00?oo003oool00002ooooo`03ool00?l00?oooooo00?ooooo00Ko003oool00?oooooooooo
ool00?l00?l5ooooo`03o`00ooooooooo`0000;ooooo00?o003oooooooooool00oooool01_l00?oo
o`00ooooooooooooo`00o`00o`Gooooo00Coo`00ooooooooooooo`000_l00?l00ooo003oooooool0
0002ool004Kooooo00?o0000ooooooooool05?ooool001[ooooo00Go0000ooooooooooooooooo`00
0002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0AOooool00ol00?oooooo
ooooo`02o`00o`_ooooo00Go003oooooooooooooooooo`00o`08ooooo`03o`000?oooooo003o00Ko
oooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo00?ooooo00Co003ooooo
ool00?oooooo0_l00?m7ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0@Oooool0
1?oo003ooooooooooooo0003ooooo`04ool00?ooooooooooool000;ooooo00?oo`00ooooooooool0
1?ooool01?oo003ooooooooooooo0009ooooo`03ool00?oooooooooo00Oooooo00Coo`00oooooooo
ooooo`001_ooool01?oo003ooooooooooooo0002ooooo`05ool00?oooooooooooooooooo00000_oo
ool00ooo003oooooooooo`14ooooo`03o`000?oooooooooo01cooooo00Go0000oooooooooooooooo
o`000002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0A?ooool3ool00005
oooooooo003o003ooooooooo00000_ooool00ooo003o003oooooo`03ooooo`06o`00oooo003ooooo
oooooooo003o003o1Oooool00ol00?ooooooool00008ooooo`06o`00oooo003ooooooooooooo003o
003o1?ooool01Ol00?ooo`00ooooooooooooo`0000;o003o00?oo`00o`00oooo00000_oo0016oooo
o`03o`000?oooooooooo01Cooooo000Kooooo`?o00001?ooool2o`0000Cooooo00?o0000oooooooo
ool0B_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00?ooooo00Go003ooooooooo
ooooooooo`00o`06ooooo`05o`00oooooooo0000ooooool00?l01_ooool01Ol00?oooooooooooooo
oooo003o00Wooooo0_l00?l00ooooooo003oooooo`19ooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool0@?ooool3ool00003oooooooo003ooooo00;ooooo00Coo`00ooooooooooooo`00
0_ooool00ooo003oooooooooo`04ooooo`04ool00?ooooooooooool000Wooooo00?oo`00oooooooo
ool01oooool01?oo003ooooooooooooo0006ooooo`04ool00?ooooooooooool000;ooooo00Koo`00
ooooooooooooooooool00?ooool3ool004Gooooo00?o0000ooooooooool07Oooool3o`0000Cooooo
0_l00005ooooo`03o`000?oooooooooo04Cooooo0ooo00001Ol00?ooo`00o`00ool00?ooo`0000;o
oooo00?oo`00ooooooooool01?ooool01?oo003ooooooooooooo0006ooooo`05o`00ooooooooo`00
ooooool00?l01oooool01?oo003ooooooooooooo0005ooooo`09o`00oooo003ooooooooooooo003o
003ooooooooo003o003o00?oo`00A_ooool00ol0003oooooooooo`0Dooooo`00:?ooool2o`0004Wo
oooo0ol00?l4ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool02?ooool00ol00?oo
ooooo`00000<ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool01?l00?oo
ooooo`00ool00?m9ooooo`;o00009_ooool00ol0003oooooooooo`10ooooo`?oo`0000?oooooool0
0?ooool00_ooool01?oo003ooooooooooooo0002ooooo`03ool00?oooooooooo00Cooooo00Coo`00
ooooooooooooo`002Oooool00ooo003oooooooooo`07ooooo`04ool00?ooooooooooool000Kooooo
00Coo`00ooooooooooooo`000_ooool01_oo003oooooooooooooooooo`00ooooo`?oo`00AOooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo04Oooooo00Go003oool00?oooooo003oool0
0002ooooo`03ool00?l00?oooooo00?ooooo00Go003oool00?ooooooooooool00008ooooo`03ool0
0?oooooo003o00Kooooo00Go003oool00?ooooooooooool00005ooooo`09o`00oooo003ooooooooo
oooo003oooooo`00oooo003o003o04Wooooo00?o0000ooooooooool05?ooool002Sooooo00?o0000
ooooooooool0B?ooool3o`00o`Cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`04
ooooo`05o`00oooooooo0000ooooool00?l01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool0Boooool00ol0003oooooooooo`0Fooooo`Go00000ooo
ool2o`0000Cooooo00?o0000ooooooooool0@?ooool3ool00003oooooooo003ooooo00;ooooo00Co
o`00ooooooooooooo`000_ooool00ooo003oooooooooo`04ooooo`04ool00?ooooooooooool000Wo
oooo00?oo`00ooooooooool01oooool01?oo003ooooooooooooo0006ooooo`04ool00?oooooooooo
ool000;ooooo00Koo`00ooooooooooooooooool00?ooool3ool004Gooooo00?o0000ooooooooool0
:oooool00ol0003oooooooooo`17ooooo`05o`00oooo003o003oo`00oooo00000_ooool00ooo003o
003oooooo`03ooooo`05o`00oooo003ooooooooooooo00001_ooool01Ol00?ooooooool00?oooooo
003o00Kooooo00Go003oool00?ooooooooooool00006ooooo`04ool00?ooooooooooool000;o003o
00?oo`00ooooooooool0Aoooool2o`0001Kooooo000Xooooo`03o`000?oooooooooo04Sooooo0_l0
0?l;ooooo`05o`00ooooooooooooooooool00?l02?ooool00ol0003oooooo`00o`06ooooo`05o`00
ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`04ooooo`;o003oB_ooool00ol0003o
ooooooooo`0Gooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool0
0ol0003oooooooooo`14ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooo
oooo0006ooooo`04ool00?ooooooooooool000Wooooo00?oo`00ooooooooool01oooool01?oo003o
oooooooooooo0006ooooo`04ool00?ooooooooooool000;ooooo00Goo`00ooooooooooooooooool0
0019ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0B?ooool01?oo003o003ooooo
oooo0002ooooo`03ool00?l00?oooooo00?ooooo00Go003oool00?ooooooooooool00006ooooo`03
o`00ooooooooo`0000Sooooo00Go003oool00?ooooooooooool00005ooooo`05o`00oooo003ooooo
oooooooo00000_l00?l00ooo003o003oooooo`18ooooo`03o`000?oooooooooo01Cooooo000Xoooo
o`03o`000?oooooooooo04[ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`03oooo
o`05o`00ooooooooooooooooool00?l01_ooool01Ol00?ooooooo`000?oooooo003o00Kooooo00Go
003oooooooooooooooooo`00o`09ooooo`04o`00oooooooo003oo`00od[ooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooo
ooooool0A?ooool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`001_oo
ool01?oo003ooooooooooooo0009ooooo`03ool00?oooooooooo00Oooooo00Coo`00oooooooooooo
o`001_ooool01?oo003ooooooooooooo0002ooooo`05ool00?oooooooooooooooooo0000BOooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo04Oooooo00Go003oool00?l00?oo003oool0
0002ooooo`03ool00?oooooooooo00Cooooo00Coo`00ooooooooooooo`001_ooool01Ol00?oooooo
ool00?oooooo003o00Oooooo00Coo`00ooooooooooooo`001Oooool02?l00?ooo`00oooooooooooo
o`00o`00ooooooooo`00B_ooool00ol0003oooooooooo`0Dooooo`00:?ooool00ol0003ooooooooo
o`18ooooo`?o003o1?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Sooooo00?o
003oooooool000003?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00Co
003oooooool00?oo003oB_ooool00ol0003oooooooooo`0Iooooo`05o`000?ooooooooooooooool0
00000_ooool01?l0003oooooooooooooool3o`0004Cooooo00Goo`00ooooooooooooooooool00002
ooooo`04ool00?ooooooooooool000Kooooo00Coo`00ooooooooooooo`002Oooool00ooo003ooooo
ooooo`07ooooo`04ool00?ooooooooooool000Kooooo00Coo`00ooooooooooooo`000_ooool01Ooo
003oooooooooooooooooo`0004Sooooo0_l0000]ooooo`03o`000?oooooooooo04Oooooo00Go003o
ool00?oooooo003oool00002ooooo`03ool00?l00?oooooo00?ooooo0ooo00000oooooooo`00oooo
o`07ooooo`03ool00?oooooo003o00Kooooo00?o003oool00?ooool00ooo0004ooooo`08o`00oooo
003ooooooooooooo003oooooo`00oooo001:ooooo`03o`000?oooooooooo01Cooooo000Xooooo`;o
0000BOooool3o`00o`Cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`04ooooo`05
o`00oooooooo0000ooooool00?l01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool0B_ooool2o`0001Sooooo00Go0000ooooooooooooooooo`000002
ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0A?ooool01Ooo003ooooooooo
ooooooooo`0000;ooooo00Coo`00ooooooooooooo`001_ooool01?oo003ooooooooooooo0009oooo
o`03ool00?oooooooooo00Oooooo00Coo`00ooooooooooooo`001_ooool01?oo003ooooooooooooo
0002ooooo`05ool00?oooooooooooooooooo0000BOooool00ol0003oooooooooo`0[ooooo`03o`00
0?oooooooooo04Oooooo00Go003oool00?l00?oo003oool00002ooooo`03ool00?l00?oooooo00?o
oooo0ooo00000oooooooo`00ooooo`06ooooo`04o`00oooo003oooooo`00o`Kooooo00?o003oool0
0?ooool00ooo0005ooooo`04ool00?ooooooooooool000;o003o00?oo`00ooooooooool0B?ooool0
0ol0003oooooooooo`0Dooooo`00:?ooool00ol0003oooooooooo`18ooooo`;o003o2oooool01Ol0
0?oooooooooooooooooo003o00Sooooo00?o0000ooooool00?l01_ooool01Ol00?oooooooooooooo
oooo003o00Cooooo00?o003oooooooooool01?ooool2o`00od[ooooo00?o0000ooooooooool05_oo
ool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000oooool00ol0003o
ooooooooo`13ooooo`?oo`000_ooool01?oo003ooooooooooooo0002ooooo`03ool00?oooooooooo
00Cooooo00Coo`00ooooooooooooo`002Oooool00ooo003oooooooooo`07ooooo`04ool00?oooooo
ooooool000Kooooo00Coo`00ooooooooooooo`000_ooool00ooo003oooooooooo`03ool004Sooooo
00?o0000ooooooooool0:oooool00ol0003oooooooooo`18ooooo`04ool00?l00?ooooooool000;o
oooo00?oo`00o`00ooooool00oooool3ool00003oooooooo003ooooo00Kooooo00?o003oool00?oo
ool02?ooool00ooo003oooooool00002ool000Cooooo00Go003oool00?ooooooooooool00002o`00
o`03ool00?oooooooooo04Oooooo0_l0000Fooooo`00:?ooool00ol0003oooooooooo`1:ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool00oooool01Ol00?oooooooooooooooooo003o
00Kooooo00Go003oooooool0003oooooo`00o`06ooooo`05o`00ooooooooooooooooool00?l02Ooo
ool01?l00?ooooooo`00ool00?m:ooooo`03o`000?oooooooooo01Oooooo0ol00004ooooo`;o0000
1?ooool00ol0003oooooooooo`13ooooo`?oo`000_ooool01?oo003ooooooooooooo0002ooooo`03
ool00?oooooooooo00Cooooo00Coo`00ooooooooooooo`002Oooool00ooo003oooooooooo`07oooo
o`04ool00?ooooooooooool000Kooooo00Coo`00ooooooooooooo`000_ooool00ooo003ooooooooo
o`03ool004Sooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`18ooooo`04ool00?oo
oooo003oool000;ooooo00?oo`00ooooooooool01oooool00ooo003oooooooooo`05ooooo`04o`00
oooo003oooooo`00o`Oooooo00?oo`00ooooooooool01_ooool02?l00?ooo`00ooooooooooooo`00
o`00ooooooooo`00B_ooool00ol0003oooooooooo`0Dooooo`00:?ooool00ol0003oooooooooo`18
ooooo`?o003o1?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Sooooo00?o003o
ooooool000003?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00Co003o
ooooool00?oo003oB_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo04?ooooo0ooo
0002ooooo`04ool00?ooooooooooool000;ooooo00?oo`00ooooooooool01?ooool01?oo003ooooo
oooooooo0009ooooo`03ool00?oooooooooo00Oooooo00Coo`00ooooooooooooo`001_ooool01?oo
003ooooooooooooo0002ooooo`03ool00?oooooooooo00?oo`00B?ooool00ol0003oooooooooo`0[
ooooo`03o`000?oooooooooo04Oooooo0ooo00001_l00?ooo`00ooooooooooooo`00o`00o`Gooooo
00Co003oooooooooooooo`002?ooool00ooo003oooooo`00o`07ooooo`04ool00?ooooooooooo`00
o`Gooooo00Ko003oool00?ooooooooooool00?ooool3ool004Wooooo00?o0000ooooooooool05?oo
ool002Sooooo00?o0000ooooooooool0B?ooool2o`00o`03ooooool00?oooooo00;ooooo00?o003o
ooooooooool01oooool00ol00?ooooooooooo`04ooooo`05o`00oooooooo0000ooooool00?l01_oo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0Booo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo04Sooooo00Coo`00ooooooooooooo`00
0_ooool00ooo003oooooooooo`04ooooo`04ool00?ooooooooooool000Wooooo00?oo`00oooooooo
ool01oooool01?oo003ooooooooooooo0006ooooo`04ool00?ooooooooooool000;ooooo00?oo`00
ooooooooool0Boooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo04Oooooo0ooo0000
1_l00?ooo`00ooooooooooooo`00o`00o`Gooooo00Co003oooooooooooooo`001oooool01?l00?oo
o`00ooooool00?l7ooooo`04ool00?ooooooooooo`00o`Kooooo00Goo`00ooooooooooooo`00o`00
o`03ool004Wooooo00?o0000ooooooooool05?ooool002Sooooo0_l0001Fooooo`05o`00oooooooo
ooooooooool00?l02?ooool00ol0003oooooo`00o`06ooooo`04o`00ooooooooooooo`00o`Gooooo
00?o003oooooooooool0Coooool2o`0002Kooooo00?o0000ooooooooool0B?ooool01?oo003ooooo
oooooooo0002ooooo`03ool00?oooooooooo00Cooooo00Coo`00ooooooooooooo`002Oooool00ooo
003oooooooooo`07ooooo`04ool00?ooooooooooool000Kooooo00Coo`00ooooooooooooo`000_oo
ool00ooo003oooooooooo`1;ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0Aooo
ool3ool00006oooooooo003ooooooooooooo003o003o1Oooool01?l00?oooooooooooooo0007oooo
o`03o`00oooo003ooooo00Sooooo00Coo`00oooooooooooo003o1Oooool01_l00?ooo`00oooooooo
ooooo`00o`00o`?oo`00B?ooool2o`0001Kooooo000Xooooo`03o`000?oooooooooo04_ooooo00Go
003oooooooooooooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`Oooooo00Go003oooooool0
003oooooo`00o`06ooooo`04o`00ooooooooooooo`00o`[ooooo00?o003oooooooooool0Boooool0
0ol0003oooooooooo`0Tooooo`;o0000BOooool01?oo003ooooooooooooo0002ooooo`03ool00?oo
oooooooo00Cooooo00Coo`00ooooooooooooo`002Oooool00ooo003oooooooooo`07ooooo`04ool0
0?ooooooooooool000Kooooo00Coo`00ooooooooooooo`000_ooool00ooo003oooooooooo`1:oooo
o`;o0000;Oooool00ol0003oooooooooo`1:ooooo`05o`00oooo003ooooooooooooo00002Oooool0
0ooo003oooooooooo`05ooooo`04o`00oooo003oooooo`00o`Oooooo00?oo`00ooooooooool01_oo
ool01_l00?ooo`00ooooooooooooo`00o`00odcooooo00?o0000ooooooooool05?ooool001cooooo
0ol00003ooooo`;o00001?ooool00ol0003oooooooooo`1;ooooo`05o`00ooooooooooooooooool0
0?l01Oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooo000000_ooooo00?o003ooooooooo
ool00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo04_ooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`18ooooo`04ool00?ooooooooooool000;ooooo00?oo`00oooo
ooooool01?ooool01?oo003ooooooooooooo0009ooooo`03ool00?oooooooooo00Oooooo00Coo`00
ooooooooooooo`001_ooool01?oo003ooooooooooooo0002ooooo`03ool00?oooooooooo04_ooooo
00?o0000ooooooooool0:oooool00ol0003oooooooooo`1:ooooo`06o`00oooo003ooooooooooooo
003o003o1Oooool01?l00?oooooooooooooo0008ooooo`03ool00?oooooo003o00Oooooo00Coo`00
oooooooooooo003o1Oooool01Ol00?ooo`00ooooooooooooo`0004gooooo00?o0000ooooooooool0
5?ooool001gooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool0
0000COooool01Ol00?oooooooooooooooooo003o00Sooooo00?o003oooooooooool01Oooool01?l0
0?ooooooo`000?l00?l7ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`1;ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0B?ooool0
1?oo003ooooooooooooo0002ooooo`03ool00?oooooooooo00Cooooo00Coo`00ooooooooooooo`00
2Oooool00ooo003oooooooooo`07ooooo`04ool00?ooooooooooool000Kooooo00Coo`00oooooooo
ooooo`000_ooool00ooo003oooooooooo`1;ooooo`03o`000?oooooooooo01kooooo0ol00003oooo
o`;o00001Oooool00ol0003oooooooooo`1:ooooo`06o`00oooo003ooooooooooooo003o003o1Ooo
ool01?l00?oooooooooooooo0007ooooo`04o`00oooo003oooooo`00o`Oooooo00Coo`00oooooooo
oooo003o1_ooool01Ooo003ooooooooooooo003o003o04cooooo00?o0000ooooooooool05?ooool0
01[ooooo1Ol00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0Coooool0
0ol00?ooooooooooo`03ooooo`04o`00ooooooooooooo`00o`Wooooo00?o0000o`00ooooool01_oo
ool01?l00?ooooooooooool00?l6ooooo`03o`00oooooooooooo04oooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`18ooooo`04ool00?ooooooooooool000;ooooo00?oo`00oooooooo
ool01?ooool01?oo003ooooooooooooo0009ooooo`03ool00?oooooooooo00Oooooo00Coo`00oooo
ooooooooo`001_ooool01?oo003ooooooooooooo0002ooooo`03ool00?oooooooooo04_ooooo00?o
0000ooooooooool07oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`1;ooooo`05ool00?ooooooooooool00?l00?l01Oooool01?l00?oo
oooooooooooo0007ooooo`03o`00oooo003ooooo00Sooooo00Coo`00oooooooooooo003o1Oooool0
1_l00?ooo`00ooooooooooooo`00o`00odcooooo00?o0000ooooooooool05?ooool001[ooooo00Co
0000oooooooooooo00000oooool01?l0003oooooooooool00003ooooo`;o0000C?ooool00ol00?oo
ooooooooo`07ooooo`04o`00ooooooooooooo`00o`Oooooo00Co003oooooool0003o003o1oooool0
1?l00?ooooooooooool00?l:ooooo`03o`00oooooooooooo04Wooooo0ol0000Vooooo`03o`000?oo
oooooooo04Sooooo00Coo`00ooooooooooooo`000_ooool00ooo003oooooooooo`04ooooo`04ool0
0?ooooooooooool000Wooooo00?oo`00ooooooooool01oooool01?oo003ooooooooooooo0006oooo
o`04ool00?ooooooooooool000;ooooo00?oo`00ooooooooool0Boooool00ol0003oooooooooo`0L
ooooo`Go00000_ooool01?l0003oooooooooool00004ooooo`;o0000Boooool01Ol00?ooo`00oooo
ooooooooo`0000Wooooo00?oo`00ooooooooool01Oooool01?l00?ooo`00ooooool00?l7ooooo`03
ool00?oooooooooo00Kooooo00Ko003oool00?ooooooooooool00?l00?m;ooooo`;o00005_ooool0
01_ooooo00?o0000ooooool000000oooool01?l0003oooooooooool00003ooooo`03o`000?oooooo
oooo04_ooooo00Go003oooooooooooooooooo`00o`06ooooo`03o`00oooooooooooo00Oooooo00?o
003oooooool000002oooool00ol00?ooooooooooo`04ooooo`05o`00ooooooooooooooooool00?l0
COooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo04Sooooo00Coo`00oooooooooooo
o`000_ooool00ooo003oooooooooo`03ooooo`?oo`0000?oooooool00?ooool02?ooool00ooo003o
ooooooooo`07ooooo`03ool00?ooooooo`0000;oo`001Oooool01?oo003ooooooooooooo0002oooo
o`03ool00?oooooooooo04_ooooo00?o0000ooooooooool07?ooool01?l0003oooooooooool00003
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0B_ooool01_l00?ooo`00oooo
ooooooooo`00o`00o`Gooooo00Co003oooooooooooooo`002?ooool00ooo003oooooo`00o`07oooo
o`04ool00?ooooooooooo`00o`Gooooo00Go003oool00?ooooooooooool0001=ooooo`03o`000?oo
oooooooo01Cooooo000Looooo`;o00000oooool01?l0003oooooooooool00003ooooo`03o`000?oo
oooooooo04_ooooo00Go003oooooooooooooooooo`00o`08ooooo`03o`00oooooooooooo00Gooooo
00Co003oooooool0003o003o1oooool00ol00?ooooooooooo`07ooooo`05o`00oooooooooooooooo
ool00?l0COooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo04Sooooo00Coo`00oooo
ooooooooo`000_ooool00ooo003oooooooooo`03ooooo`?oo`0000?oooooool00?ooool02?ooool0
0ooo003oooooooooo`07ooooo`03ool00?ooooooo`0000;oo`001Oooool01?oo003ooooooooooooo
0002ooooo`03ool00?oooooooooo04_ooooo00?o0000ooooooooool07Oooool00ol0003oooooo`00
0003ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0B_ooool01_l00?ooo`00
ooooooooooooo`00o`00o`Gooooo00?o003ooooooooo00000_oo0006ooooo`04o`00oooo003ooooo
o`00o`Kooooo0ooo00000ooooooo003oooooo`05ooooo`05ool00?ooooooooooool00?l00?l0C?oo
ool00ol0003oooooooooo`0Dooooo`007Oooool00ol0003oooooooooo`02ooooo`;o00001?ooool0
0ol0003oooooooooo`1?ooooo`03o`00oooooooooooo00Cooooo00?o003oooooool00?l02Oooool0
0ol0003o003oooooo`06ooooo`04o`00ooooooooooooo`00o`Kooooo00?o003oooooooooool0Cooo
ool00ol0003oooooooooo`0Tooooo`;o0000BOooool01?oo003ooooooooooooo0002ooooo`03ool0
0?oooooooooo00?ooooo0ooo00000oooooooo`00ooooo`08ooooo`03ool00?oooooooooo00Oooooo
00?oo`00oooooooo00000_oo0005ooooo`04ool00?ooooooooooool000;ooooo00?oo`00oooooooo
ool0B_ooool2o`00023ooooo0_l00003ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooo
ooooool0Boooool01Ooo003ooooooooooooo003o003o00Gooooo00?o003ooooooooo00000_oo0006
ooooo`03o`00oooo003ooooo00Oooooo0ooo00000ooooooo003oooooo`04ooooo`06o`00oooo003o
oooooooooooo003o003oC?ooool00ol0003oooooooooo`0Dooooo`00:?ooool00ol0003ooooooooo
o`1;ooooo`03o`00oooooooooooo00Sooooo00?o003oooooool00?l01oooool01?l00?ooooooo`00
0?l00?l8ooooo`03o`00oooooooo003o00[ooooo00?o003oooooooooool0Boooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo04Sooooo00Coo`00ooooooooooooo`000_ooool00ooo003o
ooooooooo`07ooooo`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool01oooool00ooo003o
ooooooooo`07ooooo`04ool00?ooooooooooool000;ooooo00?oo`00ooooooooool0Boooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo00;ooooo0_l00005ooooo`03o`000?oooooooooo
04[ooooo00Go003oool00?ooooooooooool00008ooooo`?oo`001_ooool01?l00?ooo`00ooooool0
0?l6ooooo`?oo`001oooool01_l00?ooo`00ooooooooooooo`00o`00odcooooo00?o0000oooooooo
ool05?ooool002Sooooo0_l0001<ooooo`05o`00ooooooooooooooooool00?l01_ooool00ol00?oo
ooooooooo`07ooooo`03o`00oooooooo000000_ooooo00?o003oooooooooool02?ooool00ol00?oo
ooooooooo`1:ooooo`;o00009_ooool00ol0003oooooooooo`18ooooo`04ool00?ooooooooooool0
00;ooooo00?oo`00ooooooooool01oooool00ooo003oooooooooo`07ooooo`03ool00?oooooooooo
00Oooooo00?oo`00ooooooooool01oooool01?oo003ooooooooooooo0002ooooo`03ool00?oooooo
oooo04_ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`1:ooooo`06o`00oooo003o
oooooooooooo003o003o1Oooool01?l00?ooooooooooool00?l8ooooo`03ool00?oooooo003o00Oo
oooo00Co003ooooooooooooo003o1Oooool01Ol00?ooo`00ooooooooooooo`0004cooooo0_l0000F
ooooo`00:?ooool00ol0003oooooooooo`1;ooooo`05o`00ooooooooooooooooool00?l02?ooool0
0ol00?ooooooooooo`06ooooo`03o`00ool0003o003o00Sooooo00?o003oooooooooool01_ooool0
1Ol00?oooooooooooooooooo003o04gooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`18ooooo`04ool00?ooooooooooool000;ooooo00?oo`00ooooooooool01oooool00ooo003ooooo
ooooo`07ooooo`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool01oooool01?oo003ooooo
oooooooo0002ooooo`03ool00?oooooooooo04_ooooo00?o0000ooooooooool0:oooool00ol0003o
ooooooooo`1:ooooo`06o`00oooo003ooooooooooooo003o003o1Oooool01?l00?ooooooooooool0
0?l7ooooo`04o`00oooo003oooooo`00o`Oooooo00Co003ooooooooooooo003o1_ooool01Ooo003o
oooooooooooo003o003o04cooooo00?o0000ooooooooool05?ooool002Sooooo00?o0000oooooooo
ool0Coooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo003o00Wooooo00?o0000o`00oooo
ool01oooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooooooo04oooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`17ooooo`?oo`0000Goooooool00?ooooooooooool00009oooo
o`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool01oooool00ooo003oooooooooo`07oooo
o`05ool00?ooooooooooool00?ooool00ooo001<ooooo`03o`000?oooooooooo02_ooooo00?o0000
ooooooooool0Boooool01Ooo003ooooooooooooo003o003o00Gooooo00Co003ooooooooooooo003o
1oooool00ol00?ooo`00ooooo`08ooooo`03o`00oooooooo003o00Kooooo00Ko003oool00?oooooo
ooooool00?l00?m<ooooo`03o`000?oooooooooo01Cooooo000Xooooo`03o`000?oooooooooo04_o
oooo00?o003oooooooooool02?ooool00ol00?ooooooo`00o`08ooooo`03o`00ool0003o003o00So
oooo00?o003oooooool00?l01_ooool01Ol00?oooooooooooooooooo003o04gooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`17ooooo`?oo`0000Goooooool00?ooooooooooool00009
ooooo`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool01oooool00ooo003oooooooooo`07
ooooo`05ool00?ooooooooooool00?ooool00ooo001<ooooo`03o`000?oooooooooo02_ooooo00?o
0000ooooooooool0B_ooool01Ol00?ooo`00ooooooooooooo`00017ooooo00Co003oool00?oooooo
003o4?ooool01Ol00?ooo`00ooooooooooooo`0004gooooo00?o0000ooooooooool05?ooool002So
oooo00?o0000ooooooooool0Boooool01Ol00?oooooooooooooooooo003o00Kooooo00?o003ooooo
ooooool02?ooool00ol00?oo0000ooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003ooooo
ooooool0Boooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo04Oooooo0ooo00001Ooo
ooooo`00ooooooooooooo`0000Wooooo00?oo`00ooooooooool01oooool00ooo003oooooooooo`07
ooooo`03ool00?oooooooooo00Oooooo00Goo`00ooooooooooooo`00ooooo`03ool004cooooo00?o
0000ooooooooool0:oooool00ol0003oooooooooo`1:ooooo`05o`00oooo003ooooooooooooo0000
1_ooool2o`00o`03ooooool00?oooooo00Oooooo00?oo`00ooooool00?l01oooool00ol00?oooooo
o`00o`06ooooo`05o`00oooo003ooooooooooooo0000COooool00ol0003oooooooooo`0Dooooo`00
:?ooool2o`0004cooooo00Go003oooooooooooooooooo`00o`08ooooo`03o`00oooooooooooo00Ko
oooo00?o003oo`000?l00?l02?ooool00ol00?ooooooooooo`06ooooo`05o`00oooooooooooooooo
ool00?l0C?ooool2o`0002Kooooo0_l0001<ooooo`04ool00?ooooooooooool000Wooooo00?oo`00
ooooooooool01oooool00ooo003oooooooooo`07ooooo`03ool00?oooooooooo00Oooooo00Coo`00
ooooooooooooo`00Coooool2o`0002gooooo00?o0000ooooooooool0B_ooool01Ol00?ooo`00oooo
ooooooooo`0000Kooooo00Co003ooooooooooooo003o1oooool01?l00?ooo`00ooooool00?l7oooo
o`03o`00oooooooo003o00Oooooo00Coo`00ooooooooooooo`00C?ooool2o`0001Kooooo000Xoooo
o`03o`000?oooooooooo04oooooo00?o003oooooooooool01?ooool00ol00?ooooooo`00o`09oooo
o`03o`000?l00?oooooo00Oooooo00?o003oooooool00?l01_ooool00ol00?ooooooooooo`1?oooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0Boooool01?oo003ooooooooooooo0009
ooooo`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool01oooool00ooo003oooooooooo`07
ooooo`04ool00?ooooooooooool0053ooooo00?o0000ooooooooool0:oooool00ol0003ooooooooo
o`1;ooooo`04ool00?ooooooooooool000Kooooo00?o003oooooool00?l02?ooool00ol00?ooo`00
ooooo`08ooooo`03o`00oooooooo003o00Kooooo00Go003oool00?ooooooooooool0001=ooooo`03
o`000?oooooooooo01Cooooo000Xooooo`03o`000?oooooooooo04_ooooo00?o003oooooooooool0
2?ooool00ol00?ooooooo`00o`08ooooo`03o`00ool0003o003o00Sooooo00?o003oooooool00?l0
1_ooool01Ol00?oooooooooooooooooo003o04gooooo00?o0000ooooooooool09?ooool00ol0003o
ooooooooo`1;ooooo`04ool00?ooooooooooool000Wooooo00?oo`00ooooooooool01oooool00ooo
003oooooooooo`07ooooo`03ool00?oooooooooo00Oooooo00Coo`00ooooooooooooo`00D?ooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo04[ooooo00Go003oool00?ooooooooooool0
000Aooooo`03o`00oooo003o003o017ooooo00Go003oool00?ooooooooooool0001=ooooo`03o`00
0?oooooooooo01Cooooo000Xooooo`03o`000?oooooooooo04_ooooo00Go003ooooooooooooooooo
o`00o`06ooooo`03o`00oooooooooooo00Sooooo00?o003oo`000?ooool02_ooool00ol00?oooooo
ooooo`08ooooo`03o`00oooooooooooo04_ooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`1;ooooo`04ool00?ooooooooooool000Wooooo00?oo`00ooooooooool01oooool00ooo003o
ooooooooo`07ooooo`03ool00?oooooooooo00Oooooo00Coo`00ooooooooooooo`00D?ooool00ol0
003oooooooooo`0[ooooo`03o`000?oooooooooo04[ooooo00Go003oool00?ooooooooooool00007
ooooo`;o003o2Oooool00ooo003o003oooooo`07ooooo`03o`00oooooooo003o00Kooooo00Go003o
ool00?ooooooooooool0001=ooooo`03o`000?oooooooooo01Cooooo000Xooooo`;o0000C?ooool0
1Ol00?oooooooooooooooooo003o00Sooooo00?o003oooooooooool01_ooool00ol00?oo0000o`00
o`08ooooo`03o`00oooooooooooo00Kooooo00Go003oooooooooooooooooo`00o`1<ooooo`;o0000
6_ooool3o`0000?ooooo0_l00004ooooo`03o`000?oooooooooo04_ooooo00Coo`00oooooooooooo
o`002Oooool00ooo003oooooooooo`07ooooo`03ool00?oooooooooo00Oooooo00?oo`00oooooooo
ool01oooool01?oo003ooooooooooooo001@ooooo`03o`000?oooooooooo02_ooooo00?o0000oooo
ooooool0B_ooool01Ol00?ooo`00ooooooooooooo`0000Oooooo0_l00?l8ooooo`03o`00oooo003o
003o00Sooooo00?o003oooooool00?l01oooool01?oo003ooooooooooooo001=ooooo`03o`000?oo
oooooooo01Cooooo000Xooooo`03o`000?oooooooooo04oooooo00?o003oooooooooool01?ooool0
0ol00?ooooooo`00o`09ooooo`03o`000?l00?oooooo00Oooooo00?o003oooooool00?l01_ooool0
0ol00?ooooooooooo`1?ooooo`03o`000?oooooooooo01Wooooo00Go0000ooooooooooooooooo`00
0002ooooo`05o`000?ooooooooooooooool00000COooool01?oo003ooooooooooooo0009ooooo`03
ool00?oooooooooo00Oooooo00?oo`00ooooooooool01oooool00ooo003oooooooooo`07ooooo`04
ool00?ooooooooooool0053ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`1;oooo
o`04ool00?ooooooooooool000Oooooo0_l00?l8ooooo`03o`00oooo003ooooo00Wooooo0_l00?l6
ooooo`05o`00oooo003ooooooooooooo0000C?ooool2o`0001Kooooo000Xooooo`03o`000?oooooo
oooo04_ooooo00?o003oooooooooool02?ooool00ol00?ooooooo`00o`08ooooo`03o`00ool0003o
003o00Sooooo0_l00?l7ooooo`05o`00ooooooooooooooooool00?l0COooool00ol0003ooooooooo
o`0Fooooo`Go00000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo04_ooooo
00Coo`00ooooooooooooo`002Oooool00ooo003oooooooooo`07ooooo`03ool00?oooooooooo00Oo
oooo00?oo`00ooooooooool01oooool01?oo003ooooooooooooo001@ooooo`03o`000?oooooooooo
02_ooooo00?o0000ooooooooool0B_ooool01Ol00?ooo`00ooooooooooooo`0001;ooooo00?oo`00
o`00ooooool04?ooool01Ol00?ooo`00ooooooooooooo`0004gooooo00?o0000ooooooooool05?oo
ool001_ooooo0ol00004ooooo`;o00001?ooool00ol0003oooooooooo`1;ooooo`05o`00oooooooo
ooooooooool00?l01_ooool00ol00?ooooooooooo`08ooooo`03o`00ool0003ooooo00Wooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`1;ooooo`03o`000?oooooooooo01Kooooo00Co
0000oooooooooooo00000oooool01?l0003oooooooooool00003ooooo`?o0000Boooool01?oo003o
oooooooooooo0009ooooo`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool01oooool00ooo
003oooooooooo`07ooooo`04ool00?ooooooooooool004oooooo0_l0000Oooooo`?o00001?ooool2
o`0000Gooooo00?o0000ooooooooool0B_ooool01Ol00?ooo`00ooooooooooooo`0000Oooooo0_l0
0?l9ooooo`03ool00?l00?oooooo00Sooooo0_l00?l6ooooo`05o`00oooo003ooooooooooooo0000
COooool00ol0003oooooooooo`0Dooooo`006_ooool01Ol0003ooooooooooooooooo000000;ooooo
00Co0000oooooooooooo00000oooool00ol0003oooooooooo`1;ooooo`05o`00oooooooooooooooo
ool00?l01oooool00ol00?ooooooooooo`07ooooo`03o`00ool0003o003o00Sooooo00?o003ooooo
ooooool01_ooool01Ol00?oooooooooooooooooo003o04gooooo00?o0000ooooooooool05oooool0
0ol0003oooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0Booo
ool01?oo003ooooooooooooo0009ooooo`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool0
1oooool00ooo003oooooooooo`07ooooo`04ool00?ooooooooooool0053ooooo00?o0000oooooooo
ool07?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00001?ooool0
0ol0003oooooooooo`1:ooooo`05o`00oooo003ooooooooooooo00001oooool2o`00o`Wooooo00?o
o`00o`00ooooool02?ooool2o`00o`Oooooo00Coo`00ooooooooooooo`00COooool00ol0003ooooo
ooooo`0Dooooo`006_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo
00000oooool2o`00053ooooo00?o003oooooooooool01?ooool2o`00o`[ooooo00?o0000o`00oooo
ool01oooool2o`00o`Oooooo00?o003oooooooooool0COooool3o`0001[ooooo0_l00003ooooo`04
o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0Boooool01?oo003ooooooooooooo0009
ooooo`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool01oooool00ooo003oooooooooo`07
ooooo`04ool00?ooooooooooool0053ooooo00?o0000ooooooooool07?ooool01Ol0003ooooooooo
oooooooo000000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1;ooooo`04
ool00?ooooooooooool000Oooooo0_l00?l9ooooo`03ool00?oooooooooo00Sooooo0_l00?l6oooo
o`05o`00oooo003ooooooooooooo0000COooool00ol0003oooooooooo`0Dooooo`006_ooool4o`00
00?ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`1;ooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool01oooool3o`00o`Sooooo0_l00?l7ooooo`05o`00oooooooo
ooooooooool00?l0COooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00;ooooo0_l0
0004ooooo`03o`000?oooooooooo04_ooooo00Coo`00ooooooooooooo`002?ooool3ool000Sooooo
00?oo`00ooooooooool01_ooool3ool000Sooooo00Coo`00ooooooooooooo`00D?ooool00ol0003o
ooooooooo`0Looooo`Co00000oooool01?l0003oooooooooool00004ooooo`;o0000Boooool01Ol0
0?ooo`00ooooooooooooo`0001;ooooo00?oo`00o`00ooooool04?ooool01Ol00?ooo`00oooooooo
ooooo`0004cooooo0_l0000Fooooo`006_ooool00ol0003oooooooooo`04ooooo`04o`000?oooooo
ooooo`0000?ooooo00?o0000ooooooooool0Boooool01Ol00?oooooooooooooooooo003o00Oooooo
00?o003oooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool0Boooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo04_ooooo
00Coo`00ooooooooooooo`002?ooool3ool000Sooooo00?oo`00ooooooooool01_ooool3ool000So
oooo00Coo`00ooooooooooooo`00D?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
00Cooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1:ooooo`05o`00oooo003o
oooooooooooo00001oooool2o`00o`Wooooo00?oo`00o`00ooooool02?ooool2o`00o`Oooooo00Co
o`00ooooooooooooo`00COooool00ol0003oooooooooo`0Dooooo`006oooool00ol0003ooooooooo
o`03ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0Boooool01Ol00?oooooo
oooooooooooo003o017ooooo0_l00?lBooooo`05o`00ooooooooooooooooool00?l0COooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo04_ooooo00Coo`00ooooooooooooo`002?ooool3
ool000Sooooo00?oo`00ooooooooool01_ooool3ool000Sooooo00Coo`00ooooooooooooo`00D?oo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`1;ooooo`04ool00?ooooooooooool000Oooooo0_l00?l9ooooo`03
ool00?l00?oooooo00Sooooo00?o003oooooooooool01_ooool01?oo003ooooooooooooo001=oooo
o`03o`000?oooooooooo01Cooooo000Looooo`;o00001?ooool2o`0000Cooooo00?o0000oooooooo
ool0Coooool00ol00?ooooooooooo`0?ooooo`;o003o4_ooool00ol00?ooooooooooo`1?ooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool0Boooool01?oo003ooooooooooooo000Coooo
o`03ool00?oooooooooo017ooooo00Coo`00ooooooooooooo`00D?ooool00ol0003oooooooooo`0N
ooooo`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool0Boooool00ooo003oooooool00002
ool0017ooooo00?oo`00ooooooooool04?ooool3ool00003oooooooo003ooooo04cooooo00?o0000
ooooooooool05?ooool002Sooooo0_l0001<ooooo`03o`00oooooooooooo01Cooooo00?o003ooooo
ooooool04?ooool01Ol00?oooooooooooooooooo003o04cooooo0_l0000Vooooo`;o0000C?ooool0
1?oo003ooooooooooooo000Cooooo`03ool00?oooooooooo017ooooo00Coo`00ooooooooooooo`00
Coooool2o`0002gooooo00?o0000ooooooooool0Boooool00ooo003oooooool00002ool0017ooooo
00?oo`00o`00ooooool04?ooool3ool00003oooooooo003ooooo04cooooo00?o0000ooooooooool0
5?ooool002Sooooo00?o0000ooooooooool0Boooool01Ol00?oooooooooooooooooo003o01;ooooo
00?o0000ooooooooool05?ooool00ol00?ooooooooooo`1;ooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool0Boooool01?oo003ooooooooooooo000Cooooo`03ool00?oooooooooo017o
oooo00Coo`00ooooooooooooo`00D?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
04_ooooo00?oo`00oooooooo00000_oo000@ooooo`?oo`004Oooool3ool00003oooooooo003ooooo
04_ooooo0_l0000Fooooo`00:?ooool00ol0003oooooooooo`1;ooooo`05o`00oooooooooooooooo
ool00?l04_ooool00ol0003oooooooooo`0@ooooo`05o`00ooooooooooooooooool00?l0COooool0
0ol0003oooooooooo`0Tooooo`03o`000?oooooooooo04_ooooo00Coo`00ooooooooooooo`004ooo
ool00ooo003oooooooooo`0Aooooo`04ool00?ooooooooooool0053ooooo00?o0000ooooooooool0
:oooool00ol0003oooooooooo`1;ooooo`04ool00?ooooooooooo`00oa7ooooo0ooo000Eooooo`03
ool00?oooooooooo04_ooooo00?o0000ooooooooool05?ooool002Sooooo00?o0000ooooooooool0
Coooool00ol00?ooooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o003oooooooooool0
Coooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo04_ooooo00Coo`00oooooooooooo
o`004oooool00ooo003oooooooooo`0Aooooo`04ool00?ooooooooooool0053ooooo00?o0000oooo
ooooool0:oooool00ol0003oooooooooo`1;ooooo`04ool00?ooooooooooo`00oa7ooooo0ooo000B
ooooo`04o`00ooooooooooooool004gooooo00?o0000ooooooooool05?ooool002Sooooo00?o0000
ooooooooool0Boooool00ol00?ooooooooooo`0Dooooo`03o`000?oooooooooo013ooooo00Go003o
ooooooooooooooooo`00o`1=ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0Booo
ool01?oo003ooooooooooooo000Cooooo`03ool00?oooooooooo017ooooo00Coo`00oooooooooooo
o`00D?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo04_ooooo00?oo`00oooooooo
ool04oooool00ol0003oooooooooo`0Aooooo`04o`00ooooooooooooool004gooooo00?o0000oooo
ooooool05?ooool002Sooooo0_l0001<ooooo`05o`00ooooooooooooooooool00?l04_ooool00ol0
003oooooooooo`0Dooooo`03o`00oooooooooooo04[ooooo0_l0000Vooooo`03o`000?oooooooooo
04_ooooo00Coo`00ooooooooooooo`004oooool00ooo003oooooooooo`0Aooooo`04ool00?oooooo
ooooool0053ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`1;ooooo`04ool00?oo
ooooooooo`00oa;ooooo00?o0000ooooooooool04Oooool01?l00?oooooooooooooo001<ooooo`;o
00005_ooool002Sooooo00?o0000ooooooooool0Boooool00ol00?ooooooooooo`02o`00oa;ooooo
00?o0000ooooooooool04?ooool01Ol00?oooooooooooooooooo003o04gooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`1;ooooo`04ool00?ooooooooooool001?ooooo00?oo`00oooo
ooooool04Oooool01?oo003ooooooooooooo001@ooooo`03o`000?oooooooooo02_ooooo00?o0000
ooooooooool0Boooool01?oo003oooooooooool00?lBooooo`03o`000?oooooooooo01Cooooo00?o
o`00ooooooooool0Boooool00ol0003oooooooooo`0Dooooo`00:?ooool00ol0003oooooooooo`1>
ooooo`03o`00oooooooooooo017ooooo00?o0000ooooooooool04?ooool00ol00?ooooooooooo`1?
ooooo`03o`000?oooooooooo02Cooooo0_l0001<ooooo`04ool00?ooooooooooool001?ooooo00?o
o`00ooooooooool04Oooool01?oo003ooooooooooooo001?ooooo`;o0000;Oooool00ol0003ooooo
ooooo`1;ooooo`04ool00?ooooooooooo`00oa;ooooo00?o0000ooooooooool04Oooool01?l00?oo
oooooooooooo001=ooooo`03o`000?oooooooooo01Cooooo000Xooooo`03o`000?oooooooooo04_o
oooo00Co003ooooooooooooo003o4oooool00ol0003oooooooooo`0@ooooo`05o`00oooooooooooo
ooooool00?l0COooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo04_ooooo00Coo`00
ooooooooooooo`004oooool00ooo003oooooooooo`0Aooooo`04ool00?ooooooooooool0053ooooo
00?o0000ooooooooool0:oooool00ol0003oooooooooo`1;ooooo`03ool00?oooooooooo01?ooooo
00?o0000ooooooooool04Oooool01?l00?oooooooooooooo001=ooooo`03o`000?oooooooooo01Co
oooo000Xooooo`03o`000?oooooooooo04_ooooo00?o003oooooooooool05?ooool00ol0003ooooo
ooooo`0Dooooo`03o`00oooooooooooo04_ooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`1;ooooo`04ool00?ooooooooooool001?ooooo00?oo`00ooooooooool04Oooool01?oo003o
oooooooooooo001@ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0Boooool01?oo
003oooooooooool00?lBooooo`03o`000?oooooooooo017ooooo00Co003oooooooooooooo`00COoo
ool00ol0003oooooooooo`0Dooooo`00:?ooool2o`0004cooooo00Co003ooooooooooooo003o4ooo
ool00ol0003oooooooooo`0@ooooo`04o`00ooooooooooooo`00odgooooo0_l0000Vooooo`03o`00
0?oooooooooo04_ooooo00Coo`00ooooooooooooo`004oooool00ooo003oooooooooo`0Aooooo`04
ool00?ooooooooooool0053ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`1;oooo
o`04ool00?ooooooooooo`00oa;ooooo00?o0000ooooooooool05?ooool00ooo003oooooooooo`1:
ooooo`;o00005_ooool002Sooooo00?o0000ooooooooool0C_ooool00ol00?ooooooooooo`0Aoooo
o`03o`000?oooooooooo013ooooo00?o003oooooooooool0Coooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo04_ooooo00Coo`00ooooooooooooo`004oooool00ooo003oooooooooo`0A
ooooo`04ool00?ooooooooooool0053ooooo00?o0000ooooooooool0:oooool00ol0003ooooooooo
o`1;ooooo`04ool00?ooooooooooo`00oa;ooooo00?o0000ooooooooool04Oooool01?l00?oooooo
oooooooo001=ooooo`03o`000?oooooooooo01Cooooo000Kooooo`?o00001?ooool2o`0000Cooooo
00?o0000ooooooooool0Boooool01?l00?ooooooooooool00?lCooooo`03o`000?oooooooooo013o
oooo00Co003ooooooooooooo003oC_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
04_ooooo00Coo`00ooooooooooooo`004oooool00ooo003oooooooooo`0Aooooo`04ool00?oooooo
ooooool0053ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`1;ooooo`03ool00?oo
oooooooo01?ooooo00?o0000ooooooooool04Oooool01?l00?oooooooooooooo001=ooooo`03o`00
0?oooooooooo01Cooooo000Jooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooo
ooooool00003ooooo`03o`000?oooooooooo04_ooooo00?o003oooooooooool05?ooool00ol0003o
ooooooooo`0Cooooo`03o`00oooooooooooo04cooooo00?o0000ooooooooool09?ooool00ol0003o
ooooooooo`1;ooooo`04ool00?ooooooooooool001?ooooo00?oo`00ooooooooool04Oooool01?oo
003ooooooooooooo001@ooooo`03o`000?oooooooooo01gooooo0ol00004ooooo`;o00001Oooool0
0ol0003oooooooooo`1;ooooo`04ool00?ooooooooooo`00oa;ooooo00?o0000ooooooooool04Ooo
ool01?l00?oooooooooooooo001=ooooo`03o`000?oooooooooo01Cooooo000Jooooo`05o`000?oo
ooooooooooooool000000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo04_o
oooo00Co003ooooooooooooo003o4oooool00ol0003oooooooooo`0@ooooo`04o`00oooooooooooo
o`00odkooooo00?o0000ooooooooool09?ooool2o`0004cooooo00Coo`00ooooooooooooo`004ooo
ool00ooo003oooooooooo`0Aooooo`04ool00?ooooooooooool004oooooo0_l0000Nooooo`05o`00
0?ooooooooooooooool000000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo
04_ooooo00Coo`00oooooooooooo003o4_ooool00ol0003oooooooooo`0Dooooo`03ool00?oooooo
oooo04_ooooo00?o0000ooooooooool05?ooool001_ooooo0ol00003ooooo`04o`000?oooooooooo
o`0000?ooooo0_l0001?ooooo`03o`00oooooooooooo017ooooo00?o0000ooooooooool04?ooool0
0ol00?ooooooooooo`1=ooooo`?o00009_ooool00ol0003oooooooooo`1;ooooo`04ool00?oooooo
ooooool001?ooooo00?oo`00ooooooooool04Oooool01?oo003ooooooooooooo001@ooooo`03o`00
0?oooooooooo01cooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`00
00Cooooo0_l0001<ooooo`04ool00?ooooooooooo`00oa;ooooo00?o0000ooooooooool04Oooool0
1?l00?oooooooooooooo001<ooooo`;o00005_ooool001[ooooo00Go0000ooooooooooooooooo`00
0002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0Boooool01?l00?oooooo
ooooool00?lCooooo`03o`000?oooooooooo013ooooo00Co003ooooooooooooo003oC_ooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo04_ooooo00Coo`00ooooooooooooo`004oooool0
0ooo003oooooooooo`0Aooooo`04ool00?ooooooooooool0053ooooo00?o0000ooooooooool07Ooo
ool3o`0000?ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1;ooooo`03ool0
0?oooooooooo01?ooooo00?o0000ooooooooool04Oooool01?l00?oooooooooooooo001=ooooo`03
o`000?oooooooooo01Cooooo000Jooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00003ooooo`03o`000?oooooooooo04_ooooo00?o003oooooooooool05?ooool00ol0
003oooooooooo`0Cooooo`03o`00oooooooooooo04cooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`1;ooooo`04ool00?ooooooooooool001?ooooo00?oo`00ooooooooool04Oooool0
1?oo003ooooooooooooo001@ooooo`03o`000?oooooooooo01cooooo00Go0000oooooooooooooooo
o`000002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0Boooool01?oo003o
ooooooooool00?lBooooo`03o`000?oooooooooo017ooooo00Co003oooooooooooooo`00COooool0
0ol0003oooooooooo`0Dooooo`006oooool3o`0000Cooooo0_l00004ooooo`03o`000?oooooooooo
04_ooooo00Co003ooooooooooooo003o4oooool00ol0003oooooooooo`0@ooooo`04o`00oooooooo
ooooo`00odkooooo00?o0000ooooooooool05oooool3o`0000Cooooo0_l00004ooooo`03o`000?oo
oooooooo04_ooooo00Coo`00ooooooooooooo`004oooool00ooo003oooooooooo`0Aooooo`04ool0
0?ooooooooooool0053ooooo00?o0000ooooooooool07?ooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1;ooooo`04ool00?oooooo
ooooo`00oa;ooooo00?o0000ooooooooool05?ooool00ooo003oooooooooo`1;ooooo`03o`000?oo
oooooooo01Cooooo000Xooooo`03o`000?oooooooooo04kooooo00?o003oooooooooool04Oooool0
0ol0003oooooooooo`0@ooooo`03o`00oooooooooooo04oooooo00?o0000ooooooooool05_ooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000oooool00ol0003ooooo
ooooo`1;ooooo`04ool00?ooooooooooool001?ooooo00?oo`00ooooooooool04Oooool01?oo003o
oooooooooooo001@ooooo`03o`000?oooooooooo01gooooo0ol00004ooooo`;o00001Oooool00ol0
003oooooooooo`1;ooooo`04ool00?ooooooooooo`00oa;ooooo00?o0000ooooooooool04Oooool0
1?l00?oooooooooooooo001=ooooo`03o`000?oooooooooo01Cooooo000Xooooo`;o0000C?ooool0
1?l00?ooooooooooool00?lCooooo`03o`000?oooooooooo013ooooo00Co003ooooooooooooo003o
COooool2o`0001Sooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`00
00?ooooo00?o0000ooooooooool0Boooool01?oo003ooooooooooooo000Cooooo`03ool00?oooooo
oooo017ooooo00Coo`00ooooooooooooo`00D?ooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo04[ooooo0ooo000Dooooo`03o`000?oooooooooo017ooooo00?o003ooooooooo00000_oo
001;ooooo`;o00005_ooool002Sooooo00?o0000ooooooooool0Boooool00ol00?ooooooooooo`0D
ooooo`03o`000?oooooooooo01?ooooo00?o003oooooooooool0C?ooool00ol0003oooooooooo`0F
ooooo`Co00000oooool01?l0003oooooooooool00003ooooo`?o0000Boooool01?oo003ooooooooo
oooo000Cooooo`03ool00?oooooooooo017ooooo00Coo`00ooooooooooooo`00Coooool2o`0002go
oooo00?o0000ooooooooool0B_ooool3ool00003ooooool00?oooooo017ooooo00?o0000oooooooo
ool04Oooool00ol00?ooooooool00002ool004cooooo00?o0000ooooooooool05?ooool002Sooooo
00?o0000ooooooooool0Boooool01?l00?ooooooooooool00?lCooooo`03o`000?oooooooooo017o
oooo00?o003oooooool00?l0C_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Co
oooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`1;ooooo`04ool00?oooooooooo
ool001?ooooo00?oo`00ooooooooool04Oooool01?oo003ooooooooooooo001@ooooo`03o`000?oo
oooooooo02_ooooo00?o0000ooooooooool0B_ooool3ool00003ooooool00?oooooo017ooooo00?o
0000ooooooooool04oooool3ool004cooooo00?o0000ooooooooool05?ooool002Sooooo00?o0000
ooooooooool0C_ooool00ol00?ooooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o003o
ooooooooool0C_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00?ooooo00Co0000
oooooooooooo00000oooool00ol0003oooooooooo`1;ooooo`04ool00?ooooooooooool001?ooooo
00?oo`00ooooooooool04Oooool01?oo003ooooooooooooo001@ooooo`03o`000?oooooooooo02_o
oooo00?o0000ooooooooool0C_ooool00ol00?ooooooooooo`0@ooooo`03o`000?oooooooooo017o
oooo00Co003ooooooooooooo003oCOooool00ol0003oooooooooo`0Dooooo`00:?ooool00ol0003o
ooooooooo`1<ooooo`03o`00oooooooo003o01?ooooo00?o0000ooooooooool04Oooool00ol00?oo
ooooo`00o`1>ooooo`03o`000?oooooooooo01Sooooo0_l00004ooooo`;o00001?ooool00ol0003o
ooooooooo`1;ooooo`04ool00?ooooooooooool001?ooooo00?oo`00ooooooooool04Oooool01?oo
003ooooooooooooo001@ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0Boooool0
1?l00?ooooooooooool00?lBooooo`03o`000?oooooooooo017ooooo00Co003ooooooooooooo003o
COooool00ol0003oooooooooo`0Dooooo`00:?ooool2o`0004gooooo00?o003oooooooooool04ooo
ool00ol0003oooooooooo`0Cooooo`03o`00oooooooooooo04_ooooo0_l0000Vooooo`03o`000?oo
oooooooo04_ooooo00Coo`00ooooooooooooo`004oooool00ooo003oooooooooo`0Aooooo`04ool0
0?ooooooooooool0053ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`1;ooooo`03
o`00oooooooooooo01?ooooo00?o0000ooooooooool04Oooool01?l00?ooooooooooool00?m<oooo
o`;o00005_ooool002Sooooo00?o0000ooooooooool0C?ooool00ol00?ooooooo`00o`0Cooooo`03
o`000?oooooooooo017ooooo00?o003oooooool00?l0C_ooool00ol0003oooooooooo`0Tooooo`03
o`000?oooooooooo04_ooooo00?oo`00oooooooo00000_oo000Booooo`03ool00?oooooooooo013o
oooo0ooo00000oooooooo`00ooooo`1?ooooo`03o`000?oooooooooo02_ooooo00?o0000oooooooo
ool0Boooool01?l00?ooooooooooool00?lBooooo`03o`000?oooooooooo06;ooooo00?o0000oooo
ooooool05?ooool002Sooooo00?o0000ooooooooool0C_ooool00ol00?ooooooooooo`0Aooooo`03
o`000?oooooooooo017ooooo00?o003oooooooooool0C_ooool00ol0003oooooooooo`0Tooooo`03
o`000?oooooooooo04_ooooo00?oo`00oooooooo00000_oo000Booooo`03ool00?oooooooooo013o
oooo0ooo00000oooooooo`00ooooo`1?ooooo`03o`000?oooooooooo02_ooooo00?o0000oooooooo
ool0C_ooool00ol00?ooooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00Co003ooooooooo
oooo003oCOooool00ol0003oooooooooo`0Dooooo`00:?ooool00ol0003oooooooooo`1<ooooo`03
o`00oooooooo003o01?ooooo00?o0000ooooooooool04Oooool00ol00?ooooooo`00o`1>ooooo`03
o`000?oooooooooo02Cooooo0_l0001<ooooo`03ool00?ooooooo`0000;oo`004Oooool3ool0017o
oooo0ooo00000oooooooo`00ooooo`1>ooooo`;o0000;Oooool00ol0003oooooooooo`1>ooooo`03
o`00oooooooooooo013ooooo00?o0000ooooooooool04Oooool01?l00?ooooooooooool00?m=oooo
o`03o`000?oooooooooo01Cooooo000Xooooo`;o0000COooool00ol00?ooooooooooo`0Cooooo`03
o`000?oooooooooo01?ooooo00?o003oooooooooool0Boooool2o`0002Kooooo00?o0000oooooooo
ool0Boooool00ooo003oooooooooo`0Cooooo`?oo`005Oooool00ooo003oooooooooo`1>ooooo`03
o`000?oooooooooo02_ooooo00?o0000ooooooooool0Boooool00ol00?ooooooooooo`0Cooooo`03
o`000?oooooooooo017ooooo00Co003ooooooooooooo003oCOooool00ol0003oooooooooo`0Doooo
o`00:?ooool00ol0003oooooooooo`1<ooooo`03o`00oooooooo003o01?ooooo00?o0000oooooooo
ool04Oooool00ol00?ooooooo`00o`1>ooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool0Boooool00ooo003oooooooooo`0Cooooo`?oo`005Oooool00ooo003oooooooooo`1>ooooo`03
o`000?oooooooooo02_ooooo00?o0000ooooooooool0Boooool01?l00?ooooooooooool00?lBoooo
o`03o`000?oooooooooo067ooooo0_l0000Fooooo`00:?ooool00ol0003oooooooooo`1>ooooo`03
o`00oooooooooooo017ooooo00?o0000ooooooooool04Oooool00ol00?ooooooooooo`1>ooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool0Boooool00ooo003oooooooooo`0[ooooo`03
ool00?oooooooooo04kooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`1;ooooo`04
o`00ooooooooooooo`00oa;ooooo00?o0000ooooooooool04Oooool01?l00?ooooooooooool00?m=
ooooo`03o`000?oooooooooo01Cooooo000Eooooo`?o00001?ooool2o`0000Cooooo0_l00004oooo
o`03o`000?oooooooooo04cooooo00?o003oooooool00?l04oooool00ol0003oooooooooo`0Aoooo
o`03o`00oooooooo003o04kooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1;oooo
o`03ool00?oooooooooo02_ooooo00?oo`00ooooooooool0C_ooool00ol0003oooooooooo`0Goooo
o`?o00001?ooool2o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo04gooooo00?o003ooooo
ooooool04Oooool00ol0003oooooooooo`0Aooooo`04o`00ooooooooooooo`00odgooooo00?o0000
ooooooooool05?ooool001Kooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0C?ooool00ol00?oooooooooo
o`0Cooooo`03o`000?oooooooooo01?ooooo00?o003oooooooooool0C?ooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo04_ooooo00?oo`00ooooooooool0:oooool00ooo003ooooooooo
o`1>ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0Boooool00ol00?oo
ooooooooo`0Cooooo`03o`000?oooooooooo017ooooo00?o003oooooool00?l0C_ooool00ol0003o
ooooooooo`0Dooooo`005_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00000oooool2o`0004gooooo00?o003oooooool00?l04oooool00ol0
003oooooooooo`0Aooooo`03o`00oooooooo003o04cooooo0ol0000Vooooo`03o`000?oooooooooo
04_ooooo00?oo`00ooooooooool0:oooool00ooo003oooooooooo`1>ooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool0Boooool00ol00?ooooooo`00o`0Cooooo`03o`000?oo
oooooooo06;ooooo00?o0000ooooooooool05?ooool001Kooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0
C_ooool00ol00?ooooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o003oooooooooool0
C_ooool00ol0003oooooooooo`0Tooooo`;o0000C?ooool00ooo003oooooooooo`0[ooooo`03ool0
0?oooooooooo04gooooo0_l0000Jooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00004ooooo`;o0000C?ooool00ol00?ooooooo`00o`0Coooo
o`03o`000?oooooooooo017ooooo00?o003oooooool00?l0COooool2o`0001Kooooo000Fooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00003
ooooo`03o`000?oooooooooo04cooooo00?o003oooooool00?l04oooool00ol0003oooooooooo`0A
ooooo`03o`00oooooooo003o04kooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1;
ooooo`03ool00?oooooooooo02_ooooo00?oo`00ooooooooool0C_ooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo04gooooo00?o003oooooooooool04Oooool00ol0003ooooo
ooooo`0Aooooo`03o`00oooooooo003o04kooooo00?o0000ooooooooool05?ooool001Gooooo0_l0
0004ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003o
ooooooooo`1<ooooo`03o`00oooooooooooo01?ooooo00?o0000ooooooooool04oooool00ol00?oo
ooooooooo`1<ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0Boooool00ooo003o
ooooooooo`0[ooooo`03ool00?oooooooooo04kooooo00?o0000ooooooooool05oooool2o`0000Co
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooo
oooo04_ooooo00?o003oooooooooool04oooool00ol0003oooooooooo`0Aooooo`03o`00oooooooo
003o04kooooo00?o0000ooooooooool05?ooool001Kooooo00?o0000ooooooooool00oooool2o`00
00Cooooo0_l00004ooooo`03o`000?oooooooooo04cooooo00?o003oooooool00?l04oooool00ol0
003oooooooooo`0Aooooo`03o`00oooooooo003o04kooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`1;ooooo`03ool00?oooooooooo02_ooooo00?oo`00ooooooooool0C_ooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`;o00001Oooool00ol0
003oooooooooo`1;ooooo`03o`00oooooooo003o01?ooooo00?o0000ooooooooool0H_ooool00ol0
003oooooooooo`0Dooooo`00:?ooool2o`0004oooooo00?o003oooooooooool04Oooool00ol0003o
ooooooooo`0Aooooo`03o`00oooooooooooo04gooooo0_l0000Vooooo`03o`000?oooooooooo04_o
oooo00?oo`00ooooooooool0:oooool00ooo003oooooooooo`1>ooooo`03o`000?oooooooooo02_o
oooo00?o0000ooooooooool0Boooool00ol00?ooooooo`00o`0Cooooo`03o`000?oooooooooo01;o
oooo0_l00?m=ooooo`;o00005_ooool002Sooooo00?o0000ooooooooool0C?ooool00ol00?oooooo
o`00o`0Cooooo`03o`000?oooooooooo017ooooo00?o003oooooool00?l0C_ooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo04_ooooo00?oo`00ooooooooool0:oooool00ooo003ooooo
ooooo`1>ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0COooool00ol00?oooooo
ooooo`0Aooooo`03o`000?oooooooooo01;ooooo0_l00?m>ooooo`03o`000?oooooooooo01Cooooo
000Xooooo`03o`000?oooooooooo04cooooo00?o003oooooooooool04oooool00ol0003ooooooooo
o`0Cooooo`03o`00oooooooooooo04cooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`1;ooooo`03ool00?oooooooooo02_ooooo00?oo`00ooooooooool0C_ooool00ol0003ooooooooo
o`0[ooooo`03o`000?oooooooooo04_ooooo00?o003oooooooooool04oooool00ol0003ooooooooo
o`0Booooo`;o003oC_ooool00ol0003oooooooooo`0Dooooo`00:?ooool00ol0003oooooooooo`1<
ooooo`03o`00oooooooo003o01?ooooo00?o0000ooooooooool04Oooool00ol00?ooooooo`00o`1>
ooooo`03o`000?oooooooooo02Cooooo0_l0001<ooooo`03ool00?oooooooooo02_ooooo00?oo`00
ooooooooool0COooool2o`0002gooooo00?o0000ooooooooool0Boooool00ol00?ooooooo`00o`0C
ooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool05?ooool002Sooooo00?o0000oooo
ooooool0C_ooool00ol00?ooooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o003ooooo
ooooool0C_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo04_ooooo00?oo`00oooo
ooooool0:oooool00ooo003oooooooooo`1>ooooo`03o`000?oooooooooo02_ooooo00?o0000oooo
ooooool0C?ooool2o`00oa?ooooo00?o0000ooooooooool04_ooool2o`00odkooooo00?o0000oooo
ooooool05?ooool002Sooooo0_l0001=ooooo`03o`00oooooooo003o01?ooooo00?o0000oooooooo
ool04Oooool00ol00?ooooooo`00o`1=ooooo`;o00009_ooool00ol0003oooooooooo`1;ooooo`03
ool00?oooooooooo02_ooooo00?oo`00ooooooooool0C_ooool00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo04gooooo00?o003oooooooooool04Oooool00ol0003oooooooooo`0Booooo`;o
003oCOooool2o`0001Kooooo000Xooooo`03o`000?oooooooooo04cooooo00?o003oooooooooool0
4oooool00ol0003oooooooooo`0Cooooo`03o`00oooooooooooo04cooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`1;ooooo`03ool00?oooooooooo02_ooooo00?oo`00ooooooooool0
C_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo04cooooo00?o003oooooooooool0
4_ooool00ol0003oooooooooo`0Booooo`;o003oC_ooool00ol0003oooooooooo`0Dooooo`00:?oo
ool00ol0003oooooooooo`1<ooooo`;o003o5?ooool00ol0003oooooooooo`0Aooooo`03o`00oooo
oooo003o04kooooo00?o0000ooooooooool05oooool3o`0000Cooooo0_l00004ooooo`03o`000?oo
oooooooo04_ooooo00?oo`00ooooooooool0:oooool00ooo003oooooooooo`1>ooooo`03o`000?oo
oooooooo02_ooooo00?o0000ooooooooool0C?ooool2o`00oa?ooooo00?o0000ooooooooool0H_oo
ool00ol0003oooooooooo`0Dooooo`00:?ooool00ol0003oooooooooo`1=ooooo`03o`00oooooooo
oooo01;ooooo00?o0000ooooooooool04Oooool00ol00?ooooooooooo`1>ooooo`03o`000?oooooo
oooo01Kooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo
00?o0000ooooooooool0Boooool00ooo003oooooooooo`0[ooooo`03ool00?oooooooooo04kooooo
00?o0000ooooooooool0:oooool00ol0003oooooooooo`1<ooooo`;o003o4oooool00ol0003ooooo
ooooo`0Booooo`;o003oC_ooool00ol0003oooooooooo`0Dooooo`00:?ooool00ol0003ooooooooo
o`1<ooooo`;o003o5?ooool00ol0003oooooooooo`0Aooooo`03o`00oooooooo003o04kooooo00?o
0000ooooooooool05_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo
00000oooool00ol0003oooooooooo`1;ooooo`03ool00?oooooooooo02_ooooo00?oo`00oooooooo
ool0C_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo04gooooo00?o003ooooooooo
ool04Oooool00ol0003oooooooooo`0Booooo`;o003oC_ooool00ol0003oooooooooo`0Dooooo`00
:?ooool2o`0004gooooo00?o003oooooooooool04oooool00ol0003oooooooooo`0Cooooo`03o`00
oooooooooooo04_ooooo0_l0000Iooooo`?o00000oooool01?l0003oooooooooool00003ooooo`?o
0000Boooool00ooo003oooooooooo`0[ooooo`03ool00?oooooooooo04gooooo0_l0000]ooooo`03
o`000?oooooooooo04cooooo00?o003oooooooooool04_ooool00ol0003oooooooooo`0Booooo`;o
003oCOooool2o`0001Kooooo000Xooooo`03o`000?oooooooooo04cooooo0_l00?lDooooo`03o`00
0?oooooooooo017ooooo0_l00?m?ooooo`03o`000?oooooooooo01Kooooo00Go0000oooooooooooo
ooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0Boooool00ooo
003oooooooooo`0[ooooo`03ool00?oooooooooo04kooooo00?o0000ooooooooool0:oooool00ol0
003oooooooooo`1<ooooo`;o003o4oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo
01Cooooo000Eooooo`?o00000_ooool5o`0000?ooooo0_l00004ooooo`03o`000?oooooooooo04go
oooo00?o003oooooooooool04_ooool00ol0003oooooooooo`0Aooooo`03o`00oooooooooooo04ko
oooo00?o0000ooooooooool05_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooo
oooooooo00000oooool00ol0003oooooooooo`1;ooooo`03ool00?oooooooooo02_ooooo00?oo`00
ooooooooool0C_ooool00ol0003oooooooooo`0Gooooo`?o00000_ooool5o`0000?ooooo0_l00005
ooooo`03o`000?oooooooooo04cooooo0_l00?lCooooo`03o`000?oooooooooo01;ooooo0_l00?m>
ooooo`03o`000?oooooooooo01Cooooo000Fooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo04cooooo0_l0
0?lDooooo`03o`000?oooooooooo017ooooo0_l00?m?ooooo`03o`000?oooooooooo01Oooooo0ol0
0004ooooo`;o00001?ooool00ol0003oooooooooo`1;ooooo`03ool00?oooooooooo02_ooooo00?o
o`00ooooooooool0C_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo04go
oooo00?o003oooooooooool04Oooool00ol0003oooooooooo`0Booooo`;o003oC_ooool00ol0003o
ooooooooo`0Dooooo`005_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00000oooool00ol0003oooooooooo`1<ooooo`03o`00oooooooooooo01?o
oooo00?o0000ooooooooool04_ooool00ol00?ooooooooooo`1=ooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool0Boooool00ooo003oooooooooo`0[ooooo`03ool00?oooooooooo04ko
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1<ooooo`03o`00oooooooooooo
01;ooooo00?o0000ooooooooool04_ooool2o`00odkooooo00?o0000ooooooooool05?ooool001Ko
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooo
oooooooooooo0_l0001=ooooo`;o003o5?ooool00ol0003oooooooooo`0Booooo`03o`00oooooooo
oooo04_ooooo0ol0000Vooooo`03o`000?oooooooooo04_ooooo00?oo`00ooooooooool0:oooool0
0ooo003oooooooooo`1>ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01?ooool0
1Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool00_ooool2o`0004gooooo0_l0
0?lCooooo`03o`000?oooooooooo067ooooo0_l0000Fooooo`005_ooool01Ol0003ooooooooooooo
oooo000000?ooooo00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo000004oo
oooo00?o003oooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`00oooooooooooo04go
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1;ooooo`03ool00?oooooooooo02_o
oooo00?oo`00ooooooooool0C_ooool00ol0003oooooooooo`0Hooooo`05o`000?oooooooooooooo
ool000000oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0C?ooool2o`00oa?ooooo00?o0000ooooooooool04_ooool2o`00odkooooo00?o0000
ooooooooool05?ooool001Gooooo0_l00003ooooo`05o`000?ooooooooooooooool000000_ooool0
1?l0003oooooooooool00003ooooo`03o`000?oooooooooo04gooooo00?o003oooooooooool04_oo
ool00ol0003oooooooooo`0Booooo`03o`00oooooooooooo04gooooo00?o0000ooooooooool09?oo
ool2o`0004_ooooo0ooo000[ooooo`?oo`00C_ooool2o`0001Wooooo0_l00003ooooo`05o`000?oo
ooooooooooooool000000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo04co
oooo0_l00?lCooooo`03o`000?oooooooooo01;ooooo0_l00?m>ooooo`03o`000?oooooooooo01Co
oooo000Fooooo`03o`000?oooooooooo00;ooooo0ol00004ooooo`;o00001?ooool00ol0003ooooo
ooooo`1Rooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`1:ooooo`?oo`00:oooool3ool004oooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`02ooooo`?o00001?ooool2o`0000Gooooo00?o0000ooooooooool0HOooool00ol0003ooooo
ooooo`1Rooooo`03o`000?oooooooooo01Cooooo000Xooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`1:ooooo`?oo`00:oooool3ool004oooooo00?o
0000ooooooooool0:oooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Cooooo000Xoooool_o00009_oo
ool00ol0003oooooo`000009ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0[oooool[o00005_ooool00?oooooo6_ooooo>o`000?oooooo3_ooool0
0?ooooooooooooofooooo`00ooooooooooooooKooooo003ooooooooooooom_ooool00001\
\>"],
  ImageRangeCache->{{{0, 755}, {145, 0}} -> {-0.0839304, -0.0144882, \
0.00419585, 0.00419585}, {{20, 243.438}, {141.5, 3.4375}} -> {-14.7187, \
-18.564, 0.104106, 1.02316}, {{265.75, 489.188}, {141.5, 3.4375}} -> \
{-38.5921, -12.8928, 0.100886, 0.713447}, {{511.562, 734.938}, {141.5, \
3.4375}} -> {-65.9107, -19.5175, 0.104139, 1.03022}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Magnitude plot of windowed DTFT as a function of frequency", \
"Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(X\[Theta]\  = DTFT[xdc, \[Theta]]\  // \ Simplify; 
    g1 = Plot[
        Abs[X\[Theta]\  /. \ \[Theta] \[Rule] \ 2  \[Pi]\ f/fs], {f, \(-fs\)/
            2, fs/2}, \ PlotStyle \[Rule] {Blue, \ Dashing[{ .01}]}, \ 
        PlotRange \[Rule] All, PlotPoints \[Rule] 200];\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.047619 0.0140438 0.00908109 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01404 -6 -4.5 ]
[-0.0125 .01404 0 4.5 ]
[-0.0125 .10485 -12 -4.5 ]
[-0.0125 .10485 0 4.5 ]
[-0.0125 .19567 -12 -4.5 ]
[-0.0125 .19567 0 4.5 ]
[-0.0125 .28648 -12 -4.5 ]
[-0.0125 .28648 0 4.5 ]
[-0.0125 .37729 -12 -4.5 ]
[-0.0125 .37729 0 4.5 ]
[-0.0125 .4681 -12 -4.5 ]
[-0.0125 .4681 0 4.5 ]
[-0.0125 .55891 -12 -4.5 ]
[-0.0125 .55891 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01404 m
.00625 .01404 L
s
[(0)] -0.0125 .01404 1 0 Mshowa
0 .10485 m
.00625 .10485 L
s
[(10)] -0.0125 .10485 1 0 Mshowa
0 .19567 m
.00625 .19567 L
s
[(20)] -0.0125 .19567 1 0 Mshowa
0 .28648 m
.00625 .28648 L
s
[(30)] -0.0125 .28648 1 0 Mshowa
0 .37729 m
.00625 .37729 L
s
[(40)] -0.0125 .37729 1 0 Mshowa
0 .4681 m
.00625 .4681 L
s
[(50)] -0.0125 .4681 1 0 Mshowa
0 .55891 m
.00625 .55891 L
s
[(60)] -0.0125 .55891 1 0 Mshowa
.125 Mabswid
0 .03221 m
.00375 .03221 L
s
0 .05037 m
.00375 .05037 L
s
0 .06853 m
.00375 .06853 L
s
0 .08669 m
.00375 .08669 L
s
0 .12302 m
.00375 .12302 L
s
0 .14118 m
.00375 .14118 L
s
0 .15934 m
.00375 .15934 L
s
0 .1775 m
.00375 .1775 L
s
0 .21383 m
.00375 .21383 L
s
0 .23199 m
.00375 .23199 L
s
0 .25015 m
.00375 .25015 L
s
0 .26831 m
.00375 .26831 L
s
0 .30464 m
.00375 .30464 L
s
0 .3228 m
.00375 .3228 L
s
0 .34096 m
.00375 .34096 L
s
0 .35913 m
.00375 .35913 L
s
0 .39545 m
.00375 .39545 L
s
0 .41361 m
.00375 .41361 L
s
0 .43177 m
.00375 .43177 L
s
0 .44994 m
.00375 .44994 L
s
0 .48626 m
.00375 .48626 L
s
0 .50442 m
.00375 .50442 L
s
0 .52258 m
.00375 .52258 L
s
0 .54075 m
.00375 .54075 L
s
0 .57707 m
.00375 .57707 L
s
0 .59523 m
.00375 .59523 L
s
0 .6134 m
.00375 .6134 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01404 m
1 .01404 L
s
.99375 .10485 m
1 .10485 L
s
.99375 .19567 m
1 .19567 L
s
.99375 .28648 m
1 .28648 L
s
.99375 .37729 m
1 .37729 L
s
.99375 .4681 m
1 .4681 L
s
.99375 .55891 m
1 .55891 L
s
.125 Mabswid
.99625 .03221 m
1 .03221 L
s
.99625 .05037 m
1 .05037 L
s
.99625 .06853 m
1 .06853 L
s
.99625 .08669 m
1 .08669 L
s
.99625 .12302 m
1 .12302 L
s
.99625 .14118 m
1 .14118 L
s
.99625 .15934 m
1 .15934 L
s
.99625 .1775 m
1 .1775 L
s
.99625 .21383 m
1 .21383 L
s
.99625 .23199 m
1 .23199 L
s
.99625 .25015 m
1 .25015 L
s
.99625 .26831 m
1 .26831 L
s
.99625 .30464 m
1 .30464 L
s
.99625 .3228 m
1 .3228 L
s
.99625 .34096 m
1 .34096 L
s
.99625 .35913 m
1 .35913 L
s
.99625 .39545 m
1 .39545 L
s
.99625 .41361 m
1 .41361 L
s
.99625 .43177 m
1 .43177 L
s
.99625 .44994 m
1 .44994 L
s
.99625 .48626 m
1 .48626 L
s
.99625 .50442 m
1 .50442 L
s
.99625 .52258 m
1 .52258 L
s
.99625 .54075 m
1 .54075 L
s
.99625 .57707 m
1 .57707 L
s
.99625 .59523 m
1 .59523 L
s
.99625 .6134 m
1 .6134 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
0 0 1 r
.5 Mabswid
[ .01 ] 0 setdash
.02381 .0184 m
.02395 .0184 L
.02408 .0184 L
.02423 .01839 L
.02437 .01838 L
.02462 .01835 L
.02489 .01831 L
.02519 .01825 L
.02551 .01817 L
.02608 .01798 L
.02722 .01748 L
.02847 .01674 L
.02973 .01586 L
.03043 .01537 L
.03077 .01514 L
.03109 .01496 L
.03125 .01489 L
.03139 .01483 L
.03147 .01481 L
.03156 .01479 L
.03171 .01477 L
.03179 .01477 L
.03188 .01478 L
.03197 .01479 L
.03206 .01482 L
.03221 .01487 L
.03238 .01495 L
.03299 .01532 L
.03355 .01571 L
.03476 .01657 L
.03605 .01736 L
.03714 .01788 L
.03777 .01811 L
.03805 .01819 L
.03836 .01826 L
.03863 .01832 L
.03892 .01836 L
.03908 .01838 L
.03923 .01839 L
.03938 .0184 L
.03952 .01841 L
.03965 .01841 L
.03978 .01841 L
.0399 .01841 L
.04003 .0184 L
.04017 .01839 L
.04031 .01838 L
.04058 .01834 L
.04089 .01829 L
.04122 .01822 L
Mistroke
.04183 .01803 L
.04243 .0178 L
.04298 .01755 L
.04525 .01613 L
.04644 .01528 L
.04673 .01509 L
.04705 .01492 L
.04722 .01485 L
.04731 .01482 L
.04739 .0148 L
.04746 .01479 L
.04755 .01478 L
.0477 .01478 L
.04778 .01478 L
.04786 .0148 L
.04802 .01484 L
.04819 .01492 L
.04836 .015 L
.04905 .01545 L
.05029 .01634 L
.05155 .01716 L
.05217 .0175 L
.05273 .01777 L
.05326 .01799 L
.05383 .01818 L
.05415 .01826 L
.05444 .01832 L
.05472 .01837 L
.05487 .01839 L
.05501 .0184 L
.05517 .01842 L
.05531 .01842 L
.05546 .01843 L
.05555 .01843 L
.05563 .01843 L
.05576 .01843 L
.05591 .01842 L
.05606 .01841 L
.0562 .0184 L
.05653 .01835 L
.05683 .0183 L
.05716 .01822 L
.05751 .01812 L
.05866 .01766 L
.05989 .01698 L
.0621 .01544 L
.0627 .01505 L
.063 .01489 L
.06309 .01486 L
.06318 .01483 L
Mistroke
.06326 .01481 L
.06334 .01479 L
.06342 .01478 L
.06351 .01478 L
.0636 .01478 L
.06369 .01479 L
.06378 .01482 L
.06387 .01484 L
.06403 .01491 L
.06434 .01507 L
.06467 .01528 L
.06583 .01611 L
.0671 .01698 L
.06827 .01764 L
.0689 .01793 L
.06951 .01815 L
.06984 .01825 L
.0702 .01833 L
.07052 .01839 L
.07068 .01841 L
.07082 .01843 L
.07096 .01844 L
.07111 .01846 L
.07119 .01846 L
.07127 .01846 L
.07142 .01847 L
.07158 .01846 L
.07172 .01846 L
.0718 .01846 L
.07188 .01845 L
.07205 .01844 L
.0722 .01842 L
.07233 .0184 L
.07264 .01835 L
.07294 .01828 L
.07326 .0182 L
.07437 .01777 L
.07504 .01743 L
.07568 .01706 L
.07688 .01625 L
.07804 .01541 L
.07837 .01518 L
.07868 .015 L
.07882 .01493 L
.07897 .01486 L
.07912 .01481 L
.07927 .01479 L
.07941 .01478 L
.07954 .01479 L
.07968 .01483 L
Mistroke
.07982 .01487 L
.08006 .01499 L
.08033 .01515 L
.08149 .01597 L
.08262 .01677 L
.08383 .01752 L
.08453 .01786 L
.08517 .01812 L
.08547 .01822 L
.08581 .01832 L
.0861 .01839 L
.08642 .01844 L
.08658 .01847 L
.08674 .01848 L
.08689 .0185 L
.08704 .01851 L
.08718 .01851 L
.08731 .01852 L
.08745 .01851 L
.08761 .01851 L
.08769 .0185 L
.08777 .0185 L
.08795 .01848 L
.08811 .01847 L
.08827 .01844 L
.08856 .01839 L
.08888 .01832 L
.08944 .01814 L
.09006 .0179 L
.09116 .01733 L
.09353 .01571 L
.09418 .01524 L
.09454 .01502 L
.09471 .01493 L
.09487 .01486 L
.09503 .01482 L
.0951 .0148 L
.09519 .01479 L
.09527 .01479 L
.09536 .0148 L
.09545 .01481 L
.09553 .01483 L
.09567 .01488 L
.09583 .01495 L
.09612 .01511 L
.09863 .0169 L
.09972 .01757 L
.1009 .01812 L
.10154 .01834 L
.10182 .01841 L
Mistroke
.10212 .01848 L
.10241 .01852 L
.10255 .01854 L
.10268 .01856 L
.10283 .01857 L
.10297 .01858 L
.10312 .01858 L
.10328 .01858 L
.10343 .01858 L
.10358 .01857 L
.10366 .01856 L
.10374 .01856 L
.10391 .01854 L
.10424 .01849 L
.10459 .01842 L
.10517 .01826 L
.10581 .01802 L
.10705 .01738 L
.10817 .01664 L
.10949 .01567 L
.11007 .01525 L
.11037 .01506 L
.11054 .01496 L
.1107 .01489 L
.11085 .01484 L
.11101 .01481 L
.11115 .0148 L
.11128 .01481 L
.11141 .01484 L
.11155 .01489 L
.11169 .01495 L
.11183 .01502 L
.11302 .01586 L
.11424 .01677 L
.11553 .01759 L
.11669 .01816 L
.11735 .0184 L
.11766 .01848 L
.11796 .01855 L
.11823 .0186 L
.11837 .01862 L
.11852 .01863 L
.11865 .01865 L
.11879 .01866 L
.11892 .01866 L
.11904 .01866 L
.11919 .01866 L
.11933 .01866 L
.11945 .01865 L
.11959 .01864 L
Mistroke
.11974 .01863 L
.1199 .01861 L
.12019 .01856 L
.1205 .01849 L
.12084 .0184 L
.12143 .0182 L
.12207 .01791 L
.12277 .01753 L
.12405 .0167 L
.12521 .01582 L
.12578 .01539 L
.12609 .01518 L
.12641 .01498 L
.12655 .01492 L
.1267 .01486 L
.12678 .01484 L
.12686 .01482 L
.12701 .01481 L
.12714 .01482 L
.12728 .01485 L
.12742 .0149 L
.12756 .01496 L
.1282 .01537 L
.12878 .0158 L
.13008 .01679 L
.13121 .01755 L
.1324 .01818 L
.13302 .01842 L
.13335 .01853 L
.1337 .01862 L
.13403 .01868 L
.13432 .01873 L
.13447 .01874 L
.13462 .01875 L
.13477 .01876 L
.1349 .01876 L
.13506 .01876 L
.13514 .01876 L
.13522 .01876 L
.13538 .01875 L
.13552 .01874 L
.13569 .01872 L
.13584 .0187 L
.13618 .01864 L
.13648 .01857 L
.1368 .01847 L
.13739 .01826 L
.13855 .01767 L
.13963 .01697 L
.14072 .01615 L
Mistroke
.14189 .01526 L
.14223 .01504 L
.1424 .01495 L
.14256 .01489 L
.1427 .01485 L
.14285 .01483 L
.14294 .01483 L
.14302 .01484 L
.14317 .01487 L
.14332 .01492 L
.14347 .015 L
.14375 .01516 L
.14437 .01562 L
.1456 .01659 L
.14677 .01743 L
.1479 .0181 L
.1484 .01834 L
.14895 .01855 L
.1495 .01871 L
.1498 .01878 L
.15008 .01883 L
.15023 .01885 L
.15038 .01886 L
.15052 .01888 L
.15067 .01888 L
.15082 .01889 L
.15091 .01889 L
.15099 .01889 L
.15115 .01888 L
.1513 .01887 L
.15145 .01886 L
.15161 .01884 L
.15193 .01878 L
.15223 .01872 L
.15251 .01864 L
.15314 .01842 L
.15382 .01811 L
.1562 .01652 L
.15746 .01552 L
.15782 .01525 L
.158 .01513 L
.15816 .01503 L
.15831 .01496 L
.15847 .01489 L
.15855 .01487 L
.15863 .01486 L
.15871 .01485 L
.1588 .01485 L
.15888 .01485 L
.15896 .01487 L
Mistroke
.15912 .01491 L
.1592 .01495 L
.15928 .01499 L
.15947 .01509 L
.1601 .01554 L
.16128 .01651 L
.16239 .01735 L
.16359 .01812 L
.16416 .01841 L
.16478 .01867 L
.16512 .01878 L
.16542 .01886 L
.16573 .01893 L
.16587 .01896 L
.16603 .01898 L
.16616 .019 L
.1663 .01901 L
.16645 .01902 L
.16658 .01903 L
.16672 .01903 L
.16685 .01903 L
.16697 .01903 L
.1671 .01902 L
.16725 .01901 L
.16739 .01899 L
.1677 .01895 L
.16799 .01889 L
.16826 .01882 L
.16882 .01863 L
.16944 .01836 L
.17069 .01764 L
.17292 .0159 L
.17355 .01539 L
.17387 .01517 L
.174 .01508 L
.17415 .015 L
.17429 .01494 L
.17442 .0149 L
.17455 .01487 L
.17469 .01487 L
.17485 .01489 L
.175 .01494 L
.17513 .015 L
.17528 .01508 L
.17659 .0161 L
.1778 .01711 L
.17908 .01802 L
.1797 .01838 L
.18028 .01867 L
.18079 .01887 L
Mistroke
.18136 .01904 L
.18165 .01911 L
.18192 .01915 L
.18207 .01917 L
.18221 .01919 L
.18237 .0192 L
.18252 .0192 L
.18266 .0192 L
.18281 .0192 L
.18295 .01919 L
.18307 .01918 L
.18322 .01917 L
.18337 .01915 L
.18369 .0191 L
.184 .01902 L
.18433 .01893 L
.18492 .0187 L
.18609 .01808 L
.18714 .01734 L
.18827 .01642 L
.18946 .01541 L
.18976 .01519 L
.18992 .01509 L
.19008 .015 L
.19017 .01496 L
.19026 .01493 L
.19035 .01491 L
.19043 .01489 L
.19052 .01489 L
.19059 .01489 L
.19068 .01491 L
.19076 .01493 L
.19091 .01498 L
.19106 .01506 L
.19134 .01524 L
.19197 .01574 L
.1932 .01682 L
.19437 .01775 L
.1955 .0185 L
.196 .01877 L
.19655 .01901 L
.1971 .0192 L
.1974 .01928 L
.19768 .01933 L
.19783 .01936 L
.19799 .01938 L
.19812 .01939 L
.19827 .0194 L
.19835 .0194 L
.19843 .0194 L
Mistroke
.19852 .01941 L
.1986 .0194 L
.19875 .0194 L
.19891 .01939 L
.19906 .01938 L
.19921 .01936 L
.19955 .0193 L
.19987 .01922 L
.20022 .01911 L
.20085 .01886 L
.20143 .01856 L
.20262 .01778 L
.20373 .01688 L
.20502 .01573 L
.20533 .01547 L
.20565 .01522 L
.20593 .01505 L
.20609 .01498 L
.20623 .01493 L
.20637 .01492 L
.20651 .01493 L
.20663 .01495 L
.20675 .015 L
.2069 .01507 L
.20705 .01516 L
.20731 .01536 L
.20848 .01639 L
.20968 .01746 L
.21096 .01843 L
.2116 .01882 L
.21219 .01913 L
.21273 .01935 L
.21304 .01944 L
.21332 .01952 L
.21361 .01957 L
.21374 .01959 L
.21388 .01961 L
.21402 .01963 L
.21416 .01964 L
.21431 .01964 L
.21439 .01964 L
.21447 .01964 L
.2146 .01964 L
.21473 .01963 L
.21485 .01962 L
.21498 .01961 L
.21526 .01957 L
.21553 .01951 L
.21609 .01935 L
.21669 .0191 L
Mistroke
.21778 .01847 L
.21908 .01748 L
.22027 .0164 L
.22084 .01586 L
.22115 .01558 L
.22145 .01533 L
.22173 .01514 L
.22188 .01505 L
.22203 .01499 L
.22215 .01496 L
.22228 .01495 L
.22242 .01496 L
.22255 .015 L
.2227 .01507 L
.22287 .01517 L
.22318 .0154 L
.22375 .01592 L
.22505 .01716 L
.22627 .01822 L
.22743 .01903 L
.22806 .01938 L
.2284 .01953 L
.22875 .01966 L
.22905 .01975 L
.22938 .01983 L
.22952 .01986 L
.22968 .01988 L
.22982 .0199 L
.22996 .01991 L
.2301 .01992 L
.23023 .01992 L
.23038 .01992 L
.23054 .01992 L
.23062 .01991 L
.2307 .01991 L
.23086 .01989 L
.23101 .01987 L
.23116 .01984 L
.23144 .01978 L
.23169 .01971 L
.23226 .01949 L
.23288 .01919 L
.23355 .01877 L
.23477 .01782 L
.23601 .01665 L
.23717 .01552 L
.23747 .01528 L
.23762 .01517 L
.23776 .01509 L
.23791 .01503 L
Mistroke
.238 .015 L
.23809 .01499 L
.23823 .01499 L
.23838 .01503 L
.23847 .01506 L
.23856 .0151 L
.23871 .0152 L
.23907 .01548 L
.23971 .0161 L
.24095 .01735 L
.24212 .01842 L
.24326 .01927 L
.24376 .01957 L
.24431 .01984 L
.24486 .02005 L
.24516 .02013 L
.24544 .02019 L
.2456 .02021 L
.24575 .02023 L
.24589 .02024 L
.24603 .02025 L
.24612 .02025 L
.24619 .02026 L
.24628 .02025 L
.24636 .02025 L
.24651 .02024 L
.24667 .02023 L
.24683 .02021 L
.24698 .02018 L
.24731 .02011 L
.24764 .02001 L
.24799 .01987 L
.24862 .01956 L
.2492 .01921 L
.2517 .017 L
.2528 .01585 L
.2531 .01556 L
.25342 .01529 L
.25357 .01518 L
.25373 .0151 L
.25386 .01505 L
.25401 .01503 L
.25416 .01504 L
.2543 .01509 L
.25443 .01515 L
.25457 .01524 L
.25517 .01577 L
.25625 .01693 L
.25748 .01821 L
.25863 .01923 L
Mistroke
.25978 .02 L
.26038 .02029 L
.26072 .02042 L
.26103 .02051 L
.26119 .02055 L
.26136 .02058 L
.2615 .02061 L
.26166 .02063 L
.26174 .02063 L
.26182 .02064 L
.26198 .02065 L
.26206 .02065 L
.26215 .02065 L
.26225 .02064 L
.26234 .02064 L
.26241 .02063 L
.2625 .02062 L
.26265 .02061 L
.2628 .02058 L
.26293 .02055 L
.26324 .02047 L
.26357 .02036 L
.26417 .0201 L
.26471 .01979 L
.26593 .01885 L
.26814 .01656 L
.26871 .01592 L
.26903 .0156 L
.26932 .01533 L
.26946 .01524 L
.2696 .01515 L
.26976 .0151 L
.2699 .01508 L
.27003 .01509 L
.27015 .01513 L
.27028 .0152 L
.27043 .01529 L
.27075 .01557 L
.2711 .01594 L
.27173 .01666 L
.27293 .01803 L
.27416 .01927 L
.27531 .02019 L
.27589 .02054 L
.27652 .02083 L
.27685 .02095 L
.27704 .021 L
.27721 .02103 L
.27737 .02106 L
.27751 .02108 L
Mistroke
.27759 .02109 L
.27767 .0211 L
.27776 .0211 L
.27784 .02111 L
.27799 .02111 L
.27813 .02111 L
.27829 .0211 L
.27843 .02108 L
.27857 .02106 L
.2787 .02104 L
.27899 .02097 L
.27931 .02087 L
.27959 .02075 L
.28024 .02042 L
.28087 .01999 L
.28155 .01943 L
.28278 .01819 L
.28403 .01672 L
.28464 .016 L
.2849 .0157 L
.28519 .01542 L
.28535 .0153 L
.28549 .01521 L
.28563 .01516 L
.28577 .01513 L
.28593 .01515 L
.28607 .01521 L
.28623 .01531 L
.2864 .01545 L
.28773 .017 L
.29011 .01973 L
.29076 .02032 L
.29145 .02084 L
.29211 .02122 L
.29239 .02135 L
.2927 .02146 L
.293 .02155 L
.29316 .02158 L
.29332 .02161 L
.29346 .02163 L
.29359 .02164 L
.29374 .02165 L
.29388 .02165 L
.29404 .02165 L
.29411 .02164 L
.2942 .02163 L
.29435 .02161 L
.2945 .02159 L
.29482 .02151 L
.29516 .0214 L
Mistroke
.29575 .02112 L
.29637 .02073 L
.29749 .01979 L
.29872 .01842 L
.29989 .01694 L
.3004 .01628 L
.30094 .01564 L
.30122 .01538 L
.3013 .01532 L
.30138 .01527 L
.30153 .01522 L
.30168 .0152 L
.30182 .01523 L
.30194 .01528 L
.30208 .01537 L
.30239 .01567 L
.30267 .01599 L
.3033 .01682 L
.30444 .01835 L
.30576 .01994 L
.30633 .02054 L
.30697 .0211 L
.30751 .02151 L
.3081 .02185 L
.30842 .02199 L
.30871 .0221 L
.30885 .02214 L
.30901 .02217 L
.30914 .0222 L
.30929 .02222 L
.30944 .02224 L
.30959 .02225 L
.30967 .02225 L
.30976 .02225 L
.30992 .02225 L
.31 .02224 L
.31009 .02223 L
.31024 .02221 L
.31043 .02217 L
.31059 .02213 L
.31089 .02203 L
.31121 .0219 L
.3118 .02157 L
.31239 .02114 L
.31294 .02065 L
.3142 .01926 L
.3155 .01752 L
.31614 .01662 L
.31646 .01619 L
.31674 .01584 L
Mistroke
.31701 .01554 L
.31717 .01542 L
.31731 .01533 L
.31746 .01528 L
.31753 .01528 L
.31762 .01529 L
.31777 .01534 L
.31791 .01544 L
.31808 .01558 L
.31823 .01575 L
.31853 .01612 L
.31919 .01705 L
.32142 .02014 L
.32259 .02139 L
.32318 .02189 L
.32383 .02232 L
.32438 .02258 L
.3247 .02269 L
.32484 .02273 L
.32498 .02275 L
.32511 .02278 L
.32524 .02279 L
.32539 .0228 L
.32553 .02281 L
.32566 .0228 L
.3258 .0228 L
.32593 .02278 L
.32606 .02276 L
.32621 .02273 L
.32635 .0227 L
.32662 .02261 L
.32691 .02249 L
.32723 .02233 L
.3278 .02195 L
.32832 .02152 L
.32953 .02024 L
.33082 .01852 L
.33195 .01685 L
.33254 .01602 L
.33284 .01568 L
.33292 .0156 L
.33301 .01552 L
.33316 .01543 L
.33331 .01538 L
.3334 .01537 L
.33347 .01538 L
.33362 .01544 L
.33377 .01553 L
.3339 .01565 L
.33403 .01579 L
Mistroke
.33431 .01614 L
.33537 .01767 L
.33761 .0207 L
.33822 .02134 L
.33887 .0219 L
.33949 .02231 L
.33976 .02245 L
.34005 .02257 L
.34021 .02263 L
.34038 .02268 L
.34054 .02272 L
.34068 .02274 L
.34077 .02276 L
.34085 .02277 L
.34094 .02277 L
.34103 .02278 L
.34112 .02278 L
.34121 .02278 L
.34136 .02277 L
.34151 .02276 L
.34167 .02273 L
.34182 .0227 L
.34195 .02267 L
.34227 .02256 L
.3426 .02241 L
.3432 .02205 L
.34376 .02162 L
.34503 .02033 L
.34729 .01731 L
.34791 .01647 L
.34825 .01606 L
.34841 .01589 L
.34857 .01575 L
.34869 .01565 L
.34884 .01556 L
.34898 .0155 L
.34913 .01548 L
.34928 .0155 L
.34936 .01552 L
.34944 .01555 L
.3496 .01564 L
.34974 .01575 L
.35039 .01639 L
.35098 .01707 L
.35232 .01848 L
.35293 .01899 L
.3535 .01937 L
.35381 .01954 L
.3541 .01967 L
.35441 .01978 L
Mistroke
.35459 .01982 L
.35475 .01986 L
.35489 .01988 L
.35504 .0199 L
.35518 .0199 L
.35531 .01991 L
.35546 .0199 L
.35554 .0199 L
.35562 .01989 L
.35577 .01987 L
.35592 .01985 L
.35608 .01981 L
.35625 .01976 L
.35657 .01965 L
.35716 .01937 L
.35772 .01902 L
.35832 .01858 L
.35938 .01767 L
.36062 .01657 L
.36178 .0157 L
.36283 .01512 L
.36311 .01498 L
.36342 .01485 L
.36354 .0148 L
.36368 .01476 L
.36383 .01473 L
.36397 .01472 L
.36411 .01473 L
.36425 .01477 L
.3644 .01485 L
.36449 .01491 L
.36456 .01498 L
.36489 .01534 L
.36519 .0158 L
.36573 .01686 L
.36632 .0184 L
.36696 .02056 L
.36763 .02347 L
.36884 .03048 L
.36998 .03944 L
.3712 .0519 L
.37341 .08254 L
.37597 .13158 L
.37839 .19082 L
.38301 .32722 L
.38791 .47435 L
.39019 .53009 L
.39138 .55406 L
.39264 .57461 L
.39329 .58309 L
Mistroke
.39399 .59073 L
.39463 .59614 L
.39523 .59983 L
.39555 .60125 L
.3957 .60181 L
.39585 .60226 L
.39597 .60258 L
.39611 .60288 L
.39626 .6031 L
.39641 .60325 L
.39649 .6033 L
.39657 .60332 L
.39672 .60329 L
.3968 .60325 L
.39688 .60318 L
.39696 .60308 L
.39706 .60294 L
.39722 .60262 L
.39737 .60222 L
.39766 .60125 L
.39795 .59997 L
.39822 .5985 L
.39884 .59418 L
.39944 .5887 L
.40008 .58148 L
.40231 .54641 L
.40487 .48987 L
.4073 .42483 L
.41192 .28737 L
.41683 .14624 L
.41927 .08355 L
.42047 .0549 L
.42099 .0428 L
.42157 .02993 L
.42183 .02419 L
.42198 .02121 L
.42212 .01877 L
.42225 .01755 L
.42239 .01845 L
.42251 .02053 L
.42263 .02279 L
.42375 .04607 L
.42612 .09317 L
.43086 .17808 L
.43543 .24612 L
.43778 .27355 L
.43908 .28592 L
.44029 .29522 L
.44151 .30229 L
.44216 .30504 L
Mistroke
.44249 .30618 L
.44285 .30719 L
.44319 .30796 L
.44334 .30823 L
.4435 .30848 L
.44365 .30867 L
.4438 .30882 L
.44389 .30889 L
.44396 .30894 L
.44412 .309 L
.44426 .30903 L
.4444 .30901 L
.44455 .30896 L
.44471 .30886 L
.44485 .30874 L
.44498 .3086 L
.44527 .30816 L
.44556 .30756 L
.44584 .30687 L
.44646 .30481 L
.44706 .30215 L
.44771 .29862 L
.44888 .29046 L
.44994 .2812 L
.45476 .22177 L
.45941 .15204 L
.46176 .11826 L
.46435 .08551 L
.46683 .05988 L
.4691 .04232 L
.46968 .03889 L
.47031 .03574 L
.47059 .03453 L
.4709 .03342 L
.47119 .03257 L
.47145 .03196 L
.47161 .03167 L
.47178 .03144 L
.47187 .03135 L
.47195 .03129 L
.47204 .03124 L
.47213 .03121 L
.47221 .0312 L
.4723 .03121 L
.47239 .03124 L
.47247 .03129 L
.47262 .03142 L
.47277 .03162 L
.47292 .03186 L
.47307 .03216 L
Mistroke
.47334 .03285 L
.47397 .03499 L
.4746 .03784 L
.47519 .041 L
.47652 .04971 L
.47894 .07056 L
.48142 .09824 L
.48366 .1283 L
.48849 .20217 L
.49314 .26823 L
.49555 .29315 L
.49676 .30216 L
.49745 .30609 L
.49809 .30895 L
.49869 .3109 L
.49903 .31168 L
.49919 .31197 L
.49935 .3122 L
.49949 .31237 L
.49962 .31249 L
.49977 .31258 L
.49993 .31262 L
.50007 .31263 L
.50023 .31258 L
.50031 .31254 L
.50039 .31248 L
.50054 .31233 L
.50069 .31215 L
.50083 .31193 L
.50114 .31131 L
.50142 .31059 L
.50171 .30967 L
.50278 .3049 L
.50337 .3013 L
.50392 .29745 L
.50514 .28692 L
.50735 .26217 L
.51214 .19223 L
.51676 .1224 L
.51933 .08922 L
.52166 .06476 L
.52283 .05466 L
.5241 .04541 L
.52529 .03837 L
.52587 .03567 L
.52639 .03367 L
.52666 .03284 L
.52696 .03211 L
.52712 .03179 L
.52727 .03156 L
Mistroke
.52741 .03139 L
.52757 .03127 L
.5277 .03121 L
.52784 .0312 L
.52797 .03124 L
.52809 .03132 L
.52822 .03145 L
.52837 .03164 L
.52852 .03191 L
.52866 .0322 L
.52899 .03307 L
.5293 .03411 L
.52987 .03656 L
.53116 .04401 L
.53358 .06365 L
.5358 .08724 L
.54056 .15157 L
.54514 .22034 L
.54768 .25492 L
.55001 .28069 L
.55116 .29075 L
.55177 .29523 L
.55241 .29933 L
.55298 .30234 L
.5536 .30502 L
.55387 .30598 L
.55416 .30687 L
.55444 .30757 L
.5547 .30809 L
.55498 .30855 L
.55514 .30873 L
.55529 .30887 L
.55543 .30895 L
.55556 .309 L
.5557 .30903 L
.55585 .30901 L
.556 .30896 L
.55608 .30891 L
.55616 .30885 L
.55631 .30872 L
.55645 .30855 L
.55676 .30805 L
.55711 .3073 L
.55775 .30538 L
.55843 .30256 L
.55965 .29557 L
.56089 .28611 L
.56224 .27342 L
.56467 .24479 L
.56962 .17003 L
Mistroke
.57208 .12687 L
.57438 .08352 L
.57659 .03884 L
.5769 .03247 L
.57723 .02558 L
.57738 .02251 L
.57747 .0209 L
.57754 .01951 L
.57768 .01773 L
.57783 .01813 L
.57797 .02029 L
.57812 .02315 L
.57838 .02869 L
.57896 .0418 L
.58356 .15689 L
.58846 .29859 L
.59317 .43789 L
.59557 .50064 L
.59684 .52926 L
.59817 .55529 L
.59937 .57427 L
.6 .58254 L
.60068 .58995 L
.60131 .59535 L
.60188 .5991 L
.60215 .60048 L
.60245 .60168 L
.60259 .60212 L
.60274 .60251 L
.60287 .60281 L
.603 .60303 L
.60315 .60321 L
.60323 .60327 L
.60331 .60331 L
.6034 .60332 L
.60349 .6033 L
.60365 .6032 L
.6038 .60302 L
.60393 .60279 L
.60408 .60245 L
.60424 .60199 L
.60457 .60076 L
.60488 .59924 L
.60559 .59446 L
.6062 .58885 L
.60676 .58254 L
.60802 .56443 L
.61031 .51894 L
.61281 .45434 L
.61771 .30495 L
Mistroke
.62243 .16957 L
.62501 .11116 L
.62619 .08921 L
.62744 .06944 L
.62859 .05427 L
.62986 .0409 L
.63101 .0315 L
.63209 .02489 L
.63269 .022 L
.63335 .01946 L
.63397 .01759 L
.63454 .01628 L
.63506 .01542 L
.6352 .01523 L
.63535 .01506 L
.63549 .01493 L
.63563 .01484 L
.63577 .01476 L
.63592 .01472 L
.63607 .01472 L
.63623 .01474 L
.63638 .01478 L
.63652 .01483 L
.63678 .01493 L
.63795 .01553 L
.63919 .01641 L
.64142 .01836 L
.64255 .0192 L
.64288 .01939 L
.64319 .01955 L
.64347 .01967 L
.64378 .01977 L
.64392 .01981 L
.64406 .01984 L
.6442 .01987 L
.64432 .01988 L
.64444 .0199 L
.64457 .0199 L
.64469 .01991 L
.64483 .0199 L
.64498 .01989 L
.64512 .01988 L
.64528 .01985 L
.64543 .01982 L
.64569 .01974 L
.64598 .01963 L
.64657 .01933 L
.64712 .01895 L
.64837 .01779 L
.64961 .0164 L
Mistroke
.64991 .01607 L
.65023 .01577 L
.65041 .01563 L
.6505 .01558 L
.65058 .01554 L
.65066 .01551 L
.65075 .01549 L
.65091 .01548 L
.65105 .01551 L
.6512 .01558 L
.65134 .01567 L
.65147 .01578 L
.65209 .01647 L
.65334 .0182 L
.65443 .01966 L
.65558 .021 L
.65614 .02154 L
.65677 .02204 L
.65734 .02238 L
.65759 .0225 L
.65787 .02261 L
.65818 .0227 L
.65835 .02273 L
.6585 .02276 L
.65865 .02277 L
.65878 .02278 L
.65893 .02278 L
.65908 .02277 L
.65924 .02276 L
.65931 .02274 L
.6594 .02273 L
.6597 .02266 L
.65987 .0226 L
.66005 .02253 L
.66038 .02238 L
.66101 .02199 L
.6616 .02151 L
.66293 .02006 L
.66409 .01848 L
.66535 .01661 L
.66567 .01616 L
.66601 .01574 L
.66615 .0156 L
.6663 .01548 L
.66639 .01543 L
.66647 .0154 L
.66662 .01537 L
.66678 .0154 L
.66692 .01547 L
.66708 .01559 L
Mistroke
.66724 .01576 L
.66782 .01651 L
.67007 .01974 L
.6712 .02106 L
.67179 .02163 L
.67242 .02211 L
.67297 .02243 L
.67328 .02257 L
.67357 .02267 L
.67371 .02271 L
.67384 .02274 L
.67395 .02276 L
.67408 .02278 L
.67421 .0228 L
.67434 .0228 L
.67447 .02281 L
.67462 .0228 L
.67478 .02279 L
.67492 .02277 L
.67508 .02274 L
.67525 .0227 L
.67557 .0226 L
.67585 .02249 L
.67643 .02217 L
.67697 .02177 L
.67818 .0206 L
.67949 .01895 L
.68074 .01716 L
.68134 .01629 L
.68161 .01594 L
.6819 .01561 L
.68205 .01546 L
.6822 .01536 L
.68234 .0153 L
.68248 .01528 L
.68264 .01531 L
.68278 .01538 L
.68294 .0155 L
.68311 .01567 L
.68444 .01744 L
.68559 .019 L
.68682 .02041 L
.68752 .02107 L
.68816 .02155 L
.68847 .02174 L
.6888 .02191 L
.68912 .02204 L
.68941 .02213 L
.68969 .0222 L
.68984 .02222 L
Mistroke
.68999 .02224 L
.69014 .02225 L
.69023 .02225 L
.69031 .02225 L
.69046 .02225 L
.69062 .02224 L
.69077 .02222 L
.69093 .02219 L
.69123 .02211 L
.69158 .02199 L
.6919 .02185 L
.69243 .02154 L
.69302 .02112 L
.6942 .02 L
.69551 .01842 L
.69676 .01674 L
.6973 .01603 L
.69759 .01568 L
.69787 .01541 L
.69802 .01531 L
.69817 .01523 L
.69826 .01521 L
.69834 .0152 L
.6985 .01523 L
.69865 .01529 L
.69878 .01538 L
.69908 .01566 L
.70151 .0187 L
.7027 .01996 L
.70379 .02084 L
.70437 .02119 L
.70466 .02133 L
.70498 .02145 L
.70515 .0215 L
.7053 .02154 L
.70545 .02158 L
.70559 .0216 L
.70576 .02163 L
.70585 .02164 L
.70594 .02164 L
.7061 .02165 L
.70618 .02165 L
.70627 .02165 L
.7064 .02164 L
.70654 .02163 L
.70669 .02161 L
.70683 .02158 L
.70708 .02153 L
.70735 .02145 L
.70796 .02119 L
Mistroke
.70851 .02086 L
.70972 .0199 L
.71083 .01875 L
.71212 .01719 L
.71276 .01639 L
.71334 .01571 L
.71361 .01545 L
.71375 .01533 L
.7139 .01523 L
.71404 .01516 L
.71417 .01514 L
.71431 .01514 L
.71443 .01517 L
.71457 .01525 L
.71472 .01535 L
.71499 .01559 L
.7156 .01627 L
.7168 .01771 L
.71809 .0191 L
.71873 .01967 L
.71934 .02014 L
.71992 .02051 L
.72047 .02078 L
.72098 .02096 L
.72124 .02102 L
.72139 .02105 L
.72153 .02107 L
.72168 .02109 L
.72182 .0211 L
.72196 .02111 L
.72205 .02111 L
.72212 .02111 L
.72226 .0211 L
.72239 .02109 L
.72254 .02108 L
.72268 .02105 L
.72297 .02099 L
.72324 .02092 L
.72386 .02067 L
.72446 .02034 L
.7251 .01989 L
.72733 .01774 L
.72856 .01633 L
.7292 .01562 L
.72953 .01532 L
.72962 .01526 L
.72972 .0152 L
.72981 .01515 L
.72989 .01511 L
.73004 .01508 L
Mistroke
.73012 .01508 L
.73021 .01509 L
.7303 .01511 L
.73039 .01515 L
.73055 .01524 L
.73084 .01547 L
.73115 .01578 L
.73232 .01707 L
.73355 .01837 L
.73471 .01938 L
.73534 .01982 L
.73592 .02014 L
.73656 .02041 L
.73692 .02052 L
.73708 .02056 L
.73725 .02059 L
.73741 .02061 L
.73756 .02063 L
.73771 .02064 L
.73786 .02065 L
.738 .02065 L
.73812 .02064 L
.73826 .02063 L
.73841 .02062 L
.73857 .0206 L
.73874 .02056 L
.73906 .02049 L
.73936 .02039 L
.73964 .02028 L
.74072 .01969 L
.74186 .01881 L
.74302 .0177 L
.74424 .0164 L
.74475 .01586 L
.74528 .01535 L
.74544 .01523 L
.74559 .01514 L
.74573 .01507 L
.74587 .01504 L
.74601 .01503 L
.74616 .01506 L
.74628 .0151 L
.74642 .01518 L
.74673 .0154 L
.747 .01566 L
.74763 .01629 L
.74876 .01746 L
.75007 .01866 L
.75064 .01909 L
.75128 .0195 L
Mistroke
.75181 .01978 L
.75239 .02002 L
.75271 .02011 L
.75285 .02014 L
.753 .02018 L
.75313 .0202 L
.75328 .02022 L
.75343 .02024 L
.75357 .02025 L
.75366 .02025 L
.75374 .02025 L
.7539 .02025 L
.75398 .02025 L
.75406 .02025 L
.75415 .02024 L
.75425 .02023 L
.75442 .02021 L
.75458 .02019 L
.75488 .02012 L
.75518 .02004 L
.75545 .01994 L
.75608 .01966 L
.75669 .01931 L
.75735 .01885 L
.75855 .01783 L
.75971 .01668 L
.7608 .0156 L
.76108 .01535 L
.76135 .01515 L
.7615 .01507 L
.76158 .01504 L
.76166 .01501 L
.7618 .01499 L
.76194 .01499 L
.76209 .01503 L
.76218 .01506 L
.76225 .0151 L
.76254 .01529 L
.7632 .01588 L
.76452 .01717 L
.76574 .01825 L
.76685 .01903 L
.76747 .01937 L
.76803 .01961 L
.76833 .01971 L
.76864 .0198 L
.76881 .01983 L
.76899 .01987 L
.76916 .01989 L
.76931 .01991 L
Mistroke
.76947 .01992 L
.76962 .01992 L
.76975 .01992 L
.7699 .01992 L
.77005 .01991 L
.77014 .0199 L
.77022 .01989 L
.77038 .01987 L
.77052 .01985 L
.77081 .01979 L
.77111 .0197 L
.77174 .01947 L
.77228 .0192 L
.77285 .01886 L
.77536 .01677 L
.77659 .0156 L
.77693 .01531 L
.77712 .01518 L
.77729 .01507 L
.77744 .01501 L
.7776 .01496 L
.77769 .01495 L
.77777 .01495 L
.77785 .01496 L
.77793 .01498 L
.77801 .015 L
.7781 .01504 L
.77825 .01512 L
.77854 .01532 L
.77919 .01589 L
.78036 .01698 L
.7816 .01803 L
.78276 .01881 L
.78335 .01911 L
.78397 .01937 L
.78433 .01948 L
.78467 .01955 L
.78482 .01958 L
.78497 .0196 L
.78505 .01961 L
.78514 .01962 L
.7853 .01963 L
.78545 .01964 L
.78559 .01964 L
.78574 .01964 L
.78582 .01964 L
.7859 .01963 L
.78605 .01962 L
.78622 .0196 L
.78637 .01958 L
Mistroke
.78652 .01955 L
.78706 .01941 L
.78733 .01932 L
.78763 .0192 L
.78893 .0185 L
.79015 .0176 L
.7914 .0165 L
.79202 .01593 L
.79259 .01543 L
.79286 .01522 L
.79311 .01506 L
.79325 .015 L
.7934 .01494 L
.79354 .01492 L
.79366 .01492 L
.7938 .01494 L
.79393 .01499 L
.79408 .01505 L
.79423 .01514 L
.79483 .0156 L
.79722 .01766 L
.79788 .01814 L
.79857 .01857 L
.79917 .01887 L
.79949 .01901 L
.79982 .01913 L
.80012 .01922 L
.80044 .0193 L
.80058 .01932 L
.80073 .01935 L
.80087 .01937 L
.801 .01938 L
.80115 .01939 L
.8013 .0194 L
.80144 .01941 L
.80158 .0194 L
.80171 .0194 L
.80183 .01939 L
.80197 .01938 L
.80211 .01936 L
.80243 .01931 L
.80279 .01923 L
.80312 .01913 L
.80343 .01902 L
.80463 .01843 L
.80579 .01764 L
.80688 .01675 L
.80809 .0157 L
.80841 .01543 L
.80875 .01518 L
Mistroke
.80891 .01507 L
.80907 .01499 L
.80921 .01493 L
.80936 .0149 L
.8095 .01489 L
.80965 .01491 L
.80973 .01493 L
.80981 .01496 L
.80996 .01502 L
.81025 .0152 L
.81052 .0154 L
.81179 .01647 L
.81287 .01735 L
.81402 .01814 L
.81464 .01849 L
.81521 .01875 L
.81578 .01896 L
.81603 .01903 L
.81631 .0191 L
.81661 .01915 L
.81678 .01917 L
.81694 .01919 L
.81708 .0192 L
.81721 .0192 L
.81737 .0192 L
.81751 .0192 L
.81767 .01919 L
.81775 .01919 L
.81783 .01918 L
.81799 .01916 L
.81813 .01914 L
.81846 .01909 L
.81881 .019 L
.81941 .0188 L
.81996 .01855 L
.82123 .01782 L
.82254 .01684 L
.82377 .0158 L
.82435 .01534 L
.82466 .01512 L
.82481 .01503 L
.82496 .01496 L
.82511 .0149 L
.82519 .01488 L
.82527 .01487 L
.82536 .01487 L
.82544 .01487 L
.82553 .01488 L
.82562 .01491 L
.8257 .01493 L
Mistroke
.82579 .01497 L
.82595 .01505 L
.82624 .01524 L
.82848 .01704 L
.82973 .0179 L
.83089 .01851 L
.83148 .01874 L
.83178 .01883 L
.8321 .01891 L
.83229 .01895 L
.83246 .01897 L
.83262 .01899 L
.83271 .019 L
.8328 .01901 L
.83296 .01902 L
.83311 .01903 L
.83319 .01903 L
.83328 .01903 L
.83343 .01903 L
.83358 .01902 L
.83367 .01901 L
.83374 .01901 L
.83388 .01899 L
.83404 .01897 L
.8343 .01893 L
.83459 .01886 L
.83522 .01867 L
.83582 .01842 L
.83689 .01783 L
.83803 .01704 L
.83926 .01606 L
.83991 .01554 L
.84026 .01527 L
.84059 .01505 L
.84073 .01498 L
.84088 .01491 L
.84096 .01489 L
.84104 .01487 L
.84119 .01485 L
.84128 .01485 L
.84136 .01485 L
.84145 .01487 L
.84153 .01489 L
.84169 .01495 L
.84185 .01504 L
.84246 .01545 L
.84302 .0159 L
.8442 .01683 L
.84547 .01771 L
.84609 .01806 L
Mistroke
.84667 .01834 L
.84725 .01856 L
.84777 .01872 L
.84805 .01878 L
.84832 .01883 L
.84845 .01884 L
.8486 .01886 L
.84875 .01887 L
.8489 .01888 L
.84902 .01889 L
.84916 .01889 L
.84929 .01888 L
.8494 .01888 L
.84954 .01887 L
.84968 .01886 L
.84982 .01884 L
.84995 .01882 L
.85023 .01877 L
.8505 .01871 L
.85111 .01853 L
.8517 .01829 L
.85233 .01798 L
.8547 .01635 L
.85596 .01537 L
.85632 .01512 L
.8565 .01502 L
.85666 .01493 L
.85681 .01488 L
.85697 .01484 L
.85712 .01483 L
.85721 .01483 L
.8573 .01485 L
.85745 .01489 L
.85754 .01492 L
.85762 .01496 L
.85792 .01513 L
.85849 .01553 L
.85977 .01653 L
.86088 .01732 L
.86208 .01801 L
.86274 .01831 L
.86304 .01842 L
.86336 .01852 L
.86364 .0186 L
.86394 .01866 L
.86411 .01869 L
.86426 .01871 L
.86441 .01873 L
.86456 .01875 L
.8647 .01876 L
Mistroke
.86485 .01876 L
.86498 .01876 L
.86511 .01876 L
.86526 .01876 L
.8654 .01875 L
.86548 .01875 L
.86556 .01874 L
.86571 .01872 L
.86599 .01868 L
.86628 .01862 L
.86681 .01848 L
.86745 .01824 L
.86805 .01797 L
.86939 .01717 L
.87065 .01625 L
.87126 .01577 L
.87182 .01535 L
.87209 .01517 L
.87238 .01499 L
.87252 .01493 L
.87266 .01487 L
.87278 .01484 L
.87291 .01482 L
.87307 .01482 L
.87321 .01484 L
.87336 .01488 L
.87344 .01491 L
.87352 .01495 L
.87409 .0153 L
.87539 .01628 L
.87658 .01713 L
.87771 .0178 L
.87831 .01809 L
.87894 .01833 L
.87927 .01843 L
.87962 .01852 L
.87994 .01858 L
.88024 .01863 L
.8804 .01864 L
.88055 .01865 L
.88069 .01866 L
.88084 .01866 L
.88092 .01866 L
.881 .01866 L
.88108 .01866 L
.88117 .01866 L
.88131 .01865 L
.88147 .01863 L
.88162 .01862 L
.88176 .0186 L
Mistroke
.88207 .01854 L
.88262 .01841 L
.88327 .01818 L
.88388 .01791 L
.8851 .01721 L
.88642 .01628 L
.88701 .01583 L
.88765 .01536 L
.88795 .01516 L
.88826 .01498 L
.88838 .01491 L
.88852 .01486 L
.88867 .01482 L
.88881 .0148 L
.88897 .01481 L
.88905 .01482 L
.88913 .01484 L
.88928 .01489 L
.88944 .01496 L
.89002 .01531 L
.89134 .01629 L
.89249 .01709 L
.89371 .01779 L
.8943 .01806 L
.89486 .01827 L
.89537 .01841 L
.89565 .01847 L
.89592 .01852 L
.89606 .01854 L
.89621 .01855 L
.89634 .01856 L
.89648 .01857 L
.89663 .01858 L
.89671 .01858 L
.89679 .01858 L
.89694 .01858 L
.89708 .01857 L
.89721 .01857 L
.89735 .01855 L
.8976 .01852 L
.89787 .01848 L
.89817 .01842 L
.89878 .01824 L
.89945 .01798 L
.90065 .01736 L
.90303 .0157 L
.90368 .01524 L
.90404 .01501 L
.90421 .01492 L
.90429 .01489 L
Mistroke
.90437 .01486 L
.90453 .01481 L
.90461 .0148 L
.90469 .01479 L
.90477 .01479 L
.90485 .0148 L
.90494 .01481 L
.90503 .01483 L
.90518 .01488 L
.90531 .01494 L
.90562 .01511 L
.9079 .01674 L
.90911 .01749 L
.90974 .01781 L
.91041 .01809 L
.91102 .01829 L
.91137 .01837 L
.91169 .01843 L
.91184 .01846 L
.91198 .01848 L
.91211 .01849 L
.91225 .0185 L
.9124 .01851 L
.91254 .01851 L
.91269 .01852 L
.91278 .01851 L
.91286 .01851 L
.913 .01851 L
.91315 .01849 L
.9133 .01848 L
.91343 .01846 L
.91369 .01843 L
.91396 .01837 L
.91458 .0182 L
.91515 .018 L
.91636 .01741 L
.91748 .01671 L
.91878 .01578 L
.91941 .01532 L
.91969 .01514 L
.91999 .01496 L
.92013 .0149 L
.92028 .01484 L
.92041 .0148 L
.92055 .01478 L
.92069 .01478 L
.92083 .0148 L
.92096 .01484 L
.92109 .01489 L
.92138 .01503 L
Mistroke
.92169 .01522 L
.92226 .01562 L
.92357 .01657 L
.92476 .01732 L
.92534 .01763 L
.92598 .01792 L
.92653 .01813 L
.92713 .0183 L
.92746 .01837 L
.92777 .01841 L
.92794 .01843 L
.92809 .01845 L
.92818 .01845 L
.92827 .01846 L
.92836 .01846 L
.92845 .01846 L
.92859 .01847 L
.92872 .01846 L
.92887 .01846 L
.92896 .01845 L
.92903 .01845 L
.92934 .01841 L
.92949 .01839 L
.92966 .01836 L
.93029 .01821 L
.93089 .01801 L
.93202 .01749 L
.93323 .01676 L
.93455 .01584 L
.9351 .01544 L
.93569 .01505 L
.93586 .01496 L
.93602 .01488 L
.93617 .01483 L
.93626 .01481 L
.93633 .01479 L
.93649 .01478 L
.93663 .01478 L
.93671 .0148 L
.93679 .01482 L
.93694 .01487 L
.9371 .01494 L
.93725 .01502 L
.93758 .01522 L
.93826 .0157 L
.93948 .01656 L
.94074 .01735 L
.94136 .01767 L
.94194 .01792 L
.94245 .01811 L
Mistroke
.94301 .01826 L
.9433 .01832 L
.94357 .01837 L
.94371 .01839 L
.94386 .0184 L
.94394 .01841 L
.94403 .01842 L
.94417 .01843 L
.94425 .01843 L
.94433 .01843 L
.94448 .01843 L
.94464 .01843 L
.94473 .01842 L
.94481 .01842 L
.94496 .01841 L
.9451 .01839 L
.94541 .01835 L
.94569 .0183 L
.94599 .01823 L
.94654 .01806 L
.94718 .01782 L
.94785 .01749 L
.94907 .01677 L
.95031 .0159 L
.95097 .01543 L
.95133 .01519 L
.95166 .01499 L
.95181 .01492 L
.95195 .01486 L
.95203 .01483 L
.95212 .01481 L
.95226 .01478 L
.95234 .01477 L
.95243 .01477 L
.95252 .01478 L
.95261 .0148 L
.95276 .01484 L
.95293 .01491 L
.95324 .01508 L
.95354 .01527 L
.95409 .01566 L
.95534 .01654 L
.95651 .01727 L
.95756 .0178 L
.95815 .01803 L
.9587 .0182 L
.95897 .01826 L
.95925 .01832 L
.95941 .01834 L
.95956 .01836 L
Mistroke
.9597 .01838 L
.95985 .01839 L
.96001 .0184 L
.96015 .01841 L
.96031 .01841 L
.9604 .01841 L
.96048 .01841 L
.96063 .0184 L
.96076 .01839 L
.96091 .01838 L
.96107 .01836 L
.96137 .01832 L
.9617 .01825 L
.96228 .01809 L
.96297 .01784 L
.9636 .01754 L
.96611 .01596 L
.96721 .01518 L
.96751 .015 L
.96768 .01492 L
.96784 .01485 L
.96798 .01481 L
.96807 .01479 L
.96814 .01478 L
.96828 .01477 L
.96842 .01478 L
.96858 .01482 L
.96872 .01487 L
.96903 .01503 L
.96961 .01539 L
.97068 .01616 L
.97191 .01698 L
.97306 .01762 L
.97378 .01793 L
.97455 .01818 L
.97476 .01824 L
.97499 .01828 L
.9752 .01832 L
.97541 .01835 L
.9756 .01837 L
.97571 .01838 L
.97582 .01839 L
.97592 .0184 L
.97601 .0184 L
.9761 .0184 L
.97619 .0184 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`005_ooool3o`0000Cooooo0_l0000iooooo`?o0000>oooool2o`0003cooooo0ol0000ioooo
o`?o00001?ooool2o`0000Oooooo000Gooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo0000=oooool01Ol0003ooooooooooooooooo000003Wooooo00Co0000oooooooooooo0000>_oo
ool01Ol0003ooooooooooooooooo000003Wooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00006ooooo`003oooool5o`0000?ooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool0000aooooo`Go00001Oooool00ol0003oooooooooo`0gooooo`04o`000?ooooooooooo`00
03kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000Kooooo000Gooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000>oooool0
0ol0003oooooooooo`0gooooo`04o`000?ooooooooooo`0003kooooo00?o0000ooooooooool0=ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Kooooo000Gooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo0000=oooool4o`0003[ooooo00Co0000oooooooooooo
0000>_ooool4o`0003[ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00006oooo
o`005_ooool2o`0000Cooooo00Co0000oooooooooooo0000=oooool00ol0003oooooooooo`0koooo
o`04o`000?ooooooooooo`0003[ooooo00?o0000ooooooooool0>_ooool2o`0000Cooooo00Co0000
oooooooooooo00001_ooool001Oooooo00?o0000ooooooooool00oooool2o`0003Sooooo1Ol0000j
ooooo`;o0000>oooool5o`0003Wooooo00?o0000ooooooooool00oooool2o`0000Oooooo003ooooo
ob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Aoooooooo00003Ol00003
ooooo`002_ooool2o`0000Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`01oooo
o`002Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0??ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03cooooo00?o0000oooo
ooooool0??ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo007ooooo0009ooooo`04
o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0Poooool00ol0003oooooooooo`22oooo
o`03o`000?oooooooooo007ooooo0009ooooo`04o`000?ooooooooooo`0000Cooooo0ol00005oooo
o`;o003o0_ooool2o`00o`;ooooo0ol00?l2ooooo`;o003o0_ooool2o`00o`?ooooo0_l00?l2oooo
o`;o003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo0_l00?l00ooooooo003oooooo`08
ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`08ooooo`;o003o0ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Co003ooooooooooooooooo0_l00?lSooooo`03
o`000?oooooooooo023ooooo0ol00?l6ooooo`05o`00ooooooooooooooooool00?l00oooool2o`00
o`;ooooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00ooooooooooooooooo`;o003o0_oo
ool2o`00o`;ooooo0_l00?l2ooooo`?o003o0_ooool2o`00o`;ooooo0_l00?l3ooooo`03o`00oooo
oooooooo00Gooooo0_l00?l6ooooo`;o003o0_ooool01?l00?ooooooooooooooool3o`00o`04oooo
ool00?oo003oo`00o`Gooooo0ol00003ooooo`002Oooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo00Cooooo0_l00?l2ooooo`;o003o0_ooool2o`00o`;ooooo00?o003ooooooooo
ool00_ooool2o`00o`;ooooo00?o003oooooooooool00_l00?l2ooooo`;o003o0oooool2o`00o`;o
oooo0_l00?l2ooooo`?o003o00?oooooo`00ool00?l00_l00?l00ooooooo003oo`00o`02ooooo`;o
003o0_ooool3o`00o`05ooooool00?oo003oo`00ooooool00ol00?l03?oooooo003oo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooo`;o003o0_ooool2o`00o`Cooooo00?o003ooooo
ooooool08Oooool00ol0003oooooooooo`0Rooooo`03o`00oooooooooooo00;o003o1Oooool00ol0
0?ooooooooooo`02ooooo`;o003o00Coooooo`00ool00?oooooo0ol00?l2ooooo`;o003o0oooool0
0ol00?ooooooo`00o`04ooooo`?o003o0_ooool2o`00o`03ooooool00?oo003o00;ooooo00?o003o
ooooooooool00_ooool2o`00o`;ooooo0ol00?l00ooooooo003oo`00o`02ooooo`;o003o0oooool2
o`00o`;ooooo0ol00?l3ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool0
0ol0003oooooooooo`01ooooo`002Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooo
oooo04Oooooo0_l00?l2ooooo`;o003o1_ooool00ol00?ooooooooooo`02ooooo`;o003o5?ooool0
0ol00?ooooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o003oooooooooool04_ooool3
o`00o`;ooooo0_l00?l2ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00
o`19ooooo`03o`000?oooooooooo007ooooo000:ooooo`;o00001Oooool00ol0003oooooooooo`1^
ooooo`03o`00oooooooooooo01;ooooo00?o0000ooooooooool04Oooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo05oooooo00?o0000ooooooooool00Oooool0017ooooo0_l0001Qoooo
o`03o`00oooooooooooo00_ooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`05oooo
o`03o`000?oooooooooo00Cooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0;oooo
o`03o`00oooooooooooo05oooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`1Pooooo`03
o`00oooooooooooo00_ooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`04ooooo`03
o`000?oooooooooo00?ooooo0_l00?l=ooooo`03o`00oooooooooooo00[ooooo00?o003ooooooooo
ool0H?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1Pooooo`03o`00
oooooooooooo01Wooooo00?o003oooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00
oooooooo003o07cooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0KOoo
ool2o`00o`_ooooo00?o003oooooool00?l01_ooool00ol0003oooooooooo`0Aooooo`03o`00oooo
oooooooo06kooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0KOooool2
o`00o`_ooooo00?o003oooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00oooooooo
oooo00Wooooo0_l00?l<ooooo`03o`00oooooooooooo063ooooo00?o0000ooooooooool00Oooool0
017ooooo0_l0001Qooooo`03o`00oooooooooooo00[ooooo0_l00?l;ooooo`03o`00oooooooo003o
00Kooooo00?o0000ooooooooool00oooool00ol00?ooooooo`00o`0;ooooo`;o003o3?ooool00ol0
0?ooooooooooo`1Oooooo`;o00000oooool0017ooooo00?o0000ooooooooool0H?ooool00ol00?oo
ooooooooo`0:ooooo`;o003o3Oooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00?o
oooo00?o003oooooool00?l02oooool2o`00o`cooooo00?o003oooooooooool0H?ooool00ol0003o
ooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1Pooooo`03o`00oooooooooooo01[ooooo
00?o003oooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00oooooooo003o01Wooooo
00?o003oooooooooool0H?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooooooo
o`1Pooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool02Oooool01?l00?oooooooooo
ool00?l5ooooo`03o`000?oooooooooo017ooooo00?o003oooooooooool0K_ooool00ol0003ooooo
ooooo`01ooooo`004Oooool00ol0003oooooooooo`1]ooooo`;o003o2oooool00ol00?oooooooooo
o`06ooooo`03o`000?oooooooooo017ooooo0_l00?l<ooooo`03o`00oooooooooooo063ooooo00?o
0000ooooooooool00Oooool0017ooooo0_l0001Rooooo`03o`00oooooooooooo00Wooooo00?o003o
ooooool00?l02Oooool00ol00?ooooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00Go003o
ooooooooooooooooo`00o`0:ooooo`;o003o3?ooool00ol00?ooooooooooo`1Oooooo`;o00000ooo
ool0017ooooo00?o0000ooooooooool0HOooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo
003o00Wooooo00Go003oooooooooooooooooo`00o`05ooooo`03o`000?oooooooooo00;ooooo00Go
003oooooooooooooooooo`00o`0:ooooo`;o003o3?ooool00ol00?ooooooooooo`1Pooooo`03o`00
0?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo067ooooo00?o003oooooooooool06Ooo
ool00ol00?ooooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`0;ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0HOooool00ol0003ooooo
ooooo`01ooooo`004Oooool00ol0003oooooooooo`1Qooooo`03o`00oooooooooooo01Gooooo00Go
003oooooooooooooooooo`00o`05ooooo`03o`000?oooooooooo00;ooooo00?o003oooooooooool0
OOooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1]ooooo`03o`00oooo
oooo003o00Wooooo00?o003oooooooooool01oooool00ol0003oooooooooo`0@ooooo`03o`00oooo
oooo003o06oooooo00?o0000ooooooooool00Oooool0017ooooo0_l0001^ooooo`03o`00oooooooo
003o00Wooooo00?o003oooooooooool01oooool00ol0003oooooooooo`02ooooo`05o`00oooooooo
ooooooooool00?l02Oooool00ol00?ooooooo`00o`0;ooooo`03o`00oooooooooooo063ooooo0_l0
0003ooooo`004Oooool00ol0003oooooooooo`1Qooooo`03o`00oooooooooooo00Wooooo00?o003o
ooooool00?l02Oooool01Ol00?oooooooooooooooooo003o00Gooooo00?o0000ooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00Wooooo00?o003oooooool00?l02oooool00ol00?oooooo
ooooo`1Qooooo`03o`000?oooooooooo007ooooo0003ooooo`?o00001?ooool2o`0000Gooooo00?o
0000ooooooooool0HOooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00gooooo00?o
003oooooooooool00oooool00ol0003oooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0
2oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo067ooooo00?o0000ooooooooool0
0Oooool000Cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00004ooooo`03o`00
0?oooooooooo067ooooo00?o003oooooooooool06_ooool00ol00?ooooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo00Go003oooooooooooooooooo`00o`1kooooo`03o`000?oooooooooo007o
oooo0004ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`1]ooooo`03o`00oooooooo003o00Wooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`02ooooo`03o`000?oooooooooo013ooooo00?o003oooooooooool0Koooool00ol0003o
ooooooooo`01ooooo`001?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Co
oooo0ol0001]ooooo`03o`00oooooooo003o00Wooooo00?o003oooooooooool01oooool00ol0003o
ooooooooo`07ooooo`03o`00oooooooooooo00Kooooo00?o003oooooool00?l02oooool00ol00?oo
ooooooooo`1Oooooo`?o00000oooool000Cooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00004ooooo`03o`000?oooooooooo067ooooo00?o003oooooooooool02Oooool00ol00?oo
ooooo`00o`09ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool01Ol0003o
oooooooooooooooo003o00Gooooo00?o003oooooooooool01_ooool00ol00?ooooooo`00o`0;oooo
o`03o`00oooooooooooo067ooooo00?o0000ooooooooool00Oooool000?ooooo0_l00004ooooo`04
o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0HOooool00ol00?ooooooooooo`09oooo
o`03o`00oooooooo003o00kooooo00?o003oooooooooool00_ooool01Ol0003ooooooooooooooooo
003o00Gooooo00?o003oooooooooool01_ooool00ol00?ooooooo`00o`0;ooooo`03o`00oooooooo
oooo067ooooo00?o0000ooooooooool00Oooool000Cooooo00?o0000ooooooooool00oooool2o`00
00Gooooo00?o0000ooooooooool0HOooool00ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo
00;ooooo00Go0000ooooooooooooooooo`00o`05ooooo`03o`00oooooooooooo01Cooooo00?o003o
ooooooooool0HOooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1Qoooo
o`03o`00oooooooooooo00_ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`03oooo
o`03o`00oooooooooooo00;ooooo00?o0000ooooooooool04?ooool00ol00?ooooooooooo`1_oooo
o`03o`000?oooooooooo007ooooo000Aooooo`;o0000K_ooool00ol00?ooooooo`00o`08ooooo`03
o`00oooooooooooo00Sooooo00?o0000ooooooooool04?ooool00ol00?ooooooo`00o`0;ooooo`03
o`00oooooooooooo063ooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`1Rooooo`03o`00
oooooooooooo00Sooooo00?o003oooooool00?l02?ooool00ol00?ooooooooooo`08ooooo`05o`00
0?ooooooooooooooool00?l01Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo003o00_o
oooo00?o003oooooooooool0HOooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooo
ooooo`1Rooooo`03o`00oooooooooooo00Sooooo00?o003oooooool00?l02?ooool00ol00?oooooo
ooooo`03ooooo`03o`00oooooooooooo00;ooooo00Go0000ooooooooooooooooo`00o`05ooooo`03
o`00oooooooooooo00Kooooo00Co003ooooooooooooo003o2_ooool00ol00?ooooooooooo`1Qoooo
o`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo06;ooooo00?o003ooooooooo
ool06Oooool00ol00?ooooooooooo`02ooooo`05o`000?ooooooooooooooool00?l01Oooool00ol0
0?ooooooooooo`0Dooooo`03o`00oooooooooooo067ooooo00?o0000ooooooooool00Oooool0017o
oooo0_l0001Sooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool00oooool00ol00?oo
ooooooooo`02ooooo`05o`000?ooooooooooooooool00?l0Ooooool2o`0000?ooooo000Aooooo`03
o`000?oooooooooo06cooooo00Go003oooooooooooooooooo`00o`07ooooo`03o`00oooooooooooo
00Sooooo00?o0000ooooooooool04?ooool01?l00?ooooooooooool00?m^ooooo`03o`000?oooooo
oooo007ooooo000Aooooo`03o`000?oooooooooo06cooooo00Go003oooooooooooooooooo`00o`07
ooooo`03o`00oooooooooooo00Sooooo00Go0000ooooooooooooooooo`00o`05ooooo`03o`00oooo
oooooooo00Kooooo00Co003ooooooooooooo003o2Oooool00ol00?ooooooooooo`1Rooooo`03o`00
0?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo06;ooooo00?o003oooooooooool01ooo
ool01Ol00?oooooooooooooooooo003o00Oooooo00?o003oooooooooool01?ooool01Ol00?oooooo
oooooooooooo000000?ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`05ooooo`05
o`00ooooooooooooooooool00?l02Oooool00ol00?ooooooooooo`1Rooooo`03o`000?oooooooooo
007ooooo000Aooooo`03o`000?oooooooooo06;ooooo00?o003oooooooooool01oooool00ol00?oo
ooooooooo`0@ooooo`05o`00ooooooooooooooooool000000_ooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00Wooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`1Roooo
o`03o`000?oooooooooo007ooooo000Aooooo`;o0000Hoooool00ol00?ooooooooooo`0Jooooo`05
o`00ooooooooooooooooool000000_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
07Oooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`1/ooooo`05o`00oooooooooooooooo
ool00?l01oooool00ol00?ooooooooooo`04ooooo`05o`00ooooooooooooooooool000004Oooool0
1Ol00?oooooooooooooooooo003o06kooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000
ooooooooool0K?ooool01Ol00?oooooooooooooooooo003o00Oooooo00?o003oooooooooool02?oo
ool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo00Cooooo00Go003ooooooooooooooooo
o`00o`09ooooo`03o`00oooooooooooo06;ooooo00?o0000ooooooooool00Oooool0017ooooo00?o
0000ooooooooool0H_ooool00ol00?ooooooooooo`07ooooo`05o`00ooooooooooooooooool00?l0
1_ooool00ol00?ooooooooooo`05ooooo`05o`00ooooooooooooooooool000000_ooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo00Cooooo00Go003oooooooooooooooooo`00o`09oooo
o`03o`00oooooooooooo06;ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooooooo
ool0H_ooool00ol00?ooooooooooo`07ooooo`05o`00ooooooooooooooooool00?l03_ooool01Ol0
0?oooooooooooooooooo000000;ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04
ooooo`05o`00ooooooooooooooooool00?l02Oooool00ol00?ooooooooooo`1Rooooo`03o`000?oo
oooooooo007ooooo000Aooooo`;o0000Hoooool00ol00?ooooooooooo`0Jooooo`05o`00oooooooo
ooooooooool000000_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01;ooooo00?o
003oooooooooool0HOooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo06;ooooo00?o003o
ooooooooool02oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00Go003o
ooooooooooooooooo`000024ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooo
oooo06cooooo00Go003oooooooooooooooooo`00o`06ooooo`03o`00oooooooooooo00Wooooo00?o
0000ooooooooool03oooool01Ol00?oooooooooooooooooo003o00Wooooo00?o003oooooooooool0
H_ooool00ol0003oooooooooo`01ooooo`000_ooool5o`0000?ooooo0_l00005ooooo`03o`000?oo
oooooooo06;ooooo00?o003oooooooooool01oooool01Ol00?oooooooooooooooooo003o00Kooooo
00?o003oooooooooool02Oooool01?l0003oooooooooool00?l7ooooo`03o`00oooooooooooo00Co
oooo00Go003oooooooooooooooooo`00o`09ooooo`03o`00oooooooooooo06;ooooo00?o0000oooo
ooooool00Oooool000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004
ooooo`03o`000?oooooooooo06;ooooo00?o003oooooooooool01oooool01Ol00?oooooooooooooo
oooo003o00Kooooo00?o003oooooooooool01Oooool01Ol00?oooooooooooooooooo000000;ooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`05o`00ooooooooooooooooool0
0?l02Oooool00ol00?ooooooooooo`1Rooooo`03o`000?oooooooooo007ooooo0004ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00001?ooool3o`0006;ooooo00?o003ooooooooo
ool06_ooool01Ol00?oooooooooooooooooo000000;ooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool0H?ooool3o`00
00?ooooo0005ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo06;ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`05oooo
o`05o`00ooooooooooooooooool00000Q?ooool00ol0003oooooooooo`01ooooo`000_ooool01Ol0
003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`1/ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`09ooooo`03o`000?oooooooooo00oooooo00Go003oooooooooooooooooo`00o`1^ooooo`03o`00
0?oooooooooo007ooooo0002ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooo
ooooool00004ooooo`03o`000?oooooooooo06cooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooooooo00Wooooo00Co0000oooooooooooo003o1oooool00ol0
0?ooooooooooo`04ooooo`05o`00ooooooooooooooooool00?l02Oooool00ol00?ooooooooooo`1R
ooooo`03o`000?oooooooooo007ooooo0003ooooo`?o00001?ooool2o`0000Gooooo00?o0000oooo
ooooool0H_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool00oooool00ol00?ooooooooooo`06ooooo`04o`00ooooooooooooo`0000;ooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool01oooool00ol00?ooooooooooo`1Rooooo`03o`000?oooooooooo007ooooo000Aoooo
o`;o0000Hoooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo017ooooo00Ko003ooooo
oooooooo0000ooooool00?l9ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo067ooooo0_l00003ooooo`004Oooool0
0ol0003oooooooooo`1Rooooo`03o`00oooooooooooo01_ooooo00Ko003ooooooooooooo0000oooo
ool00?l9ooooo`03o`00oooooooooooo07Kooooo00?o0000ooooooooool00Oooool0017ooooo00?o
0000ooooooooool0K?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool01_ooool01?l00?ooooooooooool0000Eooooo`03o`00oooooooooooo06cooooo
00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0K?ooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool02Oooool00ol0003oooooo`00
o`09ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`07ooooo`03o`00oooooooooooo06;ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000
ooooooooool0Hoooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`07ooooo`06o`00ooooooooooooo`000?oooooo003o
2Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`1Rooooo`03o`000?oooooooooo007ooooo000Aooooo`;o0000I?oo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool03?oo
ool01_l00?ooooooooooool0003oooooo`00o`Wooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0HOooool2o`0000?o
oooo000Aooooo`03o`000?oooooooooo06?ooooo00?o003oooooooooool06_ooool01_l00?oooooo
ooooool0003oooooo`00o`Wooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`1Roooo
o`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo06?ooooo00?o003ooooooooo
ool02oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Oooooo00Co003ooooooooo
oooo0000Q?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1/ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0:ooooo`03
o`000?oooooooooo00kooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`05ooooo`03
o`00oooooooooooo06?ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0
Hoooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`0:ooooo`03o`000?oooooo003o00Wooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
Hoooool00ol0003oooooooooo`01ooooo`004Oooool2o`0006Cooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01ooo
ool01_l00?ooooooooooool0003oooooo`00o`Wooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0H_ooool2o`0000?o
oooo000Aooooo`03o`000?oooooooooo06?ooooo00?o003oooooooooool06_ooool01_l00?oooooo
ooooool0003oooooo`00o`Wooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0;oooo
o`03o`00oooooooooooo06?ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooooooo
ool0Hoooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00Sooooo00?o003oooooool0
0000Q?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1[ooooo`03o`00
oooooooooooo00Cooooo00Go003oooooooooooooooooo`00o`0<ooooo`03o`000?oooooooooo00go
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`1[ooooo`03o`000?oooooooooo007o
oooo000Aooooo`;o0000K?ooool00ol00?ooooooooooo`04ooooo`04o`00ooooooooooooo`00o`go
oooo00?o0000o`00ooooool02_ooool01?l00?ooooooooooool00?l6ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool0H_ooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo06?o
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`04o`00ooooooooooooo`00
o`_ooooo00Co003oooooool0003o003o2oooool01?l00?ooooooooooool00?l6ooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool0Hoooool00ol0003oooooooooo`01ooooo`004Oooool0
0ol0003oooooooooo`1Sooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool04oooool0
1?l00?ooooooo`000?l00?l;ooooo`04o`00ooooooooooooo`00o`Kooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`1Sooooo`03o`000?oooooooooo007ooooo0003ooooo`?o00001?oo
ool2o`0000Gooooo00?o0000ooooooooool0Hoooool00ol00?ooooooooooo`0?ooooo`03o`00oooo
oooooooo00Wooooo00Co003oooooool0003o003o2oooool00ol00?ooooooooooo`1eooooo`03o`00
0?oooooooooo007ooooo0002ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooo
ooooool00004ooooo`03o`000?oooooooooo06_ooooo00?o003oooooooooool01?ooool01?l00?oo
ooooooooool00?l;ooooo`03o`00oooooooo000001Kooooo00?o003oooooooooool0Joooool00ol0
003oooooooooo`01ooooo`001_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo
00;ooooo0ol0001[ooooo`03o`00oooooooooooo00Cooooo00Co003ooooooooooooo003o3Oooool0
0ol0003o003oooooo`0:ooooo`04o`00ooooooooooooo`00o`Kooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`1Qooooo`?o00000oooool000Cooooo0_l00003ooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool0Hoooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooool00?l02oooool01?l00?ooooooo`000?l00?l;ooooo`04o`00
ooooooooooooo`00o`Kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`1Sooooo`03
o`000?oooooooooo007ooooo0006ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`1Sooooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool04oooool01?l00?ooooooo`000?l00?l;ooooo`04o`00ooooooooooooo`00o`Kooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`1Sooooo`03o`000?oooooooooo007ooooo0002oooo
o`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00004ooooo`03o`000?oo
oooooooo06?ooooo00?o003oooooooooool06oooool01?l00?ooooooo`000?l00?l;ooooo`03o`00
oooooooooooo00oooooo00?o003oooooooooool0Hoooool00ol0003oooooooooo`01ooooo`000ooo
ool3o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo06?ooooo00?o003oooooooooool03Ooo
ool00ol00?ooooooo`00o`0<ooooo`03o`00ool0003ooooo08?ooooo00?o0000ooooooooool00Ooo
ool0017ooooo0_l0001/ooooo`03o`00oooooooooooo00Gooooo0_l00?l>ooooo`03o`000?oooooo
oooo00_ooooo0_l00?l7ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0H_ooool2
o`0000?ooooo000Aooooo`03o`000?oooooooooo06?ooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo00_ooooo0_l00?l=ooooo`;o003o1oooool00ol0
0?ooooooooooo`1[ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo06?o
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Dooooo`;o003o5_ooool00ol00?oo
ooooooooo`1[ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo06?ooooo
00?o003oooooooooool07Oooool00ol0003oooooooooo`0Looooo`03o`00oooooooooooo06?ooooo
00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0Hoooool00ol00?oooooooooo
o`0Mooooo`03o`000?oooooooooo01cooooo00?o003oooooooooool0Hoooool00ol0003ooooooooo
o`01ooooo`004Oooool2o`0006cooooo00?o003oooooooooool05Oooool00ol0003oooooooooo`0D
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0H_ooool2o`0000?ooooo000Aoooo
o`03o`000?oooooooooo06_ooooo00?o003oooooooooool05Oooool00ol0003oooooooooo`0Doooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool0Hoooool00ol0003oooooooooo`01oooo
o`004Oooool00ol0003oooooooooo`1Sooooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool05Oooool00ol0003oooooooooo`0Dooooo`03o`00oooooooooooo06_ooooo00?o0000oooooooo
ool00Oooool0017ooooo00?o0000ooooooooool0Hoooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo01Gooooo00?o0000ooooooooool05?ooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo06?ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0I?oo
ool00ol00?ooooooooooo`0Looooo`03o`000?oooooooooo01cooooo00?o003oooooooooool0Hooo
ool00ol0003oooooooooo`01ooooo`004Oooool2o`0006cooooo00?o003oooooooooool05Oooool0
0ol0003oooooooooo`0Eooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0H_ooool2
o`0000?ooooo000Aooooo`03o`000?oooooooooo06_ooooo00?o003oooooooooool05Oooool00ol0
003oooooooooo`0Eooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0Hoooool00ol0
003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1Tooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool05Oooool00ol0003oooooooooo`0Eooooo`03o`00oooooooooooo06[o
oooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0I?ooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo01Gooooo00?o0000ooooooooool05Oooool00ol00?oooooo
ooooo`03ooooo`03o`00oooooooooooo06Cooooo00?o0000ooooooooool00Oooool0017ooooo00?o
0000ooooooooool0I?ooool00ol00?ooooooooooo`0Looooo`03o`000?oooooooooo01_ooooo00?o
003oooooooooool0I?ooool00ol0003oooooooooo`01ooooo`004Oooool2o`0006Gooooo00?o003o
ooooooooool07?ooool00ol0003oooooooooo`0Kooooo`03o`00oooooooooooo06?ooooo0_l00003
ooooo`004Oooool00ol0003oooooooooo`1Zooooo`03o`00oooooooooooo01Kooooo00?o0000oooo
ooooool05Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo06Cooooo00?o0000oooo
ooooool00Oooool000Cooooo0ol00003ooooo`;o00001Oooool00ol0003oooooooooo`1Tooooo`03
o`00oooooooooooo00?ooooo00?o003oooooooooool05_ooool00ol0003oooooooooo`0Eooooo`03
o`00oooooooooooo06[ooooo00?o0000ooooooooool00Oooool000Gooooo00Go0000oooooooooooo
ooooo`000002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0I?ooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooooooo01Kooooo00?o0000ooooooooool05Oooool00ol00?oo
ooooooooo`1Zooooo`03o`000?oooooooooo007ooooo0002ooooo`Go00000_ooool01?l0003ooooo
ooooool00004ooooo`?o0000I?ooool00ol00?ooooooooooo`0Looooo`03o`000?oooooooooo01_o
oooo00?o003oooooooooool0H_ooool3o`0000?ooooo0002ooooo`04o`000?ooooooooooo`0000?o
oooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1Tooooo`03o`00oooooooooooo
01cooooo00?o0000ooooooooool06oooool00ol00?ooooooooooo`1Tooooo`03o`000?oooooooooo
007ooooo0003ooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooo00001?ooool00ol0
003oooooooooo`1Zooooo`03o`00oooooooooooo01Kooooo00?o0000ooooooooool05Oooool00ol0
0?ooooooooooo`03ooooo`03o`00oooooooooooo06Cooooo00?o0000ooooooooool00Oooool000Co
oooo0_l00003ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0J_ooool00ol0
0?ooooooooooo`0Fooooo`03o`000?oooooooooo01Gooooo00?o003oooooooooool0J_ooool00ol0
003oooooooooo`01ooooo`001Oooool00ol0003oooooooooo`02ooooo`;o00001Oooool00ol0003o
ooooooooo`1Tooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool05_ooool00ol0003o
ooooooooo`0Eooooo`03o`00oooooooooooo06[ooooo00?o0000ooooooooool00Oooool0017ooooo
0_l0001Uooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool05_ooool00ol0003ooooo
ooooo`0Eooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0Hoooool2o`0000?ooooo
000Aooooo`03o`000?oooooooooo06Cooooo00?o003oooooooooool07?ooool00ol0003ooooooooo
o`0Kooooo`03o`00oooooooooooo06Cooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000
ooooooooool0J_ooool00ol00?ooooooooooo`0Fooooo`03o`000?oooooooooo01Gooooo00?o003o
ooooooooool00oooool00ol00?ooooooooooo`1Tooooo`03o`000?oooooooooo007ooooo000Aoooo
o`03o`000?oooooooooo06[ooooo00?o003oooooooooool05_ooool00ol0003oooooooooo`0Eoooo
o`03o`00oooooooooooo00?ooooo00?o003oooooooooool0I?ooool00ol0003oooooooooo`01oooo
o`004Oooool00ol0003oooooooooo`1Tooooo`03o`00oooooooooooo00?ooooo00?o003ooooooooo
ool05_ooool00ol0003oooooooooo`0Eooooo`03o`00oooooooooooo06[ooooo00?o0000oooooooo
ool00Oooool0017ooooo0_l0001Uooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0
5_ooool00ol0003oooooooooo`0Eooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0
Hoooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo06Cooooo00?o003oooooooooool07?oo
ool00ol0003oooooooooo`0Kooooo`03o`00oooooooooooo06Cooooo00?o0000ooooooooool00Ooo
ool0017ooooo00?o0000ooooooooool0I?ooool00ol00?ooooooooooo`0Looooo`03o`000?oooooo
oooo01_ooooo00?o003oooooooooool0I?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0
003oooooooooo`1Zooooo`03o`00oooooooooooo01Kooooo00?o0000ooooooooool05Oooool00ol0
0?ooooooooooo`03ooooo`03o`00oooooooooooo06Cooooo00?o0000ooooooooool00Oooool0017o
oooo00?o0000ooooooooool0I?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo01Ko
oooo00?o0000ooooooooool05Oooool00ol00?ooooooooooo`1Zooooo`03o`000?oooooooooo007o
oooo000Aooooo`;o0000IOooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo01Kooooo
00?o0000ooooooooool05Oooool00ol00?ooooooooooo`1Yooooo`;o00000oooool0017ooooo00?o
0000ooooooooool0I?ooool00ol00?ooooooooooo`0Looooo`03o`000?oooooooooo01_ooooo00?o
003oooooooooool0I?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1T
ooooo`03o`00oooooooooooo01cooooo00?o0000ooooooooool06oooool00ol00?ooooooooooo`1T
ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo06[ooooo00?o003ooooo
ooooool05_ooool00ol0003oooooooooo`0Eooooo`03o`00oooooooooooo00?ooooo00?o003ooooo
ooooool0I?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1Zooooo`03
o`00oooooooooooo01Kooooo00?o0000ooooooooool05Oooool00ol00?ooooooooooo`1Zooooo`03
o`000?oooooooooo007ooooo000Aooooo`;o0000IOooool00ol00?ooooooooooo`03ooooo`03o`00
oooooooooooo01Kooooo00?o0000ooooooooool05_ooool00ol00?ooooooooooo`1Xooooo`;o0000
0oooool0017ooooo00?o0000ooooooooool0I?ooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooooooo01Kooooo00?o0000ooooooooool05_ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo06Cooooo00?o0000ooooooooool00Oooool000?ooooo0ol00004ooooo`;o00001Oooool0
0ol0003oooooooooo`1Uooooo`03o`00oooooooooooo01_ooooo00?o0000ooooooooool06oooool0
0ol00?ooooooooooo`1Tooooo`03o`000?oooooooooo007ooooo0002ooooo`05o`000?oooooooooo
ooooool000000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo06[ooooo00?o
003oooooooooool05_ooool00ol0003oooooooooo`0Fooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool0I?ooool00ol0003oooooooooo`01ooooo`001_ooool01?l0003oooooooooool0
0002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0J_ooool00ol00?oooooooooo
o`0Fooooo`03o`000?oooooooooo01Kooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`1Tooooo`03o`000?oooooooooo007ooooo0006ooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooooooool00_ooool3o`0006Gooooo00Go003oooooooooooooooooo`00o`0Iooooo`03o`00
0?oooooooooo01Kooooo00?o003oooooooooool0Ioooool3o`0000?ooooo0002ooooo`Co00000ooo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo06Gooooo00Go003ooooooooooooo
ooooo`00o`0Iooooo`03o`000?oooooooooo01Kooooo00Go003oooooooooooooooooo`00o`1Woooo
o`03o`000?oooooooooo007ooooo0002ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooo
oooo00001?ooool00ol0003oooooooooo`1Uooooo`03o`00oooooooooooo01_ooooo00?o0000oooo
ooooool06_ooool00ol00?ooooooooooo`1Uooooo`03o`000?oooooooooo007ooooo0002ooooo`Go
00000oooool2o`0000Gooooo00?o0000ooooooooool0IOooool00ol00?ooooooooooo`0Kooooo`03
o`000?oooooooooo01[ooooo00?o003oooooooooool0IOooool00ol0003oooooooooo`01ooooo`00
4Oooool2o`0006[ooooo00?o003oooooooooool05oooool00ol0003oooooooooo`0Fooooo`05o`00
ooooooooooooooooool00?l0I_ooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo06Gooooo
00Go003oooooooooooooooooo`00o`0Iooooo`03o`000?oooooooooo01Kooooo00?o003ooooooooo
ool0JOooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1Uooooo`05o`00
ooooooooooooooooool00?l06Oooool00ol0003oooooooooo`0Fooooo`03o`00oooooooooooo06Wo
oooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0IOooool00ol00?oooooo
ooooo`0Kooooo`03o`000?oooooooooo01[ooooo00?o003oooooooooool0IOooool00ol0003ooooo
ooooo`01ooooo`004Oooool00ol0003oooooooooo`1Uooooo`03o`00oooooooooooo01_ooooo00?o
0000ooooooooool06_ooool00ol00?ooooooooooo`1Uooooo`03o`000?oooooooooo007ooooo000A
ooooo`;o0000J_ooool00ol00?ooooooooooo`0Gooooo`03o`000?oooooooooo01Kooooo00Go003o
ooooooooooooooooo`00o`1Vooooo`;o00000oooool0017ooooo00?o0000ooooooooool0JOooool0
0ol00?ooooooooooo`0Gooooo`03o`000?oooooooooo01Kooooo00?o003oooooooooool0JOooool0
0ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1Uooooo`05o`00oooooooooooo
ooooool00?l06Oooool00ol0003oooooooooo`0Fooooo`03o`00oooooooooooo06Wooooo00?o0000
ooooooooool00Oooool0017ooooo00?o0000ooooooooool0IOooool01Ol00?oooooooooooooooooo
003o01Wooooo00?o0000ooooooooool05_ooool01Ol00?oooooooooooooooooo003o06Oooooo00?o
0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0IOooool00ol00?ooooooooooo`0K
ooooo`03o`000?oooooooooo01[ooooo00?o003oooooooooool0IOooool00ol0003oooooooooo`01
ooooo`004Oooool2o`0006[ooooo00?o003oooooooooool05oooool00ol0003oooooooooo`0Foooo
o`05o`00ooooooooooooooooool00?l0I_ooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo
06Wooooo00?o003oooooooooool05oooool00ol0003oooooooooo`0Fooooo`05o`00oooooooooooo
ooooool00?l0Ioooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1Uoooo
o`05o`00ooooooooooooooooool00?l06Oooool00ol0003oooooooooo`0Fooooo`03o`00oooooooo
oooo06Wooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0IOooool01Ol0
0?oooooooooooooooooo003o01Wooooo00?o0000ooooooooool05_ooool01Ol00?oooooooooooooo
oooo003o06Oooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0IOooool0
0ol00?ooooooooooo`0Kooooo`03o`000?oooooooooo01[ooooo00?o003oooooooooool0IOooool0
0ol0003oooooooooo`01ooooo`004Oooool2o`0006Kooooo00?o003oooooooooool06oooool00ol0
003oooooooooo`0Jooooo`03o`00oooooooooooo06Cooooo0_l00003ooooo`004Oooool00ol0003o
ooooooooo`1Yooooo`03o`00oooooooooooo01Oooooo00?o0000ooooooooool05oooool01?l00?oo
ooooooooool00?mWooooo`03o`000?oooooooooo007ooooo0003ooooo`?o00001?ooool2o`0000Go
oooo00?o0000ooooooooool0I_ooool01?l00?ooooooooooool00?lIooooo`03o`000?oooooooooo
01Oooooo00?o003oooooooooool0J?ooool00ol0003oooooooooo`01ooooo`000_ooool01Ol0003o
oooooooooooooooo000000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1V
ooooo`03o`00oooooooo003o01[ooooo00?o0000ooooooooool05oooool00ol00?ooooooooooo`1X
ooooo`03o`000?oooooooooo007ooooo0002ooooo`05o`000?ooooooooooooooool000000_ooool0
1?l0003oooooooooool00004ooooo`03o`000?oooooooooo06Kooooo00?o003oooooooooool06_oo
ool00ol0003oooooooooo`0Iooooo`03o`00oooooooooooo06Kooooo00?o0000ooooooooool00Ooo
ool000;ooooo1?l00003ooooo`04o`000?ooooooooooo`0000Cooooo0ol0001Vooooo`03o`00oooo
oooooooo01[ooooo00?o0000ooooooooool06Oooool00ol00?ooooooooooo`1Tooooo`?o00000ooo
ool000;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00004ooooo`03o`000?oo
oooooooo06Sooooo00?o003oooooooooool06?ooool00ol0003oooooooooo`0Gooooo`03o`00oooo
oooo003o06Sooooo00?o0000ooooooooool00Oooool000?ooooo00?o0000ooooooooool00oooool0
1?l0003oooooooooool00004ooooo`03o`000?oooooooooo06Kooooo00?o003oooooool00?l06_oo
ool00ol0003oooooooooo`0Gooooo`03o`00oooooooooooo06Sooooo00?o0000ooooooooool00Ooo
ool000Cooooo0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`1Vooooo`03o`00oooooooo
003o01[ooooo00?o0000ooooooooool05oooool00ol00?ooooooooooo`1Xooooo`03o`000?oooooo
oooo007ooooo000Aooooo`03o`000?oooooooooo06Kooooo00?o003oooooool00?l06_ooool00ol0
003oooooooooo`0Gooooo`03o`00oooooooo003o06Sooooo00?o0000ooooooooool00Oooool0017o
oooo0_l0001Wooooo`03o`00oooooooooooo01[ooooo00?o0000ooooooooool06Oooool00ol00?oo
ooooooooo`1Uooooo`;o00000oooool0017ooooo00?o0000ooooooooool0I_ooool00ol00?oooooo
o`00o`0Jooooo`03o`000?oooooooooo01Oooooo00?o003oooooool00?l0J?ooool00ol0003ooooo
ooooo`01ooooo`004Oooool00ol0003oooooooooo`1Vooooo`03o`00oooooooo003o01[ooooo00?o
0000ooooooooool05oooool00ol00?ooooooo`00o`1Xooooo`03o`000?oooooooooo007ooooo000A
ooooo`03o`000?oooooooooo06Sooooo00?o003oooooooooool06?ooool00ol0003oooooooooo`0G
ooooo`03o`00oooooooooooo06Sooooo00?o0000ooooooooool00Oooool0017ooooo0_l0001Woooo
o`03o`00oooooooo003o01[ooooo00?o0000ooooooooool05oooool00ol00?ooooooo`00o`1Woooo
o`;o00000oooool0017ooooo00?o0000ooooooooool0Ioooool00ol00?ooooooooooo`0Iooooo`03
o`000?oooooooooo01Wooooo00?o003oooooooooool0I_ooool00ol0003oooooooooo`01ooooo`00
4Oooool00ol0003oooooooooo`1Wooooo`03o`00oooooooooooo01Wooooo00?o0000ooooooooool0
6?ooool00ol00?ooooooooooo`1Wooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oo
oooooooo06Oooooo00?o003oooooooooool06Oooool00ol0003oooooooooo`0Hooooo`03o`00oooo
oooooooo06Oooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0Poooool0
0ol0003oooooooooo`22ooooo`03o`000?oooooooooo007ooooo000Aooooo`;o00001Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool2o`00
00?ooooo000Aoooooooo00003Ol00003ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-11.9139, -6.64438, \
0.0788464, 0.413451}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Magnitude plot of DFT as a function of frequency", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(fft\  = \ DFT[xdc];\)\), "\n", 
    \(\(g3 = 
        DiscreteListPlot[\({#[\([1]\)], \ Abs[#[\([2]\)]]} &\)\  /@ \ fft, 
          Red, \ PlotRange \[Rule] All, \ Frame \[Rule] True, \ 
          Axes \[Rule] False];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0161421 0.0147151 0.0110062 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18523 -0.0125 -6 -9 ]
[.18523 -0.0125 6 0 ]
[.34665 -0.0125 -6 -9 ]
[.34665 -0.0125 6 0 ]
[.50807 -0.0125 -6 -9 ]
[.50807 -0.0125 6 0 ]
[.66949 -0.0125 -6 -9 ]
[.66949 -0.0125 6 0 ]
[.83091 -0.0125 -6 -9 ]
[.83091 -0.0125 6 0 ]
[.99233 -0.0125 -6 -9 ]
[.99233 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .12478 -12 -4.5 ]
[-0.0125 .12478 0 4.5 ]
[-0.0125 .23484 -12 -4.5 ]
[-0.0125 .23484 0 4.5 ]
[-0.0125 .3449 -12 -4.5 ]
[-0.0125 .3449 0 4.5 ]
[-0.0125 .45496 -12 -4.5 ]
[-0.0125 .45496 0 4.5 ]
[-0.0125 .56503 -12 -4.5 ]
[-0.0125 .56503 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18523 0 m
.18523 .00625 L
s
[(10)] .18523 -0.0125 0 1 Mshowa
.34665 0 m
.34665 .00625 L
s
[(20)] .34665 -0.0125 0 1 Mshowa
.50807 0 m
.50807 .00625 L
s
[(30)] .50807 -0.0125 0 1 Mshowa
.66949 0 m
.66949 .00625 L
s
[(40)] .66949 -0.0125 0 1 Mshowa
.83091 0 m
.83091 .00625 L
s
[(50)] .83091 -0.0125 0 1 Mshowa
.99233 0 m
.99233 .00625 L
s
[(60)] .99233 -0.0125 0 1 Mshowa
.125 Mabswid
.05609 0 m
.05609 .00375 L
s
.08838 0 m
.08838 .00375 L
s
.12066 0 m
.12066 .00375 L
s
.15295 0 m
.15295 .00375 L
s
.21751 0 m
.21751 .00375 L
s
.2498 0 m
.2498 .00375 L
s
.28208 0 m
.28208 .00375 L
s
.31437 0 m
.31437 .00375 L
s
.37893 0 m
.37893 .00375 L
s
.41122 0 m
.41122 .00375 L
s
.4435 0 m
.4435 .00375 L
s
.47579 0 m
.47579 .00375 L
s
.54036 0 m
.54036 .00375 L
s
.57264 0 m
.57264 .00375 L
s
.60492 0 m
.60492 .00375 L
s
.63721 0 m
.63721 .00375 L
s
.70178 0 m
.70178 .00375 L
s
.73406 0 m
.73406 .00375 L
s
.76634 0 m
.76634 .00375 L
s
.79863 0 m
.79863 .00375 L
s
.8632 0 m
.8632 .00375 L
s
.89548 0 m
.89548 .00375 L
s
.92776 0 m
.92776 .00375 L
s
.96005 0 m
.96005 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .12478 m
.00625 .12478 L
s
[(10)] -0.0125 .12478 1 0 Mshowa
0 .23484 m
.00625 .23484 L
s
[(20)] -0.0125 .23484 1 0 Mshowa
0 .3449 m
.00625 .3449 L
s
[(30)] -0.0125 .3449 1 0 Mshowa
0 .45496 m
.00625 .45496 L
s
[(40)] -0.0125 .45496 1 0 Mshowa
0 .56503 m
.00625 .56503 L
s
[(50)] -0.0125 .56503 1 0 Mshowa
.125 Mabswid
0 .03673 m
.00375 .03673 L
s
0 .05874 m
.00375 .05874 L
s
0 .08075 m
.00375 .08075 L
s
0 .10276 m
.00375 .10276 L
s
0 .14679 m
.00375 .14679 L
s
0 .1688 m
.00375 .1688 L
s
0 .19081 m
.00375 .19081 L
s
0 .21283 m
.00375 .21283 L
s
0 .25685 m
.00375 .25685 L
s
0 .27886 m
.00375 .27886 L
s
0 .30088 m
.00375 .30088 L
s
0 .32289 m
.00375 .32289 L
s
0 .36691 m
.00375 .36691 L
s
0 .38893 m
.00375 .38893 L
s
0 .41094 m
.00375 .41094 L
s
0 .43295 m
.00375 .43295 L
s
0 .47698 m
.00375 .47698 L
s
0 .49899 m
.00375 .49899 L
s
0 .521 m
.00375 .521 L
s
0 .54301 m
.00375 .54301 L
s
0 .58704 m
.00375 .58704 L
s
0 .60905 m
.00375 .60905 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.18523 .61178 m
.18523 .61803 L
s
.34665 .61178 m
.34665 .61803 L
s
.50807 .61178 m
.50807 .61803 L
s
.66949 .61178 m
.66949 .61803 L
s
.83091 .61178 m
.83091 .61803 L
s
.99233 .61178 m
.99233 .61803 L
s
.125 Mabswid
.05609 .61428 m
.05609 .61803 L
s
.08838 .61428 m
.08838 .61803 L
s
.12066 .61428 m
.12066 .61803 L
s
.15295 .61428 m
.15295 .61803 L
s
.21751 .61428 m
.21751 .61803 L
s
.2498 .61428 m
.2498 .61803 L
s
.28208 .61428 m
.28208 .61803 L
s
.31437 .61428 m
.31437 .61803 L
s
.37893 .61428 m
.37893 .61803 L
s
.41122 .61428 m
.41122 .61803 L
s
.4435 .61428 m
.4435 .61803 L
s
.47579 .61428 m
.47579 .61803 L
s
.54036 .61428 m
.54036 .61803 L
s
.57264 .61428 m
.57264 .61803 L
s
.60492 .61428 m
.60492 .61803 L
s
.63721 .61428 m
.63721 .61803 L
s
.70178 .61428 m
.70178 .61803 L
s
.73406 .61428 m
.73406 .61803 L
s
.76634 .61428 m
.76634 .61803 L
s
.79863 .61428 m
.79863 .61803 L
s
.8632 .61428 m
.8632 .61803 L
s
.89548 .61428 m
.89548 .61803 L
s
.92776 .61428 m
.92776 .61803 L
s
.96005 .61428 m
.96005 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .12478 m
1 .12478 L
s
.99375 .23484 m
1 .23484 L
s
.99375 .3449 m
1 .3449 L
s
.99375 .45496 m
1 .45496 L
s
.99375 .56503 m
1 .56503 L
s
.125 Mabswid
.99625 .03673 m
1 .03673 L
s
.99625 .05874 m
1 .05874 L
s
.99625 .08075 m
1 .08075 L
s
.99625 .10276 m
1 .10276 L
s
.99625 .14679 m
1 .14679 L
s
.99625 .1688 m
1 .1688 L
s
.99625 .19081 m
1 .19081 L
s
.99625 .21283 m
1 .21283 L
s
.99625 .25685 m
1 .25685 L
s
.99625 .27886 m
1 .27886 L
s
.99625 .30088 m
1 .30088 L
s
.99625 .32289 m
1 .32289 L
s
.99625 .36691 m
1 .36691 L
s
.99625 .38893 m
1 .38893 L
s
.99625 .41094 m
1 .41094 L
s
.99625 .43295 m
1 .43295 L
s
.99625 .47698 m
1 .47698 L
s
.99625 .49899 m
1 .49899 L
s
.99625 .521 m
1 .521 L
s
.99625 .54301 m
1 .54301 L
s
.99625 .58704 m
1 .58704 L
s
.99625 .60905 m
1 .60905 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .01472 m
.02381 .3766 L
s
.03995 .01472 m
.03995 .16134 L
s
.05609 .01472 m
.05609 .05608 L
s
.07224 .01472 m
.07224 .30568 L
s
.08838 .01472 m
.08838 .31219 L
s
.10452 .01472 m
.10452 .05953 L
s
.12066 .01472 m
.12066 .59466 L
s
.1368 .01472 m
.1368 .60332 L
s
.15295 .01472 m
.15295 .0901 L
s
.16909 .01472 m
.16909 .02118 L
s
.18523 .01472 m
.18523 .0253 L
s
.20137 .01472 m
.20137 .02533 L
s
.21751 .01472 m
.21751 .02466 L
s
.23366 .01472 m
.23366 .02393 L
s
.2498 .01472 m
.2498 .02327 L
s
.26594 .01472 m
.26594 .02271 L
s
.28208 .01472 m
.28208 .02224 L
s
.29822 .01472 m
.29822 .02184 L
s
.31437 .01472 m
.31437 .0215 L
s
.33051 .01472 m
.33051 .02121 L
s
.34665 .01472 m
.34665 .02097 L
s
.36279 .01472 m
.36279 .02076 L
s
.37893 .01472 m
.37893 .02058 L
s
.39508 .01472 m
.39508 .02044 L
s
.41122 .01472 m
.41122 .02031 L
s
.42736 .01472 m
.42736 .02021 L
s
.4435 .01472 m
.4435 .02013 L
s
.45964 .01472 m
.45964 .02007 L
s
.47579 .01472 m
.47579 .02003 L
s
.49193 .01472 m
.49193 .02001 L
s
.50807 .01472 m
.50807 .02 L
s
.52421 .01472 m
.52421 .02001 L
s
.54036 .01472 m
.54036 .02003 L
s
.5565 .01472 m
.5565 .02007 L
s
.57264 .01472 m
.57264 .02013 L
s
.58878 .01472 m
.58878 .02021 L
s
.60492 .01472 m
.60492 .02031 L
s
.62107 .01472 m
.62107 .02044 L
s
.63721 .01472 m
.63721 .02058 L
s
.65335 .01472 m
.65335 .02076 L
s
.66949 .01472 m
.66949 .02097 L
s
.68563 .01472 m
.68563 .02121 L
s
.70178 .01472 m
.70178 .0215 L
s
.71792 .01472 m
.71792 .02184 L
s
.73406 .01472 m
.73406 .02224 L
s
.7502 .01472 m
.7502 .02271 L
s
.76634 .01472 m
.76634 .02327 L
s
.78249 .01472 m
.78249 .02393 L
s
.79863 .01472 m
.79863 .02466 L
s
.81477 .01472 m
.81477 .02533 L
s
.83091 .01472 m
.83091 .0253 L
s
.84705 .01472 m
.84705 .02118 L
s
.8632 .01472 m
.8632 .0901 L
s
.87934 .01472 m
.87934 .60332 L
s
.89548 .01472 m
.89548 .59466 L
s
.91162 .01472 m
.91162 .05953 L
s
.92776 .01472 m
.92776 .31219 L
s
.94391 .01472 m
.94391 .30568 L
s
.96005 .01472 m
.96005 .05608 L
s
.97619 .01472 m
.97619 .16134 L
s
.015 w
.02381 .3766 Mdot
.03995 .16134 Mdot
.05609 .05608 Mdot
.07224 .30568 Mdot
.08838 .31219 Mdot
.10452 .05953 Mdot
.12066 .59466 Mdot
.1368 .60332 Mdot
.15295 .0901 Mdot
.16909 .02118 Mdot
.18523 .0253 Mdot
.20137 .02533 Mdot
.21751 .02466 Mdot
.23366 .02393 Mdot
.2498 .02327 Mdot
.26594 .02271 Mdot
.28208 .02224 Mdot
.29822 .02184 Mdot
.31437 .0215 Mdot
.33051 .02121 Mdot
.34665 .02097 Mdot
.36279 .02076 Mdot
.37893 .02058 Mdot
.39508 .02044 Mdot
.41122 .02031 Mdot
.42736 .02021 Mdot
.4435 .02013 Mdot
.45964 .02007 Mdot
.47579 .02003 Mdot
.49193 .02001 Mdot
.50807 .02 Mdot
.52421 .02001 Mdot
.54036 .02003 Mdot
.5565 .02007 Mdot
.57264 .02013 Mdot
.58878 .02021 Mdot
.60492 .02031 Mdot
.62107 .02044 Mdot
.63721 .02058 Mdot
.65335 .02076 Mdot
.66949 .02097 Mdot
.68563 .02121 Mdot
.70178 .0215 Mdot
.71792 .02184 Mdot
.73406 .02224 Mdot
.7502 .02271 Mdot
.76634 .02327 Mdot
.78249 .02393 Mdot
.79863 .02466 Mdot
.81477 .02533 Mdot
.83091 .0253 Mdot
.84705 .02118 Mdot
.8632 .0901 Mdot
.87934 .60332 Mdot
.89548 .59466 Mdot
.91162 .05953 Mdot
.92776 .31219 Mdot
.94391 .30568 Mdot
.96005 .05608 Mdot
.97619 .16134 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`005Oooool2o`0002Gooooo0ol00004ooooo`;o00008Oooool5o`0000?ooooo0_l0000Roooo
o`?o00001?ooool2o`0002?ooooo0ol00003ooooo`;o00008_ooool3o`0000Cooooo0_l0000Roooo
o`?o00001?ooool2o`0000Cooooo000Dooooo`04o`000?ooooooooooo`0002Gooooo00?o0000oooo
ooooool00_ooool01?l0003oooooooooool0000Qooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00008?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooo
oooo00008oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool07_ooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00008?ooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00000oooool001Cooooo00Co0000oooooooo
oooo00009Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0002;ooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool0000Tooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooooooool07_ooool5o`0000;ooooo00Co0000oooooooooooo00009?ooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo01kooooo00Go0000ooooooooooooooooo`000002
ooooo`04o`000?ooooooooooo`0000?ooooo000Dooooo`04o`000?ooooooooooo`0002Gooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool0000Sooooo`05o`000?ooooooooooooooool0
00000_ooool00ol0003oooooooooo`0Pooooo`;o00000oooool01?l0003oooooooooool0000Poooo
o`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00009?ooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooooooo01kooooo1?l00003ooooo`04o`000?ooooooooooo`0000?o
oooo000Dooooo`04o`000?ooooooooooo`0002Gooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool0000Pooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0
000Tooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool07oooool00ol0003ooooo
o`000003ooooo`04o`000?ooooooooooo`00023ooooo1?l00003ooooo`04o`000?ooooooooooo`00
023ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00003ooooo`005?ooool01?l0
003oooooooooool0000Tooooo`;o00001?ooool01?l0003oooooooooool0000Pooooo`05o`000?oo
ooooooooooooool000000_ooool01?l0003oooooooooool0000Pooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool0000Rooooo`;o00000oooool01?l0003oooooooooool0
000Pooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00008Oooool00ol0003ooooo
ooooo`03ooooo`04o`000?ooooooooooo`0000?ooooo000Eooooo`;o00009_ooool00ol0003ooooo
ooooo`03ooooo`;o00008_ooool3o`0000Cooooo0_l0000Rooooo`?o00001?ooool2o`0002Cooooo
00?o0000ooooooooool00_ooool2o`00027ooooo1Ol00003ooooo`;o00008oooool2o`0000Cooooo
0_l00004ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00
4?ooooooo`0000co00001Oooool000Sooooo0_l00006ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooool000001Oooool000Oooooo00Co0000oooooooooooo00001Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooo000000Gooooo0007ooooo`04o`000?ooooooooooo`0000Gooooo00?o
0000ooooooooool0ooooool8ooooo`03o`000?oooooooooo00?ooooo0007ooooo`04o`000?oooooo
ooooo`0000Gooooo0_l00004ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003ooooo
ooooo`02ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ooooo`05
ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooo
oooooooo00000oooool01Ooo003oooooooooooooooooo`0000Cooooo00Goo`00oooooooooooooooo
ool00003ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003ooooo`03
ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooo
oooooooo00001?ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_oo
ool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_ooool01Ooo003ooooo
ooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00004ooooo`05ool00?oooooooooo
oooooooo00000oooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00000ooo
ool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooo
ooooooooooooo`0000Cooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo
00;ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00Goo`00
ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00001?ooool01Ooo003ooooo
ooooooooooooo`0000?ooooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`00
00?ooooo00?oo`00ooooooooool00_ooool01?oo003oooooooooooooool3o`0000Gooooo0007oooo
o`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00oooool01Ooo003ooooooooooooo
ooooo`0000?ooooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000?ooooo
00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00oooooooo
ool00ooo0003ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02oooo
o`05ool00?oooooooooooooooooo00000_ooool3ool00004oooooooo003oo`00ool000;ooooo0ooo
00001Oooooooo`00ool00?oo003ooooo00?oo`0000Coooooool00?oo003oo`000_ooool3ool00005
oooooooo003oo`00ool00?ooool00ooo0002ooooo`?oo`0000Goooooool00?oo003oo`00ooooo`03
ool000;ooooo0ooo00001Oooooooo`00ool00?oo003ooooo00?oo`0000Coooooool00?oo003oo`00
0_ooool3ool00005oooooooo003oo`00ool00?ooool00ooo0002ooooo`?oo`0000Goooooool00?oo
003oo`00ooooo`03ool00004oooooooo003oo`00ool000;ooooo0ooo00001Oooooooo`00ool00?oo
003ooooo00?oo`000_ooool3ool00005oooooooo003oo`00ool00?ooool00ooo0002ooooo`?oo`00
00Coooooool00?oo003oo`000oooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00oooo
ooooool00_ooool01Ooo003oooooooooooooooooo`0000;ooooo0ooo0002ooooo`03ool00?oooooo
oooo00;ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00Go
o`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`001oooool01?l0003oooooooooool00005ooooo`03o`00
0?oooooooooo00?ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;o
oooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00Goo`00oooo
ooooooooooooool00003ooooo`03ool00?oooooooooo00?oo`0000Coooooool00?oo003oo`000_oo
ool3ool00005oooooooo003oo`00ool00?ooool00ooo0002ooooo`?oo`0000Goooooool00?oo003o
o`00ooooo`03ool000;ooooo0ooo00001Oooooooo`00ool00?oo003ooooo00?oo`0000Coooooool0
0?oo003oo`000_ooool3ool00005oooooooo003oo`00ool00?ooool00ooo0002ooooo`?oo`0000Go
ooooool00?oo003oo`00ooooo`03ool000;ooooo0ooo00001Oooooooo`00ool00?oo003ooooo00?o
o`0000Coooooool00?oo003oo`000_ooool3ool00005oooooooo003oo`00ool00?ooool00ooo0002
ooooo`?oo`0000Goooooool00?oo003oo`00ooooo`03ool00004oooooooo003oo`00ool000;ooooo
0ooo00001Oooooooo`00ool00?oo003ooooo00?oo`000_ooool3ool00005oooooooo003oo`00ool0
0?ooool00ooo0002ooooo`?oo`0000Goooooool00?oo003oo`00ooooo`03ool00004oooooooo003o
o`00ool000;ooooo0ooo00001Oooooooo`00ool00?oo003ooooo00?oo`000_ooool3ool000;ooooo
00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00oooooooo
ool00_ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo0008ooooo`;o00001_ooool00ol0003o
ooooooooo`03ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02oooo
o`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ooooo`05ool00?oooooo
oooooooooooo00000oooool00ooo003oooooooooo`03ool00004oooooooo003oo`00ool000;ooooo
0ooo00001Oooooooo`00ool00?oo003ooooo00?oo`000_ooool3ool00005oooooooo003oo`00ool0
0?ooool00ooo0002ooooo`?oo`0000Goooooool00?oo003oo`00ooooo`03ool00004oooooooo003o
o`00ool000;ooooo0ooo00001Oooooooo`00ool00?oo003ooooo00?oo`000_ooool3ool00005oooo
oooo003oo`00ool00?ooool00ooo0002ooooo`?oo`0000Goooooool00?oo003oo`00ooooo`03ool0
0004oooooooo003oo`00ool000;ooooo0ooo00001Oooooooo`00ool00?oo003ooooo00?oo`000_oo
ool3ool00005oooooooo003oo`00ool00?ooool00ooo00001?ooooooo`00ool00?oo0002ooooo`?o
o`0000Goooooool00?oo003oo`00ooooo`03ool000;ooooo0ooo00001Oooooooo`00ool00?oo003o
oooo00?oo`000_ooool3ool00005oooooooo003oo`00ool00?ooool00ooo00001?ooooooo`00ool0
0?oo0002ooooo`?oo`0000Goooooool00?oo003oo`00ooooo`03ool000;ooooo0ooo0002ooooo`03
ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo
00;ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00oooool00ol0003oooooooooo`03ooooo`004?ooool00ol0003oooooooooo`03oooo
o`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ooooo`05ool00?oooooo
oooooooooooo00000oooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo0000
0oooool00ooo003oooooooooo`04ooooo`?oo`000_ooool3ool00005oooooooo003oo`00ool00?oo
ool00ooo0002ooooo`?oo`00Q_ooool3ool00004oooooooo003oo`00ool000;ooooo0ooo00001Ooo
ooooo`00ool00?oo003ooooo00?oo`001oooool00ooo003oooooooooo`02ooooo`05ool00?oooooo
oooooooooooo00000oooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo0000
0oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool0013ooooo00?o0000ooooooooool00oooool01Ooo003oooooooooooooooooo`0000?ooooo
00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00oooooooo
ool00_ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool0^_ooool00ooo
003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02
ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool0013ooooo0_l00004ooooo`05ool00?oooooo
oooooooooooo00000oooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo0000
0oooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003o
ooooooooo`2jooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003oooo
o`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool2o`0000Gooooo000@ooooo`03o`000?oooooooooo
00?ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00Goo`00
ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00Goo`00oooooooooooooooo
ool00003ooooo`03ool00?oooooooooo0;[ooooo00?oo`00ooooooooool00_ooool01Ooo003ooooo
ooooooooooooo`0000?ooooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`00
00?ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo000@ooooo`03o`000?oooooooooo00?ooooo00Goo`00ooooooooooooooooool00003oooo
o`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooo
oooo00;ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo0;[ooooo00?o
o`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool0
0_ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo000@ooooo`03o`000?oooooooooo00?ooooo
00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00Goo`00oooooooo
ooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003
ooooo`03ool00?oooooooooo0;[ooooo00?oo`00ooooooooool00_ooool01Ooo003ooooooooooooo
ooooo`0000?ooooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000?ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
000@ooooo`03o`000?oooooooooo00?ooooo00Goo`00ooooooooooooooooool00002ooooo`?oo`00
0oooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_ooool01Ooo003o
ooooooooooooooooo`0000?ooooo00?oo`00ooooooooool0^_ooool00ooo003oooooooooo`02oooo
o`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ooooo`05ool00?oooooo
oooooooooooo00000_ooool3ool000?ooooo00?oo`00ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`004?ooool00ol0003oooooooooo`03ooooo`05ool00?oooooooooooooooooo00000_oo
ool3ool000?ooooo00Goo`00ooooooooooooooooool00002ooooo`?oo`000oooool01Ooo003ooooo
ooooooooooooo`0000?ooooo00?oo`00ooooooooool0^_ooool00ooo003oooooooooo`02ooooo`05
ool00?oooooooooooooooooo00000_ooool3ool000?ooooo00Goo`00ooooooooooooooooool00002
ooooo`?oo`000oooool00ooo003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo000@oooo
o`;o00001?ooool01Ooo003oooooooooooooooooo`0000;ooooo0ooo0003ooooo`05ool00?oooooo
oooooooooooo00000_ooool3ool000?ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool0
0?oooooooooo0;[ooooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000;o
oooo0ooo0003ooooo`05ool00?oooooooooooooooooo00000_ooool3ool000?ooooo00?oo`00oooo
ooooool00_ooool2o`0000Gooooo000@ooooo`03o`000?oooooooooo00?ooooo00Goo`00oooooooo
ooooooooool00008ooooo`05ool00?oooooooooooooooooo00000_ooool3ool000?ooooo00Goo`00
ooooooooooooooooool00003ooooo`03ool00?oooooooooo0;[ooooo00?oo`00ooooooooool00_oo
ool01Ooo003oooooooooooooooooo`0000;ooooo0ooo0003ooooo`05ool00?oooooooooooooooooo
00002?ooool00ooo003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo000@ooooo`03o`00
0?oooooooooo00?ooooo00Goo`00ooooooooooooooooool00008ooooo`05ool00?oooooooooooooo
oooo00002?ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool0^_ooool0
0ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00002?ooool01Ooo003ooooooooo
ooooooooo`0000Sooooo00?oo`00ooooooooool00oooool00ol0003oooooooooo`03ooooo`004?oo
ool00ol0003oooooooooo`03ooooo`05ool00?oooooooooooooooooo00002?ooool01Ooo003ooooo
ooooooooooooo`0000Sooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo
0;[ooooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000Sooooo00Goo`00
ooooooooooooooooool00008ooooo`03ool00?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool0013ooooo00?o0000ooooooooool00oooool01Ooo003oooooooooooooooooo`0000Sooooo00Go
o`00ooooooooooooooooool00008ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003o
ooooooooo`2jooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00008oooo
o`05ool00?oooooooooooooooooo00002?ooool00ooo003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo000@ooooo`;o00001?ooool01Ooo003oooooooooooooooooo`0000Sooooo00Goo`00
ooooooooooooooooool00008ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003ooooo
ooooo`2jooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00008ooooo`05
ool00?oooooooooooooooooo00002?ooool00ooo003oooooooooo`02ooooo`;o00001Oooool0013o
oooo00?o0000ooooooooool00oooool01Ooo003oooooooooooooooooo`0000Sooooo00Goo`00oooo
ooooooooooooool00008ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003ooooooooo
o`2jooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00008ooooo`05ool0
0?oooooooooooooooooo00002?ooool00ooo003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo000@ooooo`03o`000?oooooooooo00?ooooo00Goo`00ooooooooooooooooool00008ooooo`05
ool00?oooooooooooooooooo00002?ooool01Ooo003oooooooooooooooooo`0000;ooooo0ooo002j
ooooo`?oo`000oooool01Ooo003oooooooooooooooooo`0000Sooooo00Goo`00oooooooooooooooo
ool00008ooooo`03ool00?oooooooooo00?ooooo00?o0000ooooooooool00oooool0013ooooo00?o
0000ooooooooool00oooool01Ooo003oooooooooooooooooo`0000Sooooo00Goo`00oooooooooooo
ooooool00008ooooo`05ool00?oooooooooooooooooo00000_ooool3ool00;[ooooo0ooo0003oooo
o`05ool00?oooooooooooooooooo00002?ooool01Ooo003oooooooooooooooooo`0000Sooooo00?o
o`00ooooooooool00oooool00ol0003oooooooooo`03ooooo`004?ooool00ol0003oooooooooo`03
ooooo`05ool00?oooooooooooooooooo00002?ooool01Ooo003oooooooooooooooooo`0000Sooooo
00Goo`00ooooooooooooooooool00002ooooo`?oo`00^_ooool3ool000?ooooo00Goo`00oooooooo
ooooooooool00008ooooo`05ool00?oooooooooooooooooo00002?ooool00ooo003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo000@ooooo`03o`000?oooooooooo00?ooooo00Goo`00oooo
ooooooooooooool00008ooooo`05ool00?oooooooooooooooooo00002?ooool01Ooo003ooooooooo
ooooooooo`000<Gooooo00Goo`00ooooooooooooooooool00008ooooo`05ool00?oooooooooooooo
oooo00002?ooool00ooo003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo000@ooooo`;o
00001?ooool01Ooo003oooooooooooooooooo`0000Sooooo00Goo`00ooooooooooooooooool00008
ooooo`05ool00?oooooooooooooooooo0000aOooool01Ooo003oooooooooooooooooo`0000Sooooo
00Goo`00ooooooooooooooooool00008ooooo`03ool00?oooooooooo00;ooooo0_l00005ooooo`00
4?ooool00ol0003oooooooooo`03ooooo`05ool00?oooooooooooooooooo00002?ooool01Ooo003o
ooooooooooooooooo`0000Sooooo00Goo`00ooooooooooooooooool00035ooooo`05ool00?oooooo
oooooooooooo00002?ooool01Ooo003oooooooooooooooooo`0000Sooooo00?oo`00ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`004?ooool00ol0003oooooooooo`03ooooo`05ool00?oo
oooooooooooooooo00002?ooool01Ooo003oooooooooooooooooo`0000Sooooo00Goo`00oooooooo
ooooooooool00035ooooo`05ool00?oooooooooooooooooo00002?ooool01Ooo003ooooooooooooo
ooooo`0000Sooooo00?oo`00ooooooooool00oooool00ol0003oooooooooo`03ooooo`004?ooool0
0ol0003oooooooooo`03ooooo`05ool00?oooooooooooooooooo00002?ooool01Ooo003ooooooooo
ooooooooo`0000Sooooo00Goo`00ooooooooooooooooool00035ooooo`05ool00?oooooooooooooo
oooo00002?ooool01Ooo003oooooooooooooooooo`0000Sooooo00?oo`00ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`0000Coooooo`000?l0003o00001?ooool2o`0000Kooooo00?o0000
ooooooooool00oooool01Ooo003oooooooooooooooooo`0000Sooooo00Goo`00oooooooooooooooo
ool00008ooooo`05ool00?oooooooooooooooooo0000aOooool01Ooo003oooooooooooooooooo`00
00Sooooo00Goo`00ooooooooooooooooool00008ooooo`03ool00?oooooooooo00?ooooo00?o0000
ooooooooool00oooool000;ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00005
ooooo`03o`000?oooooooooo00?ooooo00Goo`00ooooooooooooooooool00008ooooo`05ool00?oo
oooooooooooooooo00002?ooool01Ooo003oooooooooooooooooo`000<Gooooo00Goo`00oooooooo
ooooooooool00008ooooo`05ool00?oooooooooooooooooo00002?ooool00ooo003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo0002ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00001Oooool2o`0000Cooooo00Goo`00ooooooooooooooooool00008ooooo`05ool00?oo
oooooooooooooooo00002?ooool01Ooo003oooooooooooooooooo`000<Gooooo00Goo`00oooooooo
ooooooooool00008ooooo`05ool00?oooooooooooooooooo00002?ooool01?oo003ooooooooooooo
ool3o`0000Gooooo0002ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001Ooo
ool00ol0003oooooooooo`03ooooo`05ool00?oooooooooooooooooo00002?ooool01Ooo003ooooo
ooooooooooooo`0000Sooooo00Goo`00ooooooooooooooooool00035ooooo`05ool00?oooooooooo
oooooooo00002?ooool01Ooo003oooooooooooooooooo`0000Sooooo00?oo`00ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`000_ooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000Gooooo00?o0000ooooooooool00oooool01Ooo003oooooooooooooooooo`0000Sooooo
00Goo`00ooooooooooooooooool00008ooooo`05ool00?oooooooooooooooooo0000aOooool01Ooo
003oooooooooooooooooo`0000Sooooo00Goo`00ooooooooooooooooool00008ooooo`03ool00?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00003ooooool0003o000000Cooooo00Co0000
oooooooooooo00001Oooool00ol0003oooooooooo`03ooooo`05ool00?oooooooooooooooooo0000
2?ooool01Ooo003oooooooooooooooooo`0000Sooooo00Goo`00ooooooooooooooooool00035oooo
o`05ool00?oooooooooooooooooo00002?ooool01Ooo003oooooooooooooooooo`0000Sooooo00?o
o`00ooooooooool00oooool00ol0003oooooooooo`03ooooo`000_ooool00ol0003oooooooooo`03
ooooo`;o00001_ooool00ol0003oooooooooo`03ooooo`05ool00?oooooooooooooooooo00002?oo
ool01Ooo003oooooooooooooooooo`0000Sooooo00Goo`00ooooooooooooooooool00035ooooo`05
ool00?oooooooooooooooooo00002?ooool01Ooo003oooooooooooooooooo`0000Sooooo00?oo`00
ooooooooool00oooool00ol0003oooooooooo`03ooooo`004?ooool00ol0003oooooooooo`03oooo
o`05ool00?oooooooooooooooooo00002?ooool01Ooo003oooooooooooooooooo`0000Sooooo00Go
o`00ooooooooooooooooool00035ooooo`05ool00?oooooooooooooooooo00002?ooool01Ooo003o
ooooooooooooooooo`0000Sooooo00?oo`00ooooooooool00oooool00ol0003oooooooooo`03oooo
o`004?ooool2o`0000Cooooo00Goo`00ooooooooooooooooool00008ooooo`05ool00?oooooooooo
oooooooo00002?ooool01Ooo003oooooooooooooooooo`000<Gooooo00Goo`00oooooooooooooooo
ool00008ooooo`05ool00?oooooooooooooooooo00002?ooool00ooo003oooooooooo`02ooooo`;o
00001Oooool0013ooooo00?o0000ooooooooool00oooool01Ooo003oooooooooooooooooo`0000So
oooo00Goo`00ooooooooooooooooool00008ooooo`05ool00?oooooooooooooooooo0000aOooool0
1Ooo003oooooooooooooooooo`0000Sooooo00Goo`00ooooooooooooooooool00008ooooo`03ool0
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool0013ooooo00?o0000ooooooooool00ooo
ool01Ooo003oooooooooooooooooo`0000Sooooo00Goo`00ooooooooooooooooool00008ooooo`05
ool00?oooooooooooooooooo0000aOooool01Ooo003oooooooooooooooooo`0000Sooooo00Goo`00
ooooooooooooooooool00008ooooo`03ool00?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool0013ooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`03ool000Oooooo00Goo`00
ooooooooooooooooool00008ooooo`05ool00?oooooooooooooooooo0000aOooool01Ooo003ooooo
ooooooooooooo`0000Sooooo00Goo`00ooooooooooooooooool00006ooooo`?oo`001Oooool00ol0
003oooooooooo`03ooooo`004?ooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo00?o
o`001oooool01Ooo003oooooooooooooooooo`0000Sooooo00Goo`00ooooooooooooooooool00035
ooooo`05ool00?oooooooooooooooooo00002?ooool01Ooo003oooooooooooooooooo`0000Kooooo
0ooo0005ooooo`03o`000?oooooooooo00?ooooo000@ooooo`03o`000?oooooooooo00?ooooo00?o
o`00ooooooooool00ooo0007ooooo`05ool00?oooooooooooooooooo00002?ooool01Ooo003ooooo
ooooooooooooo`000<Gooooo00Goo`00ooooooooooooooooool00008ooooo`05ool00?oooooooooo
oooooooo00001_ooool3ool000Gooooo00?o0000ooooooooool00oooool0013ooooo0_l00004oooo
o`03ool00?oooooooooo00[ooooo00Goo`00ooooooooooooooooool00008ooooo`05ool00?oooooo
oooooooooooo0000aOooool01Ooo003oooooooooooooooooo`0000Sooooo00Goo`00oooooooooooo
ooooool0000=ooooo`;o00001Oooool0013ooooo00?o0000ooooooooool00oooool00ooo003ooooo
ooooo`0:ooooo`05ool00?oooooooooooooooooo00002?ooool01Ooo003oooooooooooooooooo`00
0<Gooooo00Goo`00ooooooooooooooooool00008ooooo`05ool00?oooooooooooooooooo00003_oo
ool00ol0003oooooooooo`03ooooo`004?ooool00ol0003oooooooooo`03ooooo`03ool00?oooooo
oooo00[ooooo00Goo`00ooooooooooooooooool00008ooooo`05ool00?oooooooooooooooooo0000
aOooool01Ooo003oooooooooooooooooo`0000Sooooo00Goo`00ooooooooooooooooool0000>oooo
o`03o`000?oooooooooo00?ooooo000@ooooo`03o`000?oooooooooo00?ooooo00?oo`00oooooooo
ool02_ooool01Ooo003oooooooooooooooooo`0000Sooooo00Goo`00ooooooooooooooooool00035
ooooo`05ool00?oooooooooooooooooo00002?ooool01Ooo003oooooooooooooooooo`0000kooooo
00?o0000ooooooooool00oooool0013ooooo00?o0000ooooooooool00oooool00ooo003ooooooooo
o`0:ooooo`05ool00?oooooooooooooooooo00002?ooool01Ooo003oooooooooooooooooo`000<Go
oooo00Goo`00ooooooooooooooooool00008ooooo`05ool00?oooooooooooooooooo00003_ooool0
0ol0003oooooooooo`03ooooo`004?ooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo
00[ooooo00Goo`00ooooooooooooooooool00008ooooo`05ool00?oooooooooooooooooo0000aOoo
ool01Ooo003oooooooooooooooooo`0000Sooooo00Goo`00ooooooooooooooooool0000>ooooo`03
o`000?oooooooooo00?ooooo000@ooooo`;o00001?ooool00ooo003oooooooooo`0:ooooo`05ool0
0?oooooooooooooooooo00002?ooool01Ooo003oooooooooooooooooo`000<Gooooo00Goo`00oooo
ooooooooooooool00008ooooo`05ool00?oooooooooooooooooo00003Oooool2o`0000Gooooo000@
ooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool02_ooool01Ooo003ooooooooooooo
ooooo`0000Sooooo00Goo`00ooooooooooooooooool00035ooooo`05ool00?oooooooooooooooooo
00002?ooool01Ooo003oooooooooooooooooo`0000kooooo00?o0000ooooooooool00oooool0013o
oooo00?o0000ooooooooool00oooool00ooo003oooooooooo`0:ooooo`05ool00?oooooooooooooo
oooo00002?ooool01Ooo003oooooooooooooooooo`000<Gooooo00Goo`00ooooooooooooooooool0
0008ooooo`05ool00?oooooooooooooooooo00003_ooool00ol0003oooooooooo`03ooooo`004?oo
ool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo00[ooooo00Goo`00oooooooooooooooo
ool00008ooooo`05ool00?oooooooooooooooooo0000aOooool01Ooo003oooooooooooooooooo`00
00Sooooo00Goo`00ooooooooooooooooool0000>ooooo`03o`000?oooooooooo00?ooooo000@oooo
o`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool02_ooool01Ooo003ooooooooooooooooo
o`0000Sooooo00Goo`00ooooooooooooooooool00035ooooo`05ool00?oooooooooooooooooo0000
2?ooool01Ooo003oooooooooooooooooo`0000kooooo00?o0000ooooooooool00oooool0013ooooo
00?o0000ooooooooool00oooool00ooo003oooooooooo`0:ooooo`05ool00?oooooooooooooooooo
00002?ooool01Ooo003oooooooooooooooooo`000<Gooooo00Goo`00ooooooooooooooooool00008
ooooo`05ool00?oooooooooooooooooo00003_ooool00ol0003oooooooooo`03ooooo`004?ooool2
o`0000Cooooo00?oo`00ooooooooool02_ooool01Ooo003oooooooooooooooooo`0000Sooooo00Go
o`00ooooooooooooooooool00035ooooo`05ool00?oooooooooooooooooo00002?ooool01Ooo003o
ooooooooooooooooo`0000gooooo0_l00005ooooo`004?ooool00ol0003oooooooooo`03ooooo`03
ool00?oooooooooo00[ooooo00Goo`00ooooooooooooooooool00008ooooo`05ool00?oooooooooo
oooooooo0000aOooool01Ooo003oooooooooooooooooo`0000Sooooo00Goo`00oooooooooooooooo
ool0000>ooooo`03o`000?oooooooooo00?ooooo000@ooooo`03o`000?oooooooooo00?ooooo00?o
o`00ooooooooool02_ooool01Ooo003oooooooooooooooooo`0000Sooooo00Goo`00oooooooooooo
ooooool00035ooooo`05ool00?oooooooooooooooooo00002?ooool01Ooo003ooooooooooooooooo
o`0000kooooo00?o0000ooooooooool00oooool000Go00000oooool2o`0000Kooooo00?o0000oooo
ooooool00oooool00ooo003oooooooooo`0:ooooo`05ool00?oooooooooooooooooo00002?ooool0
1Ooo003oooooooooooooooooo`000<Gooooo00Goo`00ooooooooooooooooool00008ooooo`05ool0
0?oooooooooooooooooo00003_ooool00ol0003oooooooooo`03ooooo`0000Goooooo`000?oooooo
ooooo`000002ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00oooool00ooo
003oooooooooo`0:ooooo`05ool00?oooooooooooooooooo00002?ooool01Ooo003ooooooooooooo
ooooo`000<Gooooo00Goo`00ooooooooooooooooool00008ooooo`05ool00?oooooooooooooooooo
00003_ooool00ol0003oooooooooo`03ooooo`000_ooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000Gooooo0_l00004ooooo`03ool00?oooooooooo00[ooooo00Goo`00oooooooo
ooooooooool00008ooooo`05ool00?oooooooooooooooooo0000aOooool01Ooo003ooooooooooooo
ooooo`0000Sooooo00Goo`00ooooooooooooooooool0000<ooooo`?o00001Oooool000?ooooo00Go
0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ooo003oooooooooo`0:ooooo`05ool00?oooooooooooooooooo00002?ooool01Ooo003o
ooooooooooooooooo`000<Gooooo00Goo`00ooooooooooooooooool00008ooooo`05ool00?oooooo
oooooooooooo00003_ooool00ol0003oooooooooo`03ooooo`0000Go0000ooooooooooooooooo`00
0002ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00oooool00ooo003ooooo
ooooo`0:ooooo`05ool00?oooooooooooooooooo00002?ooool01Ooo003oooooooooooooooooo`00
0<Gooooo00Goo`00ooooooooooooooooool00008ooooo`05ool00?oooooooooooooooooo00003_oo
ool00ol0003oooooooooo`03ooooo`0000Go0000ooooooooooooooooo`000002ooooo`04o`000?oo
ooooooooo`0000Gooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`0:ooooo`05ool0
0?oooooooooooooooooo00002?ooool01Ooo003oooooooooooooooooo`000<Gooooo00Goo`00oooo
ooooooooooooool00008ooooo`05ool00?oooooooooooooooooo00003_ooool00ol0003ooooooooo
o`03ooooo`0000Coooooo`000?l0003o00001?ooool2o`0000Kooooo00?o0000ooooooooool00ooo
ool00ooo003oooooooooo`0:ooooo`05ool00?oooooooooooooooooo00002?ooool01Ooo003ooooo
ooooooooooooo`000<Gooooo00Goo`00ooooooooooooooooool00008ooooo`05ool00?oooooooooo
oooooooo00003_ooool00ol0003oooooooooo`03ooooo`004?ooool00ol0003oooooooooo`03oooo
o`03ool00?oooooooooo00[ooooo00Goo`00ooooooooooooooooool00008ooooo`05ool00?oooooo
oooooooooooo0000aOooool01Ooo003oooooooooooooooooo`0000Sooooo00Goo`00oooooooooooo
ooooool0000>ooooo`03o`000?oooooooooo00?ooooo000@ooooo`;o00001?ooool00ooo003ooooo
ooooo`0:ooooo`05ool00?oooooooooooooooooo00002?ooool01Ooo003oooooooooooooooooo`00
0<Gooooo00Goo`00ooooooooooooooooool00008ooooo`05ool00?oooooooooooooooooo00003Ooo
ool2o`0000Gooooo000@ooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool02_ooool0
1Ooo003oooooooooooooooooo`0000Sooooo00Goo`00ooooooooooooooooool00035ooooo`05ool0
0?oooooooooooooooooo00002?ooool01Ooo003oooooooooooooooooo`0000kooooo00?o0000oooo
ooooool00oooool0013ooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`0:ooooo`05
ool00?oooooooooooooooooo00002?ooool01Ooo003oooooooooooooooooo`000<Gooooo00Goo`00
ooooooooooooooooool00008ooooo`05ool00?oooooooooooooooooo00003_ooool00ol0003ooooo
ooooo`03ooooo`004?ooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo00[ooooo00Go
o`00ooooooooooooooooool00008ooooo`05ool00?oooooooooooooooooo0000aOooool01Ooo003o
ooooooooooooooooo`0000Sooooo00Goo`00ooooooooooooooooool0000>ooooo`03o`000?oooooo
oooo00?ooooo000@ooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool02_ooool01Ooo
003oooooooooooooooooo`0000Sooooo00Goo`00ooooooooooooooooool00035ooooo`05ool00?oo
oooooooooooooooo00002?ooool01Ooo003oooooooooooooooooo`0000kooooo00?o0000oooooooo
ool00oooool0013ooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`0:ooooo`05ool0
0?oooooooooooooooooo00002?ooool01Ooo003oooooooooooooooooo`000<Gooooo00Goo`00oooo
ooooooooooooool00008ooooo`05ool00?oooooooooooooooooo00003_ooool00ol0003ooooooooo
o`03ooooo`004?ooool2o`0000Cooooo00?oo`00ooooooooool02_ooool01Ooo003ooooooooooooo
ooooo`0000Sooooo00Goo`00ooooooooooooooooool00035ooooo`05ool00?oooooooooooooooooo
00002?ooool01Ooo003oooooooooooooooooo`0000gooooo0_l00005ooooo`004?ooool00ol0003o
ooooooooo`03ooooo`03ool00?oooooooooo00[ooooo00Goo`00ooooooooooooooooool00008oooo
o`05ool00?oooooooooooooooooo0000aOooool01Ooo003oooooooooooooooooo`0000Sooooo00Go
o`00ooooooooooooooooool0000>ooooo`03o`000?oooooooooo00?ooooo000@ooooo`03o`000?oo
oooooooo00?ooooo00?oo`00ooooooooool02_ooool01Ooo003oooooooooooooooooo`0000Sooooo
00Goo`00ooooooooooooooooool00035ooooo`05ool00?oooooooooooooooooo00002?ooool01Ooo
003oooooooooooooooooo`0000kooooo00?o0000ooooooooool00oooool0013ooooo00?o0000oooo
ooooool00oooool00ooo003oooooooooo`0:ooooo`05ool00?oooooooooooooooooo00002?ooool0
1Ooo003oooooooooooooooooo`000<Gooooo00Goo`00ooooooooooooooooool00008ooooo`05ool0
0?oooooooooooooooooo00003_ooool00ol0003oooooooooo`03ooooo`004?ooool00ol0003ooooo
ooooo`03ooooo`03ool00?oooooooooo00[ooooo00Goo`00ooooooooooooooooool00008ooooo`05
ool00?oooooooooooooooooo0000aOooool01Ooo003oooooooooooooooooo`0000Sooooo00Goo`00
ooooooooooooooooool0000>ooooo`03o`000?oooooooooo00?ooooo000@ooooo`03o`000?oooooo
oooo00?ooooo00?oo`00ooooooooool02_ooool01Ooo003oooooooooooooooooo`0000Sooooo00Go
o`00ooooooooooooooooool00035ooooo`05ool00?oooooooooooooooooo00002?ooool01Ooo003o
ooooooooooooooooo`0000kooooo00?o0000ooooooooool00oooool0013ooooo0_l00004ooooo`03
ool00?oooooooooo00[ooooo00Goo`00ooooooooooooooooool00008ooooo`05ool00?oooooooooo
oooooooo0000aOooool01Ooo003oooooooooooooooooo`0000Sooooo00Goo`00oooooooooooooooo
ool0000=ooooo`;o00001Oooool0013ooooo00?o0000ooooooooool00oooool00ooo003ooooooooo
o`08ooooo`?oo`000oooool00ooo003oooooooooo`06ooooo`05ool00?oooooooooooooooooo0000
aOooool01Ooo003oooooooooooooooooo`0000Sooooo00?oo`00oooooooo00000_oo000>ooooo`03
o`000?oooooooooo00?ooooo000@ooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool0
2?ooool3ool000;ooooo0ooo0007ooooo`05ool00?oooooooooooooooooo0000aOooool01Ooo003o
ooooooooooooooooo`0000Kooooo0ooo00001?ooooooo`00ool00?oo000>ooooo`03o`000?oooooo
oooo00?ooooo000@ooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool02?ooool3ool0
00;ooooo0ooo0007ooooo`05ool00?oooooooooooooooooo0000aOooool01Ooo003ooooooooooooo
ooooo`0000Kooooo0ooo00001?ooooooo`00ool00?oo000>ooooo`03o`000?oooooooooo00?ooooo
000@ooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool03Oooool3ool000Oooooo00Go
o`00ooooooooooooooooool00035ooooo`05ool00?oooooooooooooooooo00001_ooool3ool001;o
oooo00?o0000ooooooooool00oooool0013ooooo00?o0000ooooooooool00oooool00ooo003ooooo
ooooo`0Gooooo`05ool00?oooooooooooooooooo0000aOooool01Ooo003oooooooooooooooooo`00
01_ooooo00?o0000ooooooooool00oooool0013ooooo0_l00004ooooo`03ool00?oooooooooo01Oo
oooo00Goo`00ooooooooooooooooool00035ooooo`05ool00?oooooooooooooooooo00006_ooool2
o`0000Gooooo000@ooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool05oooool01Ooo
003oooooooooooooooooo`000<Gooooo00Goo`00ooooooooooooooooool0000Kooooo`03o`000?oo
oooooooo00?ooooo000@ooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool05oooool0
1Ooo003oooooooooooooooooo`000<Gooooo00Goo`00ooooooooooooooooool0000Kooooo`03o`00
0?oooooooooo00?ooooo00001?oooooo0000o`000?l00004ooooo`;o00001_ooool00ol0003ooooo
ooooo`03ooooo`03ool00?oooooooooo01Oooooo00Goo`00ooooooooooooooooool00035ooooo`05
ool00?oooooooooooooooooo00006oooool00ol0003oooooooooo`03ooooo`0000Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00oooool0
0ooo003oooooooooo`0Gooooo`05ool00?oooooooooooooooooo0000aOooool01Ooo003ooooooooo
ooooooooo`0001_ooooo00?o0000ooooooooool00oooool000Cooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool0
5oooool01Ooo003oooooooooooooooooo`000<Gooooo00Goo`00ooooooooooooooooool0000Koooo
o`03o`000?oooooooooo00?ooooo0002ooooo`;o00000oooool01?l0003oooooooooool00005oooo
o`;o00001?ooool00ooo003oooooooooo`0Gooooo`05ool00?oooooooooooooooooo0000aOooool0
1Ooo003oooooooooooooooooo`0001Wooooo0ol00005ooooo`001?ooool01?l0003oooooooooool0
0002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ooo003ooooooooo
o`0Gooooo`05ool00?oooooooooooooooooo0000aOooool01Ooo003oooooooooooooooooo`0001_o
oooo00?o0000ooooooooool00oooool00005o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00005ooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool05oooool01Ooo
003oooooooooooooooooo`000<Gooooo00Goo`00ooooooooooooooooool0000Kooooo`03o`000?oo
oooooooo00?ooooo00001?oooooo0000o`000?l00004ooooo`;o00001_ooool00ol0003ooooooooo
o`03ooooo`03ool00?oooooooooo01Oooooo00Goo`00ooooooooooooooooool00035ooooo`05ool0
0?oooooooooooooooooo00006oooool00ol0003oooooooooo`03ooooo`004?ooool00ol0003ooooo
ooooo`03ooooo`03ool00?oooooooooo01Oooooo00Goo`00ooooooooooooooooool00035ooooo`05
ool00?oooooooooooooooooo00006oooool00ol0003oooooooooo`03ooooo`004?ooool00ol0003o
ooooooooo`03ooooo`03ool00?oooooooooo01Oooooo00Goo`00ooooooooooooooooool00035oooo
o`05ool00?oooooooooooooooooo00006oooool00ol0003oooooooooo`03ooooo`004?ooool2o`00
00Cooooo00?oo`00ooooooooool05oooool01Ooo003oooooooooooooooooo`000<Gooooo00Goo`00
ooooooooooooooooool0000Jooooo`;o00001Oooool0013ooooo00?o0000ooooooooool00oooool0
0ooo003oooooooooo`0Gooooo`05ool00?oooooooooooooooooo0000aOooool01Ooo003ooooooooo
ooooooooo`0001_ooooo00?o0000ooooooooool00oooool0013ooooo00Co0000oooooooooooooooo
0ooo000Iooooo`05ool00?oooooooooooooooooo0000aOooool01Ooo003oooooooooooooooooo`00
01_ooooo00?o0000ooooooooool00oooool0013ooooo00Co0000oooooooooooooooo0ooo000Ioooo
o`05ool00?oooooooooooooooooo0000aOooool01Ooo003oooooooooooooooooo`0001_ooooo00?o
0000ooooooooool00oooool0013ooooo00Co0000oooooooooooooooo0ooo000Iooooo`05ool00?oo
oooooooooooooooo0000aOooool01Ooo003oooooooooooooooooo`0001_ooooo00?o0000oooooooo
ool00oooool0013ooooo0_l0000Nooooo`05ool00?oooooooooooooooooo0000aOooool01Ooo003o
ooooooooooooooooo`0001[ooooo0_l00005ooooo`004?ooool00ol0003oooooooooo`0Mooooo`05
ool00?oooooooooooooooooo0000aOooool01Ooo003oooooooooooooooooo`0001_ooooo00?o0000
ooooooooool00oooool0013ooooo00?o0000ooooooooool07Oooool01Ooo003ooooooooooooooooo
o`000<Gooooo00Goo`00ooooooooooooooooool0000Kooooo`03o`000?oooooooooo00?ooooo000@
ooooo`03o`000?oooooooooo01gooooo00Goo`00ooooooooooooooooool00035ooooo`05ool00?oo
oooooooooooooooo00006oooool00ol0003oooooooooo`03ooooo`004?ooool00ol0003ooooooooo
o`0Mooooo`05ool00?oooooooooooooooooo0000aOooool01Ooo003oooooooooooooooooo`0001_o
oooo00?o0000ooooooooool00oooool0013ooooo00?o0000ooooooooool07Oooool01Ooo003ooooo
ooooooooooooo`000<Gooooo00Goo`00ooooooooooooooooool0000Kooooo`03o`000?oooooooooo
00?ooooo000@ooooo`;o00007_ooool01Ooo003oooooooooooooooooo`000<Gooooo00Goo`00oooo
ooooooooooooool0000Jooooo`;o00001Oooool0013ooooo00?o0000ooooooooool07Oooool01Ooo
003oooooooooooooooooo`000<Gooooo00Goo`00ooooooooooooooooool0000Kooooo`03o`000?oo
oooooooo00?ooooo000@ooooo`03o`000?oooooooooo01gooooo00Goo`00ooooooooooooooooool0
0035ooooo`05ool00?oooooooooooooooooo00006oooool00ol0003oooooooooo`03ooooo`004?oo
ool00ol0003oooooooooo`0Mooooo`05ool00?oooooooooooooooooo0000aOooool01Ooo003ooooo
ooooooooooooo`0001_ooooo00?o0000ooooooooool00oooool0013ooooo00?o0000ooooooooool0
7Oooool01Ooo003oooooooooooooooooo`000<Gooooo00Goo`00ooooooooooooooooool0000Koooo
o`03o`000?oooooooooo00?ooooo000@ooooo`03o`000?oooooooooo01gooooo00Goo`00oooooooo
ooooooooool00035ooooo`05ool00?oooooooooooooooooo00006oooool00ol0003oooooooooo`03
ooooo`004?ooool2o`0001kooooo00Goo`00ooooooooooooooooool00035ooooo`05ool00?oooooo
oooooooooooo00006_ooool2o`0000Gooooo000@ooooo`03o`000?oooooooooo01gooooo00Goo`00
ooooooooooooooooool00035ooooo`05ool00?oooooooooooooooooo00006oooool00ol0003ooooo
ooooo`03ooooo`004?ooool00ol0003oooooooooo`0Mooooo`05ool00?oooooooooooooooooo0000
aOooool01Ooo003oooooooooooooooooo`0001_ooooo00?o0000ooooooooool00oooool0013ooooo
00?o0000ooooooooool07Oooool01Ooo003oooooooooooooooooo`000<Gooooo00Goo`00oooooooo
ooooooooool0000Kooooo`03o`000?oooooooooo00?ooooo0002ooooo`?o00000oooool2o`0000Ko
oooo00?o0000ooooooooool07Oooool01Ooo003oooooooooooooooooo`000<Gooooo00Goo`00oooo
ooooooooooooool0000Kooooo`03o`000?oooooooooo00?ooooo0003ooooo`05o`000?oooooooooo
ooooool000000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01gooooo00Goo`00
ooooooooooooooooool00035ooooo`05ool00?oooooooooooooooooo00006oooool00ol0003ooooo
ooooo`03ooooo`001Ol00002ooooo`04o`000?ooooooooooo`0000Gooooo0_l0000Nooooo`05ool0
0?oooooooooooooooooo0000aOooool01Ooo003oooooooooooooooooo`0001Wooooo0ol00005oooo
o`0000Co0000oooooooooooo00000oooool01?l0003oooooooooool00005ooooo`03o`000?oooooo
oooo01gooooo00Goo`00ooooooooooooooooool00035ooooo`05ool00?oooooooooooooooooo0000
6oooool00ol0003oooooooooo`03ooooo`0000Coooooo`000?oooooo00000oooool01?l0003ooooo
ooooool00005ooooo`03o`000?oooooooooo01gooooo00Goo`00ooooooooooooooooool00035oooo
o`05ool00?oooooooooooooooooo00006oooool00ol0003oooooooooo`03ooooo`000_ooool2o`00
00?ooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`0Mooooo`05ool00?oooooo
oooooooooooo0000aOooool01Ooo003oooooooooooooooooo`0001_ooooo00?o0000ooooooooool0
0oooool000?ooooo00?o0000ooooooooool00_ooool2o`0000Kooooo00?o0000ooooooooool07Ooo
ool01Ooo003oooooooooooooooooo`000<Gooooo00Goo`00ooooooooooooooooool0000Kooooo`03
o`000?oooooooooo00?ooooo000@ooooo`03o`000?oooooooooo01gooooo00Goo`00oooooooooooo
ooooool00035ooooo`05ool00?oooooooooooooooooo00006oooool00ol0003oooooooooo`03oooo
o`004?ooool2o`0001kooooo00Goo`00ooooooooooooooooool00035ooooo`05ool00?oooooooooo
oooooooo00006_ooool2o`0000Gooooo000@ooooo`03o`000?oooooooooo01gooooo00Goo`00oooo
ooooooooooooool00035ooooo`05ool00?oooooooooooooooooo00006oooool00ol0003ooooooooo
o`03ooooo`004?ooool00ol0003oooooooooo`0Mooooo`05ool00?oooooooooooooooooo0000aOoo
ool01Ooo003oooooooooooooooooo`0001_ooooo00?o0000ooooooooool00oooool0013ooooo00?o
0000ooooooooool07Oooool01Ooo003oooooooooooooooooo`000<Gooooo00Goo`00oooooooooooo
ooooool0000Kooooo`03o`000?oooooooooo00?ooooo000@ooooo`03o`000?oooooooooo01gooooo
00Goo`00ooooooooooooooooool00035ooooo`05ool00?oooooooooooooooooo00006oooool00ol0
003oooooooooo`03ooooo`004?ooool00ol0003oooooooooo`0Mooooo`05ool00?oooooooooooooo
oooo0000aOooool01Ooo003oooooooooooooooooo`0001_ooooo00?o0000ooooooooool00oooool0
013ooooo0_l0000Nooooo`05ool00?oooooooooooooooooo0000aOooool01Ooo003ooooooooooooo
ooooo`0001[ooooo0_l00005ooooo`004?ooool00ol0003oooooooooo`0Mooooo`05ool00?oooooo
oooooooooooo0000aOooool01Ooo003oooooooooooooooooo`0001_ooooo00?o0000ooooooooool0
0oooool0013ooooo00?o0000ooooooooool07Oooool01Ooo003oooooooooooooooooo`000<Gooooo
00Goo`00ooooooooooooooooool0000Kooooo`03o`000?oooooooooo00?ooooo000@ooooo`03o`00
0?oooooooooo01gooooo00Goo`00ooooooooooooooooool00035ooooo`05ool00?oooooooooooooo
oooo00006oooool00ol0003oooooooooo`03ooooo`004?ooool00ol0003oooooooooo`0Mooooo`05
ool00?oooooooooooooooooo0000aOooool01Ooo003oooooooooooooooooo`0001_ooooo00?o0000
ooooooooool00oooool0013ooooo00?o0000ooooooooool07Oooool01Ooo003ooooooooooooooooo
o`000<Gooooo00Goo`00ooooooooooooooooool0000Kooooo`03o`000?oooooooooo00?ooooo000@
ooooo`;o00007_ooool01Ooo003oooooooooooooooooo`000<Gooooo00Goo`00oooooooooooooooo
ool0000Jooooo`;o00001Oooool0013ooooo00?o0000ooooooooool07Oooool01Ooo003ooooooooo
ooooooooo`000<Gooooo00Goo`00ooooooooooooooooool0000Kooooo`03o`000?oooooooooo00?o
oooo000@ooooo`03o`000?oooooooooo01gooooo00Goo`00ooooooooooooooooool00035ooooo`05
ool00?oooooooooooooooooo00006oooool00ol0003oooooooooo`03ooooo`004?ooool00ol0003o
ooooooooo`0Mooooo`05ool00?oooooooooooooooooo0000aOooool01Ooo003ooooooooooooooooo
o`0001_ooooo00?o0000ooooooooool00oooool0013ooooo00?o0000ooooooooool07Oooool01Ooo
003oooooooooooooooooo`000<Gooooo00Goo`00ooooooooooooooooool0000Kooooo`03o`000?oo
oooooooo00?ooooo000@ooooo`03o`000?oooooooooo01gooooo00Goo`00ooooooooooooooooool0
0035ooooo`05ool00?oooooooooooooooooo00006oooool00ol0003oooooooooo`03ooooo`004?oo
ool2o`0001kooooo00Goo`00ooooooooooooooooool00035ooooo`05ool00?oooooooooooooooooo
00006_ooool2o`0000Gooooo000@ooooo`03o`000?oooooooooo01gooooo00Goo`00oooooooooooo
ooooool00035ooooo`05ool00?oooooooooooooooooo00006oooool00ol0003oooooooooo`03oooo
o`004?ooool00ol0003oooooooooo`0Mooooo`05ool00?oooooooooooooooooo0000aOooool01Ooo
003oooooooooooooooooo`0001_ooooo00?o0000ooooooooool00oooool00004ooooool0003o0000
o`0000Cooooo0_l00006ooooo`03o`000?oooooooooo01gooooo00Goo`00ooooooooooooooooool0
0035ooooo`05ool00?oooooooooooooooooo00006oooool00ol0003oooooooooo`03ooooo`0000Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000oooooooo
ool07Oooool01Ooo003oooooooooooooooooo`000<Gooooo00Goo`00ooooooooooooooooool0000K
ooooo`03o`000?oooooooooo00?ooooo0004ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool00oooool2o`0001kooooo00Goo`00ooooooooooooooooool00035ooooo`05ool00?oo
oooooooooooooooo00006Oooool3o`0000Gooooo0004ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Mooooo`05ool00?oooooooooooooooooo
0000aOooool01Ooo003oooooooooooooooooo`0001_ooooo00?o0000ooooooooool00oooool000Co
00000oooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo01gooooo00Goo`00oooo
ooooooooooooool00035ooooo`05ool00?oooooooooooooooooo00006oooool00ol0003ooooooooo
o`03ooooo`0000?o0000ooooooooool01?ooool01?l0003oooooooooool00005ooooo`03o`000?oo
oooooooo01gooooo00Goo`00ooooooooooooooooool00035ooooo`05ool00?oooooooooooooooooo
00006oooool00ol0003oooooooooo`03ooooo`001Ol00003ooooo`;o00001_ooool00ol0003ooooo
ooooo`0Mooooo`05ool00?oooooooooooooooooo0000aOooool01Ooo003oooooooooooooooooo`00
01_ooooo00?o0000ooooooooool00oooool0013ooooo00?o0000ooooooooool07Oooool01Ooo003o
ooooooooooooooooo`000<Gooooo00Goo`00ooooooooooooooooool0000Kooooo`03o`000?oooooo
oooo00?ooooo000@ooooo`;o00007_ooool01Ooo003oooooooooooooooooo`000<Gooooo00Goo`00
ooooooooooooooooool0000Jooooo`;o00001Oooool0013ooooo00?o0000ooooooooool07Oooool0
1Ooo003oooooooooooooooooo`000<Gooooo00Goo`00ooooooooooooooooool0000Kooooo`03o`00
0?oooooooooo00?ooooo000@ooooo`03o`000?oooooooooo01_ooooo0ooo0003ooooo`03ool00?oo
oooooooo0<?ooooo00?oo`00ooooooooool00ooo000Jooooo`03o`000?oooooooooo00?ooooo000@
ooooo`03o`000?oooooooooo01_ooooo0ooo0003ooooo`03ool00?oooooooooo0<?ooooo00?oo`00
ooooooooool00ooo000Jooooo`03o`000?oooooooooo00?ooooo000@ooooo`03o`000?oooooooooo
01_ooooo0ooo0002ooooo`?oo`00`_ooool3ool000;ooooo0ooo000Jooooo`03o`000?oooooooooo
00?ooooo000@ooooo`03o`000?oooooooooo023ooooo0ooo0032ooooo`?oo`007oooool00ol0003o
ooooooooo`03ooooo`004?ooool2o`00027ooooo0ooo0032ooooo`?oo`007_ooool2o`0000Gooooo
000@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooool000001Oooool0013oooooool0000<
o`0000Gooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-5.20018, -5.5432, 0.232596, \
0.341134}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Rearrange and scale DFT result", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(g5 = 
        DiscreteListPlot[FourierRearrange[Abs[Last\  /@ \ fft], fs], Red, 
          PlotRange \[Rule] All, ImageSize \[Rule] 504, \ 
          Frame \[Rule] True, \ Axes \[Rule] False, \ 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(g6\  = \ Show[g1, g5];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.047619 0.0147151 0.00907075 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .10542 -12 -4.5 ]
[-0.0125 .10542 0 4.5 ]
[-0.0125 .19613 -12 -4.5 ]
[-0.0125 .19613 0 4.5 ]
[-0.0125 .28684 -12 -4.5 ]
[-0.0125 .28684 0 4.5 ]
[-0.0125 .37754 -12 -4.5 ]
[-0.0125 .37754 0 4.5 ]
[-0.0125 .46825 -12 -4.5 ]
[-0.0125 .46825 0 4.5 ]
[-0.0125 .55896 -12 -4.5 ]
[-0.0125 .55896 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .10542 m
.00625 .10542 L
s
[(10)] -0.0125 .10542 1 0 Mshowa
0 .19613 m
.00625 .19613 L
s
[(20)] -0.0125 .19613 1 0 Mshowa
0 .28684 m
.00625 .28684 L
s
[(30)] -0.0125 .28684 1 0 Mshowa
0 .37754 m
.00625 .37754 L
s
[(40)] -0.0125 .37754 1 0 Mshowa
0 .46825 m
.00625 .46825 L
s
[(50)] -0.0125 .46825 1 0 Mshowa
0 .55896 m
.00625 .55896 L
s
[(60)] -0.0125 .55896 1 0 Mshowa
.125 Mabswid
0 .03286 m
.00375 .03286 L
s
0 .051 m
.00375 .051 L
s
0 .06914 m
.00375 .06914 L
s
0 .08728 m
.00375 .08728 L
s
0 .12356 m
.00375 .12356 L
s
0 .14171 m
.00375 .14171 L
s
0 .15985 m
.00375 .15985 L
s
0 .17799 m
.00375 .17799 L
s
0 .21427 m
.00375 .21427 L
s
0 .23241 m
.00375 .23241 L
s
0 .25055 m
.00375 .25055 L
s
0 .2687 m
.00375 .2687 L
s
0 .30498 m
.00375 .30498 L
s
0 .32312 m
.00375 .32312 L
s
0 .34126 m
.00375 .34126 L
s
0 .3594 m
.00375 .3594 L
s
0 .39569 m
.00375 .39569 L
s
0 .41383 m
.00375 .41383 L
s
0 .43197 m
.00375 .43197 L
s
0 .45011 m
.00375 .45011 L
s
0 .48639 m
.00375 .48639 L
s
0 .50454 m
.00375 .50454 L
s
0 .52268 m
.00375 .52268 L
s
0 .54082 m
.00375 .54082 L
s
0 .5771 m
.00375 .5771 L
s
0 .59524 m
.00375 .59524 L
s
0 .61338 m
.00375 .61338 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .10542 m
1 .10542 L
s
.99375 .19613 m
1 .19613 L
s
.99375 .28684 m
1 .28684 L
s
.99375 .37754 m
1 .37754 L
s
.99375 .46825 m
1 .46825 L
s
.99375 .55896 m
1 .55896 L
s
.125 Mabswid
.99625 .03286 m
1 .03286 L
s
.99625 .051 m
1 .051 L
s
.99625 .06914 m
1 .06914 L
s
.99625 .08728 m
1 .08728 L
s
.99625 .12356 m
1 .12356 L
s
.99625 .14171 m
1 .14171 L
s
.99625 .15985 m
1 .15985 L
s
.99625 .17799 m
1 .17799 L
s
.99625 .21427 m
1 .21427 L
s
.99625 .23241 m
1 .23241 L
s
.99625 .25055 m
1 .25055 L
s
.99625 .2687 m
1 .2687 L
s
.99625 .30498 m
1 .30498 L
s
.99625 .32312 m
1 .32312 L
s
.99625 .34126 m
1 .34126 L
s
.99625 .3594 m
1 .3594 L
s
.99625 .39569 m
1 .39569 L
s
.99625 .41383 m
1 .41383 L
s
.99625 .43197 m
1 .43197 L
s
.99625 .45011 m
1 .45011 L
s
.99625 .48639 m
1 .48639 L
s
.99625 .50454 m
1 .50454 L
s
.99625 .52268 m
1 .52268 L
s
.99625 .54082 m
1 .54082 L
s
.99625 .5771 m
1 .5771 L
s
.99625 .59524 m
1 .59524 L
s
.99625 .61338 m
1 .61338 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
0 0 1 r
.5 Mabswid
[ .01 ] 0 setdash
.02381 .01907 m
.02395 .01907 L
.02408 .01906 L
.02423 .01905 L
.02437 .01904 L
.02462 .01901 L
.02489 .01897 L
.02519 .01891 L
.02551 .01883 L
.02608 .01865 L
.02722 .01815 L
.02847 .01741 L
.02973 .01653 L
.03043 .01604 L
.03077 .01581 L
.03109 .01563 L
.03125 .01556 L
.03139 .0155 L
.03147 .01548 L
.03156 .01546 L
.03171 .01544 L
.03179 .01544 L
.03188 .01545 L
.03197 .01546 L
.03206 .01549 L
.03221 .01554 L
.03238 .01562 L
.03299 .01599 L
.03355 .01638 L
.03476 .01723 L
.03605 .01803 L
.03714 .01855 L
.03777 .01877 L
.03805 .01885 L
.03836 .01893 L
.03863 .01898 L
.03892 .01903 L
.03908 .01905 L
.03923 .01906 L
.03938 .01907 L
.03952 .01907 L
.03965 .01908 L
.03978 .01908 L
.0399 .01907 L
.04003 .01907 L
.04017 .01906 L
.04031 .01904 L
.04058 .01901 L
.04089 .01896 L
.04122 .01888 L
Mistroke
.04183 .0187 L
.04243 .01847 L
.04298 .01821 L
.04525 .0168 L
.04644 .01595 L
.04673 .01576 L
.04705 .01559 L
.04722 .01552 L
.04731 .01549 L
.04739 .01547 L
.04746 .01546 L
.04755 .01545 L
.0477 .01545 L
.04778 .01546 L
.04786 .01547 L
.04802 .01552 L
.04819 .01559 L
.04836 .01567 L
.04905 .01612 L
.05029 .017 L
.05155 .01783 L
.05217 .01817 L
.05273 .01844 L
.05326 .01866 L
.05383 .01885 L
.05415 .01893 L
.05444 .01899 L
.05472 .01904 L
.05487 .01906 L
.05501 .01907 L
.05517 .01908 L
.05531 .01909 L
.05546 .0191 L
.05555 .0191 L
.05563 .0191 L
.05576 .01909 L
.05591 .01909 L
.05606 .01908 L
.0562 .01906 L
.05653 .01902 L
.05683 .01897 L
.05716 .01889 L
.05751 .01879 L
.05866 .01833 L
.05989 .01765 L
.0621 .01611 L
.0627 .01572 L
.063 .01556 L
.06309 .01553 L
.06318 .0155 L
Mistroke
.06326 .01548 L
.06334 .01546 L
.06342 .01545 L
.06351 .01545 L
.0636 .01545 L
.06369 .01546 L
.06378 .01549 L
.06387 .01551 L
.06403 .01558 L
.06434 .01574 L
.06467 .01595 L
.06583 .01678 L
.0671 .01765 L
.06827 .01831 L
.0689 .0186 L
.06951 .01882 L
.06984 .01891 L
.0702 .019 L
.07052 .01906 L
.07068 .01908 L
.07082 .0191 L
.07096 .01911 L
.07111 .01912 L
.07119 .01913 L
.07127 .01913 L
.07142 .01913 L
.07158 .01913 L
.07172 .01913 L
.0718 .01912 L
.07188 .01912 L
.07205 .0191 L
.0722 .01909 L
.07233 .01907 L
.07264 .01902 L
.07294 .01895 L
.07326 .01886 L
.07437 .01844 L
.07504 .0181 L
.07568 .01773 L
.07688 .01692 L
.07804 .01608 L
.07837 .01585 L
.07868 .01567 L
.07882 .0156 L
.07897 .01553 L
.07912 .01548 L
.07927 .01546 L
.07941 .01545 L
.07954 .01547 L
.07968 .0155 L
Mistroke
.07982 .01555 L
.08006 .01566 L
.08033 .01582 L
.08149 .01664 L
.08262 .01744 L
.08383 .01818 L
.08453 .01853 L
.08517 .01879 L
.08547 .01889 L
.08581 .01898 L
.0861 .01905 L
.08642 .01911 L
.08658 .01913 L
.08674 .01915 L
.08689 .01916 L
.08704 .01917 L
.08718 .01918 L
.08731 .01918 L
.08745 .01918 L
.08761 .01918 L
.08769 .01917 L
.08777 .01917 L
.08795 .01915 L
.08811 .01913 L
.08827 .01911 L
.08856 .01906 L
.08888 .01898 L
.08944 .01881 L
.09006 .01857 L
.09116 .018 L
.09353 .01637 L
.09418 .01591 L
.09454 .01569 L
.09471 .0156 L
.09487 .01553 L
.09503 .01549 L
.0951 .01547 L
.09519 .01546 L
.09527 .01546 L
.09536 .01547 L
.09545 .01548 L
.09553 .0155 L
.09567 .01555 L
.09583 .01562 L
.09612 .01578 L
.09863 .01757 L
.09972 .01824 L
.1009 .01879 L
.10154 .01901 L
.10182 .01908 L
Mistroke
.10212 .01914 L
.10241 .01919 L
.10255 .01921 L
.10268 .01922 L
.10283 .01923 L
.10297 .01924 L
.10312 .01925 L
.10328 .01925 L
.10343 .01924 L
.10358 .01924 L
.10366 .01923 L
.10374 .01922 L
.10391 .01921 L
.10424 .01916 L
.10459 .01909 L
.10517 .01892 L
.10581 .01868 L
.10705 .01805 L
.10817 .01731 L
.10949 .01634 L
.11007 .01592 L
.11037 .01573 L
.11054 .01564 L
.1107 .01556 L
.11085 .01551 L
.11101 .01548 L
.11115 .01547 L
.11128 .01548 L
.11141 .01551 L
.11155 .01556 L
.11169 .01562 L
.11183 .01569 L
.11302 .01653 L
.11424 .01743 L
.11553 .01826 L
.11669 .01883 L
.11735 .01906 L
.11766 .01915 L
.11796 .01922 L
.11823 .01926 L
.11837 .01928 L
.11852 .0193 L
.11865 .01931 L
.11879 .01932 L
.11892 .01933 L
.11904 .01933 L
.11919 .01933 L
.11933 .01933 L
.11945 .01932 L
.11959 .01931 L
Mistroke
.11974 .01929 L
.1199 .01927 L
.12019 .01923 L
.1205 .01916 L
.12084 .01907 L
.12143 .01886 L
.12207 .01858 L
.12277 .0182 L
.12405 .01736 L
.12521 .01649 L
.12578 .01606 L
.12609 .01585 L
.12641 .01565 L
.12655 .01559 L
.1267 .01553 L
.12678 .01551 L
.12686 .0155 L
.12701 .01548 L
.12714 .01549 L
.12728 .01552 L
.12742 .01557 L
.12756 .01563 L
.1282 .01603 L
.12878 .01647 L
.13008 .01746 L
.13121 .01822 L
.1324 .01884 L
.13302 .01909 L
.13335 .01919 L
.1337 .01928 L
.13403 .01935 L
.13432 .01939 L
.13447 .01941 L
.13462 .01942 L
.13477 .01943 L
.1349 .01943 L
.13506 .01943 L
.13514 .01943 L
.13522 .01943 L
.13538 .01942 L
.13552 .01941 L
.13569 .01939 L
.13584 .01937 L
.13618 .0193 L
.13648 .01923 L
.1368 .01914 L
.13739 .01892 L
.13855 .01834 L
.13963 .01764 L
.14072 .01682 L
Mistroke
.14189 .01593 L
.14223 .01571 L
.1424 .01562 L
.14256 .01556 L
.1427 .01552 L
.14285 .0155 L
.14294 .0155 L
.14302 .01551 L
.14317 .01554 L
.14332 .01559 L
.14347 .01567 L
.14375 .01583 L
.14437 .01629 L
.1456 .01726 L
.14677 .0181 L
.1479 .01877 L
.1484 .019 L
.14895 .01922 L
.1495 .01938 L
.1498 .01945 L
.15008 .01949 L
.15023 .01951 L
.15038 .01953 L
.15052 .01954 L
.15067 .01955 L
.15082 .01955 L
.15091 .01955 L
.15099 .01955 L
.15115 .01955 L
.1513 .01954 L
.15145 .01952 L
.15161 .0195 L
.15193 .01945 L
.15223 .01938 L
.15251 .01931 L
.15314 .01908 L
.15382 .01877 L
.1562 .01719 L
.15746 .01619 L
.15782 .01592 L
.158 .0158 L
.15816 .0157 L
.15831 .01563 L
.15847 .01556 L
.15855 .01554 L
.15863 .01553 L
.15871 .01552 L
.1588 .01552 L
.15888 .01552 L
.15896 .01554 L
Mistroke
.15912 .01558 L
.1592 .01562 L
.15928 .01566 L
.15947 .01576 L
.1601 .01621 L
.16128 .01717 L
.16239 .01802 L
.16359 .01878 L
.16416 .01908 L
.16478 .01933 L
.16512 .01945 L
.16542 .01953 L
.16573 .0196 L
.16587 .01962 L
.16603 .01965 L
.16616 .01966 L
.1663 .01968 L
.16645 .01969 L
.16658 .01969 L
.16672 .0197 L
.16685 .0197 L
.16697 .01969 L
.1671 .01969 L
.16725 .01967 L
.16739 .01966 L
.1677 .01961 L
.16799 .01955 L
.16826 .01948 L
.16882 .0193 L
.16944 .01903 L
.17069 .0183 L
.17292 .01657 L
.17355 .01606 L
.17387 .01584 L
.174 .01575 L
.17415 .01567 L
.17429 .01561 L
.17442 .01557 L
.17455 .01554 L
.17469 .01554 L
.17485 .01556 L
.175 .01561 L
.17513 .01567 L
.17528 .01575 L
.17659 .01677 L
.1778 .01777 L
.17908 .01868 L
.1797 .01905 L
.18028 .01933 L
.18079 .01954 L
Mistroke
.18136 .01971 L
.18165 .01977 L
.18192 .01982 L
.18207 .01984 L
.18221 .01985 L
.18237 .01986 L
.18252 .01987 L
.18266 .01987 L
.18281 .01987 L
.18295 .01986 L
.18307 .01985 L
.18322 .01984 L
.18337 .01982 L
.18369 .01976 L
.184 .01969 L
.18433 .01959 L
.18492 .01937 L
.18609 .01875 L
.18714 .01801 L
.18827 .01709 L
.18946 .01608 L
.18976 .01586 L
.18992 .01576 L
.19008 .01567 L
.19017 .01563 L
.19026 .0156 L
.19035 .01558 L
.19043 .01556 L
.19052 .01556 L
.19059 .01556 L
.19068 .01558 L
.19076 .0156 L
.19091 .01565 L
.19106 .01573 L
.19134 .01591 L
.19197 .01641 L
.1932 .01748 L
.19437 .01842 L
.1955 .01917 L
.196 .01944 L
.19655 .01968 L
.1971 .01986 L
.1974 .01994 L
.19768 .02 L
.19783 .02002 L
.19799 .02004 L
.19812 .02005 L
.19827 .02006 L
.19835 .02007 L
.19843 .02007 L
Mistroke
.19852 .02007 L
.1986 .02007 L
.19875 .02007 L
.19891 .02006 L
.19906 .02004 L
.19921 .02002 L
.19955 .01996 L
.19987 .01989 L
.20022 .01978 L
.20085 .01953 L
.20143 .01923 L
.20262 .01845 L
.20373 .01755 L
.20502 .0164 L
.20533 .01614 L
.20565 .01589 L
.20593 .01572 L
.20609 .01565 L
.20623 .0156 L
.20637 .01559 L
.20651 .0156 L
.20663 .01562 L
.20675 .01567 L
.2069 .01574 L
.20705 .01583 L
.20731 .01603 L
.20848 .01706 L
.20968 .01812 L
.21096 .0191 L
.2116 .01949 L
.21219 .01979 L
.21273 .02001 L
.21304 .02011 L
.21332 .02018 L
.21361 .02024 L
.21374 .02026 L
.21388 .02028 L
.21402 .02029 L
.21416 .0203 L
.21431 .02031 L
.21439 .02031 L
.21447 .02031 L
.2146 .0203 L
.21473 .0203 L
.21485 .02029 L
.21498 .02027 L
.21526 .02023 L
.21553 .02018 L
.21609 .02001 L
.21669 .01976 L
Mistroke
.21778 .01914 L
.21908 .01815 L
.22027 .01707 L
.22084 .01653 L
.22115 .01625 L
.22145 .016 L
.22173 .01581 L
.22188 .01572 L
.22203 .01566 L
.22215 .01563 L
.22228 .01562 L
.22242 .01563 L
.22255 .01567 L
.2227 .01574 L
.22287 .01584 L
.22318 .01607 L
.22375 .01659 L
.22505 .01782 L
.22627 .01889 L
.22743 .01969 L
.22806 .02004 L
.2284 .02019 L
.22875 .02032 L
.22905 .02042 L
.22938 .02049 L
.22952 .02052 L
.22968 .02055 L
.22982 .02056 L
.22996 .02058 L
.2301 .02058 L
.23023 .02059 L
.23038 .02059 L
.23054 .02058 L
.23062 .02058 L
.2307 .02057 L
.23086 .02055 L
.23101 .02053 L
.23116 .02051 L
.23144 .02044 L
.23169 .02037 L
.23226 .02016 L
.23288 .01985 L
.23355 .01944 L
.23477 .01849 L
.23601 .01732 L
.23717 .01619 L
.23747 .01595 L
.23762 .01584 L
.23776 .01576 L
.23791 .0157 L
Mistroke
.238 .01567 L
.23809 .01566 L
.23823 .01566 L
.23838 .0157 L
.23847 .01573 L
.23856 .01577 L
.23871 .01587 L
.23907 .01615 L
.23971 .01677 L
.24095 .01802 L
.24212 .01909 L
.24326 .01994 L
.24376 .02024 L
.24431 .02051 L
.24486 .02071 L
.24516 .0208 L
.24544 .02085 L
.2456 .02088 L
.24575 .0209 L
.24589 .02091 L
.24603 .02092 L
.24612 .02092 L
.24619 .02092 L
.24628 .02092 L
.24636 .02092 L
.24651 .02091 L
.24667 .02089 L
.24683 .02087 L
.24698 .02085 L
.24731 .02077 L
.24764 .02067 L
.24799 .02054 L
.24862 .02023 L
.2492 .01987 L
.2517 .01767 L
.2528 .01652 L
.2531 .01623 L
.25342 .01596 L
.25357 .01585 L
.25373 .01577 L
.25386 .01572 L
.25401 .0157 L
.25416 .01571 L
.2543 .01576 L
.25443 .01582 L
.25457 .01591 L
.25517 .01644 L
.25625 .0176 L
.25748 .01888 L
.25863 .01989 L
Mistroke
.25978 .02066 L
.26038 .02096 L
.26072 .02108 L
.26103 .02118 L
.26119 .02121 L
.26136 .02125 L
.2615 .02127 L
.26166 .02129 L
.26174 .0213 L
.26182 .0213 L
.26198 .02131 L
.26206 .02131 L
.26215 .02131 L
.26225 .02131 L
.26234 .0213 L
.26241 .0213 L
.2625 .02129 L
.26265 .02127 L
.2628 .02125 L
.26293 .02122 L
.26324 .02114 L
.26357 .02103 L
.26417 .02076 L
.26471 .02045 L
.26593 .01952 L
.26814 .01723 L
.26871 .01659 L
.26903 .01627 L
.26932 .016 L
.26946 .01591 L
.2696 .01582 L
.26976 .01577 L
.2699 .01575 L
.27003 .01576 L
.27015 .0158 L
.27028 .01587 L
.27043 .01596 L
.27075 .01624 L
.2711 .01661 L
.27173 .01733 L
.27293 .01869 L
.27416 .01994 L
.27531 .02085 L
.27589 .02121 L
.27652 .02149 L
.27685 .02161 L
.27704 .02166 L
.27721 .0217 L
.27737 .02173 L
.27751 .02175 L
Mistroke
.27759 .02175 L
.27767 .02176 L
.27776 .02177 L
.27784 .02177 L
.27799 .02177 L
.27813 .02177 L
.27829 .02176 L
.27843 .02174 L
.27857 .02172 L
.2787 .0217 L
.27899 .02163 L
.27931 .02153 L
.27959 .02141 L
.28024 .02108 L
.28087 .02065 L
.28155 .0201 L
.28278 .01885 L
.28403 .01739 L
.28464 .01666 L
.2849 .01637 L
.28519 .01609 L
.28535 .01597 L
.28549 .01588 L
.28563 .01583 L
.28577 .0158 L
.28593 .01582 L
.28607 .01588 L
.28623 .01598 L
.2864 .01612 L
.28773 .01767 L
.29011 .0204 L
.29076 .02098 L
.29145 .0215 L
.29211 .02188 L
.29239 .02201 L
.2927 .02212 L
.293 .02221 L
.29316 .02225 L
.29332 .02227 L
.29346 .02229 L
.29359 .0223 L
.29374 .02231 L
.29388 .02231 L
.29404 .02231 L
.29411 .0223 L
.2942 .02229 L
.29435 .02228 L
.2945 .02225 L
.29482 .02218 L
.29516 .02206 L
Mistroke
.29575 .02179 L
.29637 .0214 L
.29749 .02045 L
.29872 .01909 L
.29989 .0176 L
.3004 .01694 L
.30094 .01631 L
.30122 .01605 L
.3013 .01599 L
.30138 .01594 L
.30153 .01589 L
.30168 .01587 L
.30182 .0159 L
.30194 .01595 L
.30208 .01604 L
.30239 .01633 L
.30267 .01666 L
.3033 .01749 L
.30444 .01902 L
.30576 .02061 L
.30633 .0212 L
.30697 .02177 L
.30751 .02217 L
.3081 .02251 L
.30842 .02265 L
.30871 .02276 L
.30885 .0228 L
.30901 .02284 L
.30914 .02286 L
.30929 .02289 L
.30944 .0229 L
.30959 .02291 L
.30967 .02291 L
.30976 .02291 L
.30992 .02291 L
.31 .0229 L
.31009 .02289 L
.31024 .02287 L
.31043 .02283 L
.31059 .02279 L
.31089 .0227 L
.31121 .02256 L
.3118 .02224 L
.31239 .02181 L
.31294 .02132 L
.3142 .01993 L
.3155 .01819 L
.31614 .01729 L
.31646 .01686 L
.31674 .01651 L
Mistroke
.31701 .01621 L
.31717 .01609 L
.31731 .016 L
.31746 .01595 L
.31753 .01595 L
.31762 .01596 L
.31777 .01601 L
.31791 .01611 L
.31808 .01625 L
.31823 .01642 L
.31853 .01679 L
.31919 .01772 L
.32142 .0208 L
.32259 .02206 L
.32318 .02255 L
.32383 .02298 L
.32438 .02325 L
.3247 .02335 L
.32484 .02339 L
.32498 .02342 L
.32511 .02344 L
.32524 .02345 L
.32539 .02347 L
.32553 .02347 L
.32566 .02347 L
.3258 .02346 L
.32593 .02344 L
.32606 .02342 L
.32621 .02339 L
.32635 .02336 L
.32662 .02327 L
.32691 .02315 L
.32723 .02299 L
.3278 .02262 L
.32832 .02218 L
.32953 .0209 L
.33082 .01918 L
.33195 .01751 L
.33254 .01669 L
.33284 .01634 L
.33292 .01627 L
.33301 .01619 L
.33316 .0161 L
.33331 .01605 L
.3334 .01604 L
.33347 .01605 L
.33362 .0161 L
.33377 .0162 L
.3339 .01632 L
.33403 .01645 L
Mistroke
.33431 .01681 L
.33537 .01834 L
.33761 .02136 L
.33822 .022 L
.33887 .02256 L
.33949 .02297 L
.33976 .02311 L
.34005 .02323 L
.34021 .02329 L
.34038 .02334 L
.34054 .02338 L
.34068 .0234 L
.34077 .02342 L
.34085 .02343 L
.34094 .02343 L
.34103 .02344 L
.34112 .02344 L
.34121 .02344 L
.34136 .02343 L
.34151 .02342 L
.34167 .02339 L
.34182 .02336 L
.34195 .02333 L
.34227 .02322 L
.3426 .02307 L
.3432 .02272 L
.34376 .02229 L
.34503 .021 L
.34729 .01798 L
.34791 .01714 L
.34825 .01673 L
.34841 .01656 L
.34857 .01642 L
.34869 .01632 L
.34884 .01623 L
.34898 .01617 L
.34913 .01615 L
.34928 .01617 L
.34936 .01619 L
.34944 .01622 L
.3496 .01631 L
.34974 .01642 L
.35039 .01706 L
.35098 .01774 L
.35232 .01914 L
.35293 .01966 L
.3535 .02004 L
.35381 .02021 L
.3541 .02033 L
.35441 .02044 L
Mistroke
.35459 .02049 L
.35475 .02052 L
.35489 .02054 L
.35504 .02056 L
.35518 .02057 L
.35531 .02057 L
.35546 .02057 L
.35554 .02056 L
.35562 .02056 L
.35577 .02054 L
.35592 .02051 L
.35608 .02047 L
.35625 .02043 L
.35657 .02032 L
.35716 .02004 L
.35772 .01969 L
.35832 .01925 L
.35938 .01833 L
.36062 .01724 L
.36178 .01637 L
.36283 .01579 L
.36311 .01565 L
.36342 .01552 L
.36354 .01547 L
.36368 .01543 L
.36383 .0154 L
.36397 .01539 L
.36411 .0154 L
.36425 .01544 L
.3644 .01552 L
.36449 .01558 L
.36456 .01565 L
.36489 .01601 L
.36519 .01647 L
.36573 .01753 L
.36632 .01906 L
.36696 .02123 L
.36763 .02413 L
.36884 .03114 L
.36998 .04008 L
.3712 .05253 L
.37341 .08313 L
.37597 .13212 L
.37839 .19129 L
.38301 .32753 L
.38791 .4745 L
.39019 .53018 L
.39138 .55412 L
.39264 .57465 L
.39329 .58311 L
Mistroke
.39399 .59075 L
.39463 .59615 L
.39523 .59983 L
.39555 .60125 L
.3957 .60182 L
.39585 .60226 L
.39597 .60259 L
.39611 .60288 L
.39626 .6031 L
.39641 .60325 L
.39649 .6033 L
.39657 .60332 L
.39672 .60329 L
.3968 .60325 L
.39688 .60318 L
.39696 .60308 L
.39706 .60294 L
.39722 .60262 L
.39737 .60222 L
.39766 .60125 L
.39795 .59997 L
.39822 .5985 L
.39884 .59419 L
.39944 .58872 L
.40008 .5815 L
.40231 .54648 L
.40487 .49 L
.4073 .42503 L
.41192 .28773 L
.41683 .14676 L
.41927 .08414 L
.42047 .05553 L
.42099 .04344 L
.42157 .03058 L
.42183 .02485 L
.42198 .02187 L
.42212 .01944 L
.42225 .01821 L
.42239 .01912 L
.42251 .0212 L
.42263 .02345 L
.42375 .04671 L
.42612 .09375 L
.43086 .17857 L
.43543 .24653 L
.43778 .27393 L
.43908 .28628 L
.44029 .29557 L
.44151 .30264 L
.44216 .30538 L
Mistroke
.44249 .30652 L
.44285 .30753 L
.44319 .3083 L
.44334 .30857 L
.4435 .30882 L
.44365 .309 L
.4438 .30916 L
.44389 .30922 L
.44396 .30927 L
.44412 .30934 L
.44426 .30936 L
.4444 .30935 L
.44455 .3093 L
.44471 .3092 L
.44485 .30908 L
.44498 .30893 L
.44527 .30849 L
.44556 .3079 L
.44584 .30721 L
.44646 .30515 L
.44706 .30249 L
.44771 .29897 L
.44888 .29082 L
.44994 .28157 L
.45476 .22221 L
.45941 .15255 L
.46176 .11881 L
.46435 .0861 L
.46683 .0605 L
.4691 .04296 L
.46968 .03953 L
.47031 .03638 L
.47059 .03517 L
.4709 .03407 L
.47119 .03322 L
.47145 .03261 L
.47161 .03233 L
.47178 .0321 L
.47187 .03201 L
.47195 .03194 L
.47204 .03189 L
.47213 .03186 L
.47221 .03185 L
.4723 .03186 L
.47239 .03189 L
.47247 .03194 L
.47262 .03207 L
.47277 .03227 L
.47292 .03251 L
.47307 .03281 L
Mistroke
.47334 .0335 L
.47397 .03564 L
.4746 .03849 L
.47519 .04164 L
.47652 .05034 L
.47894 .07117 L
.48142 .09882 L
.48366 .12884 L
.48849 .20263 L
.49314 .26861 L
.49555 .2935 L
.49676 .3025 L
.49745 .30643 L
.49809 .30928 L
.49869 .31123 L
.49903 .31202 L
.49919 .31231 L
.49935 .31253 L
.49949 .3127 L
.49962 .31282 L
.49977 .31291 L
.49993 .31296 L
.50007 .31296 L
.50023 .31291 L
.50031 .31287 L
.50039 .31281 L
.50054 .31267 L
.50069 .31248 L
.50083 .31226 L
.50114 .31164 L
.50142 .31093 L
.50171 .31001 L
.50278 .30524 L
.50337 .30165 L
.50392 .2978 L
.50514 .28728 L
.50735 .26256 L
.51214 .1927 L
.51676 .12295 L
.51933 .0898 L
.52166 .06537 L
.52283 .05528 L
.5241 .04605 L
.52529 .03902 L
.52587 .03631 L
.52639 .03432 L
.52666 .03349 L
.52696 .03276 L
.52712 .03244 L
.52727 .03221 L
Mistroke
.52741 .03204 L
.52757 .03192 L
.5277 .03186 L
.52784 .03185 L
.52797 .03189 L
.52809 .03197 L
.52822 .0321 L
.52837 .03229 L
.52852 .03256 L
.52866 .03285 L
.52899 .03372 L
.5293 .03476 L
.52987 .0372 L
.53116 .04465 L
.53358 .06427 L
.5358 .08783 L
.54056 .15208 L
.54514 .22078 L
.54768 .25532 L
.55001 .28106 L
.55116 .2911 L
.55177 .29558 L
.55241 .29968 L
.55298 .30268 L
.5536 .30536 L
.55387 .30632 L
.55416 .30721 L
.55444 .30791 L
.5547 .30843 L
.55498 .30888 L
.55514 .30907 L
.55529 .3092 L
.55543 .30929 L
.55556 .30934 L
.5557 .30936 L
.55585 .30935 L
.556 .30929 L
.55608 .30924 L
.55616 .30919 L
.55631 .30905 L
.55645 .30889 L
.55676 .30839 L
.55711 .30764 L
.55775 .30572 L
.55843 .3029 L
.55965 .29592 L
.56089 .28647 L
.56224 .2738 L
.56467 .2452 L
.56962 .17053 L
Mistroke
.57208 .12742 L
.57438 .08412 L
.57659 .03948 L
.5769 .03312 L
.57723 .02624 L
.57738 .02317 L
.57747 .02157 L
.57754 .02017 L
.57768 .0184 L
.57783 .01879 L
.57797 .02095 L
.57812 .02381 L
.57838 .02934 L
.57896 .04244 L
.58356 .1574 L
.58846 .29894 L
.59317 .43808 L
.59557 .50075 L
.59684 .52935 L
.59817 .55535 L
.59937 .57431 L
.6 .58256 L
.60068 .58996 L
.60131 .59536 L
.60188 .5991 L
.60215 .60049 L
.60245 .60168 L
.60259 .60212 L
.60274 .60252 L
.60287 .60281 L
.603 .60303 L
.60315 .60321 L
.60323 .60327 L
.60331 .60331 L
.6034 .60332 L
.60349 .6033 L
.60365 .6032 L
.6038 .60303 L
.60393 .60279 L
.60408 .60245 L
.60424 .602 L
.60457 .60076 L
.60488 .59924 L
.60559 .59447 L
.6062 .58886 L
.60676 .58257 L
.60802 .56447 L
.61031 .51904 L
.61281 .45451 L
.61771 .30529 L
Mistroke
.62243 .17006 L
.62501 .11172 L
.62619 .0898 L
.62744 .07005 L
.62859 .0549 L
.62986 .04154 L
.63101 .03215 L
.63209 .02554 L
.63269 .02266 L
.63335 .02013 L
.63397 .01826 L
.63454 .01695 L
.63506 .01609 L
.6352 .0159 L
.63535 .01573 L
.63549 .0156 L
.63563 .01551 L
.63577 .01544 L
.63592 .01539 L
.63607 .01539 L
.63623 .01541 L
.63638 .01545 L
.63652 .0155 L
.63678 .0156 L
.63795 .0162 L
.63919 .01708 L
.64142 .01903 L
.64255 .01987 L
.64288 .02006 L
.64319 .02022 L
.64347 .02033 L
.64378 .02044 L
.64392 .02048 L
.64406 .02051 L
.6442 .02053 L
.64432 .02055 L
.64444 .02056 L
.64457 .02057 L
.64469 .02057 L
.64483 .02057 L
.64498 .02056 L
.64512 .02054 L
.64528 .02052 L
.64543 .02048 L
.64569 .02041 L
.64598 .0203 L
.64657 .02 L
.64712 .01962 L
.64837 .01845 L
.64961 .01707 L
Mistroke
.64991 .01674 L
.65023 .01644 L
.65041 .0163 L
.6505 .01625 L
.65058 .01621 L
.65066 .01618 L
.65075 .01616 L
.65091 .01615 L
.65105 .01618 L
.6512 .01625 L
.65134 .01634 L
.65147 .01645 L
.65209 .01714 L
.65334 .01887 L
.65443 .02032 L
.65558 .02166 L
.65614 .0222 L
.65677 .0227 L
.65734 .02304 L
.65759 .02317 L
.65787 .02327 L
.65818 .02336 L
.65835 .0234 L
.6585 .02342 L
.65865 .02343 L
.65878 .02344 L
.65893 .02344 L
.65908 .02343 L
.65924 .02342 L
.65931 .02341 L
.6594 .02339 L
.6597 .02332 L
.65987 .02326 L
.66005 .0232 L
.66038 .02304 L
.66101 .02265 L
.6616 .02217 L
.66293 .02073 L
.66409 .01914 L
.66535 .01728 L
.66567 .01683 L
.66601 .01641 L
.66615 .01627 L
.6663 .01615 L
.66639 .0161 L
.66647 .01607 L
.66662 .01604 L
.66678 .01607 L
.66692 .01614 L
.66708 .01626 L
Mistroke
.66724 .01643 L
.66782 .01718 L
.67007 .0204 L
.6712 .02173 L
.67179 .02229 L
.67242 .02277 L
.67297 .02309 L
.67328 .02323 L
.67357 .02333 L
.67371 .02337 L
.67384 .0234 L
.67395 .02343 L
.67408 .02344 L
.67421 .02346 L
.67434 .02347 L
.67447 .02347 L
.67462 .02346 L
.67478 .02345 L
.67492 .02343 L
.67508 .0234 L
.67525 .02336 L
.67557 .02326 L
.67585 .02315 L
.67643 .02283 L
.67697 .02244 L
.67818 .02126 L
.67949 .01962 L
.68074 .01783 L
.68134 .01696 L
.68161 .01661 L
.6819 .01628 L
.68205 .01613 L
.6822 .01603 L
.68234 .01597 L
.68248 .01595 L
.68264 .01598 L
.68278 .01605 L
.68294 .01617 L
.68311 .01634 L
.68444 .01811 L
.68559 .01966 L
.68682 .02108 L
.68752 .02173 L
.68816 .02221 L
.68847 .0224 L
.6888 .02257 L
.68912 .0227 L
.68941 .02279 L
.68969 .02286 L
.68984 .02288 L
Mistroke
.68999 .0229 L
.69014 .02291 L
.69023 .02291 L
.69031 .02291 L
.69046 .02291 L
.69062 .0229 L
.69077 .02288 L
.69093 .02285 L
.69123 .02278 L
.69158 .02265 L
.6919 .02251 L
.69243 .0222 L
.69302 .02178 L
.6942 .02066 L
.69551 .01908 L
.69676 .01741 L
.6973 .0167 L
.69759 .01635 L
.69787 .01608 L
.69802 .01598 L
.69817 .0159 L
.69826 .01588 L
.69834 .01587 L
.6985 .0159 L
.69865 .01596 L
.69878 .01605 L
.69908 .01633 L
.70151 .01936 L
.7027 .02063 L
.70379 .02151 L
.70437 .02185 L
.70466 .02199 L
.70498 .02211 L
.70515 .02216 L
.7053 .02221 L
.70545 .02224 L
.70559 .02227 L
.70576 .02229 L
.70585 .0223 L
.70594 .02231 L
.7061 .02231 L
.70618 .02231 L
.70627 .02231 L
.7064 .0223 L
.70654 .02229 L
.70669 .02227 L
.70683 .02225 L
.70708 .02219 L
.70735 .02211 L
.70796 .02185 L
Mistroke
.70851 .02153 L
.70972 .02057 L
.71083 .01942 L
.71212 .01785 L
.71276 .01706 L
.71334 .01638 L
.71361 .01612 L
.71375 .016 L
.7139 .0159 L
.71404 .01583 L
.71417 .01581 L
.71431 .01581 L
.71443 .01584 L
.71457 .01591 L
.71472 .01602 L
.71499 .01626 L
.7156 .01694 L
.7168 .01838 L
.71809 .01976 L
.71873 .02034 L
.71934 .0208 L
.71992 .02118 L
.72047 .02144 L
.72098 .02162 L
.72124 .02169 L
.72139 .02172 L
.72153 .02174 L
.72168 .02176 L
.72182 .02177 L
.72196 .02177 L
.72205 .02177 L
.72212 .02177 L
.72226 .02177 L
.72239 .02176 L
.72254 .02174 L
.72268 .02172 L
.72297 .02166 L
.72324 .02158 L
.72386 .02133 L
.72446 .021 L
.7251 .02056 L
.72733 .01841 L
.72856 .017 L
.7292 .01629 L
.72953 .01599 L
.72962 .01593 L
.72972 .01587 L
.72981 .01582 L
.72989 .01578 L
.73004 .01575 L
Mistroke
.73012 .01575 L
.73021 .01576 L
.7303 .01578 L
.73039 .01582 L
.73055 .01591 L
.73084 .01614 L
.73115 .01645 L
.73232 .01774 L
.73355 .01904 L
.73471 .02005 L
.73534 .02049 L
.73592 .02081 L
.73656 .02108 L
.73692 .02118 L
.73708 .02122 L
.73725 .02125 L
.73741 .02128 L
.73756 .02129 L
.73771 .0213 L
.73786 .02131 L
.738 .02131 L
.73812 .02131 L
.73826 .0213 L
.73841 .02128 L
.73857 .02126 L
.73874 .02123 L
.73906 .02115 L
.73936 .02105 L
.73964 .02094 L
.74072 .02036 L
.74186 .01948 L
.74302 .01837 L
.74424 .01706 L
.74475 .01653 L
.74528 .01602 L
.74544 .0159 L
.74559 .01581 L
.74573 .01575 L
.74587 .01571 L
.74601 .0157 L
.74616 .01573 L
.74628 .01577 L
.74642 .01585 L
.74673 .01607 L
.747 .01633 L
.74763 .01696 L
.74876 .01813 L
.75007 .01932 L
.75064 .01976 L
.75128 .02017 L
Mistroke
.75181 .02045 L
.75239 .02068 L
.75271 .02077 L
.75285 .02081 L
.753 .02084 L
.75313 .02086 L
.75328 .02089 L
.75343 .0209 L
.75357 .02091 L
.75366 .02092 L
.75374 .02092 L
.7539 .02092 L
.75398 .02092 L
.75406 .02091 L
.75415 .02091 L
.75425 .0209 L
.75442 .02088 L
.75458 .02085 L
.75488 .02078 L
.75518 .0207 L
.75545 .0206 L
.75608 .02033 L
.75669 .01997 L
.75735 .01951 L
.75855 .01849 L
.75971 .01735 L
.7608 .01627 L
.76108 .01602 L
.76135 .01582 L
.7615 .01574 L
.76158 .01571 L
.76166 .01568 L
.7618 .01566 L
.76194 .01566 L
.76209 .0157 L
.76218 .01573 L
.76225 .01577 L
.76254 .01596 L
.7632 .01654 L
.76452 .01784 L
.76574 .01892 L
.76685 .0197 L
.76747 .02004 L
.76803 .02028 L
.76833 .02038 L
.76864 .02046 L
.76881 .0205 L
.76899 .02053 L
.76916 .02056 L
.76931 .02057 L
Mistroke
.76947 .02058 L
.76962 .02059 L
.76975 .02059 L
.7699 .02058 L
.77005 .02057 L
.77014 .02057 L
.77022 .02056 L
.77038 .02054 L
.77052 .02051 L
.77081 .02045 L
.77111 .02037 L
.77174 .02013 L
.77227 .01987 L
.77285 .01952 L
.77536 .01744 L
.77659 .01627 L
.77693 .01598 L
.77712 .01585 L
.77729 .01574 L
.77744 .01568 L
.7776 .01563 L
.77769 .01562 L
.77777 .01562 L
.77785 .01563 L
.77793 .01565 L
.77801 .01567 L
.7781 .01571 L
.77825 .01579 L
.77854 .01599 L
.77919 .01656 L
.78036 .01765 L
.7816 .0187 L
.78276 .01948 L
.78335 .01978 L
.78397 .02003 L
.78433 .02014 L
.78467 .02022 L
.78482 .02024 L
.78497 .02027 L
.78505 .02028 L
.78514 .02029 L
.7853 .0203 L
.78545 .02031 L
.78559 .02031 L
.78574 .02031 L
.78582 .0203 L
.7859 .0203 L
.78605 .02029 L
.78622 .02027 L
.78637 .02024 L
Mistroke
.78652 .02022 L
.78706 .02008 L
.78733 .01999 L
.78763 .01987 L
.78893 .01917 L
.79015 .01827 L
.7914 .01717 L
.79202 .0166 L
.79259 .0161 L
.79286 .01589 L
.79311 .01573 L
.79325 .01567 L
.7934 .01561 L
.79354 .01559 L
.79366 .01559 L
.7938 .01561 L
.79393 .01566 L
.79408 .01572 L
.79423 .01581 L
.79483 .01627 L
.79722 .01833 L
.79788 .0188 L
.79857 .01923 L
.79917 .01954 L
.79949 .01967 L
.79982 .01979 L
.80012 .01988 L
.80044 .01996 L
.80058 .01999 L
.80073 .02001 L
.80087 .02003 L
.801 .02005 L
.80115 .02006 L
.8013 .02007 L
.80144 .02007 L
.80158 .02007 L
.80171 .02006 L
.80183 .02006 L
.80197 .02005 L
.80211 .02003 L
.80243 .01998 L
.80279 .0199 L
.80312 .0198 L
.80343 .01969 L
.80463 .01909 L
.80579 .01831 L
.80688 .01742 L
.80809 .01636 L
.80841 .0161 L
.80875 .01585 L
Mistroke
.80891 .01574 L
.80907 .01566 L
.80921 .01561 L
.80936 .01557 L
.8095 .01556 L
.80965 .01558 L
.80973 .0156 L
.80981 .01563 L
.80996 .01569 L
.81025 .01587 L
.81052 .01607 L
.81179 .01714 L
.81287 .01802 L
.81402 .01881 L
.81464 .01916 L
.81521 .01942 L
.81578 .01962 L
.81603 .0197 L
.81631 .01976 L
.81661 .01981 L
.81678 .01984 L
.81694 .01985 L
.81708 .01986 L
.81721 .01987 L
.81737 .01987 L
.81751 .01987 L
.81767 .01986 L
.81775 .01985 L
.81783 .01985 L
.81799 .01983 L
.81813 .01981 L
.81846 .01975 L
.81881 .01966 L
.81941 .01946 L
.81996 .01922 L
.82123 .01848 L
.82254 .0175 L
.82377 .01647 L
.82435 .01601 L
.82466 .01579 L
.82481 .0157 L
.82496 .01563 L
.82511 .01557 L
.82519 .01555 L
.82527 .01554 L
.82536 .01554 L
.82544 .01554 L
.82553 .01555 L
.82562 .01558 L
.8257 .0156 L
Mistroke
.82579 .01564 L
.82595 .01572 L
.82624 .01591 L
.82848 .0177 L
.82973 .01857 L
.83089 .01918 L
.83148 .0194 L
.83178 .01949 L
.8321 .01957 L
.83229 .01961 L
.83246 .01964 L
.83262 .01966 L
.83271 .01967 L
.8328 .01968 L
.83296 .01969 L
.83311 .0197 L
.83319 .0197 L
.83328 .0197 L
.83343 .01969 L
.83358 .01969 L
.83367 .01968 L
.83374 .01967 L
.83388 .01966 L
.83404 .01964 L
.8343 .01959 L
.83459 .01953 L
.83522 .01933 L
.83582 .01909 L
.83689 .0185 L
.83803 .01771 L
.83926 .01673 L
.83991 .01621 L
.84026 .01594 L
.84059 .01572 L
.84073 .01565 L
.84088 .01558 L
.84096 .01556 L
.84104 .01554 L
.84119 .01552 L
.84128 .01552 L
.84136 .01552 L
.84145 .01554 L
.84153 .01556 L
.84169 .01562 L
.84185 .01571 L
.84246 .01612 L
.84302 .01656 L
.8442 .0175 L
.84547 .01837 L
.84609 .01872 L
Mistroke
.84667 .01901 L
.84725 .01923 L
.84777 .01938 L
.84805 .01945 L
.84832 .01949 L
.84845 .01951 L
.8486 .01953 L
.84875 .01954 L
.8489 .01955 L
.84902 .01955 L
.84916 .01955 L
.84929 .01955 L
.8494 .01955 L
.84954 .01954 L
.84968 .01952 L
.84982 .01951 L
.84995 .01949 L
.85023 .01944 L
.8505 .01938 L
.85111 .0192 L
.8517 .01896 L
.85233 .01864 L
.8547 .01702 L
.85596 .01604 L
.85632 .01579 L
.8565 .01569 L
.85666 .0156 L
.85681 .01555 L
.85697 .01551 L
.85712 .0155 L
.85721 .0155 L
.8573 .01552 L
.85745 .01556 L
.85754 .01559 L
.85762 .01563 L
.85792 .0158 L
.85849 .0162 L
.85977 .0172 L
.86088 .01799 L
.86208 .01868 L
.86274 .01898 L
.86304 .01908 L
.86336 .01919 L
.86364 .01926 L
.86394 .01933 L
.86411 .01936 L
.86426 .01938 L
.86441 .0194 L
.86456 .01941 L
.8647 .01942 L
Mistroke
.86485 .01943 L
.86498 .01943 L
.86511 .01943 L
.86526 .01943 L
.8654 .01942 L
.86548 .01941 L
.86556 .0194 L
.86571 .01939 L
.86599 .01935 L
.86628 .01929 L
.86681 .01915 L
.86745 .01891 L
.86805 .01863 L
.86939 .01783 L
.87065 .01692 L
.87126 .01644 L
.87182 .01602 L
.87209 .01584 L
.87238 .01566 L
.87252 .0156 L
.87266 .01554 L
.87278 .01551 L
.87291 .01549 L
.87307 .01549 L
.87321 .01551 L
.87336 .01555 L
.87344 .01558 L
.87352 .01562 L
.87409 .01597 L
.87539 .01695 L
.87658 .0178 L
.87771 .01847 L
.87831 .01876 L
.87894 .019 L
.87927 .0191 L
.87962 .01919 L
.87994 .01925 L
.88024 .01929 L
.8804 .01931 L
.88055 .01932 L
.88069 .01933 L
.88084 .01933 L
.88092 .01933 L
.881 .01933 L
.88108 .01933 L
.88117 .01932 L
.88131 .01931 L
.88147 .0193 L
.88162 .01928 L
.88176 .01926 L
Mistroke
.88207 .01921 L
.88262 .01907 L
.88327 .01885 L
.88388 .01857 L
.8851 .01788 L
.88642 .01695 L
.88701 .0165 L
.88765 .01603 L
.88795 .01583 L
.88826 .01565 L
.88838 .01558 L
.88852 .01553 L
.88867 .01549 L
.88881 .01547 L
.88897 .01548 L
.88905 .01549 L
.88913 .01551 L
.88928 .01556 L
.88944 .01563 L
.89002 .01598 L
.89134 .01696 L
.89249 .01776 L
.89371 .01846 L
.8943 .01873 L
.89486 .01893 L
.89537 .01908 L
.89565 .01914 L
.89592 .01918 L
.89606 .0192 L
.89621 .01922 L
.89634 .01923 L
.89648 .01924 L
.89663 .01925 L
.89671 .01925 L
.89679 .01925 L
.89694 .01925 L
.89708 .01924 L
.89721 .01923 L
.89735 .01922 L
.8976 .01919 L
.89787 .01915 L
.89817 .01908 L
.89878 .01891 L
.89945 .01865 L
.90065 .01803 L
.90303 .01637 L
.90368 .01591 L
.90404 .01568 L
.90421 .01559 L
.90429 .01556 L
Mistroke
.90437 .01553 L
.90453 .01548 L
.90461 .01547 L
.90469 .01546 L
.90477 .01546 L
.90485 .01547 L
.90494 .01548 L
.90503 .0155 L
.90518 .01555 L
.90531 .01561 L
.90562 .01578 L
.9079 .01741 L
.90911 .01815 L
.90974 .01848 L
.91041 .01876 L
.91102 .01895 L
.91137 .01904 L
.91169 .0191 L
.91184 .01912 L
.91198 .01914 L
.91211 .01916 L
.91225 .01917 L
.9124 .01918 L
.91254 .01918 L
.91269 .01918 L
.91278 .01918 L
.91286 .01918 L
.913 .01917 L
.91315 .01916 L
.9133 .01915 L
.91343 .01913 L
.91369 .01909 L
.91396 .01904 L
.91458 .01887 L
.91515 .01867 L
.91636 .01808 L
.91748 .01738 L
.91878 .01645 L
.91941 .01599 L
.91969 .01581 L
.91999 .01563 L
.92013 .01557 L
.92028 .01551 L
.92041 .01547 L
.92055 .01545 L
.92069 .01545 L
.92083 .01547 L
.92096 .01551 L
.92109 .01556 L
.92138 .0157 L
Mistroke
.92169 .01589 L
.92226 .01629 L
.92357 .01723 L
.92476 .01799 L
.92534 .0183 L
.92598 .01859 L
.92653 .01879 L
.92713 .01896 L
.92746 .01903 L
.92777 .01908 L
.92794 .0191 L
.92809 .01911 L
.92818 .01912 L
.92827 .01913 L
.92836 .01913 L
.92845 .01913 L
.92859 .01913 L
.92872 .01913 L
.92887 .01912 L
.92896 .01912 L
.92903 .01911 L
.92934 .01908 L
.92949 .01906 L
.92966 .01903 L
.93029 .01888 L
.93089 .01868 L
.93202 .01816 L
.93323 .01743 L
.93455 .01651 L
.9351 .01611 L
.93569 .01572 L
.93586 .01563 L
.93602 .01555 L
.93617 .0155 L
.93626 .01548 L
.93633 .01546 L
.93649 .01545 L
.93663 .01546 L
.93671 .01547 L
.93679 .01549 L
.93694 .01554 L
.9371 .01561 L
.93725 .01569 L
.93758 .01589 L
.93826 .01637 L
.93948 .01723 L
.94074 .01802 L
.94136 .01834 L
.94194 .01859 L
.94245 .01877 L
Mistroke
.94301 .01893 L
.9433 .01899 L
.94357 .01904 L
.94371 .01905 L
.94386 .01907 L
.94394 .01908 L
.94403 .01908 L
.94417 .01909 L
.94425 .01909 L
.94433 .0191 L
.94448 .0191 L
.94464 .01909 L
.94473 .01909 L
.94481 .01908 L
.94496 .01907 L
.9451 .01906 L
.94541 .01902 L
.94569 .01896 L
.94599 .01889 L
.94654 .01873 L
.94718 .01848 L
.94785 .01816 L
.94907 .01744 L
.95031 .01657 L
.95097 .0161 L
.95133 .01586 L
.95166 .01566 L
.95181 .01559 L
.95195 .01553 L
.95203 .0155 L
.95212 .01548 L
.95226 .01545 L
.95234 .01544 L
.95243 .01544 L
.95252 .01545 L
.95261 .01547 L
.95276 .01551 L
.95293 .01558 L
.95324 .01575 L
.95354 .01594 L
.95409 .01633 L
.95534 .01721 L
.95651 .01794 L
.95756 .01847 L
.95815 .0187 L
.9587 .01886 L
.95897 .01893 L
.95925 .01898 L
.95941 .01901 L
.95956 .01903 L
Mistroke
.9597 .01905 L
.95985 .01906 L
.96001 .01907 L
.96015 .01907 L
.96031 .01908 L
.9604 .01908 L
.96048 .01907 L
.96063 .01907 L
.96076 .01906 L
.96091 .01905 L
.96107 .01903 L
.96137 .01898 L
.9617 .01892 L
.96228 .01876 L
.96297 .0185 L
.9636 .01821 L
.96611 .01663 L
.96721 .01585 L
.96751 .01567 L
.96768 .01559 L
.96784 .01552 L
.96798 .01548 L
.96807 .01546 L
.96814 .01545 L
.96828 .01544 L
.96842 .01546 L
.96858 .01549 L
.96872 .01554 L
.96903 .0157 L
.96961 .01606 L
.97068 .01683 L
.97191 .01765 L
.97306 .01829 L
.97378 .0186 L
.97455 .01885 L
.97476 .0189 L
.97499 .01895 L
.9752 .01899 L
.97541 .01902 L
.9756 .01904 L
.97571 .01905 L
.97582 .01906 L
.97592 .01906 L
.97601 .01907 L
.9761 .01907 L
.97619 .01907 L
Mfstroke
1 0 0 r
[ ] 0 setdash
.03968 .01472 m
.03968 .01908 L
s
.05556 .01472 m
.05556 .0191 L
s
.07143 .01472 m
.07143 .01913 L
s
.0873 .01472 m
.0873 .01918 L
s
.10317 .01472 m
.10317 .01925 L
s
.11905 .01472 m
.11905 .01933 L
s
.13492 .01472 m
.13492 .01943 L
s
.15079 .01472 m
.15079 .01955 L
s
.16667 .01472 m
.16667 .0197 L
s
.18254 .01472 m
.18254 .01987 L
s
.19841 .01472 m
.19841 .02007 L
s
.21429 .01472 m
.21429 .02031 L
s
.23016 .01472 m
.23016 .02059 L
s
.24603 .01472 m
.24603 .02092 L
s
.2619 .01472 m
.2619 .02131 L
s
.27778 .01472 m
.27778 .02177 L
s
.29365 .01472 m
.29365 .02231 L
s
.30952 .01472 m
.30952 .02291 L
s
.3254 .01472 m
.3254 .02347 L
s
.34127 .01472 m
.34127 .02344 L
s
.35714 .01472 m
.35714 .02005 L
s
.37302 .01472 m
.37302 .07684 L
s
.38889 .01472 m
.38889 .49981 L
s
.40476 .01472 m
.40476 .49268 L
s
.42063 .01472 m
.42063 .05165 L
s
.43651 .01472 m
.43651 .25988 L
s
.45238 .01472 m
.45238 .25452 L
s
.46825 .01472 m
.46825 .0488 L
s
.48413 .01472 m
.48413 .13555 L
s
.5 .01472 m
.5 .31296 L
s
.51587 .01472 m
.51587 .13555 L
s
.53175 .01472 m
.53175 .0488 L
s
.54762 .01472 m
.54762 .25452 L
s
.56349 .01472 m
.56349 .25988 L
s
.57937 .01472 m
.57937 .05165 L
s
.59524 .01472 m
.59524 .49268 L
s
.61111 .01472 m
.61111 .49981 L
s
.62698 .01472 m
.62698 .07684 L
s
.64286 .01472 m
.64286 .02005 L
s
.65873 .01472 m
.65873 .02344 L
s
.6746 .01472 m
.6746 .02347 L
s
.69048 .01472 m
.69048 .02291 L
s
.70635 .01472 m
.70635 .02231 L
s
.72222 .01472 m
.72222 .02177 L
s
.7381 .01472 m
.7381 .02131 L
s
.75397 .01472 m
.75397 .02092 L
s
.76984 .01472 m
.76984 .02059 L
s
.78571 .01472 m
.78571 .02031 L
s
.80159 .01472 m
.80159 .02007 L
s
.81746 .01472 m
.81746 .01987 L
s
.83333 .01472 m
.83333 .0197 L
s
.84921 .01472 m
.84921 .01955 L
s
.86508 .01472 m
.86508 .01943 L
s
.88095 .01472 m
.88095 .01933 L
s
.89683 .01472 m
.89683 .01925 L
s
.9127 .01472 m
.9127 .01918 L
s
.92857 .01472 m
.92857 .01913 L
s
.94444 .01472 m
.94444 .0191 L
s
.96032 .01472 m
.96032 .01908 L
s
.97619 .01472 m
.97619 .01907 L
s
.015 w
.03968 .01908 Mdot
.05556 .0191 Mdot
.07143 .01913 Mdot
.0873 .01918 Mdot
.10317 .01925 Mdot
.11905 .01933 Mdot
.13492 .01943 Mdot
.15079 .01955 Mdot
.16667 .0197 Mdot
.18254 .01987 Mdot
.19841 .02007 Mdot
.21429 .02031 Mdot
.23016 .02059 Mdot
.24603 .02092 Mdot
.2619 .02131 Mdot
.27778 .02177 Mdot
.29365 .02231 Mdot
.30952 .02291 Mdot
.3254 .02347 Mdot
.34127 .02344 Mdot
.35714 .02005 Mdot
.37302 .07684 Mdot
.38889 .49981 Mdot
.40476 .49268 Mdot
.42063 .05165 Mdot
.43651 .25988 Mdot
.45238 .25452 Mdot
.46825 .0488 Mdot
.48413 .13555 Mdot
.5 .31296 Mdot
.51587 .13555 Mdot
.53175 .0488 Mdot
.54762 .25452 Mdot
.56349 .25988 Mdot
.57937 .05165 Mdot
.59524 .49268 Mdot
.61111 .49981 Mdot
.62698 .07684 Mdot
.64286 .02005 Mdot
.65873 .02344 Mdot
.6746 .02347 Mdot
.69048 .02291 Mdot
.70635 .02231 Mdot
.72222 .02177 Mdot
.7381 .02131 Mdot
.75397 .02092 Mdot
.76984 .02059 Mdot
.78571 .02031 Mdot
.80159 .02007 Mdot
.81746 .01987 Mdot
.83333 .0197 Mdot
.84921 .01955 Mdot
.86508 .01943 Mdot
.88095 .01933 Mdot
.89683 .01925 Mdot
.9127 .01918 Mdot
.92857 .01913 Mdot
.94444 .0191 Mdot
.96032 .01908 Mdot
.97619 .01907 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`005_ooool3o`0000Cooooo0_l0000iooooo`?o0000>oooool2o`0003cooooo0ol0000ioooo
o`?o00001?ooool2o`0000Oooooo000Gooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo0000=oooool01Ol0003ooooooooooooooooo000003Wooooo00Co0000oooooooooooo0000>_oo
ool01Ol0003ooooooooooooooooo000003Wooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00006ooooo`003oooool5o`0000?ooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool0000aooooo`Go00001Oooool00ol0003oooooooooo`0gooooo`04o`000?ooooooooooo`00
03kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000Kooooo000Gooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000>oooool0
0ol0003oooooooooo`0gooooo`04o`000?ooooooooooo`0003kooooo00?o0000ooooooooool0=ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Kooooo000Gooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo0000=oooool4o`0003[ooooo00Co0000oooooooooooo
0000>_ooool4o`0003[ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00006oooo
o`005_ooool2o`0000Cooooo00Co0000oooooooooooo0000=oooool00ol0003oooooooooo`0koooo
o`04o`000?ooooooooooo`0003[ooooo00?o0000ooooooooool0>_ooool2o`0000Cooooo00Co0000
oooooooooooo00001_ooool001Oooooo00?o0000ooooooooool00oooool2o`0003Sooooo1Ol0000j
ooooo`;o0000>oooool5o`0003Wooooo00?o0000ooooooooool00oooool2o`0000Oooooo003ooooo
ob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Aoooooooo00003Ol00003
ooooo`002_ooool2o`0000Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`01oooo
o`002Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0??ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03cooooo00?o0000oooo
ooooool0??ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo007ooooo0009ooooo`04
o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0Poooool00ol0003oooooooooo`22oooo
o`03o`000?oooooooooo007ooooo0009ooooo`04o`000?ooooooooooo`0000Cooooo0ol00005oooo
o`;o003o0ooo00001Ol00?ooo`00ool00?oo003o003o00?oo`0000Go003oool00?oo003oo`00o`00
o`03ool00003ooooool00?ooo`0000;oo`000_l00?l05?oo003oooooooooool00?ooooooool00?oo
oooo003ooooooooo003oooooo`00ooooooooo`00ooooool00?ooooooool00?oooooo003o0_ooool0
1Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool0
0?oooooooooo00;ooooo00ooo`00o`00ool00?ooooooool00?oooooo003ooooooooo003oooooo`00
ooooooooo`00ooooool00?l00_ooool01Ooo003o003oo`00ooooooooo`0000?ooooo00Goo`00oooo
ooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool0
0003ooooo`05ool00?oooooooooooooooooo00001?ooool01Ooo003oooooooooooooooooo`0000?o
oooo00Goo`00ooooooooooooooooool00004ooooo`05ool00?oooooooooooooooooo00000oooool0
1Ooo003oooooooooooooooooo`0000?ooooo00Koo`00ooooooooooooooooo`00oooo0003ooooo`09
ool00?oooooo003ooooooooo003oooooo`00ooooooooo`0000;ooooo00?o003ooooooooo00000_l0
0?l01oooooooo`00o`00ool00?ooooooool00?ooool00_l00?l01Ooo003oooooo`00ool00?ooo`00
00;ooooo00?o003ooooooooo00000_l00?l02_ooooooo`00ooooool00?ooooooool00?oooooo003o
oooooooo0002ooooo`03o`00ooooooooo`0000?ooooo00?oo`00o`00ool00?l00ooo00001Ooooooo
o`00ool00?oo003o003o00?oo`0000Co003oool00?oo003oo`000_l00?l3ool00005o`00oooo003o
o`00ool00?l00?l00ooo0003ooooo`?o00000oooool000Wooooo00Co0000oooooooooooo00001?oo
ool00ol0003oooooooooo`04ooooo`;o003o00Goooooool00?oo003oo`00ooooo`03ool00005oooo
oooo003oo`00ool00?ooool00ooo00001?l00?ooo`00ool00?oo0002ooooo`?oo`0000Goooooool0
0?oo003oo`00ooooo`03ool00004oooooooo003oo`00ool000;ooooo0ooo00001Oooooooo`00ool0
0?oo003o003o00?oo`0000Coooooool00?oo003oo`000_l00?l3ool00005oooooooo003oo`00ool0
0?ooool00ooo00001Ol00?ooo`00ool00?oo003o003o00?oo`000ol00?l01Ooo003oooooo`00ool0
0?ooo`0000;o003o0ooo00001?oooooo003ooooooooo0003ooooo`05ool00?oooooooooooooooooo
00000oooool00ooo003o003oooooo`02ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo
003oooooooooooooooooo`0000Cooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oo
oooooooooooooooo00001?ooool01Ooo003oooooooooool00?ooo`0000?ooooo00Goo`00oooooooo
ooooooooool00003ooooo`03ool00?oooooo003o00?oo`0000So003oooooooooooooo`00o`00oooo
oooo003oool000;o003o0ooo00001Oooooooo`00ool00?oo003o003o00?oo`000_l00?l3ool00005
oooooooo003oo`00ool00?ooool00ooo00001Oooooooo`00ool00?oo003o003o00?oo`0000?o003o
oooooooo00000_oo00001Oooooooo`00ool00?oo003ooooo00?oo`0000Ko003oool00?oo003oo`00
o`00ooooool3ool00005oooooooo003oo`00ool00?l00?l00ooo00001_l00?ooo`00ool00?oo003o
003oooooo`?oo`0000Goooooool00?oo003oo`00ooooo`03ool000Gooooo00?o0000ooooooooool0
0Oooool000Wooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`07ooooo`?oo`00
00Goooooool00?oo003oo`00ooooo`03ool00005oooooooo003oo`00ool00?ooool00ooo0002oooo
o`?oo`0000Goooooool00?oo003oo`00ooooo`03ool00004oooooooo003oo`00ool000;ooooo0ooo
00001Oooooooo`00ool00?oo003ooooo00?oo`0000Coooooool00?oo003oo`000_ooool3ool00005
oooooooo003oo`00ool00?ooool00ooo00001Oooooooo`00ool00?oo003ooooo00?oo`000_ooool3
ool00005oooooooo003oo`00ool00?ooool00ooo00001?oooooo003ooooooooo0003ooooo`05ool0
0?oooooooooooooooooo00000oooool00ooo003o003oooooo`02ooooo`05ool00?oooooooooooooo
oooo00000oooool01Ooo003oooooooooooooooooo`0000Cooooo00Goo`00ooooooooooooooooool0
0003ooooo`05ool00?oooooooooooooooooo00001?ooool01Ooo003oooooooooool00?ooo`0000?o
oooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooo003o00?oo`0000Koooooool0
0?oo003oo`00o`00ooooool3ool00005oooooooo003oo`00ool00?ooool00ooo00001?ooooooo`00
ool00?oo0002ooooo`?oo`0000Goooooool00?oo003oo`00ooooo`03ool00005oooooooo003oo`00
ool00?ooool00ooo0002ooooo`?oo`0000Goooooool00?oo003oo`00ooooo`03ool00004oooooooo
003oo`00ool000;ooooo0ooo00001Oooooooo`00ool00?oo003ooooo00?oo`0000Coooooool00?oo
003oo`000_ooool3ool00005oooooooo003oo`00ool00?ooool00ooo0005ooooo`03o`000?oooooo
oooo007ooooo000:ooooo`;o00001Oooool00ol0003oooooooooo`0Pooooo`?oo`0000Goooooool0
0?oo003oo`00ooooo`03ool000;ooooo0ooo00001Oooooooo`00ool00?oo003ooooo00?oo`0000Co
ooooool00?oo003oo`000_ooool3ool00005oooooooo003oo`00ool00?ooool00ooo00001Ooooooo
o`00ool00?oo003ooooo00?oo`000_ooool3ool00005oooooooo003oo`00ool00?ooool00ooo0003
ooooo`05ool00?oooooooooooooooooo00000oooool01_oo003oooooooooooooooooo`00o`00o`?o
oooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00001?ooool0
1Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00004ooooo`05ool0
0?ooooooooooo`00oooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00oooo
ool00?l00ooo00001?ooooooo`00ool00?oo0002ooooo`?oo`0000Goooooool00?oo003oo`00oooo
o`03ool00004oooooooo003oo`00ool000;ooooo0ooo00001Oooooooo`00ool00?oo003ooooo00?o
o`0000Goooooool00?oo003oo`00ooooo`03ool000;ooooo0ooo00001Oooooooo`00ool00?oo003o
oooo00?oo`0000Coooooool00?oo003oo`008oooool00ol0003oooooooooo`01ooooo`004Oooool0
0ol0003oooooooooo`1Cooooo`?oo`0000Coooooool00?oo003oo`001oooool01Ooo003ooooooooo
ooooooooo`0000?ooooo00Koo`00ooooooooooooooooool00?l00?l3ooooo`05ool00?oooooooooo
oooooooo00000oooool01Ooo003oooooooooooooooooo`0000Cooooo00Goo`00oooooooooooooooo
ool00002ooooo`03o`00oooo003ooooo00;ooooo00?oo`00ooooooooool00_ooool01Ooo003ooooo
ooooool00?ooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooo003o
00Cooooo0ooo0002ooooo`?oo`00EOooool00ol0003oooooooooo`01ooooo`004Oooool2o`00067o
oooo00?o003oool00?ooool00_ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00o`00
ooooool00_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooool00?ooooooool0
0004ooooo`05ool00?oooooooooooooooooo00000_ooool00ol00?ooo`00ooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00Goo`00oooooooooooo003oool00003ooooo`05ool00?oooooooooooooo
oooo00000oooool00ooo003oooooooooo`1Pooooo`;o00000oooool0017ooooo00?o0000oooooooo
ool0H?ooool00ol00?ooo`00ooooo`02ooooo`05ool00?oooooooooooooooooo00000oooool00ooo
003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003o003oo`00oooo
ooooo`0000Cooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo
00001?ooool01Ooo003oooooooooool00?ooo`0000?ooooo00Goo`00ooooooooooooooooool00003
ooooo`03ool00?oooooooooo067ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooo
ooooool0H?ooool00ol00?ooo`00ooooo`02ooooo`05ool00?oooooooooooooooooo00000oooool0
0ooo003o003oooooo`02ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooo`00
ooooooooo`0000Cooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooo
oooo00001?ooool01Ooo003oooooooooool00?ooo`0000?ooooo00Goo`00ooooooooooooooooool0
0003ooooo`03ool00?l00?oooooo067ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000
ooooooooool0HOooool01Ooo003oooooooooooooooooo`0000?ooooo00Koo`00oooooooooooooooo
ool00?l00?l3ooooo`05ool00?oooooooooooooooooo00000_ooool3ool00003o`00ooooooooo`00
00Cooooo00Ooo`00ooooooooooooooooool00?oooooo003o00?oo`000_ooool00ooo003ooooooooo
o`02ooooo`05ool00?ooooooooooo`00oooo00000oooool01Ooo003oooooooooooooooooo`0000?o
oooo00?oo`00o`00ooooool0HOooool00ol0003oooooooooo`01ooooo`004Oooool2o`0006;ooooo
00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00?oo`000oooool01Ooo003o
ooooooooooooooooo`0000;ooooo0ooo0002ooooo`03ool00?oooooooooo00;ooooo00Ooo`00oooo
ooooooooooooool00?oooooo003o00?oo`000_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
ooooo`0000;oo`000oooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00o`00ooooool0
H?ooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo063ooooo00?o003oool00?ooool00_oo
ool01Ooo003oooooooooooooooooo`0000;ooooo0ooo0003ooooo`05ool00?oooooooooooooooooo
00000_ooool3ool000;ooooo00?oo`00ooooooooool00_ooool01ooo003oooooooooooooooooo`00
ooooool00?l00ooo0002ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo00000_oo0003
ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`1Qooooo`03o`000?oo
oooooooo007ooooo000Aooooo`03o`000?oooooooooo063ooooo00?o003oool00?ooool00_ooool0
1Ooo003oooooooooooooooooo`0000;ooooo0ooo0003ooooo`05ool00?oooooooooooooooooo0000
0oooool01Ol00?ooooooo`00ooooooooo`0000Cooooo00Goo`00ooooooooooooooooool00003oooo
o`05o`00oooooooooooooooooooo00001?ooool00ooo003oooooool00002ool000?ooooo00Goo`00
ooooooooooooooooool00003ooooo`03ool00?oooooooooo067ooooo00?o0000ooooooooool00Ooo
ool0017ooooo00?o0000ooooooooool0H?ooool00ol00?ooo`00ooooo`02ooooo`05ool00?oooooo
oooooooooooo00000oooool00ol00?ooooooooooo`02ooooo`05ool00?oooooooooooooooooo0000
0oooool01Ol00?ooooooo`00ooooooooo`0000Cooooo00Goo`00ooooooooooooooooool00003oooo
o`05o`00oooooooooooooooooooo00001?ooool00ooo003oooooooooo`02o`00o`?ooooo00Goo`00
ooooooooooooooooool00003ooooo`03ool00?l00?oooooo067ooooo00?o0000ooooooooool00Ooo
ool0017ooooo00?o0000ooooooooool0H?ooool00ol00?ooo`00ooooo`02ooooo`05ool00?oooooo
oooooooooooo00000oooool00ol00?ooooooo`00o`02ooooo`05ool00?oooooooooooooooooo0000
0oooool01Ol00?ooooooooooool00?ooo`0000Cooooo00Koo`00ooooooooooooooooool00?l00?l6
ooooo`03ool00?oooooooooo00;ooooo00Coo`00oooooooooooo003o1?ooool01Ooo003ooooooooo
ooooooooo`0000?ooooo00?oo`00o`00ooooool0HOooool00ol0003oooooooooo`01ooooo`004Ooo
ool2o`0006;ooooo00Goo`00ooooooooooooooooool00003ooooo`07ool00?ooooooooooooooool0
0?ooooooo`00o`02ooooo`05ool00?oooooooooooooooooo00000oooool01Ol00?oooooooooooooo
ooooo`0000Cooooo00Koo`00ooooooooooooooooool00?l00?l6ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_l00?l3ooooo`05ool00?oooooooooooooooooo00000oooool00ooo
003o003oooooo`1Pooooo`;o00000oooool0017ooooo00?o0000ooooooooool0HOooool01Ooo003o
ooooooooooooooooo`0000?ooooo00Ooo`00ooooooooooooooooo`00oooooooo003o00;ooooo00Go
o`00ooooooooooooooooool00007ooooo`03ool00?oooooooooo00;ooooo00Koo`00oooooooooooo
ooooool00?l00?l3ooooo`04o`00ooooooooooooool000Cooooo00Goo`00ooooooooooooooooo`00
o`03ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003o003oooooo`1Qooooo`03o`00
0?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo05oooooo0ooo0003ooooo`05ool00?oo
oooooooooooooooo00001Oooool01?l00?oooooooooooooo0003ooooo`03ool00?oooooooooo00Co
oooo00?o003oool00?ooool00oooool01_oo003oooooooooooooooooo`00o`00o`?ooooo00Co003o
ooooooooooooo`001?ooool01Ooo003oooooo`00oooooooo003o00?ooooo00Goo`00oooooooooooo
ooooool00002ooooo`?oo`00H_ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooo
ooooo`1Oooooo`?oo`000oooool01Ooo003oooooooooooooooooo`0000?ooooo00?o003ooooooooo
ool00_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Ko003oooooooooooooooooo`00oooo
0004ooooo`05ool00?oooooooooooooooooo00001?ooool01?l00?oooooooooooooo0004ooooo`05
ool00?oooooo003oooooool00?l00oooool01Ooo003oooooooooooooooooo`0000;ooooo0ooo001R
ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo05oooooo0ooo0003oooo
o`05ool00?oooooooooooooooooo00000oooool00ol00?ooooooooooo`02ooooo`05ool00?oooooo
oooooooooooo00000_ooool01_l00?oooooooooooooooooo003oool000Cooooo00Koo`00oooooooo
ooooooooool00?l00?l6ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooool00?l01Oooool0
1Ooo003oooooooooooooooooo`0000;ooooo0ooo001Rooooo`03o`000?oooooooooo007ooooo000A
ooooo`;o0000I_ooool01Ooo003oooooooooooooooooo`0000?ooooo00?o003oooooool00?l00_oo
ool01Ooo003oooooooooooooooooo`0000;ooooo00Ko003oooooooooooooooooo`00oooo0004oooo
o`06ool00?oooooooooooooooooo003o003o1_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooo003o00Gooooo00Goo`00ooooooooooooooooool00003ooooo`03o`00oooooooooooo063ooooo
0_l00003ooooo`004Oooool00ol0003oooooooooo`1Uooooo`05ool00?oooooooooooooooooo0000
0oooool00ol00?ooooooo`00o`02ooooo`05ool00?oooooooooooooooooo00001oooool00ooo003o
ooooooooo`02ooooo`06ool00?oooooooooooooooooo003o003o0oooool01?l00?oooooooooooooo
0004ooooo`05ool00?ooooooooooooooool00?l00oooool01Ooo003oooooooooooooooooo`0000?o
oooo00?o003oooooooooool0HOooool00ol0003oooooooooo`01ooooo`000oooool3o`0000Cooooo
0_l00005ooooo`03o`000?oooooooooo067ooooo00Go003oooooooooooooooooool00003ooooo`03
ool00?oooooooooo00?ooooo00Co003oooooooooooooo`000oooool00ooo003oooooooooo`05oooo
o`03ool00?oooooooooo00;ooooo00Koo`00ooooooooooooooooool00?l00?l3ooooo`04o`00oooo
ooooooooool000Cooooo00Goo`00ooooooooooooooooo`00o`03ooooo`05ool00?oooooooooooooo
oooo0000Ioooool00ol0003oooooooooo`01ooooo`001?ooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0HOooool01Ol00?oooooooooooooooooo
o`0000?ooooo00?oo`00ooooooooool01_ooool01Ooo003oooooooooooooooooo`0000;ooooo00?o
003oooooooooool00_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo0000
1?ooool01?l00?oooooooooooooo0004ooooo`05ool00?oooooo003oooooool00?l00oooool01Ooo
003oooooooooooooooooo`0006Oooooo00?o0000ooooooooool00Oooool000Cooooo00?o0000oooo
ooooool00_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo067ooooo00Go003o
ooooooooooooooooool00003ooooo`05ool00?ooooooooooooooool00?l01?ooool01Ooo003ooooo
ooooooooooooo`0000;ooooo00?o003oooooooooool00_ooool00ooo003oooooooooo`02ooooo`05
ool00?oooooooooooooooooo00001?ooool01?l00?oooooooooooooo0004ooooo`03ool00?oooooo
003o00Gooooo00Goo`00ooooooooooooooooool00003ooooo`03o`00oooooooooooo067ooooo00?o
0000ooooooooool00Oooool000Cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0004ooooo`?o0000IOooool01Ooo003oooooooooooooooooo`0000?ooooo00?o003oooooool00?l0
0_ooool01Ooo003oooooooooooooooooo`0000;ooooo00?o003oooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`05ool00?oooooooooooooooooo00001oooool00ooo003oooooooooo`02oooo
o`03ool00?oooooo003o00Gooooo00Goo`00ooooooooooooooooool00003ooooo`03o`00oooooooo
oooo05oooooo0ol00003ooooo`001?ooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooooooool0IOooool01Ooo003oooooooooooooooooo`0000?ooooo00?o
003oooooool00?l00_ooool01Ooo003oooooooooooooooooo`0000;ooooo00?o003oooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00001Oooool00ol00?oo
ooooool00004ooooo`05ool00?ooooooooooooooool00?l00oooool01Ooo003ooooooooooooooooo
o`0000?ooooo00?o003oooooooooool0HOooool00ol0003oooooooooo`01ooooo`000oooool2o`00
00Cooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1Qooooo`05o`00oooooooo
oooooooooooo00000oooool00ooo003oooooooooo`03ooooo`04o`00ooooooooooooool000?ooooo
00?oo`00ooooooooool01Oooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo
00001Oooool00ol00?ooooooool00004ooooo`05ool00?ooooooooooooooool00?l00oooool01Ooo
003oooooooooooooooooo`0006Oooooo00?o0000ooooooooool00Oooool000Cooooo00?o0000oooo
ooooool00oooool2o`0000Gooooo00?o0000ooooooooool0HOooool01Ol00?oooooooooooooooooo
o`0000?ooooo00?oo`00ooooooooool00oooool01?l00?oooooooooooooo0003ooooo`03ool00?oo
oooo003o00Gooooo00?oo`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000Gooooo
00?o003ooooooooo00001?ooool01Ooo003oooooo`00oooooooo003o00?ooooo00Goo`00oooooooo
ooooooooool0001Wooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo067o
oooo00Go003oooooooooooooooooool00003ooooo`05ool00?ooooooooooooooool00?l01?ooool0
1ooo003oooooooooooooooooo`00ooooool00?l01Oooool00ooo003oooooooooo`02ooooo`05ool0
0?oooooooooooooooooo00001Oooool00ol00?ooooooool00004ooooo`05ool00?oooooo003ooooo
ool00?l00oooool01Ooo003oooooooooooooooooo`0000?ooooo00?o003oooooooooool0HOooool0
0ol0003oooooooooo`01ooooo`004Oooool2o`0006;ooooo00Go003oooooooooooooooooool00003
ooooo`07ool00?ooooooooooooooool00?ooooooo`00o`02ooooo`07ool00?oooooooooooooooooo
003oooooo`00o`05ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00007
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooool00?l01Oooool01Ooo003ooooooooooooo
ooooo`0000?ooooo00?o003oooooooooool0H?ooool2o`0000?ooooo000Aooooo`03o`000?oooooo
oooo06Gooooo00Goo`00ooooooooooooooooool00003ooooo`03o`00oooooooo003o00;ooooo00Oo
o`00ooooooooooooooooool00?oooooo003o00Gooooo00?oo`00ooooooooool00_ooool01Ooo003o
ooooooooooooooooo`0000Oooooo00?oo`00ooooooooool00_ooool00ooo003oooooo`00o`02oooo
o`04o`00ooooooooooooool000?ooooo00Goo`00ooooooooooooooooo`00o`1Sooooo`03o`000?oo
oooooooo007ooooo000Aooooo`03o`000?oooooooooo06;ooooo00Co003oooooooooooooo`000ooo
ool01Ooo003ooooooooooooooooo003o00;ooooo00?o003ooooooooo00000oooool00ooo003ooooo
ooooo`04ooooo`?oo`000oooool00ooo003oooooool00002ool000Gooooo00?o003ooooooooo0000
1?ooool00ooo003oooooooooo`02ooooo`04o`00ooooooooooooool000?ooooo00Goo`00oooooooo
ooooooooo`00o`1Sooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo06;o
oooo00Co003oooooooooooooo`000oooool00ooo003oooooooooo`04ooooo`03o`00ooooooooo`00
00?ooooo00?oo`00ooooooooool01?ooool3ool000?ooooo00?oo`00oooooooo00000_oo0005oooo
o`03o`00ooooooooo`0000Cooooo00?oo`00ooooool00?l00_ooool01?l00?oooooooooooooo0003
ooooo`03ool00?oooooooooo06Gooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooo
ooooool0H_ooool01?l00?oooooooooooooo0003ooooo`05ool00?ooooooooooooooool00?l01?oo
ool01ooo003oooooooooooooooooo`00ooooool00?l01?ooool3ool000?ooooo00?oo`00oooooooo
00000_oo0005ooooo`03o`00ooooooooo`0000Cooooo00?oo`00ooooool00?l00_ooool01?l00?oo
oooooooooooo0003ooooo`05ool00?ooooooooooooooool00?l0Hoooool00ol0003oooooooooo`01
ooooo`004Oooool2o`0006?ooooo00Co003oooooooooooooo`000oooool01Ooo003ooooooooooooo
oooo003o00Cooooo00Ooo`00ooooooooooooooooool00?oooooo003o00Kooooo00Go003ooooooooo
ooooooooool00003ooooo`03o`00oooooooooooo00Gooooo00?oo`00ooooooooool00_ooool00ooo
003o003oooooo`05ooooo`05ool00?oooooooooooooooooo00000oooool00ol00?ooooooooooo`1P
ooooo`;o00000oooool0017ooooo00?o0000ooooooooool0IOooool01Ooo003ooooooooooooooooo
o`0000;ooooo00Oo003oooooooooooooooooo`00ooooooooo`0000?ooooo00?oo`00ooooool00?l0
1_ooool01Ol00?ooooooooooooooooooo`0000?ooooo00?o003oooooooooool01Oooool00ooo003o
ooooooooo`02ooooo`03ool00?l00?oooooo00Gooooo00Goo`00ooooooooooooooooool00002oooo
o`03o`00oooooooooooo06;ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooooooo
ool0IOooool01Ooo003oooooooooooooooooo`0000;ooooo00Oo003oooooooooooooooooo`00oooo
ooooo`0000?ooooo00?oo`00ooooooooool02_ooool01Ooo003ooooooooooooooooo003o00Gooooo
00?o003ooooooooo00001?ooool00ooo003oooooooooo`02ooooo`04o`00ooooooooooooool000?o
oooo00Coo`00oooooooooooo003oI?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003o
ooooooooo`1Rooooo`04o`00ooooooooooooool000?ooooo00?oo`00ooooooooool01?ooool00ol0
0?ooooooool00003ooooo`03ool00?oooooooooo00Kooooo00Go003oooooooooooooooooool00003
ooooo`03o`00oooooooooooo00?ooooo00?o003ooooooooo00001?ooool00ooo003oooooooooo`02
ooooo`04o`00ooooooooooooool000?ooooo00?oo`00ooooooooool0IOooool00ol0003ooooooooo
o`01ooooo`004Oooool2o`0006?ooooo00Co003oooooooooooooo`000oooool00ooo003ooooooooo
o`06ooooo`07ool00?oooooooooooooooooo003oooooo`00o`06ooooo`05o`00oooooooooooooooo
oooo00002_ooool00ol00?ooo`00ooooo`03ooooo`03ool00?l00?oooooo00;ooooo00Co003ooooo
ooooooooo`000oooool00ooo003oooooooooo`1Tooooo`;o00000oooool0017ooooo00?o0000oooo
ooooool0H_ooool01?l00?oooooooooooooo0003ooooo`04ool00?ooooooooooo`00o`Gooooo00Oo
o`00ooooooooooooooooool00?oooooo003o00Kooooo00Go003oooooooooooooooooool00002oooo
o`03o`00oooooooooooo00Gooooo00?o003oool00?ooool00oooool00ooo003o003oooooo`05oooo
o`05ool00?oooooooooooooooooo00000_ooool00ol00?ooooooooooo`1Rooooo`03o`000?oooooo
oooo007ooooo000Aooooo`03o`000?oooooooooo06Gooooo00Goo`00ooooooooooooooooool00002
ooooo`07o`00ooooooooooooooooool00?ooooooool00003ooooo`03ool00?l00?oooooo00Kooooo
00Go003oooooooooooooooooool00002ooooo`03o`00oooooooooooo00Kooooo00?oo`00oooooooo
ool00_ooool00ooo003o003oooooo`05ooooo`05ool00?oooooooooooooooooo00000_ooool00ol0
0?ooooooooooo`1Rooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo06Go
oooo00Goo`00ooooooooooooooooool00002ooooo`07o`00ooooooooooooooooool00?ooooooool0
0003ooooo`03ool00?l00?oooooo00[ooooo00Coo`00oooooooooooo003o1oooool00ol00?ooo`00
ooooo`03ooooo`03ool00?l00?oooooo00;ooooo00Co003oooooooooooooo`000oooool01?oo003o
ooooooooool00?mTooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo06;o
oooo00Co003oooooooooooooo`000oooool00ooo003oooooooooo`04ooooo`03o`00ooooooooo`00
00?ooooo00?oo`00ooooooooool02_ooool01?oo003oooooooooool00?l7ooooo`03o`00oooo003o
oooo00?ooooo00?oo`00ooooooooool00_ooool01?l00?oooooooooooooo0003ooooo`03ool00?oo
oooooooo06Gooooo00?o0000ooooooooool00Oooool0017ooooo0_l0001Sooooo`04o`00oooooooo
ooooool000?ooooo00?oo`00ooooooooool01?ooool00ol00?ooooooool00003ooooo`03ool00?l0
0?oooooo00Kooooo00Go003oooooooooooooooooool0000:ooooo`03o`00oooo003ooooo00?ooooo
00?oo`00ooooooooool00_ooool01?l00?oooooooooooooo0003ooooo`03ool00?oooooooooo06Co
oooo0_l00003ooooo`004Oooool00ol0003oooooooooo`1Rooooo`04o`00ooooooooooooool000?o
oooo00Coo`00oooooooooooo003o1Oooool01_oo003oooooooooooooooooo`00o`00o`Oooooo00Go
003oooooooooooooooooool0000:ooooo`03o`00oooo003ooooo00?ooooo00?oo`00o`00ooooool0
0_ooool01?l00?oooooooooooooo0003ooooo`04ool00?ooooooooooo`00ofCooooo00?o0000oooo
ooooool00Oooool0017ooooo00?o0000ooooooooool0H_ooool01?l00?oooooooooooooo0003oooo
o`04ool00?ooooooooooo`00o`?ooooo00?o003ooooooooo00000oooool00ooo003o003oooooo`06
ooooo`05o`00oooooooooooooooooooo00000_ooool00ol00?ooooooooooo`06ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00o`00ooooool01Oooool01Ooo003oooooooooooooooooo`0000;ooooo
00?o003oooooooooool0H_ooool00ol0003oooooooooo`01ooooo`000_ooool5o`0000?ooooo0_l0
0005ooooo`03o`000?oooooooooo06Gooooo00Goo`00ooooooooooooooooool00002ooooo`07o`00
ooooooooooooooooool00?ooooooool00003ooooo`03ool00?l00?oooooo00[ooooo00Coo`00oooo
oooooooo003o2?ooool00ooo003oooooooooo`02ooooo`03ool00?l00?oooooo00;ooooo00Co003o
ooooooooooooo`000oooool01?oo003oooooooooool00?mTooooo`03o`000?oooooooooo007ooooo
0003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`1Rooooo`04o`00ooooooooooooool000?ooooo00Coo`00oooooooooooo003o0oooool0
0ol00?ooooooool00003ooooo`03ool00?oooooooooo00[ooooo00Coo`00oooooooooooo003o1ooo
ool00ol00?ooo`00ooooo`03ooooo`03ool00?l00?oooooo00;ooooo00Co003oooooooooooooo`00
0oooool01?oo003oooooooooool00?mTooooo`03o`000?oooooooooo007ooooo0004ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00001?ooool3o`0006;ooooo00Co003ooooooooo
ooooo`000oooool00ooo003oooooooooo`04ooooo`03o`00ooooooooo`0000?ooooo00?oo`00oooo
ooooool01_ooool01Ol00?ooooooooooooooooooo`0000[ooooo00?o003oool00?ooool00oooool0
0ooo003oooooooooo`02ooooo`04o`00ooooooooooooool000?ooooo00?oo`00ooooooooool0Hooo
ool3o`0000?ooooo0005ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo06;ooooo00Co003oooooooooooooo`000oooool01?oo003ooooo
ooooool00?l5ooooo`06ool00?oooooooooooooooooo003o003o1oooool01Ol00?oooooooooooooo
ooooo`0000[ooooo00?o003oool00?ooool00oooool00ooo003o003oooooo`02ooooo`04o`00oooo
ooooooooool000?ooooo00Coo`00oooooooooooo003oI?ooool00ol0003oooooooooo`01ooooo`00
0_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00001?ooool00ol0
003oooooooooo`1Rooooo`04o`00ooooooooooooool000?ooooo00Coo`00oooooooooooo003o1Ooo
ool01_oo003oooooooooooooooooo`00o`00o`Sooooo00Co003oooooooooooooo`000_ooool00ol0
0?ooooooooooo`06ooooo`03ool00?oooooooooo00;ooooo00?oo`00o`00ooooool01Oooool01Ooo
003oooooooooooooooooo`0000;ooooo00?o003oooooooooool0H_ooool00ol0003oooooooooo`01
ooooo`000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00001?oo
ool00ol0003oooooooooo`1Uooooo`05ool00?oooooooooooooooooo00000_ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooo003ooooo00;ooooo00?oo`00o`00ooooool01oooool01?l00?oooooo
oooooooo0002ooooo`03o`00oooooooooooo00Kooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`05ooooo`05ool00?oooooooooooooooooo00000_ooool00ol00?ooooooooooo`1Roooo
o`03o`000?oooooooooo007ooooo0003ooooo`?o00001?ooool2o`0000Gooooo00?o0000oooooooo
ool0IOooool01Ooo003oooooooooooooooooo`0000;ooooo00?o003oooooooooool00_ooool00ol0
0?ooo`00ooooo`02ooooo`03ool00?oooooooooo00[ooooo00?oo`00ooooool00?l02?ooool00ol0
0?ooo`00ooooo`03ooooo`03ool00?oooooooooo00;ooooo00Co003oooooooooooooo`000oooool0
1?oo003oooooooooool00?mTooooo`03o`000?oooooooooo007ooooo000Aooooo`;o0000Hoooool0
1?l00?oooooooooooooo0003ooooo`03ool00?oooooooooo00Gooooo00?o003oool00?ooool00_oo
ool00ooo003oooooooooo`07ooooo`06o`00ooooooooooooool00?oooooo003o2?ooool00ol00?oo
o`00ooooo`03ooooo`03ool00?oooooooooo00;ooooo00Co003oooooooooooooo`000oooool00ooo
003oooooooooo`1Tooooo`;o00000oooool0017ooooo00?o0000ooooooooool0H_ooool01?l00?oo
oooooooooooo0003ooooo`03ool00?oooooooooo00Kooooo00Koo`00ooooooooooooooooool00?l0
0?l8ooooo`04o`00ooooooooooooool000_ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`04o`00ooooooooooooool000?ooooo00?oo`00ooooooooool0IOooool00ol0003o
ooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1Rooooo`04o`00ooooooooooooool000?o
oooo00Coo`00oooooooooooo003o1Oooool01_oo003oooooooooooooooooo`00o`00o`Sooooo00Ko
003oooooooooooooo`00ooooool00?l9ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool01Oooool01Ooo003oooooooooooooooooo`0000;ooooo00?o003oooooooooool0H_ooool00ol0
003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1Uooooo`05ool00?oooooooooooooo
oooo00000_ooool00ol00?ooooooooooo`02ooooo`03o`00oooo003ooooo00;ooooo00?oo`00o`00
ooooool01oooool01_l00?oooooooooooooo003oooooo`00o`Wooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`05ooooo`05ool00?oooooooooooooooooo00000_ooool00ol00?oooooo
ooooo`1Rooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo06Gooooo00Go
o`00ooooooooooooooooool00002ooooo`03o`00oooooooooooo00;ooooo00?o003oool00?ooool0
0_ooool00ooo003oooooooooo`0:ooooo`03ool00?oooooo003o00Wooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`04o`00ooooooooooooool000?ooooo00Coo`00oooooooo
oooo003oI?ooool00ol0003oooooooooo`01ooooo`004Oooool2o`0006Cooooo00?o003ooooooooo
00000oooool00ooo003oooooooooo`05ooooo`03o`00oooo003ooooo00;ooooo00?oo`00oooooooo
ool01oooool01_l00?oooooooooooooo003oooooo`00o`Wooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`04o`00ooooooooooooool000?ooooo00?oo`00ooooooooool0I?oo
ool2o`0000?ooooo000Aooooo`03o`000?oooooooooo06?ooooo00?o003ooooooooo00000oooool0
0ooo003oooooooooo`05ooooo`03o`00oooo003ooooo00;ooooo00?oo`00ooooooooool01oooool0
1?l00?oooooooooooooo000;ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00ooo
ool00ol00?ooooooool00003ooooo`03ool00?oooooooooo06Gooooo00?o0000ooooooooool00Ooo
ool0017ooooo00?o0000ooooooooool0Hoooool00ol00?ooooooool00003ooooo`04ool00?oooooo
ooooo`00o`Gooooo00Goo`00ooooooooooooooooool00009ooooo`04o`00ooooooooooooool000_o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03ooooo`03o`00ooooooooo`0000?o
oooo00Coo`00oooooooooooo003oI?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003o
ooooooooo`1Sooooo`03o`00ooooooooo`0000?ooooo00Coo`00oooooooooooo003o1?ooool00ol0
0?ooo`00ooooo`02ooooo`03ool00?oooooooooo00Oooooo00Ko003oooooooooooooo`00ooooool0
0?l9ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool01Oooool01Ooo003ooooooooo
ooooooooo`0000;ooooo00?o003oooooooooool0H_ooool00ol0003oooooooooo`01ooooo`004Ooo
ool00ol0003oooooooooo`1Uooooo`07ool00?oooooooooooooooooo003oooooo`00o`05ooooo`03
o`00oooo003ooooo00;ooooo00?oo`00ooooooooool02_ooool00ooo003oooooo`00o`09ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00oooool00ol00?ooooooool00003ooooo`03
ool00?oooooo003o06Gooooo00?o0000ooooooooool00Oooool0017ooooo0_l0001Tooooo`03o`00
ooooooooo`0000?ooooo00?oo`00ooooool00?l01Oooool00ol00?ooo`00ooooo`03ool000cooooo
00?oo`00ooooool00?l02?ooool3ool000?ooooo00?oo`00ooooooooool00oooool00ol00?oooooo
ool00003ooooo`03ool00?oooooo003o06Cooooo0_l00003ooooo`004Oooool00ol0003ooooooooo
o`1Sooooo`03o`00ooooooooo`0000?ooooo00?oo`00ooooooooool01_ooool00ooo003oooooool0
0002ool000Wooooo00Co003oooooooooooooo`002_ooool3ool000?ooooo00?oo`00ooooooooool0
0oooool00ol00?ooooooool00003ooooo`03ool00?oooooooooo06Gooooo00?o0000ooooooooool0
0Oooool0017ooooo00?o0000ooooooooool0Hoooool00ol00?ooooooool00003ooooo`03ool00?oo
oooo003o00Cooooo0ooo00001?ooooooo`00ool00?oo0009ooooo`04o`00ooooooooooooool000[o
oooo0ooo00001?ooooooo`00ool00?oo0005ooooo`03o`00ooooooooo`0000?ooooo00?oo`00oooo
ool00?l0IOooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1Sooooo`03
o`00ooooooooo`0000?ooooo00?oo`00ooooool00?l01?ooool3ool000?ooooo00?o003ooooooooo
ool02?ooool01?l00?ooooooool00?l00?l=ooooo`?oo`001oooool01ooo003ooooooooooooooooo
o`00ooooool00?l0IOooool00ol0003oooooooooo`01ooooo`004Oooool2o`0006Kooooo00Ooo`00
ooooooooooooooooool00?oooooo003o00Cooooo0ooo0003ooooo`03o`00oooooooooooo00[ooooo
00?oo`00o`00ooooool03?ooool3ool000Oooooo00Ooo`00ooooooooooooooooool00?oooooo003o
06Cooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`1Uooooo`07ool00?oooooooooooooo
oooo003oooooo`00o`06ooooo`03o`00oooooooooooo00kooooo00?oo`00o`00ooooool02_ooool0
1?l00?ooooooooooool00?l6ooooo`03o`00ooooooooo`0000?ooooo00?oo`00ooooool00?l0IOoo
ool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1Sooooo`03o`00oooooooo
o`0000?ooooo00?oo`00ooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`04o`00oooooooo
o`00o`00o`_ooooo00?o003oooooooooool01oooool00ol00?ooooooool00003ooooo`03ool00?oo
oooooooo06Gooooo00?o0000ooooooooool00Oooool000?ooooo0ol00004ooooo`;o00001Oooool0
0ol0003oooooooooo`1Sooooo`03o`00ooooooooo`0000?ooooo00?oo`00ooooooooool02Oooool0
0ol00?ooooooooooo`09ooooo`03o`00ooooooooo`0000cooooo00?o003oooooooooool01oooool0
0ol00?ooooooool00003ooooo`03ool00?oooooooooo06Gooooo00?o0000ooooooooool00Oooool0
00;ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooooooool0Hoooool00ol00?ooooooool00003ooooo`03ool00?oooooo003o00Wooooo00?o
003oooooooooool02Oooool01?l00?ooooooool00?l00?l;ooooo`04o`00ooooooooooooo`00o`So
oooo00Ooo`00ooooooooooooooooool00?oooooo003o06Gooooo00?o0000ooooooooool00Oooool0
00Kooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`?o0000IOooool0
1ooo003oooooooooooooooooo`00ooooool00?l01_ooool01?l00?ooooooooooool00?l;ooooo`04
o`00ooooooooo`00o`00o`kooooo00?o003oooooooooool01_ooool01ooo003ooooooooooooooooo
o`00ooooool00?l0Hoooool3o`0000?ooooo0004ooooo`;o00000oooool01?l0003oooooooooool0
0004ooooo`03o`000?oooooooooo06Gooooo00Ooo`00ooooooooooooooooool00?oooooo003o00Ko
oooo00?o003oooooooooool03_ooool00ooo003o003oooooo`0:ooooo`04o`00ooooooooooooo`00
o`Kooooo00?o003ooooooooo00000oooool00ooo003oooooo`00o`1Uooooo`03o`000?oooooooooo
007ooooo0006ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`1Sooooo`03o`00ooooooooo`0000?ooooo00?oo`00ooooooooool01oooool00ol0
0?ooooooooooo`0;ooooo`04o`00ooooooooo`00o`00o`_ooooo00?o003oooooooooool01oooool0
0ol00?ooooooool00003ooooo`03ool00?oooooooooo06Gooooo00?o0000ooooooooool00Oooool0
00;ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooooooool0Hoooool00ol00?ooooooool00003ooooo`03ool00?oooooooooo00Oooooo00?o
003oooooool00?l02oooool00ol00?ooooooool0000<ooooo`03o`00oooooooooooo00Oooooo00?o
003ooooooooo00000oooool00ooo003oooooooooo`1Uooooo`03o`000?oooooooooo007ooooo0003
ooooo`?o00001?ooool2o`0000Gooooo00?o0000ooooooooool0Hoooool00ol00?ooooooool00003
ooooo`03ool00?oooooo003o00Wooooo00?o003oooooooooool02_ooool00ol00?ooo`00ooooo`0<
ooooo`;o003o1oooool00ol00?ooooooool00003ooooo`03ool00?oooooo003o06Gooooo00?o0000
ooooooooool00Oooool0017ooooo0_l0001Tooooo`03o`00ooooooooo`0000?ooooo00?oo`00oooo
ool00?l01oooool2o`00o`gooooo00?o003oool00?ooool03Oooool00ol00?ooooooooooo`07oooo
o`07ool00?oooooooooooooooooo003oooooo`00o`1Tooooo`;o00000oooool0017ooooo00?o0000
ooooooooool0IOooool01ooo003oooooooooooooooooo`00ooooool00?l02?ooool00ol00?oooooo
ooooo`0<ooooo`03ool00?oooooooooo00_ooooo0_l00?l7ooooo`03o`00ooooooooo`0000?ooooo
00?oo`00ooooool00?l0IOooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooooooo
o`1Sooooo`03o`00ooooooooo`0000?ooooo00?oo`00ooooool00?l05Oooool3ool001Kooooo00?o
003ooooooooo00000oooool00ooo003oooooo`00o`1Uooooo`03o`000?oooooooooo007ooooo000A
ooooo`03o`000?oooooooooo06?ooooo00?o003ooooooooo00000oooool00ooo003oooooooooo`0E
ooooo`?oo`005_ooool00ol00?ooooooool00003ooooo`03ool00?oooooo003o06Gooooo00?o0000
ooooooooool00Oooool0017ooooo00?o0000ooooooooool0Hoooool00ol00?ooooooool00003oooo
o`03ool00?oooooo003o01Gooooo0ooo000Fooooo`03o`00ooooooooo`0000?ooooo00?oo`00oooo
ool00?l0IOooool00ol0003oooooooooo`01ooooo`004Oooool2o`0006Cooooo00?o003ooooooooo
00000oooool00ooo003oooooo`00o`0Gooooo`03o`000?oooooooooo01Kooooo00Goo`00oooooooo
ooooooooool0001Vooooo`;o00000oooool0017ooooo00?o0000ooooooooool0IOooool01ooo003o
ooooooooooooooooo`00ooooool00?l05oooool00ol0003oooooooooo`0Fooooo`05ool00?oooooo
oooooooooooo0000Ioooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1U
ooooo`07ool00?oooooooooooooooooo003oooooo`00o`0Gooooo`03o`000?oooooooooo01Cooooo
00?o003ooooooooo00000oooool00ooo003oooooo`00o`1Uooooo`03o`000?oooooooooo007ooooo
000Aooooo`03o`000?oooooooooo06?ooooo00?o003ooooooooo00000oooool00ooo003ooooooooo
o`0Gooooo`03o`000?oooooooooo01Cooooo00?o003ooooooooo00000oooool00ooo003oooooo`00
o`1Uooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo06?ooooo00?o003o
oooooooo00000oooool00ooo003oooooooooo`0Gooooo`03o`000?oooooooooo01Cooooo00?o003o
oooooooo00000oooool00ooo003oooooo`00o`1Uooooo`03o`000?oooooooooo007ooooo000Aoooo
o`;o0000IOooool00ol00?ooo`00ooooo`02ooooo`03ool00?oooooo003o01Oooooo00?o0000oooo
ooooool05_ooool01Ooo003oooooooooooooooooo`0006Kooooo0_l00003ooooo`004Oooool00ol0
003oooooooooo`1Uooooo`07ool00?oooooooooooooooooo003oooooo`00o`0Gooooo`03o`000?oo
oooooooo01Kooooo00Goo`00ooooooooooooooooool0001Wooooo`03o`000?oooooooooo007ooooo
000Aooooo`03o`000?oooooooooo06Gooooo00Ooo`00ooooooooooooooooool00?oooooo003o01Oo
oooo00?o0000ooooooooool05Oooool00ol00?ooo`00ooooo`02ooooo`03ool00?oooooo003o06Go
oooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0I?ooool00ol00?ooo`00
ooooo`02ooooo`03ool00?oooooooooo01Oooooo00?o0000ooooooooool05Oooool00ol00?ooo`00
ooooo`02ooooo`03ool00?oooooo003o06Gooooo00?o0000ooooooooool00Oooool0017ooooo00?o
0000ooooooooool0I?ooool00ol00?ooo`00ooooo`02ooooo`03ool00?oooooooooo01Oooooo00?o
0000ooooooooool05Oooool00ol00?ooo`00ooooo`02ooooo`03ool00?l00?oooooo06Gooooo00?o
0000ooooooooool00Oooool0017ooooo0_l0001Uooooo`03o`00oooo003ooooo00;ooooo00?oo`00
o`00ooooool05oooool00ol0003oooooooooo`0Eooooo`03o`00oooo003ooooo00;ooooo00?oo`00
o`00ooooool0I?ooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo06Cooooo00?o003oool0
0?ooool00_ooool00ooo003o003oooooo`0Gooooo`03o`000?oooooooooo01Kooooo00Goo`00oooo
ooooooooooooool0001Wooooo`03o`000?oooooooooo007ooooo0004ooooo`?o00000oooool2o`00
00Gooooo00?o0000ooooooooool0IOooool01_oo003oooooooooooooooooo`00o`00oaSooooo00?o
0000ooooooooool05Oooool00ol00?ooo`00ooooo`02ooooo`03ool00?l00?oooooo06Gooooo00?o
0000ooooooooool00Oooool000Gooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0I?ooool00ol00?ooo`00ooooo`02ooooo`03ool00?l0
0?oooooo01Oooooo00?o0000ooooooooool05Oooool00ol00?ooo`00ooooo`02ooooo`03ool00?l0
0?oooooo06Gooooo00?o0000ooooooooool00Oooool000;ooooo1Ol00002ooooo`04o`000?oooooo
ooooo`0000Cooooo0ol0001Tooooo`03o`00oooo003ooooo00;ooooo00?oo`00ooooooooool05ooo
ool00ol0003oooooooooo`0Eooooo`03o`00oooo003ooooo00;ooooo00?oo`00o`00ooooool0Hooo
ool3o`0000?ooooo0002ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`1Tooooo`03o`00oooo003ooooo00;ooooo00?oo`00o`00ooooool0
5oooool00ol0003oooooooooo`0Eooooo`03o`00oooo003ooooo00;ooooo00?oo`00o`00ooooool0
IOooool00ol0003oooooooooo`01ooooo`000oooool00ol0003oooooo`000003ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool0I?ooool00ol00?ooo`00ooooo`02ooooo`03ool0
0?l00?oooooo01Oooooo00?o0000ooooooooool05_ooool01Ooo003oooooooooooooooooo`0006Oo
oooo00?o0000ooooooooool00Oooool000Cooooo0_l00003ooooo`04o`000?ooooooooooo`0000Co
oooo00?o0000ooooooooool0IOooool01_oo003oooooooooooooooooo`00o`00oaSooooo00?o0000
ooooooooool05_ooool01Ooo003oooooooooooooooooo`0006Oooooo00?o0000ooooooooool00Ooo
ool000Gooooo00?o0000ooooooooool00_ooool2o`0000Gooooo00?o0000ooooooooool0IOooool0
1_oo003oooooooooooooooooo`00o`00oaSooooo00?o0000ooooooooool05Oooool00ol00?ooo`00
ooooo`02ooooo`03ool00?l00?oooooo06Gooooo00?o0000ooooooooool00Oooool0017ooooo0_l0
001Uooooo`03o`00oooo003ooooo00;ooooo00?oo`00ooooooooool05oooool00ol0003ooooooooo
o`0Eooooo`03o`00oooo003ooooo00;ooooo00?oo`00o`00ooooool0I?ooool2o`0000?ooooo000A
ooooo`03o`000?oooooooooo06Cooooo00?o003oool00?ooool00_ooool00ooo003oooooooooo`0G
ooooo`03o`000?oooooooooo01Gooooo00?o003oool00?ooool00_ooool00ooo003o003oooooo`1U
ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo06Cooooo00?o003oool0
0?ooool00_ooool00ooo003o003oooooo`0Gooooo`03o`000?oooooooooo01Kooooo00Goo`00oooo
ooooooooooooool0001Wooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo
06Gooooo00Koo`00ooooooooooooooooool00?l00?lHooooo`03o`000?oooooooooo01Kooooo00Go
o`00ooooooooooooooooool0001Wooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oo
oooooooo06Gooooo00Koo`00ooooooooooooooooool00?l00?lHooooo`03o`000?oooooooooo01Go
oooo00?o003oool00?ooool00_ooool00ooo003o003oooooo`1Uooooo`03o`000?oooooooooo007o
oooo000Aooooo`;o0000IOooool00ol00?ooo`00ooooo`02ooooo`03ool00?oooooooooo01Oooooo
00?o0000ooooooooool05Oooool00ol00?ooo`00ooooo`02ooooo`03ool00?l00?oooooo06Cooooo
0_l00003ooooo`004Oooool00ol0003oooooooooo`1Tooooo`03o`00oooo003ooooo00;ooooo00?o
o`00ooooooooool05oooool00ol0003oooooooooo`0Eooooo`03o`00oooo003ooooo00;ooooo00?o
o`00o`00ooooool0IOooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1T
ooooo`03o`00oooo003ooooo00;ooooo00?oo`00o`00ooooool05oooool00ol0003oooooooooo`0E
ooooo`03o`00oooo003ooooo00;ooooo00?oo`00o`00ooooool0IOooool00ol0003oooooooooo`01
ooooo`004Oooool00ol0003oooooooooo`1Tooooo`03o`00oooo003ooooo00;ooooo00?oo`00o`00
ooooool05oooool00ol0003oooooooooo`0Fooooo`05ool00?oooooooooooooooooo0000Ioooool0
0ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1Uooooo`06ool00?oooooooooo
oooooooo003o003o6?ooool00ol0003oooooooooo`0Eooooo`03o`00oooo003ooooo00;ooooo00?o
o`00o`00ooooool0IOooool00ol0003oooooooooo`01ooooo`004Oooool2o`0006Gooooo00?o003o
ool00?ooool00_ooool00ooo003o003oooooo`0Gooooo`03o`000?oooooooooo01Gooooo00?o003o
ool00?ooool00_ooool00ooo003o003oooooo`1Tooooo`;o00000oooool0017ooooo00?o0000oooo
ooooool0I?ooool00ol00?ooo`00ooooo`02ooooo`03ool00?oooooooooo01Oooooo00?o0000oooo
ooooool05Oooool00ol00?ooo`00ooooo`02ooooo`03ool00?l00?oooooo06Gooooo00?o0000oooo
ooooool00Oooool0017ooooo00?o0000ooooooooool0I?ooool00ol00?ooo`00ooooo`02ooooo`03
ool00?l00?oooooo01Oooooo00?o0000ooooooooool05Oooool00ol00?ooo`00ooooo`02ooooo`03
ool00?l00?oooooo06Gooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0
I?ooool00ol00?ooo`00ooooo`02ooooo`03ool00?l00?oooooo01Oooooo00?o0000ooooooooool0
5_ooool01Ooo003oooooooooooooooooo`0006Oooooo00?o0000ooooooooool00Oooool0017ooooo
00?o0000ooooooooool0IOooool01_oo003oooooooooooooooooo`00o`00oaSooooo00?o0000oooo
ooooool05_ooool01Ooo003oooooooooooooooooo`0006Oooooo00?o0000ooooooooool00Oooool0
017ooooo0_l0001Vooooo`06ool00?oooooooooooooooooo003o003o6?ooool00ol0003ooooooooo
o`0Eooooo`03o`00oooo003ooooo00;ooooo00?oo`00o`00ooooool0I?ooool2o`0000?ooooo000A
ooooo`03o`000?oooooooooo06Gooooo00Goo`00ooooooooooooooooool0000Iooooo`03o`000?oo
oooooooo01Gooooo00?o003oool00?ooool00_ooool00ooo003o003oooooo`1Uooooo`03o`000?oo
oooooooo007ooooo0003ooooo`?o00001?ooool2o`0000Gooooo00?o0000ooooooooool0IOooool0
1_oo003oooooooooooooooooo`00o`00oaSooooo00?o0000ooooooooool05_ooool01_oo003ooooo
ooooooooooooo`00o`00ofKooooo00?o0000ooooooooool00Oooool000;ooooo00Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0IOooool0
1_oo003oooooooooooooooooo`00o`00oaSooooo00?o0000ooooooooool05_ooool01Ooo003ooooo
ooooooooooooo`0006Oooooo00?o0000ooooooooool00Oooool000Kooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo06Gooooo00Goo`00oooooooo
ooooooooool0000Iooooo`03o`000?oooooooooo01Kooooo00Goo`00ooooooooooooooooool0001W
ooooo`03o`000?oooooooooo007ooooo0006ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool00_ooool3o`0006Gooooo00Goo`00ooooooooooooooooool0000Iooooo`03o`000?oo
oooooooo01Kooooo00Goo`00ooooooooooooooooool0001Uooooo`?o00000oooool000;ooooo1?l0
0003ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0IOooool01Ooo003ooooo
ooooooooooooo`0001Wooooo00?o0000ooooooooool05_ooool01Ooo003oooooooooooooooooo`00
06Oooooo00?o0000ooooooooool00Oooool000;ooooo00?o0000ooooooooool01?ooool01?l0003o
ooooooooool00004ooooo`03o`000?oooooooooo06Gooooo00Goo`00ooooooooooooooooool0000I
ooooo`03o`000?oooooooooo01Kooooo00Goo`00ooooooooooooooooool0001Wooooo`03o`000?oo
oooooooo007ooooo0002ooooo`Go00000oooool2o`0000Gooooo00?o0000ooooooooool0IOooool0
1Ooo003oooooooooooooooooo`0001Wooooo00?o0000ooooooooool05_ooool01Ooo003ooooooooo
ooooooooo`0006Oooooo00?o0000ooooooooool00Oooool0017ooooo0_l0001Vooooo`05ool00?oo
oooooooooooooooo00006Oooool00ol0003oooooooooo`0Fooooo`05ool00?oooooooooooooooooo
0000I_ooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo06Gooooo00Goo`00oooooooooooo
ooooool0000Iooooo`03o`000?oooooooooo01Kooooo00Goo`00ooooooooooooooooool0001Woooo
o`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo06Gooooo00?oo`00oooooooo
ool00ooo000Hooooo`03o`000?oooooooooo01Gooooo0ooo0002ooooo`03ool00?oooooooooo06Go
oooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0I?ooool3ool00004oooo
oooo003oo`00ool001Sooooo00?o0000ooooooooool05Oooool3ool00004oooooooo003oo`00ool0
06Kooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0I?ooool3ool00004
oooooooo003oo`00ool001Sooooo00?o0000ooooooooool05Oooool3ool00004oooooooo003oo`00
ool006Kooooo00?o0000ooooooooool00Oooool0017ooooo0_l0001Uooooo`?oo`000_ooool00ol0
0?ooooooooooo`0Gooooo`03o`000?oooooooooo01Wooooo0ooo001Uooooo`;o00000oooool0017o
oooo00?o0000ooooooooool0JOooool00ol00?ooooooooooo`0Gooooo`03o`000?oooooooooo08;o
oooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0IOooool01Ol00?oooooo
oooooooooooo003o01Wooooo00?o0000ooooooooool05_ooool01Ol00?oooooooooooooooooo003o
06Oooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0IOooool00ol00?oo
ooooooooo`0Kooooo`03o`000?oooooooooo01Kooooo00Go003oooooooooooooooooo`00o`1Woooo
o`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo06Gooooo00Go003ooooooooo
ooooooooo`00o`0Iooooo`03o`000?oooooooooo01Kooooo00Go003oooooooooooooooooo`00o`1W
ooooo`03o`000?oooooooooo007ooooo000Aooooo`;o0000I_ooool01Ol00?oooooooooooooooooo
003o01Wooooo00?o0000ooooooooool0POooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo
06Wooooo00?o003oooooooooool05oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo
007ooooo000Aooooo`03o`000?oooooooooo06Wooooo00?o003oooooooooool05oooool00ol0003o
ooooooooo`0Fooooo`05o`00ooooooooooooooooool00?l0Ioooool00ol0003oooooooooo`01oooo
o`004Oooool00ol0003oooooooooo`1Uooooo`03o`00oooooooooooo01_ooooo00?o0000oooooooo
ool05_ooool01Ol00?oooooooooooooooooo003o06Oooooo00?o0000ooooooooool00Oooool0017o
oooo00?o0000ooooooooool0IOooool00ol00?ooooooooooo`0Kooooo`03o`000?oooooooooo01Oo
oooo00Co003ooooooooooooo003oIoooool00ol0003oooooooooo`01ooooo`004Oooool2o`0006Ko
oooo00Go003oooooooooooooooooo`00o`0Iooooo`03o`000?oooooooooo01Oooooo00?o003ooooo
ooooool0Ioooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo06Wooooo00?o003ooooooooo
ool05oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo007ooooo0003ooooo`?o0000
1?ooool2o`0000Gooooo00?o0000ooooooooool0JOooool00ol00?ooooooooooo`0Gooooo`03o`00
0?oooooooooo01Oooooo00Co003ooooooooooooo003oIoooool00ol0003oooooooooo`01ooooo`00
0_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00001?ooool00ol0
003oooooooooo`1Vooooo`03o`00oooooooooooo01[ooooo00?o0000ooooooooool05oooool01?l0
0?ooooooooooool00?mWooooo`03o`000?oooooooooo007ooooo0002ooooo`05o`000?oooooooooo
ooooool000000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo06Kooooo00?o
003oooooooooool06_ooool00ol0003oooooooooo`0Gooooo`03o`00oooooooo003o06Sooooo00?o
0000ooooooooool00Oooool000;ooooo1?l00003ooooo`04o`000?ooooooooooo`0000Cooooo0ol0
001Vooooo`03o`00oooooooo003o01[ooooo00?o0000ooooooooool05oooool00ol00?ooooooo`00
o`1Vooooo`?o00000oooool000;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0
0004ooooo`03o`000?oooooooooo06Kooooo00?o003oooooool00?l06_ooool00ol0003ooooooooo
o`22ooooo`03o`000?oooooooooo007ooooo0003ooooo`03o`000?oooooooooo00?ooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`1Xooooo`03o`00oooooooooooo01Sooooo00?o
0000ooooooooool06Oooool00ol00?ooooooooooo`1Vooooo`03o`000?oooooooooo007ooooo0004
ooooo`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool0I_ooool00ol00?ooooooo`00o`0J
ooooo`03o`000?oooooooooo01Oooooo00?o003oooooool00?l0J?ooool00ol0003oooooooooo`01
ooooo`004Oooool00ol0003oooooooooo`1Vooooo`03o`00oooooooooooo01[ooooo00?o0000oooo
ooooool05oooool00ol00?ooooooo`00o`1Xooooo`03o`000?oooooooooo007ooooo000Aooooo`;o
0000Ioooool00ol00?ooooooo`00o`0Jooooo`03o`000?oooooooooo01Oooooo00?o003oooooool0
0?l0Ioooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo06Kooooo00?o003oooooool00?l0
6_ooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oo
oooooooo06Kooooo00?o003oooooool00?l06_ooool00ol0003oooooooooo`22ooooo`03o`000?oo
oooooooo007ooooo000Aooooo`03o`000?oooooooooo06Kooooo00?o003oooooool00?l06_ooool0
0ol0003oooooooooo`0Gooooo`03o`00oooooooo003o06Sooooo00?o0000ooooooooool00Oooool0
017ooooo0_l00024ooooo`03o`000?oooooooooo01Sooooo0_l00?mWooooo`;o00000oooool0017o
oooo00?o0000ooooooooool0Ioooool00ol00?ooooooooooo`0Iooooo`03o`000?oooooooooo01So
oooo0_l00?mXooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo06Oooooo
00?o003oooooooooool06Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo007ooooo
000Aooooo`03o`000?oooooooooo06Oooooo00?o003oooooooooool06Oooool00ol0003ooooooooo
o`22ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo08?ooooo00?o0000
ooooooooool0P_ooool00ol0003oooooooooo`01ooooo`004Oooool2o`0000Gooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo0_l00003oooo
o`004Oooooooo`0000go00000oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-11.9139, -6.72597, \
0.0788464, 0.413923}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Show both", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(gw2 = 
        Show[GraphicsArray[{{g1, g5, \ g6}}], \ 
          ImageSize \[Rule] 504*1.5];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .19314 
%%ImageSize: 756 146.011 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.00459847 0.31746 [
[ 0 0 0 0 ]
[ 1 .19314 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .19314 L
0 .19314 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00459847 0.321429 0.188537 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.047619 0.0140438 0.00908109 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01404 -6 -4.5 ]
[-0.0125 .01404 0 4.5 ]
[-0.0125 .10485 -12 -4.5 ]
[-0.0125 .10485 0 4.5 ]
[-0.0125 .19567 -12 -4.5 ]
[-0.0125 .19567 0 4.5 ]
[-0.0125 .28648 -12 -4.5 ]
[-0.0125 .28648 0 4.5 ]
[-0.0125 .37729 -12 -4.5 ]
[-0.0125 .37729 0 4.5 ]
[-0.0125 .4681 -12 -4.5 ]
[-0.0125 .4681 0 4.5 ]
[-0.0125 .55891 -12 -4.5 ]
[-0.0125 .55891 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01404 m
.00625 .01404 L
s
[(0)] -0.0125 .01404 1 0 Mshowa
0 .10485 m
.00625 .10485 L
s
[(10)] -0.0125 .10485 1 0 Mshowa
0 .19567 m
.00625 .19567 L
s
[(20)] -0.0125 .19567 1 0 Mshowa
0 .28648 m
.00625 .28648 L
s
[(30)] -0.0125 .28648 1 0 Mshowa
0 .37729 m
.00625 .37729 L
s
[(40)] -0.0125 .37729 1 0 Mshowa
0 .4681 m
.00625 .4681 L
s
[(50)] -0.0125 .4681 1 0 Mshowa
0 .55891 m
.00625 .55891 L
s
[(60)] -0.0125 .55891 1 0 Mshowa
.125 Mabswid
0 .03221 m
.00375 .03221 L
s
0 .05037 m
.00375 .05037 L
s
0 .06853 m
.00375 .06853 L
s
0 .08669 m
.00375 .08669 L
s
0 .12302 m
.00375 .12302 L
s
0 .14118 m
.00375 .14118 L
s
0 .15934 m
.00375 .15934 L
s
0 .1775 m
.00375 .1775 L
s
0 .21383 m
.00375 .21383 L
s
0 .23199 m
.00375 .23199 L
s
0 .25015 m
.00375 .25015 L
s
0 .26831 m
.00375 .26831 L
s
0 .30464 m
.00375 .30464 L
s
0 .3228 m
.00375 .3228 L
s
0 .34096 m
.00375 .34096 L
s
0 .35913 m
.00375 .35913 L
s
0 .39545 m
.00375 .39545 L
s
0 .41361 m
.00375 .41361 L
s
0 .43177 m
.00375 .43177 L
s
0 .44994 m
.00375 .44994 L
s
0 .48626 m
.00375 .48626 L
s
0 .50442 m
.00375 .50442 L
s
0 .52258 m
.00375 .52258 L
s
0 .54075 m
.00375 .54075 L
s
0 .57707 m
.00375 .57707 L
s
0 .59523 m
.00375 .59523 L
s
0 .6134 m
.00375 .6134 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01404 m
1 .01404 L
s
.99375 .10485 m
1 .10485 L
s
.99375 .19567 m
1 .19567 L
s
.99375 .28648 m
1 .28648 L
s
.99375 .37729 m
1 .37729 L
s
.99375 .4681 m
1 .4681 L
s
.99375 .55891 m
1 .55891 L
s
.125 Mabswid
.99625 .03221 m
1 .03221 L
s
.99625 .05037 m
1 .05037 L
s
.99625 .06853 m
1 .06853 L
s
.99625 .08669 m
1 .08669 L
s
.99625 .12302 m
1 .12302 L
s
.99625 .14118 m
1 .14118 L
s
.99625 .15934 m
1 .15934 L
s
.99625 .1775 m
1 .1775 L
s
.99625 .21383 m
1 .21383 L
s
.99625 .23199 m
1 .23199 L
s
.99625 .25015 m
1 .25015 L
s
.99625 .26831 m
1 .26831 L
s
.99625 .30464 m
1 .30464 L
s
.99625 .3228 m
1 .3228 L
s
.99625 .34096 m
1 .34096 L
s
.99625 .35913 m
1 .35913 L
s
.99625 .39545 m
1 .39545 L
s
.99625 .41361 m
1 .41361 L
s
.99625 .43177 m
1 .43177 L
s
.99625 .44994 m
1 .44994 L
s
.99625 .48626 m
1 .48626 L
s
.99625 .50442 m
1 .50442 L
s
.99625 .52258 m
1 .52258 L
s
.99625 .54075 m
1 .54075 L
s
.99625 .57707 m
1 .57707 L
s
.99625 .59523 m
1 .59523 L
s
.99625 .6134 m
1 .6134 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
0 0 1 r
.5 Mabswid
[ .01 ] 0 setdash
.02381 .0184 m
.02395 .0184 L
.02408 .0184 L
.02423 .01839 L
.02437 .01838 L
.02462 .01835 L
.02489 .01831 L
.02519 .01825 L
.02551 .01817 L
.02608 .01798 L
.02722 .01748 L
.02847 .01674 L
.02973 .01586 L
.03043 .01537 L
.03077 .01514 L
.03109 .01496 L
.03125 .01489 L
.03139 .01483 L
.03147 .01481 L
.03156 .01479 L
.03171 .01477 L
.03179 .01477 L
.03188 .01478 L
.03197 .01479 L
.03206 .01482 L
.03221 .01487 L
.03238 .01495 L
.03299 .01532 L
.03355 .01571 L
.03476 .01657 L
.03605 .01736 L
.03714 .01788 L
.03777 .01811 L
.03805 .01819 L
.03836 .01826 L
.03863 .01832 L
.03892 .01836 L
.03908 .01838 L
.03923 .01839 L
.03938 .0184 L
.03952 .01841 L
.03965 .01841 L
.03978 .01841 L
.0399 .01841 L
.04003 .0184 L
.04017 .01839 L
.04031 .01838 L
.04058 .01834 L
.04089 .01829 L
.04122 .01822 L
Mistroke
.04183 .01803 L
.04243 .0178 L
.04298 .01755 L
.04525 .01613 L
.04644 .01528 L
.04673 .01509 L
.04705 .01492 L
.04722 .01485 L
.04731 .01482 L
.04739 .0148 L
.04746 .01479 L
.04755 .01478 L
.0477 .01478 L
.04778 .01478 L
.04786 .0148 L
.04802 .01484 L
.04819 .01492 L
.04836 .015 L
.04905 .01545 L
.05029 .01634 L
.05155 .01716 L
.05217 .0175 L
.05273 .01777 L
.05326 .01799 L
.05383 .01818 L
.05415 .01826 L
.05444 .01832 L
.05472 .01837 L
.05487 .01839 L
.05501 .0184 L
.05517 .01842 L
.05531 .01842 L
.05546 .01843 L
.05555 .01843 L
.05563 .01843 L
.05576 .01843 L
.05591 .01842 L
.05606 .01841 L
.0562 .0184 L
.05653 .01835 L
.05683 .0183 L
.05716 .01822 L
.05751 .01812 L
.05866 .01766 L
.05989 .01698 L
.0621 .01544 L
.0627 .01505 L
.063 .01489 L
.06309 .01486 L
.06318 .01483 L
Mistroke
.06326 .01481 L
.06334 .01479 L
.06342 .01478 L
.06351 .01478 L
.0636 .01478 L
.06369 .01479 L
.06378 .01482 L
.06387 .01484 L
.06403 .01491 L
.06434 .01507 L
.06467 .01528 L
.06583 .01611 L
.0671 .01698 L
.06827 .01764 L
.0689 .01793 L
.06951 .01815 L
.06984 .01825 L
.0702 .01833 L
.07052 .01839 L
.07068 .01841 L
.07082 .01843 L
.07096 .01844 L
.07111 .01846 L
.07119 .01846 L
.07127 .01846 L
.07142 .01847 L
.07158 .01846 L
.07172 .01846 L
.0718 .01846 L
.07188 .01845 L
.07205 .01844 L
.0722 .01842 L
.07233 .0184 L
.07264 .01835 L
.07294 .01828 L
.07326 .0182 L
.07437 .01777 L
.07504 .01743 L
.07568 .01706 L
.07688 .01625 L
.07804 .01541 L
.07837 .01518 L
.07868 .015 L
.07882 .01493 L
.07897 .01486 L
.07912 .01481 L
.07927 .01479 L
.07941 .01478 L
.07954 .01479 L
.07968 .01483 L
Mistroke
.07982 .01487 L
.08006 .01499 L
.08033 .01515 L
.08149 .01597 L
.08262 .01677 L
.08383 .01752 L
.08453 .01786 L
.08517 .01812 L
.08547 .01822 L
.08581 .01832 L
.0861 .01839 L
.08642 .01844 L
.08658 .01847 L
.08674 .01848 L
.08689 .0185 L
.08704 .01851 L
.08718 .01851 L
.08731 .01852 L
.08745 .01851 L
.08761 .01851 L
.08769 .0185 L
.08777 .0185 L
.08795 .01848 L
.08811 .01847 L
.08827 .01844 L
.08856 .01839 L
.08888 .01832 L
.08944 .01814 L
.09006 .0179 L
.09116 .01733 L
.09353 .01571 L
.09418 .01524 L
.09454 .01502 L
.09471 .01493 L
.09487 .01486 L
.09503 .01482 L
.0951 .0148 L
.09519 .01479 L
.09527 .01479 L
.09536 .0148 L
.09545 .01481 L
.09553 .01483 L
.09567 .01488 L
.09583 .01495 L
.09612 .01511 L
.09863 .0169 L
.09972 .01757 L
.1009 .01812 L
.10154 .01834 L
.10182 .01841 L
Mistroke
.10212 .01848 L
.10241 .01852 L
.10255 .01854 L
.10268 .01856 L
.10283 .01857 L
.10297 .01858 L
.10312 .01858 L
.10328 .01858 L
.10343 .01858 L
.10358 .01857 L
.10366 .01856 L
.10374 .01856 L
.10391 .01854 L
.10424 .01849 L
.10459 .01842 L
.10517 .01826 L
.10581 .01802 L
.10705 .01738 L
.10817 .01664 L
.10949 .01567 L
.11007 .01525 L
.11037 .01506 L
.11054 .01496 L
.1107 .01489 L
.11085 .01484 L
.11101 .01481 L
.11115 .0148 L
.11128 .01481 L
.11141 .01484 L
.11155 .01489 L
.11169 .01495 L
.11183 .01502 L
.11302 .01586 L
.11424 .01677 L
.11553 .01759 L
.11669 .01816 L
.11735 .0184 L
.11766 .01848 L
.11796 .01855 L
.11823 .0186 L
.11837 .01862 L
.11852 .01863 L
.11865 .01865 L
.11879 .01866 L
.11892 .01866 L
.11904 .01866 L
.11919 .01866 L
.11933 .01866 L
.11945 .01865 L
.11959 .01864 L
Mistroke
.11974 .01863 L
.1199 .01861 L
.12019 .01856 L
.1205 .01849 L
.12084 .0184 L
.12143 .0182 L
.12207 .01791 L
.12277 .01753 L
.12405 .0167 L
.12521 .01582 L
.12578 .01539 L
.12609 .01518 L
.12641 .01498 L
.12655 .01492 L
.1267 .01486 L
.12678 .01484 L
.12686 .01482 L
.12701 .01481 L
.12714 .01482 L
.12728 .01485 L
.12742 .0149 L
.12756 .01496 L
.1282 .01537 L
.12878 .0158 L
.13008 .01679 L
.13121 .01755 L
.1324 .01818 L
.13302 .01842 L
.13335 .01853 L
.1337 .01862 L
.13403 .01868 L
.13432 .01873 L
.13447 .01874 L
.13462 .01875 L
.13477 .01876 L
.1349 .01876 L
.13506 .01876 L
.13514 .01876 L
.13522 .01876 L
.13538 .01875 L
.13552 .01874 L
.13569 .01872 L
.13584 .0187 L
.13618 .01864 L
.13648 .01857 L
.1368 .01847 L
.13739 .01826 L
.13855 .01767 L
.13963 .01697 L
.14072 .01615 L
Mistroke
.14189 .01526 L
.14223 .01504 L
.1424 .01495 L
.14256 .01489 L
.1427 .01485 L
.14285 .01483 L
.14294 .01483 L
.14302 .01484 L
.14317 .01487 L
.14332 .01492 L
.14347 .015 L
.14375 .01516 L
.14437 .01562 L
.1456 .01659 L
.14677 .01743 L
.1479 .0181 L
.1484 .01834 L
.14895 .01855 L
.1495 .01871 L
.1498 .01878 L
.15008 .01883 L
.15023 .01885 L
.15038 .01886 L
.15052 .01888 L
.15067 .01888 L
.15082 .01889 L
.15091 .01889 L
.15099 .01889 L
.15115 .01888 L
.1513 .01887 L
.15145 .01886 L
.15161 .01884 L
.15193 .01878 L
.15223 .01872 L
.15251 .01864 L
.15314 .01842 L
.15382 .01811 L
.1562 .01652 L
.15746 .01552 L
.15782 .01525 L
.158 .01513 L
.15816 .01503 L
.15831 .01496 L
.15847 .01489 L
.15855 .01487 L
.15863 .01486 L
.15871 .01485 L
.1588 .01485 L
.15888 .01485 L
.15896 .01487 L
Mistroke
.15912 .01491 L
.1592 .01495 L
.15928 .01499 L
.15947 .01509 L
.1601 .01554 L
.16128 .01651 L
.16239 .01735 L
.16359 .01812 L
.16416 .01841 L
.16478 .01867 L
.16512 .01878 L
.16542 .01886 L
.16573 .01893 L
.16587 .01896 L
.16603 .01898 L
.16616 .019 L
.1663 .01901 L
.16645 .01902 L
.16658 .01903 L
.16672 .01903 L
.16685 .01903 L
.16697 .01903 L
.1671 .01902 L
.16725 .01901 L
.16739 .01899 L
.1677 .01895 L
.16799 .01889 L
.16826 .01882 L
.16882 .01863 L
.16944 .01836 L
.17069 .01764 L
.17292 .0159 L
.17355 .01539 L
.17387 .01517 L
.174 .01508 L
.17415 .015 L
.17429 .01494 L
.17442 .0149 L
.17455 .01487 L
.17469 .01487 L
.17485 .01489 L
.175 .01494 L
.17513 .015 L
.17528 .01508 L
.17659 .0161 L
.1778 .01711 L
.17908 .01802 L
.1797 .01838 L
.18028 .01867 L
.18079 .01887 L
Mistroke
.18136 .01904 L
.18165 .01911 L
.18192 .01915 L
.18207 .01917 L
.18221 .01919 L
.18237 .0192 L
.18252 .0192 L
.18266 .0192 L
.18281 .0192 L
.18295 .01919 L
.18307 .01918 L
.18322 .01917 L
.18337 .01915 L
.18369 .0191 L
.184 .01902 L
.18433 .01893 L
.18492 .0187 L
.18609 .01808 L
.18714 .01734 L
.18827 .01642 L
.18946 .01541 L
.18976 .01519 L
.18992 .01509 L
.19008 .015 L
.19017 .01496 L
.19026 .01493 L
.19035 .01491 L
.19043 .01489 L
.19052 .01489 L
.19059 .01489 L
.19068 .01491 L
.19076 .01493 L
.19091 .01498 L
.19106 .01506 L
.19134 .01524 L
.19197 .01574 L
.1932 .01682 L
.19437 .01775 L
.1955 .0185 L
.196 .01877 L
.19655 .01901 L
.1971 .0192 L
.1974 .01928 L
.19768 .01933 L
.19783 .01936 L
.19799 .01938 L
.19812 .01939 L
.19827 .0194 L
.19835 .0194 L
.19843 .0194 L
Mistroke
.19852 .01941 L
.1986 .0194 L
.19875 .0194 L
.19891 .01939 L
.19906 .01938 L
.19921 .01936 L
.19955 .0193 L
.19987 .01922 L
.20022 .01911 L
.20085 .01886 L
.20143 .01856 L
.20262 .01778 L
.20373 .01688 L
.20502 .01573 L
.20533 .01547 L
.20565 .01522 L
.20593 .01505 L
.20609 .01498 L
.20623 .01493 L
.20637 .01492 L
.20651 .01493 L
.20663 .01495 L
.20675 .015 L
.2069 .01507 L
.20705 .01516 L
.20731 .01536 L
.20848 .01639 L
.20968 .01746 L
.21096 .01843 L
.2116 .01882 L
.21219 .01913 L
.21273 .01935 L
.21304 .01944 L
.21332 .01952 L
.21361 .01957 L
.21374 .01959 L
.21388 .01961 L
.21402 .01963 L
.21416 .01964 L
.21431 .01964 L
.21439 .01964 L
.21447 .01964 L
.2146 .01964 L
.21473 .01963 L
.21485 .01962 L
.21498 .01961 L
.21526 .01957 L
.21553 .01951 L
.21609 .01935 L
.21669 .0191 L
Mistroke
.21778 .01847 L
.21908 .01748 L
.22027 .0164 L
.22084 .01586 L
.22115 .01558 L
.22145 .01533 L
.22173 .01514 L
.22188 .01505 L
.22203 .01499 L
.22215 .01496 L
.22228 .01495 L
.22242 .01496 L
.22255 .015 L
.2227 .01507 L
.22287 .01517 L
.22318 .0154 L
.22375 .01592 L
.22505 .01716 L
.22627 .01822 L
.22743 .01903 L
.22806 .01938 L
.2284 .01953 L
.22875 .01966 L
.22905 .01975 L
.22938 .01983 L
.22952 .01986 L
.22968 .01988 L
.22982 .0199 L
.22996 .01991 L
.2301 .01992 L
.23023 .01992 L
.23038 .01992 L
.23054 .01992 L
.23062 .01991 L
.2307 .01991 L
.23086 .01989 L
.23101 .01987 L
.23116 .01984 L
.23144 .01978 L
.23169 .01971 L
.23226 .01949 L
.23288 .01919 L
.23355 .01877 L
.23477 .01782 L
.23601 .01665 L
.23717 .01552 L
.23747 .01528 L
.23762 .01517 L
.23776 .01509 L
.23791 .01503 L
Mistroke
.238 .015 L
.23809 .01499 L
.23823 .01499 L
.23838 .01503 L
.23847 .01506 L
.23856 .0151 L
.23871 .0152 L
.23907 .01548 L
.23971 .0161 L
.24095 .01735 L
.24212 .01842 L
.24326 .01927 L
.24376 .01957 L
.24431 .01984 L
.24486 .02005 L
.24516 .02013 L
.24544 .02019 L
.2456 .02021 L
.24575 .02023 L
.24589 .02024 L
.24603 .02025 L
.24612 .02025 L
.24619 .02026 L
.24628 .02025 L
.24636 .02025 L
.24651 .02024 L
.24667 .02023 L
.24683 .02021 L
.24698 .02018 L
.24731 .02011 L
.24764 .02001 L
.24799 .01987 L
.24862 .01956 L
.2492 .01921 L
.2517 .017 L
.2528 .01585 L
.2531 .01556 L
.25342 .01529 L
.25357 .01518 L
.25373 .0151 L
.25386 .01505 L
.25401 .01503 L
.25416 .01504 L
.2543 .01509 L
.25443 .01515 L
.25457 .01524 L
.25517 .01577 L
.25625 .01693 L
.25748 .01821 L
.25863 .01923 L
Mistroke
.25978 .02 L
.26038 .02029 L
.26072 .02042 L
.26103 .02051 L
.26119 .02055 L
.26136 .02058 L
.2615 .02061 L
.26166 .02063 L
.26174 .02063 L
.26182 .02064 L
.26198 .02065 L
.26206 .02065 L
.26215 .02065 L
.26225 .02064 L
.26234 .02064 L
.26241 .02063 L
.2625 .02062 L
.26265 .02061 L
.2628 .02058 L
.26293 .02055 L
.26324 .02047 L
.26357 .02036 L
.26417 .0201 L
.26471 .01979 L
.26593 .01885 L
.26814 .01656 L
.26871 .01592 L
.26903 .0156 L
.26932 .01533 L
.26946 .01524 L
.2696 .01515 L
.26976 .0151 L
.2699 .01508 L
.27003 .01509 L
.27015 .01513 L
.27028 .0152 L
.27043 .01529 L
.27075 .01557 L
.2711 .01594 L
.27173 .01666 L
.27293 .01803 L
.27416 .01927 L
.27531 .02019 L
.27589 .02054 L
.27652 .02083 L
.27685 .02095 L
.27704 .021 L
.27721 .02103 L
.27737 .02106 L
.27751 .02108 L
Mistroke
.27759 .02109 L
.27767 .0211 L
.27776 .0211 L
.27784 .02111 L
.27799 .02111 L
.27813 .02111 L
.27829 .0211 L
.27843 .02108 L
.27857 .02106 L
.2787 .02104 L
.27899 .02097 L
.27931 .02087 L
.27959 .02075 L
.28024 .02042 L
.28087 .01999 L
.28155 .01943 L
.28278 .01819 L
.28403 .01672 L
.28464 .016 L
.2849 .0157 L
.28519 .01542 L
.28535 .0153 L
.28549 .01521 L
.28563 .01516 L
.28577 .01513 L
.28593 .01515 L
.28607 .01521 L
.28623 .01531 L
.2864 .01545 L
.28773 .017 L
.29011 .01973 L
.29076 .02032 L
.29145 .02084 L
.29211 .02122 L
.29239 .02135 L
.2927 .02146 L
.293 .02155 L
.29316 .02158 L
.29332 .02161 L
.29346 .02163 L
.29359 .02164 L
.29374 .02165 L
.29388 .02165 L
.29404 .02165 L
.29411 .02164 L
.2942 .02163 L
.29435 .02161 L
.2945 .02159 L
.29482 .02151 L
.29516 .0214 L
Mistroke
.29575 .02112 L
.29637 .02073 L
.29749 .01979 L
.29872 .01842 L
.29989 .01694 L
.3004 .01628 L
.30094 .01564 L
.30122 .01538 L
.3013 .01532 L
.30138 .01527 L
.30153 .01522 L
.30168 .0152 L
.30182 .01523 L
.30194 .01528 L
.30208 .01537 L
.30239 .01567 L
.30267 .01599 L
.3033 .01682 L
.30444 .01835 L
.30576 .01994 L
.30633 .02054 L
.30697 .0211 L
.30751 .02151 L
.3081 .02185 L
.30842 .02199 L
.30871 .0221 L
.30885 .02214 L
.30901 .02217 L
.30914 .0222 L
.30929 .02222 L
.30944 .02224 L
.30959 .02225 L
.30967 .02225 L
.30976 .02225 L
.30992 .02225 L
.31 .02224 L
.31009 .02223 L
.31024 .02221 L
.31043 .02217 L
.31059 .02213 L
.31089 .02203 L
.31121 .0219 L
.3118 .02157 L
.31239 .02114 L
.31294 .02065 L
.3142 .01926 L
.3155 .01752 L
.31614 .01662 L
.31646 .01619 L
.31674 .01584 L
Mistroke
.31701 .01554 L
.31717 .01542 L
.31731 .01533 L
.31746 .01528 L
.31753 .01528 L
.31762 .01529 L
.31777 .01534 L
.31791 .01544 L
.31808 .01558 L
.31823 .01575 L
.31853 .01612 L
.31919 .01705 L
.32142 .02014 L
.32259 .02139 L
.32318 .02189 L
.32383 .02232 L
.32438 .02258 L
.3247 .02269 L
.32484 .02273 L
.32498 .02275 L
.32511 .02278 L
.32524 .02279 L
.32539 .0228 L
.32553 .02281 L
.32566 .0228 L
.3258 .0228 L
.32593 .02278 L
.32606 .02276 L
.32621 .02273 L
.32635 .0227 L
.32662 .02261 L
.32691 .02249 L
.32723 .02233 L
.3278 .02195 L
.32832 .02152 L
.32953 .02024 L
.33082 .01852 L
.33195 .01685 L
.33254 .01602 L
.33284 .01568 L
.33292 .0156 L
.33301 .01552 L
.33316 .01543 L
.33331 .01538 L
.3334 .01537 L
.33347 .01538 L
.33362 .01544 L
.33377 .01553 L
.3339 .01565 L
.33403 .01579 L
Mistroke
.33431 .01614 L
.33537 .01767 L
.33761 .0207 L
.33822 .02134 L
.33887 .0219 L
.33949 .02231 L
.33976 .02245 L
.34005 .02257 L
.34021 .02263 L
.34038 .02268 L
.34054 .02272 L
.34068 .02274 L
.34077 .02276 L
.34085 .02277 L
.34094 .02277 L
.34103 .02278 L
.34112 .02278 L
.34121 .02278 L
.34136 .02277 L
.34151 .02276 L
.34167 .02273 L
.34182 .0227 L
.34195 .02267 L
.34227 .02256 L
.3426 .02241 L
.3432 .02205 L
.34376 .02162 L
.34503 .02033 L
.34729 .01731 L
.34791 .01647 L
.34825 .01606 L
.34841 .01589 L
.34857 .01575 L
.34869 .01565 L
.34884 .01556 L
.34898 .0155 L
.34913 .01548 L
.34928 .0155 L
.34936 .01552 L
.34944 .01555 L
.3496 .01564 L
.34974 .01575 L
.35039 .01639 L
.35098 .01707 L
.35232 .01848 L
.35293 .01899 L
.3535 .01937 L
.35381 .01954 L
.3541 .01967 L
.35441 .01978 L
Mistroke
.35459 .01982 L
.35475 .01986 L
.35489 .01988 L
.35504 .0199 L
.35518 .0199 L
.35531 .01991 L
.35546 .0199 L
.35554 .0199 L
.35562 .01989 L
.35577 .01987 L
.35592 .01985 L
.35608 .01981 L
.35625 .01976 L
.35657 .01965 L
.35716 .01937 L
.35772 .01902 L
.35832 .01858 L
.35938 .01767 L
.36062 .01657 L
.36178 .0157 L
.36283 .01512 L
.36311 .01498 L
.36342 .01485 L
.36354 .0148 L
.36368 .01476 L
.36383 .01473 L
.36397 .01472 L
.36411 .01473 L
.36425 .01477 L
.3644 .01485 L
.36449 .01491 L
.36456 .01498 L
.36489 .01534 L
.36519 .0158 L
.36573 .01686 L
.36632 .0184 L
.36696 .02056 L
.36763 .02347 L
.36884 .03048 L
.36998 .03944 L
.3712 .0519 L
.37341 .08254 L
.37597 .13158 L
.37839 .19082 L
.38301 .32722 L
.38791 .47435 L
.39019 .53009 L
.39138 .55406 L
.39264 .57461 L
.39329 .58309 L
Mistroke
.39399 .59073 L
.39463 .59614 L
.39523 .59983 L
.39555 .60125 L
.3957 .60181 L
.39585 .60226 L
.39597 .60258 L
.39611 .60288 L
.39626 .6031 L
.39641 .60325 L
.39649 .6033 L
.39657 .60332 L
.39672 .60329 L
.3968 .60325 L
.39688 .60318 L
.39696 .60308 L
.39706 .60294 L
.39722 .60262 L
.39737 .60222 L
.39766 .60125 L
.39795 .59997 L
.39822 .5985 L
.39884 .59418 L
.39944 .5887 L
.40008 .58148 L
.40231 .54641 L
.40487 .48987 L
.4073 .42483 L
.41192 .28737 L
.41683 .14624 L
.41927 .08355 L
.42047 .0549 L
.42099 .0428 L
.42157 .02993 L
.42183 .02419 L
.42198 .02121 L
.42212 .01877 L
.42225 .01755 L
.42239 .01845 L
.42251 .02053 L
.42263 .02279 L
.42375 .04607 L
.42612 .09317 L
.43086 .17808 L
.43543 .24612 L
.43778 .27355 L
.43908 .28592 L
.44029 .29522 L
.44151 .30229 L
.44216 .30504 L
Mistroke
.44249 .30618 L
.44285 .30719 L
.44319 .30796 L
.44334 .30823 L
.4435 .30848 L
.44365 .30867 L
.4438 .30882 L
.44389 .30889 L
.44396 .30894 L
.44412 .309 L
.44426 .30903 L
.4444 .30901 L
.44455 .30896 L
.44471 .30886 L
.44485 .30874 L
.44498 .3086 L
.44527 .30816 L
.44556 .30756 L
.44584 .30687 L
.44646 .30481 L
.44706 .30215 L
.44771 .29862 L
.44888 .29046 L
.44994 .2812 L
.45476 .22177 L
.45941 .15204 L
.46176 .11826 L
.46435 .08551 L
.46683 .05988 L
.4691 .04232 L
.46968 .03889 L
.47031 .03574 L
.47059 .03453 L
.4709 .03342 L
.47119 .03257 L
.47145 .03196 L
.47161 .03167 L
.47178 .03144 L
.47187 .03135 L
.47195 .03129 L
.47204 .03124 L
.47213 .03121 L
.47221 .0312 L
.4723 .03121 L
.47239 .03124 L
.47247 .03129 L
.47262 .03142 L
.47277 .03162 L
.47292 .03186 L
.47307 .03216 L
Mistroke
.47334 .03285 L
.47397 .03499 L
.4746 .03784 L
.47519 .041 L
.47652 .04971 L
.47894 .07056 L
.48142 .09824 L
.48366 .1283 L
.48849 .20217 L
.49314 .26823 L
.49555 .29315 L
.49676 .30216 L
.49745 .30609 L
.49809 .30895 L
.49869 .3109 L
.49903 .31168 L
.49919 .31197 L
.49935 .3122 L
.49949 .31237 L
.49962 .31249 L
.49977 .31258 L
.49993 .31262 L
.50007 .31263 L
.50023 .31258 L
.50031 .31254 L
.50039 .31248 L
.50054 .31233 L
.50069 .31215 L
.50083 .31193 L
.50114 .31131 L
.50142 .31059 L
.50171 .30967 L
.50278 .3049 L
.50337 .3013 L
.50392 .29745 L
.50514 .28692 L
.50735 .26217 L
.51214 .19223 L
.51676 .1224 L
.51933 .08922 L
.52166 .06476 L
.52283 .05466 L
.5241 .04541 L
.52529 .03837 L
.52587 .03567 L
.52639 .03367 L
.52666 .03284 L
.52696 .03211 L
.52712 .03179 L
.52727 .03156 L
Mistroke
.52741 .03139 L
.52757 .03127 L
.5277 .03121 L
.52784 .0312 L
.52797 .03124 L
.52809 .03132 L
.52822 .03145 L
.52837 .03164 L
.52852 .03191 L
.52866 .0322 L
.52899 .03307 L
.5293 .03411 L
.52987 .03656 L
.53116 .04401 L
.53358 .06365 L
.5358 .08724 L
.54056 .15157 L
.54514 .22034 L
.54768 .25492 L
.55001 .28069 L
.55116 .29075 L
.55177 .29523 L
.55241 .29933 L
.55298 .30234 L
.5536 .30502 L
.55387 .30598 L
.55416 .30687 L
.55444 .30757 L
.5547 .30809 L
.55498 .30855 L
.55514 .30873 L
.55529 .30887 L
.55543 .30895 L
.55556 .309 L
.5557 .30903 L
.55585 .30901 L
.556 .30896 L
.55608 .30891 L
.55616 .30885 L
.55631 .30872 L
.55645 .30855 L
.55676 .30805 L
.55711 .3073 L
.55775 .30538 L
.55843 .30256 L
.55965 .29557 L
.56089 .28611 L
.56224 .27342 L
.56467 .24479 L
.56962 .17003 L
Mistroke
.57208 .12687 L
.57438 .08352 L
.57659 .03884 L
.5769 .03247 L
.57723 .02558 L
.57738 .02251 L
.57747 .0209 L
.57754 .01951 L
.57768 .01773 L
.57783 .01813 L
.57797 .02029 L
.57812 .02315 L
.57838 .02869 L
.57896 .0418 L
.58356 .15689 L
.58846 .29859 L
.59317 .43789 L
.59557 .50064 L
.59684 .52926 L
.59817 .55529 L
.59937 .57427 L
.6 .58254 L
.60068 .58995 L
.60131 .59535 L
.60188 .5991 L
.60215 .60048 L
.60245 .60168 L
.60259 .60212 L
.60274 .60251 L
.60287 .60281 L
.603 .60303 L
.60315 .60321 L
.60323 .60327 L
.60331 .60331 L
.6034 .60332 L
.60349 .6033 L
.60365 .6032 L
.6038 .60302 L
.60393 .60279 L
.60408 .60245 L
.60424 .60199 L
.60457 .60076 L
.60488 .59924 L
.60559 .59446 L
.6062 .58885 L
.60676 .58254 L
.60802 .56443 L
.61031 .51894 L
.61281 .45434 L
.61771 .30495 L
Mistroke
.62243 .16957 L
.62501 .11116 L
.62619 .08921 L
.62744 .06944 L
.62859 .05427 L
.62986 .0409 L
.63101 .0315 L
.63209 .02489 L
.63269 .022 L
.63335 .01946 L
.63397 .01759 L
.63454 .01628 L
.63506 .01542 L
.6352 .01523 L
.63535 .01506 L
.63549 .01493 L
.63563 .01484 L
.63577 .01476 L
.63592 .01472 L
.63607 .01472 L
.63623 .01474 L
.63638 .01478 L
.63652 .01483 L
.63678 .01493 L
.63795 .01553 L
.63919 .01641 L
.64142 .01836 L
.64255 .0192 L
.64288 .01939 L
.64319 .01955 L
.64347 .01967 L
.64378 .01977 L
.64392 .01981 L
.64406 .01984 L
.6442 .01987 L
.64432 .01988 L
.64444 .0199 L
.64457 .0199 L
.64469 .01991 L
.64483 .0199 L
.64498 .01989 L
.64512 .01988 L
.64528 .01985 L
.64543 .01982 L
.64569 .01974 L
.64598 .01963 L
.64657 .01933 L
.64712 .01895 L
.64837 .01779 L
.64961 .0164 L
Mistroke
.64991 .01607 L
.65023 .01577 L
.65041 .01563 L
.6505 .01558 L
.65058 .01554 L
.65066 .01551 L
.65075 .01549 L
.65091 .01548 L
.65105 .01551 L
.6512 .01558 L
.65134 .01567 L
.65147 .01578 L
.65209 .01647 L
.65334 .0182 L
.65443 .01966 L
.65558 .021 L
.65614 .02154 L
.65677 .02204 L
.65734 .02238 L
.65759 .0225 L
.65787 .02261 L
.65818 .0227 L
.65835 .02273 L
.6585 .02276 L
.65865 .02277 L
.65878 .02278 L
.65893 .02278 L
.65908 .02277 L
.65924 .02276 L
.65931 .02274 L
.6594 .02273 L
.6597 .02266 L
.65987 .0226 L
.66005 .02253 L
.66038 .02238 L
.66101 .02199 L
.6616 .02151 L
.66293 .02006 L
.66409 .01848 L
.66535 .01661 L
.66567 .01616 L
.66601 .01574 L
.66615 .0156 L
.6663 .01548 L
.66639 .01543 L
.66647 .0154 L
.66662 .01537 L
.66678 .0154 L
.66692 .01547 L
.66708 .01559 L
Mistroke
.66724 .01576 L
.66782 .01651 L
.67007 .01974 L
.6712 .02106 L
.67179 .02163 L
.67242 .02211 L
.67297 .02243 L
.67328 .02257 L
.67357 .02267 L
.67371 .02271 L
.67384 .02274 L
.67395 .02276 L
.67408 .02278 L
.67421 .0228 L
.67434 .0228 L
.67447 .02281 L
.67462 .0228 L
.67478 .02279 L
.67492 .02277 L
.67508 .02274 L
.67525 .0227 L
.67557 .0226 L
.67585 .02249 L
.67643 .02217 L
.67697 .02177 L
.67818 .0206 L
.67949 .01895 L
.68074 .01716 L
.68134 .01629 L
.68161 .01594 L
.6819 .01561 L
.68205 .01546 L
.6822 .01536 L
.68234 .0153 L
.68248 .01528 L
.68264 .01531 L
.68278 .01538 L
.68294 .0155 L
.68311 .01567 L
.68444 .01744 L
.68559 .019 L
.68682 .02041 L
.68752 .02107 L
.68816 .02155 L
.68847 .02174 L
.6888 .02191 L
.68912 .02204 L
.68941 .02213 L
.68969 .0222 L
.68984 .02222 L
Mistroke
.68999 .02224 L
.69014 .02225 L
.69023 .02225 L
.69031 .02225 L
.69046 .02225 L
.69062 .02224 L
.69077 .02222 L
.69093 .02219 L
.69123 .02211 L
.69158 .02199 L
.6919 .02185 L
.69243 .02154 L
.69302 .02112 L
.6942 .02 L
.69551 .01842 L
.69676 .01674 L
.6973 .01603 L
.69759 .01568 L
.69787 .01541 L
.69802 .01531 L
.69817 .01523 L
.69826 .01521 L
.69834 .0152 L
.6985 .01523 L
.69865 .01529 L
.69878 .01538 L
.69908 .01566 L
.70151 .0187 L
.7027 .01996 L
.70379 .02084 L
.70437 .02119 L
.70466 .02133 L
.70498 .02145 L
.70515 .0215 L
.7053 .02154 L
.70545 .02158 L
.70559 .0216 L
.70576 .02163 L
.70585 .02164 L
.70594 .02164 L
.7061 .02165 L
.70618 .02165 L
.70627 .02165 L
.7064 .02164 L
.70654 .02163 L
.70669 .02161 L
.70683 .02158 L
.70708 .02153 L
.70735 .02145 L
.70796 .02119 L
Mistroke
.70851 .02086 L
.70972 .0199 L
.71083 .01875 L
.71212 .01719 L
.71276 .01639 L
.71334 .01571 L
.71361 .01545 L
.71375 .01533 L
.7139 .01523 L
.71404 .01516 L
.71417 .01514 L
.71431 .01514 L
.71443 .01517 L
.71457 .01525 L
.71472 .01535 L
.71499 .01559 L
.7156 .01627 L
.7168 .01771 L
.71809 .0191 L
.71873 .01967 L
.71934 .02014 L
.71992 .02051 L
.72047 .02078 L
.72098 .02096 L
.72124 .02102 L
.72139 .02105 L
.72153 .02107 L
.72168 .02109 L
.72182 .0211 L
.72196 .02111 L
.72205 .02111 L
.72212 .02111 L
.72226 .0211 L
.72239 .02109 L
.72254 .02108 L
.72268 .02105 L
.72297 .02099 L
.72324 .02092 L
.72386 .02067 L
.72446 .02034 L
.7251 .01989 L
.72733 .01774 L
.72856 .01633 L
.7292 .01562 L
.72953 .01532 L
.72962 .01526 L
.72972 .0152 L
.72981 .01515 L
.72989 .01511 L
.73004 .01508 L
Mistroke
.73012 .01508 L
.73021 .01509 L
.7303 .01511 L
.73039 .01515 L
.73055 .01524 L
.73084 .01547 L
.73115 .01578 L
.73232 .01707 L
.73355 .01837 L
.73471 .01938 L
.73534 .01982 L
.73592 .02014 L
.73656 .02041 L
.73692 .02052 L
.73708 .02056 L
.73725 .02059 L
.73741 .02061 L
.73756 .02063 L
.73771 .02064 L
.73786 .02065 L
.738 .02065 L
.73812 .02064 L
.73826 .02063 L
.73841 .02062 L
.73857 .0206 L
.73874 .02056 L
.73906 .02049 L
.73936 .02039 L
.73964 .02028 L
.74072 .01969 L
.74186 .01881 L
.74302 .0177 L
.74424 .0164 L
.74475 .01586 L
.74528 .01535 L
.74544 .01523 L
.74559 .01514 L
.74573 .01507 L
.74587 .01504 L
.74601 .01503 L
.74616 .01506 L
.74628 .0151 L
.74642 .01518 L
.74673 .0154 L
.747 .01566 L
.74763 .01629 L
.74876 .01746 L
.75007 .01866 L
.75064 .01909 L
.75128 .0195 L
Mistroke
.75181 .01978 L
.75239 .02002 L
.75271 .02011 L
.75285 .02014 L
.753 .02018 L
.75313 .0202 L
.75328 .02022 L
.75343 .02024 L
.75357 .02025 L
.75366 .02025 L
.75374 .02025 L
.7539 .02025 L
.75398 .02025 L
.75406 .02025 L
.75415 .02024 L
.75425 .02023 L
.75442 .02021 L
.75458 .02019 L
.75488 .02012 L
.75518 .02004 L
.75545 .01994 L
.75608 .01966 L
.75669 .01931 L
.75735 .01885 L
.75855 .01783 L
.75971 .01668 L
.7608 .0156 L
.76108 .01535 L
.76135 .01515 L
.7615 .01507 L
.76158 .01504 L
.76166 .01501 L
.7618 .01499 L
.76194 .01499 L
.76209 .01503 L
.76218 .01506 L
.76225 .0151 L
.76254 .01529 L
.7632 .01588 L
.76452 .01717 L
.76574 .01825 L
.76685 .01903 L
.76747 .01937 L
.76803 .01961 L
.76833 .01971 L
.76864 .0198 L
.76881 .01983 L
.76899 .01987 L
.76916 .01989 L
.76931 .01991 L
Mistroke
.76947 .01992 L
.76962 .01992 L
.76975 .01992 L
.7699 .01992 L
.77005 .01991 L
.77014 .0199 L
.77022 .01989 L
.77038 .01987 L
.77052 .01985 L
.77081 .01979 L
.77111 .0197 L
.77174 .01947 L
.77228 .0192 L
.77285 .01886 L
.77536 .01677 L
.77659 .0156 L
.77693 .01531 L
.77712 .01518 L
.77729 .01507 L
.77744 .01501 L
.7776 .01496 L
.77769 .01495 L
.77777 .01495 L
.77785 .01496 L
.77793 .01498 L
.77801 .015 L
.7781 .01504 L
.77825 .01512 L
.77854 .01532 L
.77919 .01589 L
.78036 .01698 L
.7816 .01803 L
.78276 .01881 L
.78335 .01911 L
.78397 .01937 L
.78433 .01948 L
.78467 .01955 L
.78482 .01958 L
.78497 .0196 L
.78505 .01961 L
.78514 .01962 L
.7853 .01963 L
.78545 .01964 L
.78559 .01964 L
.78574 .01964 L
.78582 .01964 L
.7859 .01963 L
.78605 .01962 L
.78622 .0196 L
.78637 .01958 L
Mistroke
.78652 .01955 L
.78706 .01941 L
.78733 .01932 L
.78763 .0192 L
.78893 .0185 L
.79015 .0176 L
.7914 .0165 L
.79202 .01593 L
.79259 .01543 L
.79286 .01522 L
.79311 .01506 L
.79325 .015 L
.7934 .01494 L
.79354 .01492 L
.79366 .01492 L
.7938 .01494 L
.79393 .01499 L
.79408 .01505 L
.79423 .01514 L
.79483 .0156 L
.79722 .01766 L
.79788 .01814 L
.79857 .01857 L
.79917 .01887 L
.79949 .01901 L
.79982 .01913 L
.80012 .01922 L
.80044 .0193 L
.80058 .01932 L
.80073 .01935 L
.80087 .01937 L
.801 .01938 L
.80115 .01939 L
.8013 .0194 L
.80144 .01941 L
.80158 .0194 L
.80171 .0194 L
.80183 .01939 L
.80197 .01938 L
.80211 .01936 L
.80243 .01931 L
.80279 .01923 L
.80312 .01913 L
.80343 .01902 L
.80463 .01843 L
.80579 .01764 L
.80688 .01675 L
.80809 .0157 L
.80841 .01543 L
.80875 .01518 L
Mistroke
.80891 .01507 L
.80907 .01499 L
.80921 .01493 L
.80936 .0149 L
.8095 .01489 L
.80965 .01491 L
.80973 .01493 L
.80981 .01496 L
.80996 .01502 L
.81025 .0152 L
.81052 .0154 L
.81179 .01647 L
.81287 .01735 L
.81402 .01814 L
.81464 .01849 L
.81521 .01875 L
.81578 .01896 L
.81603 .01903 L
.81631 .0191 L
.81661 .01915 L
.81678 .01917 L
.81694 .01919 L
.81708 .0192 L
.81721 .0192 L
.81737 .0192 L
.81751 .0192 L
.81767 .01919 L
.81775 .01919 L
.81783 .01918 L
.81799 .01916 L
.81813 .01914 L
.81846 .01909 L
.81881 .019 L
.81941 .0188 L
.81996 .01855 L
.82123 .01782 L
.82254 .01684 L
.82377 .0158 L
.82435 .01534 L
.82466 .01512 L
.82481 .01503 L
.82496 .01496 L
.82511 .0149 L
.82519 .01488 L
.82527 .01487 L
.82536 .01487 L
.82544 .01487 L
.82553 .01488 L
.82562 .01491 L
.8257 .01493 L
Mistroke
.82579 .01497 L
.82595 .01505 L
.82624 .01524 L
.82848 .01704 L
.82973 .0179 L
.83089 .01851 L
.83148 .01874 L
.83178 .01883 L
.8321 .01891 L
.83229 .01895 L
.83246 .01897 L
.83262 .01899 L
.83271 .019 L
.8328 .01901 L
.83296 .01902 L
.83311 .01903 L
.83319 .01903 L
.83328 .01903 L
.83343 .01903 L
.83358 .01902 L
.83367 .01901 L
.83374 .01901 L
.83388 .01899 L
.83404 .01897 L
.8343 .01893 L
.83459 .01886 L
.83522 .01867 L
.83582 .01842 L
.83689 .01783 L
.83803 .01704 L
.83926 .01606 L
.83991 .01554 L
.84026 .01527 L
.84059 .01505 L
.84073 .01498 L
.84088 .01491 L
.84096 .01489 L
.84104 .01487 L
.84119 .01485 L
.84128 .01485 L
.84136 .01485 L
.84145 .01487 L
.84153 .01489 L
.84169 .01495 L
.84185 .01504 L
.84246 .01545 L
.84302 .0159 L
.8442 .01683 L
.84547 .01771 L
.84609 .01806 L
Mistroke
.84667 .01834 L
.84725 .01856 L
.84777 .01872 L
.84805 .01878 L
.84832 .01883 L
.84845 .01884 L
.8486 .01886 L
.84875 .01887 L
.8489 .01888 L
.84902 .01889 L
.84916 .01889 L
.84929 .01888 L
.8494 .01888 L
.84954 .01887 L
.84968 .01886 L
.84982 .01884 L
.84995 .01882 L
.85023 .01877 L
.8505 .01871 L
.85111 .01853 L
.8517 .01829 L
.85233 .01798 L
.8547 .01635 L
.85596 .01537 L
.85632 .01512 L
.8565 .01502 L
.85666 .01493 L
.85681 .01488 L
.85697 .01484 L
.85712 .01483 L
.85721 .01483 L
.8573 .01485 L
.85745 .01489 L
.85754 .01492 L
.85762 .01496 L
.85792 .01513 L
.85849 .01553 L
.85977 .01653 L
.86088 .01732 L
.86208 .01801 L
.86274 .01831 L
.86304 .01842 L
.86336 .01852 L
.86364 .0186 L
.86394 .01866 L
.86411 .01869 L
.86426 .01871 L
.86441 .01873 L
.86456 .01875 L
.8647 .01876 L
Mistroke
.86485 .01876 L
.86498 .01876 L
.86511 .01876 L
.86526 .01876 L
.8654 .01875 L
.86548 .01875 L
.86556 .01874 L
.86571 .01872 L
.86599 .01868 L
.86628 .01862 L
.86681 .01848 L
.86745 .01824 L
.86805 .01797 L
.86939 .01717 L
.87065 .01625 L
.87126 .01577 L
.87182 .01535 L
.87209 .01517 L
.87238 .01499 L
.87252 .01493 L
.87266 .01487 L
.87278 .01484 L
.87291 .01482 L
.87307 .01482 L
.87321 .01484 L
.87336 .01488 L
.87344 .01491 L
.87352 .01495 L
.87409 .0153 L
.87539 .01628 L
.87658 .01713 L
.87771 .0178 L
.87831 .01809 L
.87894 .01833 L
.87927 .01843 L
.87962 .01852 L
.87994 .01858 L
.88024 .01863 L
.8804 .01864 L
.88055 .01865 L
.88069 .01866 L
.88084 .01866 L
.88092 .01866 L
.881 .01866 L
.88108 .01866 L
.88117 .01866 L
.88131 .01865 L
.88147 .01863 L
.88162 .01862 L
.88176 .0186 L
Mistroke
.88207 .01854 L
.88262 .01841 L
.88327 .01818 L
.88388 .01791 L
.8851 .01721 L
.88642 .01628 L
.88701 .01583 L
.88765 .01536 L
.88795 .01516 L
.88826 .01498 L
.88838 .01491 L
.88852 .01486 L
.88867 .01482 L
.88881 .0148 L
.88897 .01481 L
.88905 .01482 L
.88913 .01484 L
.88928 .01489 L
.88944 .01496 L
.89002 .01531 L
.89134 .01629 L
.89249 .01709 L
.89371 .01779 L
.8943 .01806 L
.89486 .01827 L
.89537 .01841 L
.89565 .01847 L
.89592 .01852 L
.89606 .01854 L
.89621 .01855 L
.89634 .01856 L
.89648 .01857 L
.89663 .01858 L
.89671 .01858 L
.89679 .01858 L
.89694 .01858 L
.89708 .01857 L
.89721 .01857 L
.89735 .01855 L
.8976 .01852 L
.89787 .01848 L
.89817 .01842 L
.89878 .01824 L
.89945 .01798 L
.90065 .01736 L
.90303 .0157 L
.90368 .01524 L
.90404 .01501 L
.90421 .01492 L
.90429 .01489 L
Mistroke
.90437 .01486 L
.90453 .01481 L
.90461 .0148 L
.90469 .01479 L
.90477 .01479 L
.90485 .0148 L
.90494 .01481 L
.90503 .01483 L
.90518 .01488 L
.90531 .01494 L
.90562 .01511 L
.9079 .01674 L
.90911 .01749 L
.90974 .01781 L
.91041 .01809 L
.91102 .01829 L
.91137 .01837 L
.91169 .01843 L
.91184 .01846 L
.91198 .01848 L
.91211 .01849 L
.91225 .0185 L
.9124 .01851 L
.91254 .01851 L
.91269 .01852 L
.91278 .01851 L
.91286 .01851 L
.913 .01851 L
.91315 .01849 L
.9133 .01848 L
.91343 .01846 L
.91369 .01843 L
.91396 .01837 L
.91458 .0182 L
.91515 .018 L
.91636 .01741 L
.91748 .01671 L
.91878 .01578 L
.91941 .01532 L
.91969 .01514 L
.91999 .01496 L
.92013 .0149 L
.92028 .01484 L
.92041 .0148 L
.92055 .01478 L
.92069 .01478 L
.92083 .0148 L
.92096 .01484 L
.92109 .01489 L
.92138 .01503 L
Mistroke
.92169 .01522 L
.92226 .01562 L
.92357 .01657 L
.92476 .01732 L
.92534 .01763 L
.92598 .01792 L
.92653 .01813 L
.92713 .0183 L
.92746 .01837 L
.92777 .01841 L
.92794 .01843 L
.92809 .01845 L
.92818 .01845 L
.92827 .01846 L
.92836 .01846 L
.92845 .01846 L
.92859 .01847 L
.92872 .01846 L
.92887 .01846 L
.92896 .01845 L
.92903 .01845 L
.92934 .01841 L
.92949 .01839 L
.92966 .01836 L
.93029 .01821 L
.93089 .01801 L
.93202 .01749 L
.93323 .01676 L
.93455 .01584 L
.9351 .01544 L
.93569 .01505 L
.93586 .01496 L
.93602 .01488 L
.93617 .01483 L
.93626 .01481 L
.93633 .01479 L
.93649 .01478 L
.93663 .01478 L
.93671 .0148 L
.93679 .01482 L
.93694 .01487 L
.9371 .01494 L
.93725 .01502 L
.93758 .01522 L
.93826 .0157 L
.93948 .01656 L
.94074 .01735 L
.94136 .01767 L
.94194 .01792 L
.94245 .01811 L
Mistroke
.94301 .01826 L
.9433 .01832 L
.94357 .01837 L
.94371 .01839 L
.94386 .0184 L
.94394 .01841 L
.94403 .01842 L
.94417 .01843 L
.94425 .01843 L
.94433 .01843 L
.94448 .01843 L
.94464 .01843 L
.94473 .01842 L
.94481 .01842 L
.94496 .01841 L
.9451 .01839 L
.94541 .01835 L
.94569 .0183 L
.94599 .01823 L
.94654 .01806 L
.94718 .01782 L
.94785 .01749 L
.94907 .01677 L
.95031 .0159 L
.95097 .01543 L
.95133 .01519 L
.95166 .01499 L
.95181 .01492 L
.95195 .01486 L
.95203 .01483 L
.95212 .01481 L
.95226 .01478 L
.95234 .01477 L
.95243 .01477 L
.95252 .01478 L
.95261 .0148 L
.95276 .01484 L
.95293 .01491 L
.95324 .01508 L
.95354 .01527 L
.95409 .01566 L
.95534 .01654 L
.95651 .01727 L
.95756 .0178 L
.95815 .01803 L
.9587 .0182 L
.95897 .01826 L
.95925 .01832 L
.95941 .01834 L
.95956 .01836 L
Mistroke
.9597 .01838 L
.95985 .01839 L
.96001 .0184 L
.96015 .01841 L
.96031 .01841 L
.9604 .01841 L
.96048 .01841 L
.96063 .0184 L
.96076 .01839 L
.96091 .01838 L
.96107 .01836 L
.96137 .01832 L
.9617 .01825 L
.96228 .01809 L
.96297 .01784 L
.9636 .01754 L
.96611 .01596 L
.96721 .01518 L
.96751 .015 L
.96768 .01492 L
.96784 .01485 L
.96798 .01481 L
.96807 .01479 L
.96814 .01478 L
.96828 .01477 L
.96842 .01478 L
.96858 .01482 L
.96872 .01487 L
.96903 .01503 L
.96961 .01539 L
.97068 .01616 L
.97191 .01698 L
.97306 .01762 L
.97378 .01793 L
.97455 .01818 L
.97476 .01824 L
.97499 .01828 L
.9752 .01832 L
.97541 .01835 L
.9756 .01837 L
.97571 .01838 L
.97582 .01839 L
.97592 .0184 L
.97601 .0184 L
.9761 .0184 L
.97619 .0184 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.00459847 0.64881 0.188537 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.491929 0.0484262 0.0147151 0.0110062 [
[.00767 -0.0125 -9 -9 ]
[.00767 -0.0125 9 0 ]
[.2498 -0.0125 -6 -9 ]
[.2498 -0.0125 6 0 ]
[.49193 -0.0125 -3 -9 ]
[.49193 -0.0125 3 0 ]
[.73406 -0.0125 -3 -9 ]
[.73406 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .12478 -12 -4.5 ]
[-0.0125 .12478 0 4.5 ]
[-0.0125 .23484 -12 -4.5 ]
[-0.0125 .23484 0 4.5 ]
[-0.0125 .3449 -12 -4.5 ]
[-0.0125 .3449 0 4.5 ]
[-0.0125 .45496 -12 -4.5 ]
[-0.0125 .45496 0 4.5 ]
[-0.0125 .56503 -12 -4.5 ]
[-0.0125 .56503 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.00767 0 m
.00767 .00625 L
s
[(-10)] .00767 -0.0125 0 1 Mshowa
.2498 0 m
.2498 .00625 L
s
[(-5)] .2498 -0.0125 0 1 Mshowa
.49193 0 m
.49193 .00625 L
s
[(0)] .49193 -0.0125 0 1 Mshowa
.73406 0 m
.73406 .00625 L
s
[(5)] .73406 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05609 0 m
.05609 .00375 L
s
.10452 0 m
.10452 .00375 L
s
.15295 0 m
.15295 .00375 L
s
.20137 0 m
.20137 .00375 L
s
.29822 0 m
.29822 .00375 L
s
.34665 0 m
.34665 .00375 L
s
.39508 0 m
.39508 .00375 L
s
.4435 0 m
.4435 .00375 L
s
.54036 0 m
.54036 .00375 L
s
.58878 0 m
.58878 .00375 L
s
.63721 0 m
.63721 .00375 L
s
.68563 0 m
.68563 .00375 L
s
.78249 0 m
.78249 .00375 L
s
.83091 0 m
.83091 .00375 L
s
.87934 0 m
.87934 .00375 L
s
.92776 0 m
.92776 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .12478 m
.00625 .12478 L
s
[(10)] -0.0125 .12478 1 0 Mshowa
0 .23484 m
.00625 .23484 L
s
[(20)] -0.0125 .23484 1 0 Mshowa
0 .3449 m
.00625 .3449 L
s
[(30)] -0.0125 .3449 1 0 Mshowa
0 .45496 m
.00625 .45496 L
s
[(40)] -0.0125 .45496 1 0 Mshowa
0 .56503 m
.00625 .56503 L
s
[(50)] -0.0125 .56503 1 0 Mshowa
.125 Mabswid
0 .03673 m
.00375 .03673 L
s
0 .05874 m
.00375 .05874 L
s
0 .08075 m
.00375 .08075 L
s
0 .10276 m
.00375 .10276 L
s
0 .14679 m
.00375 .14679 L
s
0 .1688 m
.00375 .1688 L
s
0 .19081 m
.00375 .19081 L
s
0 .21283 m
.00375 .21283 L
s
0 .25685 m
.00375 .25685 L
s
0 .27886 m
.00375 .27886 L
s
0 .30088 m
.00375 .30088 L
s
0 .32289 m
.00375 .32289 L
s
0 .36691 m
.00375 .36691 L
s
0 .38893 m
.00375 .38893 L
s
0 .41094 m
.00375 .41094 L
s
0 .43295 m
.00375 .43295 L
s
0 .47698 m
.00375 .47698 L
s
0 .49899 m
.00375 .49899 L
s
0 .521 m
.00375 .521 L
s
0 .54301 m
.00375 .54301 L
s
0 .58704 m
.00375 .58704 L
s
0 .60905 m
.00375 .60905 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.00767 .61178 m
.00767 .61803 L
s
.2498 .61178 m
.2498 .61803 L
s
.49193 .61178 m
.49193 .61803 L
s
.73406 .61178 m
.73406 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.05609 .61428 m
.05609 .61803 L
s
.10452 .61428 m
.10452 .61803 L
s
.15295 .61428 m
.15295 .61803 L
s
.20137 .61428 m
.20137 .61803 L
s
.29822 .61428 m
.29822 .61803 L
s
.34665 .61428 m
.34665 .61803 L
s
.39508 .61428 m
.39508 .61803 L
s
.4435 .61428 m
.4435 .61803 L
s
.54036 .61428 m
.54036 .61803 L
s
.58878 .61428 m
.58878 .61803 L
s
.63721 .61428 m
.63721 .61803 L
s
.68563 .61428 m
.68563 .61803 L
s
.78249 .61428 m
.78249 .61803 L
s
.83091 .61428 m
.83091 .61803 L
s
.87934 .61428 m
.87934 .61803 L
s
.92776 .61428 m
.92776 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .12478 m
1 .12478 L
s
.99375 .23484 m
1 .23484 L
s
.99375 .3449 m
1 .3449 L
s
.99375 .45496 m
1 .45496 L
s
.99375 .56503 m
1 .56503 L
s
.125 Mabswid
.99625 .03673 m
1 .03673 L
s
.99625 .05874 m
1 .05874 L
s
.99625 .08075 m
1 .08075 L
s
.99625 .10276 m
1 .10276 L
s
.99625 .14679 m
1 .14679 L
s
.99625 .1688 m
1 .1688 L
s
.99625 .19081 m
1 .19081 L
s
.99625 .21283 m
1 .21283 L
s
.99625 .25685 m
1 .25685 L
s
.99625 .27886 m
1 .27886 L
s
.99625 .30088 m
1 .30088 L
s
.99625 .32289 m
1 .32289 L
s
.99625 .36691 m
1 .36691 L
s
.99625 .38893 m
1 .38893 L
s
.99625 .41094 m
1 .41094 L
s
.99625 .43295 m
1 .43295 L
s
.99625 .47698 m
1 .47698 L
s
.99625 .49899 m
1 .49899 L
s
.99625 .521 m
1 .521 L
s
.99625 .54301 m
1 .54301 L
s
.99625 .58704 m
1 .58704 L
s
.99625 .60905 m
1 .60905 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .01472 m
.02381 .02001 L
s
.03995 .01472 m
.03995 .02003 L
s
.05609 .01472 m
.05609 .02007 L
s
.07224 .01472 m
.07224 .02013 L
s
.08838 .01472 m
.08838 .02021 L
s
.10452 .01472 m
.10452 .02031 L
s
.12066 .01472 m
.12066 .02044 L
s
.1368 .01472 m
.1368 .02058 L
s
.15295 .01472 m
.15295 .02076 L
s
.16909 .01472 m
.16909 .02097 L
s
.18523 .01472 m
.18523 .02121 L
s
.20137 .01472 m
.20137 .0215 L
s
.21751 .01472 m
.21751 .02184 L
s
.23366 .01472 m
.23366 .02224 L
s
.2498 .01472 m
.2498 .02271 L
s
.26594 .01472 m
.26594 .02327 L
s
.28208 .01472 m
.28208 .02393 L
s
.29822 .01472 m
.29822 .02466 L
s
.31437 .01472 m
.31437 .02533 L
s
.33051 .01472 m
.33051 .0253 L
s
.34665 .01472 m
.34665 .02118 L
s
.36279 .01472 m
.36279 .0901 L
s
.37893 .01472 m
.37893 .60332 L
s
.39508 .01472 m
.39508 .59466 L
s
.41122 .01472 m
.41122 .05953 L
s
.42736 .01472 m
.42736 .31219 L
s
.4435 .01472 m
.4435 .30568 L
s
.45964 .01472 m
.45964 .05608 L
s
.47579 .01472 m
.47579 .16134 L
s
.49193 .01472 m
.49193 .3766 L
s
.50807 .01472 m
.50807 .16134 L
s
.52421 .01472 m
.52421 .05608 L
s
.54036 .01472 m
.54036 .30568 L
s
.5565 .01472 m
.5565 .31219 L
s
.57264 .01472 m
.57264 .05953 L
s
.58878 .01472 m
.58878 .59466 L
s
.60492 .01472 m
.60492 .60332 L
s
.62107 .01472 m
.62107 .0901 L
s
.63721 .01472 m
.63721 .02118 L
s
.65335 .01472 m
.65335 .0253 L
s
.66949 .01472 m
.66949 .02533 L
s
.68563 .01472 m
.68563 .02466 L
s
.70178 .01472 m
.70178 .02393 L
s
.71792 .01472 m
.71792 .02327 L
s
.73406 .01472 m
.73406 .02271 L
s
.7502 .01472 m
.7502 .02224 L
s
.76634 .01472 m
.76634 .02184 L
s
.78249 .01472 m
.78249 .0215 L
s
.79863 .01472 m
.79863 .02121 L
s
.81477 .01472 m
.81477 .02097 L
s
.83091 .01472 m
.83091 .02076 L
s
.84705 .01472 m
.84705 .02058 L
s
.8632 .01472 m
.8632 .02044 L
s
.87934 .01472 m
.87934 .02031 L
s
.89548 .01472 m
.89548 .02021 L
s
.91162 .01472 m
.91162 .02013 L
s
.92776 .01472 m
.92776 .02007 L
s
.94391 .01472 m
.94391 .02003 L
s
.96005 .01472 m
.96005 .02001 L
s
.97619 .01472 m
.97619 .02 L
s
.015 w
.02381 .02001 Mdot
.03995 .02003 Mdot
.05609 .02007 Mdot
.07224 .02013 Mdot
.08838 .02021 Mdot
.10452 .02031 Mdot
.12066 .02044 Mdot
.1368 .02058 Mdot
.15295 .02076 Mdot
.16909 .02097 Mdot
.18523 .02121 Mdot
.20137 .0215 Mdot
.21751 .02184 Mdot
.23366 .02224 Mdot
.2498 .02271 Mdot
.26594 .02327 Mdot
.28208 .02393 Mdot
.29822 .02466 Mdot
.31437 .02533 Mdot
.33051 .0253 Mdot
.34665 .02118 Mdot
.36279 .0901 Mdot
.37893 .60332 Mdot
.39508 .59466 Mdot
.41122 .05953 Mdot
.42736 .31219 Mdot
.4435 .30568 Mdot
.45964 .05608 Mdot
.47579 .16134 Mdot
.49193 .3766 Mdot
.50807 .16134 Mdot
.52421 .05608 Mdot
.54036 .30568 Mdot
.5565 .31219 Mdot
.57264 .05953 Mdot
.58878 .59466 Mdot
.60492 .60332 Mdot
.62107 .0901 Mdot
.63721 .02118 Mdot
.65335 .0253 Mdot
.66949 .02533 Mdot
.68563 .02466 Mdot
.70178 .02393 Mdot
.71792 .02327 Mdot
.73406 .02271 Mdot
.7502 .02224 Mdot
.76634 .02184 Mdot
.78249 .0215 Mdot
.79863 .02121 Mdot
.81477 .02097 Mdot
.83091 .02076 Mdot
.84705 .02058 Mdot
.8632 .02044 Mdot
.87934 .02031 Mdot
.89548 .02021 Mdot
.91162 .02013 Mdot
.92776 .02007 Mdot
.94391 .02003 Mdot
.96005 .02001 Mdot
.97619 .02 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.00459847 0.97619 0.188537 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.047619 0.0147151 0.00907075 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .10542 -12 -4.5 ]
[-0.0125 .10542 0 4.5 ]
[-0.0125 .19613 -12 -4.5 ]
[-0.0125 .19613 0 4.5 ]
[-0.0125 .28684 -12 -4.5 ]
[-0.0125 .28684 0 4.5 ]
[-0.0125 .37754 -12 -4.5 ]
[-0.0125 .37754 0 4.5 ]
[-0.0125 .46825 -12 -4.5 ]
[-0.0125 .46825 0 4.5 ]
[-0.0125 .55896 -12 -4.5 ]
[-0.0125 .55896 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .10542 m
.00625 .10542 L
s
[(10)] -0.0125 .10542 1 0 Mshowa
0 .19613 m
.00625 .19613 L
s
[(20)] -0.0125 .19613 1 0 Mshowa
0 .28684 m
.00625 .28684 L
s
[(30)] -0.0125 .28684 1 0 Mshowa
0 .37754 m
.00625 .37754 L
s
[(40)] -0.0125 .37754 1 0 Mshowa
0 .46825 m
.00625 .46825 L
s
[(50)] -0.0125 .46825 1 0 Mshowa
0 .55896 m
.00625 .55896 L
s
[(60)] -0.0125 .55896 1 0 Mshowa
.125 Mabswid
0 .03286 m
.00375 .03286 L
s
0 .051 m
.00375 .051 L
s
0 .06914 m
.00375 .06914 L
s
0 .08728 m
.00375 .08728 L
s
0 .12356 m
.00375 .12356 L
s
0 .14171 m
.00375 .14171 L
s
0 .15985 m
.00375 .15985 L
s
0 .17799 m
.00375 .17799 L
s
0 .21427 m
.00375 .21427 L
s
0 .23241 m
.00375 .23241 L
s
0 .25055 m
.00375 .25055 L
s
0 .2687 m
.00375 .2687 L
s
0 .30498 m
.00375 .30498 L
s
0 .32312 m
.00375 .32312 L
s
0 .34126 m
.00375 .34126 L
s
0 .3594 m
.00375 .3594 L
s
0 .39569 m
.00375 .39569 L
s
0 .41383 m
.00375 .41383 L
s
0 .43197 m
.00375 .43197 L
s
0 .45011 m
.00375 .45011 L
s
0 .48639 m
.00375 .48639 L
s
0 .50454 m
.00375 .50454 L
s
0 .52268 m
.00375 .52268 L
s
0 .54082 m
.00375 .54082 L
s
0 .5771 m
.00375 .5771 L
s
0 .59524 m
.00375 .59524 L
s
0 .61338 m
.00375 .61338 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .10542 m
1 .10542 L
s
.99375 .19613 m
1 .19613 L
s
.99375 .28684 m
1 .28684 L
s
.99375 .37754 m
1 .37754 L
s
.99375 .46825 m
1 .46825 L
s
.99375 .55896 m
1 .55896 L
s
.125 Mabswid
.99625 .03286 m
1 .03286 L
s
.99625 .051 m
1 .051 L
s
.99625 .06914 m
1 .06914 L
s
.99625 .08728 m
1 .08728 L
s
.99625 .12356 m
1 .12356 L
s
.99625 .14171 m
1 .14171 L
s
.99625 .15985 m
1 .15985 L
s
.99625 .17799 m
1 .17799 L
s
.99625 .21427 m
1 .21427 L
s
.99625 .23241 m
1 .23241 L
s
.99625 .25055 m
1 .25055 L
s
.99625 .2687 m
1 .2687 L
s
.99625 .30498 m
1 .30498 L
s
.99625 .32312 m
1 .32312 L
s
.99625 .34126 m
1 .34126 L
s
.99625 .3594 m
1 .3594 L
s
.99625 .39569 m
1 .39569 L
s
.99625 .41383 m
1 .41383 L
s
.99625 .43197 m
1 .43197 L
s
.99625 .45011 m
1 .45011 L
s
.99625 .48639 m
1 .48639 L
s
.99625 .50454 m
1 .50454 L
s
.99625 .52268 m
1 .52268 L
s
.99625 .54082 m
1 .54082 L
s
.99625 .5771 m
1 .5771 L
s
.99625 .59524 m
1 .59524 L
s
.99625 .61338 m
1 .61338 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
0 0 1 r
.5 Mabswid
[ .01 ] 0 setdash
.02381 .01907 m
.02395 .01907 L
.02408 .01906 L
.02423 .01905 L
.02437 .01904 L
.02462 .01901 L
.02489 .01897 L
.02519 .01891 L
.02551 .01883 L
.02608 .01865 L
.02722 .01815 L
.02847 .01741 L
.02973 .01653 L
.03043 .01604 L
.03077 .01581 L
.03109 .01563 L
.03125 .01556 L
.03139 .0155 L
.03147 .01548 L
.03156 .01546 L
.03171 .01544 L
.03179 .01544 L
.03188 .01545 L
.03197 .01546 L
.03206 .01549 L
.03221 .01554 L
.03238 .01562 L
.03299 .01599 L
.03355 .01638 L
.03476 .01723 L
.03605 .01803 L
.03714 .01855 L
.03777 .01877 L
.03805 .01885 L
.03836 .01893 L
.03863 .01898 L
.03892 .01903 L
.03908 .01905 L
.03923 .01906 L
.03938 .01907 L
.03952 .01907 L
.03965 .01908 L
.03978 .01908 L
.0399 .01907 L
.04003 .01907 L
.04017 .01906 L
.04031 .01904 L
.04058 .01901 L
.04089 .01896 L
.04122 .01888 L
Mistroke
.04183 .0187 L
.04243 .01847 L
.04298 .01821 L
.04525 .0168 L
.04644 .01595 L
.04673 .01576 L
.04705 .01559 L
.04722 .01552 L
.04731 .01549 L
.04739 .01547 L
.04746 .01546 L
.04755 .01545 L
.0477 .01545 L
.04778 .01546 L
.04786 .01547 L
.04802 .01552 L
.04819 .01559 L
.04836 .01567 L
.04905 .01612 L
.05029 .017 L
.05155 .01783 L
.05217 .01817 L
.05273 .01844 L
.05326 .01866 L
.05383 .01885 L
.05415 .01893 L
.05444 .01899 L
.05472 .01904 L
.05487 .01906 L
.05501 .01907 L
.05517 .01908 L
.05531 .01909 L
.05546 .0191 L
.05555 .0191 L
.05563 .0191 L
.05576 .01909 L
.05591 .01909 L
.05606 .01908 L
.0562 .01906 L
.05653 .01902 L
.05683 .01897 L
.05716 .01889 L
.05751 .01879 L
.05866 .01833 L
.05989 .01765 L
.0621 .01611 L
.0627 .01572 L
.063 .01556 L
.06309 .01553 L
.06318 .0155 L
Mistroke
.06326 .01548 L
.06334 .01546 L
.06342 .01545 L
.06351 .01545 L
.0636 .01545 L
.06369 .01546 L
.06378 .01549 L
.06387 .01551 L
.06403 .01558 L
.06434 .01574 L
.06467 .01595 L
.06583 .01678 L
.0671 .01765 L
.06827 .01831 L
.0689 .0186 L
.06951 .01882 L
.06984 .01891 L
.0702 .019 L
.07052 .01906 L
.07068 .01908 L
.07082 .0191 L
.07096 .01911 L
.07111 .01912 L
.07119 .01913 L
.07127 .01913 L
.07142 .01913 L
.07158 .01913 L
.07172 .01913 L
.0718 .01912 L
.07188 .01912 L
.07205 .0191 L
.0722 .01909 L
.07233 .01907 L
.07264 .01902 L
.07294 .01895 L
.07326 .01886 L
.07437 .01844 L
.07504 .0181 L
.07568 .01773 L
.07688 .01692 L
.07804 .01608 L
.07837 .01585 L
.07868 .01567 L
.07882 .0156 L
.07897 .01553 L
.07912 .01548 L
.07927 .01546 L
.07941 .01545 L
.07954 .01547 L
.07968 .0155 L
Mistroke
.07982 .01555 L
.08006 .01566 L
.08033 .01582 L
.08149 .01664 L
.08262 .01744 L
.08383 .01818 L
.08453 .01853 L
.08517 .01879 L
.08547 .01889 L
.08581 .01898 L
.0861 .01905 L
.08642 .01911 L
.08658 .01913 L
.08674 .01915 L
.08689 .01916 L
.08704 .01917 L
.08718 .01918 L
.08731 .01918 L
.08745 .01918 L
.08761 .01918 L
.08769 .01917 L
.08777 .01917 L
.08795 .01915 L
.08811 .01913 L
.08827 .01911 L
.08856 .01906 L
.08888 .01898 L
.08944 .01881 L
.09006 .01857 L
.09116 .018 L
.09353 .01637 L
.09418 .01591 L
.09454 .01569 L
.09471 .0156 L
.09487 .01553 L
.09503 .01549 L
.0951 .01547 L
.09519 .01546 L
.09527 .01546 L
.09536 .01547 L
.09545 .01548 L
.09553 .0155 L
.09567 .01555 L
.09583 .01562 L
.09612 .01578 L
.09863 .01757 L
.09972 .01824 L
.1009 .01879 L
.10154 .01901 L
.10182 .01908 L
Mistroke
.10212 .01914 L
.10241 .01919 L
.10255 .01921 L
.10268 .01922 L
.10283 .01923 L
.10297 .01924 L
.10312 .01925 L
.10328 .01925 L
.10343 .01924 L
.10358 .01924 L
.10366 .01923 L
.10374 .01922 L
.10391 .01921 L
.10424 .01916 L
.10459 .01909 L
.10517 .01892 L
.10581 .01868 L
.10705 .01805 L
.10817 .01731 L
.10949 .01634 L
.11007 .01592 L
.11037 .01573 L
.11054 .01564 L
.1107 .01556 L
.11085 .01551 L
.11101 .01548 L
.11115 .01547 L
.11128 .01548 L
.11141 .01551 L
.11155 .01556 L
.11169 .01562 L
.11183 .01569 L
.11302 .01653 L
.11424 .01743 L
.11553 .01826 L
.11669 .01883 L
.11735 .01906 L
.11766 .01915 L
.11796 .01922 L
.11823 .01926 L
.11837 .01928 L
.11852 .0193 L
.11865 .01931 L
.11879 .01932 L
.11892 .01933 L
.11904 .01933 L
.11919 .01933 L
.11933 .01933 L
.11945 .01932 L
.11959 .01931 L
Mistroke
.11974 .01929 L
.1199 .01927 L
.12019 .01923 L
.1205 .01916 L
.12084 .01907 L
.12143 .01886 L
.12207 .01858 L
.12277 .0182 L
.12405 .01736 L
.12521 .01649 L
.12578 .01606 L
.12609 .01585 L
.12641 .01565 L
.12655 .01559 L
.1267 .01553 L
.12678 .01551 L
.12686 .0155 L
.12701 .01548 L
.12714 .01549 L
.12728 .01552 L
.12742 .01557 L
.12756 .01563 L
.1282 .01603 L
.12878 .01647 L
.13008 .01746 L
.13121 .01822 L
.1324 .01884 L
.13302 .01909 L
.13335 .01919 L
.1337 .01928 L
.13403 .01935 L
.13432 .01939 L
.13447 .01941 L
.13462 .01942 L
.13477 .01943 L
.1349 .01943 L
.13506 .01943 L
.13514 .01943 L
.13522 .01943 L
.13538 .01942 L
.13552 .01941 L
.13569 .01939 L
.13584 .01937 L
.13618 .0193 L
.13648 .01923 L
.1368 .01914 L
.13739 .01892 L
.13855 .01834 L
.13963 .01764 L
.14072 .01682 L
Mistroke
.14189 .01593 L
.14223 .01571 L
.1424 .01562 L
.14256 .01556 L
.1427 .01552 L
.14285 .0155 L
.14294 .0155 L
.14302 .01551 L
.14317 .01554 L
.14332 .01559 L
.14347 .01567 L
.14375 .01583 L
.14437 .01629 L
.1456 .01726 L
.14677 .0181 L
.1479 .01877 L
.1484 .019 L
.14895 .01922 L
.1495 .01938 L
.1498 .01945 L
.15008 .01949 L
.15023 .01951 L
.15038 .01953 L
.15052 .01954 L
.15067 .01955 L
.15082 .01955 L
.15091 .01955 L
.15099 .01955 L
.15115 .01955 L
.1513 .01954 L
.15145 .01952 L
.15161 .0195 L
.15193 .01945 L
.15223 .01938 L
.15251 .01931 L
.15314 .01908 L
.15382 .01877 L
.1562 .01719 L
.15746 .01619 L
.15782 .01592 L
.158 .0158 L
.15816 .0157 L
.15831 .01563 L
.15847 .01556 L
.15855 .01554 L
.15863 .01553 L
.15871 .01552 L
.1588 .01552 L
.15888 .01552 L
.15896 .01554 L
Mistroke
.15912 .01558 L
.1592 .01562 L
.15928 .01566 L
.15947 .01576 L
.1601 .01621 L
.16128 .01717 L
.16239 .01802 L
.16359 .01878 L
.16416 .01908 L
.16478 .01933 L
.16512 .01945 L
.16542 .01953 L
.16573 .0196 L
.16587 .01962 L
.16603 .01965 L
.16616 .01966 L
.1663 .01968 L
.16645 .01969 L
.16658 .01969 L
.16672 .0197 L
.16685 .0197 L
.16697 .01969 L
.1671 .01969 L
.16725 .01967 L
.16739 .01966 L
.1677 .01961 L
.16799 .01955 L
.16826 .01948 L
.16882 .0193 L
.16944 .01903 L
.17069 .0183 L
.17292 .01657 L
.17355 .01606 L
.17387 .01584 L
.174 .01575 L
.17415 .01567 L
.17429 .01561 L
.17442 .01557 L
.17455 .01554 L
.17469 .01554 L
.17485 .01556 L
.175 .01561 L
.17513 .01567 L
.17528 .01575 L
.17659 .01677 L
.1778 .01777 L
.17908 .01868 L
.1797 .01905 L
.18028 .01933 L
.18079 .01954 L
Mistroke
.18136 .01971 L
.18165 .01977 L
.18192 .01982 L
.18207 .01984 L
.18221 .01985 L
.18237 .01986 L
.18252 .01987 L
.18266 .01987 L
.18281 .01987 L
.18295 .01986 L
.18307 .01985 L
.18322 .01984 L
.18337 .01982 L
.18369 .01976 L
.184 .01969 L
.18433 .01959 L
.18492 .01937 L
.18609 .01875 L
.18714 .01801 L
.18827 .01709 L
.18946 .01608 L
.18976 .01586 L
.18992 .01576 L
.19008 .01567 L
.19017 .01563 L
.19026 .0156 L
.19035 .01558 L
.19043 .01556 L
.19052 .01556 L
.19059 .01556 L
.19068 .01558 L
.19076 .0156 L
.19091 .01565 L
.19106 .01573 L
.19134 .01591 L
.19197 .01641 L
.1932 .01748 L
.19437 .01842 L
.1955 .01917 L
.196 .01944 L
.19655 .01968 L
.1971 .01986 L
.1974 .01994 L
.19768 .02 L
.19783 .02002 L
.19799 .02004 L
.19812 .02005 L
.19827 .02006 L
.19835 .02007 L
.19843 .02007 L
Mistroke
.19852 .02007 L
.1986 .02007 L
.19875 .02007 L
.19891 .02006 L
.19906 .02004 L
.19921 .02002 L
.19955 .01996 L
.19987 .01989 L
.20022 .01978 L
.20085 .01953 L
.20143 .01923 L
.20262 .01845 L
.20373 .01755 L
.20502 .0164 L
.20533 .01614 L
.20565 .01589 L
.20593 .01572 L
.20609 .01565 L
.20623 .0156 L
.20637 .01559 L
.20651 .0156 L
.20663 .01562 L
.20675 .01567 L
.2069 .01574 L
.20705 .01583 L
.20731 .01603 L
.20848 .01706 L
.20968 .01812 L
.21096 .0191 L
.2116 .01949 L
.21219 .01979 L
.21273 .02001 L
.21304 .02011 L
.21332 .02018 L
.21361 .02024 L
.21374 .02026 L
.21388 .02028 L
.21402 .02029 L
.21416 .0203 L
.21431 .02031 L
.21439 .02031 L
.21447 .02031 L
.2146 .0203 L
.21473 .0203 L
.21485 .02029 L
.21498 .02027 L
.21526 .02023 L
.21553 .02018 L
.21609 .02001 L
.21669 .01976 L
Mistroke
.21778 .01914 L
.21908 .01815 L
.22027 .01707 L
.22084 .01653 L
.22115 .01625 L
.22145 .016 L
.22173 .01581 L
.22188 .01572 L
.22203 .01566 L
.22215 .01563 L
.22228 .01562 L
.22242 .01563 L
.22255 .01567 L
.2227 .01574 L
.22287 .01584 L
.22318 .01607 L
.22375 .01659 L
.22505 .01782 L
.22627 .01889 L
.22743 .01969 L
.22806 .02004 L
.2284 .02019 L
.22875 .02032 L
.22905 .02042 L
.22938 .02049 L
.22952 .02052 L
.22968 .02055 L
.22982 .02056 L
.22996 .02058 L
.2301 .02058 L
.23023 .02059 L
.23038 .02059 L
.23054 .02058 L
.23062 .02058 L
.2307 .02057 L
.23086 .02055 L
.23101 .02053 L
.23116 .02051 L
.23144 .02044 L
.23169 .02037 L
.23226 .02016 L
.23288 .01985 L
.23355 .01944 L
.23477 .01849 L
.23601 .01732 L
.23717 .01619 L
.23747 .01595 L
.23762 .01584 L
.23776 .01576 L
.23791 .0157 L
Mistroke
.238 .01567 L
.23809 .01566 L
.23823 .01566 L
.23838 .0157 L
.23847 .01573 L
.23856 .01577 L
.23871 .01587 L
.23907 .01615 L
.23971 .01677 L
.24095 .01802 L
.24212 .01909 L
.24326 .01994 L
.24376 .02024 L
.24431 .02051 L
.24486 .02071 L
.24516 .0208 L
.24544 .02085 L
.2456 .02088 L
.24575 .0209 L
.24589 .02091 L
.24603 .02092 L
.24612 .02092 L
.24619 .02092 L
.24628 .02092 L
.24636 .02092 L
.24651 .02091 L
.24667 .02089 L
.24683 .02087 L
.24698 .02085 L
.24731 .02077 L
.24764 .02067 L
.24799 .02054 L
.24862 .02023 L
.2492 .01987 L
.2517 .01767 L
.2528 .01652 L
.2531 .01623 L
.25342 .01596 L
.25357 .01585 L
.25373 .01577 L
.25386 .01572 L
.25401 .0157 L
.25416 .01571 L
.2543 .01576 L
.25443 .01582 L
.25457 .01591 L
.25517 .01644 L
.25625 .0176 L
.25748 .01888 L
.25863 .01989 L
Mistroke
.25978 .02066 L
.26038 .02096 L
.26072 .02108 L
.26103 .02118 L
.26119 .02121 L
.26136 .02125 L
.2615 .02127 L
.26166 .02129 L
.26174 .0213 L
.26182 .0213 L
.26198 .02131 L
.26206 .02131 L
.26215 .02131 L
.26225 .02131 L
.26234 .0213 L
.26241 .0213 L
.2625 .02129 L
.26265 .02127 L
.2628 .02125 L
.26293 .02122 L
.26324 .02114 L
.26357 .02103 L
.26417 .02076 L
.26471 .02045 L
.26593 .01952 L
.26814 .01723 L
.26871 .01659 L
.26903 .01627 L
.26932 .016 L
.26946 .01591 L
.2696 .01582 L
.26976 .01577 L
.2699 .01575 L
.27003 .01576 L
.27015 .0158 L
.27028 .01587 L
.27043 .01596 L
.27075 .01624 L
.2711 .01661 L
.27173 .01733 L
.27293 .01869 L
.27416 .01994 L
.27531 .02085 L
.27589 .02121 L
.27652 .02149 L
.27685 .02161 L
.27704 .02166 L
.27721 .0217 L
.27737 .02173 L
.27751 .02175 L
Mistroke
.27759 .02175 L
.27767 .02176 L
.27776 .02177 L
.27784 .02177 L
.27799 .02177 L
.27813 .02177 L
.27829 .02176 L
.27843 .02174 L
.27857 .02172 L
.2787 .0217 L
.27899 .02163 L
.27931 .02153 L
.27959 .02141 L
.28024 .02108 L
.28087 .02065 L
.28155 .0201 L
.28278 .01885 L
.28403 .01739 L
.28464 .01666 L
.2849 .01637 L
.28519 .01609 L
.28535 .01597 L
.28549 .01588 L
.28563 .01583 L
.28577 .0158 L
.28593 .01582 L
.28607 .01588 L
.28623 .01598 L
.2864 .01612 L
.28773 .01767 L
.29011 .0204 L
.29076 .02098 L
.29145 .0215 L
.29211 .02188 L
.29239 .02201 L
.2927 .02212 L
.293 .02221 L
.29316 .02225 L
.29332 .02227 L
.29346 .02229 L
.29359 .0223 L
.29374 .02231 L
.29388 .02231 L
.29404 .02231 L
.29411 .0223 L
.2942 .02229 L
.29435 .02228 L
.2945 .02225 L
.29482 .02218 L
.29516 .02206 L
Mistroke
.29575 .02179 L
.29637 .0214 L
.29749 .02045 L
.29872 .01909 L
.29989 .0176 L
.3004 .01694 L
.30094 .01631 L
.30122 .01605 L
.3013 .01599 L
.30138 .01594 L
.30153 .01589 L
.30168 .01587 L
.30182 .0159 L
.30194 .01595 L
.30208 .01604 L
.30239 .01633 L
.30267 .01666 L
.3033 .01749 L
.30444 .01902 L
.30576 .02061 L
.30633 .0212 L
.30697 .02177 L
.30751 .02217 L
.3081 .02251 L
.30842 .02265 L
.30871 .02276 L
.30885 .0228 L
.30901 .02284 L
.30914 .02286 L
.30929 .02289 L
.30944 .0229 L
.30959 .02291 L
.30967 .02291 L
.30976 .02291 L
.30992 .02291 L
.31 .0229 L
.31009 .02289 L
.31024 .02287 L
.31043 .02283 L
.31059 .02279 L
.31089 .0227 L
.31121 .02256 L
.3118 .02224 L
.31239 .02181 L
.31294 .02132 L
.3142 .01993 L
.3155 .01819 L
.31614 .01729 L
.31646 .01686 L
.31674 .01651 L
Mistroke
.31701 .01621 L
.31717 .01609 L
.31731 .016 L
.31746 .01595 L
.31753 .01595 L
.31762 .01596 L
.31777 .01601 L
.31791 .01611 L
.31808 .01625 L
.31823 .01642 L
.31853 .01679 L
.31919 .01772 L
.32142 .0208 L
.32259 .02206 L
.32318 .02255 L
.32383 .02298 L
.32438 .02325 L
.3247 .02335 L
.32484 .02339 L
.32498 .02342 L
.32511 .02344 L
.32524 .02345 L
.32539 .02347 L
.32553 .02347 L
.32566 .02347 L
.3258 .02346 L
.32593 .02344 L
.32606 .02342 L
.32621 .02339 L
.32635 .02336 L
.32662 .02327 L
.32691 .02315 L
.32723 .02299 L
.3278 .02262 L
.32832 .02218 L
.32953 .0209 L
.33082 .01918 L
.33195 .01751 L
.33254 .01669 L
.33284 .01634 L
.33292 .01627 L
.33301 .01619 L
.33316 .0161 L
.33331 .01605 L
.3334 .01604 L
.33347 .01605 L
.33362 .0161 L
.33377 .0162 L
.3339 .01632 L
.33403 .01645 L
Mistroke
.33431 .01681 L
.33537 .01834 L
.33761 .02136 L
.33822 .022 L
.33887 .02256 L
.33949 .02297 L
.33976 .02311 L
.34005 .02323 L
.34021 .02329 L
.34038 .02334 L
.34054 .02338 L
.34068 .0234 L
.34077 .02342 L
.34085 .02343 L
.34094 .02343 L
.34103 .02344 L
.34112 .02344 L
.34121 .02344 L
.34136 .02343 L
.34151 .02342 L
.34167 .02339 L
.34182 .02336 L
.34195 .02333 L
.34227 .02322 L
.3426 .02307 L
.3432 .02272 L
.34376 .02229 L
.34503 .021 L
.34729 .01798 L
.34791 .01714 L
.34825 .01673 L
.34841 .01656 L
.34857 .01642 L
.34869 .01632 L
.34884 .01623 L
.34898 .01617 L
.34913 .01615 L
.34928 .01617 L
.34936 .01619 L
.34944 .01622 L
.3496 .01631 L
.34974 .01642 L
.35039 .01706 L
.35098 .01774 L
.35232 .01914 L
.35293 .01966 L
.3535 .02004 L
.35381 .02021 L
.3541 .02033 L
.35441 .02044 L
Mistroke
.35459 .02049 L
.35475 .02052 L
.35489 .02054 L
.35504 .02056 L
.35518 .02057 L
.35531 .02057 L
.35546 .02057 L
.35554 .02056 L
.35562 .02056 L
.35577 .02054 L
.35592 .02051 L
.35608 .02047 L
.35625 .02043 L
.35657 .02032 L
.35716 .02004 L
.35772 .01969 L
.35832 .01925 L
.35938 .01833 L
.36062 .01724 L
.36178 .01637 L
.36283 .01579 L
.36311 .01565 L
.36342 .01552 L
.36354 .01547 L
.36368 .01543 L
.36383 .0154 L
.36397 .01539 L
.36411 .0154 L
.36425 .01544 L
.3644 .01552 L
.36449 .01558 L
.36456 .01565 L
.36489 .01601 L
.36519 .01647 L
.36573 .01753 L
.36632 .01906 L
.36696 .02123 L
.36763 .02413 L
.36884 .03114 L
.36998 .04008 L
.3712 .05253 L
.37341 .08313 L
.37597 .13212 L
.37839 .19129 L
.38301 .32753 L
.38791 .4745 L
.39019 .53018 L
.39138 .55412 L
.39264 .57465 L
.39329 .58311 L
Mistroke
.39399 .59075 L
.39463 .59615 L
.39523 .59983 L
.39555 .60125 L
.3957 .60182 L
.39585 .60226 L
.39597 .60259 L
.39611 .60288 L
.39626 .6031 L
.39641 .60325 L
.39649 .6033 L
.39657 .60332 L
.39672 .60329 L
.3968 .60325 L
.39688 .60318 L
.39696 .60308 L
.39706 .60294 L
.39722 .60262 L
.39737 .60222 L
.39766 .60125 L
.39795 .59997 L
.39822 .5985 L
.39884 .59419 L
.39944 .58872 L
.40008 .5815 L
.40231 .54648 L
.40487 .49 L
.4073 .42503 L
.41192 .28773 L
.41683 .14676 L
.41927 .08414 L
.42047 .05553 L
.42099 .04344 L
.42157 .03058 L
.42183 .02485 L
.42198 .02187 L
.42212 .01944 L
.42225 .01821 L
.42239 .01912 L
.42251 .0212 L
.42263 .02345 L
.42375 .04671 L
.42612 .09375 L
.43086 .17857 L
.43543 .24653 L
.43778 .27393 L
.43908 .28628 L
.44029 .29557 L
.44151 .30264 L
.44216 .30538 L
Mistroke
.44249 .30652 L
.44285 .30753 L
.44319 .3083 L
.44334 .30857 L
.4435 .30882 L
.44365 .309 L
.4438 .30916 L
.44389 .30922 L
.44396 .30927 L
.44412 .30934 L
.44426 .30936 L
.4444 .30935 L
.44455 .3093 L
.44471 .3092 L
.44485 .30908 L
.44498 .30893 L
.44527 .30849 L
.44556 .3079 L
.44584 .30721 L
.44646 .30515 L
.44706 .30249 L
.44771 .29897 L
.44888 .29082 L
.44994 .28157 L
.45476 .22221 L
.45941 .15255 L
.46176 .11881 L
.46435 .0861 L
.46683 .0605 L
.4691 .04296 L
.46968 .03953 L
.47031 .03638 L
.47059 .03517 L
.4709 .03407 L
.47119 .03322 L
.47145 .03261 L
.47161 .03233 L
.47178 .0321 L
.47187 .03201 L
.47195 .03194 L
.47204 .03189 L
.47213 .03186 L
.47221 .03185 L
.4723 .03186 L
.47239 .03189 L
.47247 .03194 L
.47262 .03207 L
.47277 .03227 L
.47292 .03251 L
.47307 .03281 L
Mistroke
.47334 .0335 L
.47397 .03564 L
.4746 .03849 L
.47519 .04164 L
.47652 .05034 L
.47894 .07117 L
.48142 .09882 L
.48366 .12884 L
.48849 .20263 L
.49314 .26861 L
.49555 .2935 L
.49676 .3025 L
.49745 .30643 L
.49809 .30928 L
.49869 .31123 L
.49903 .31202 L
.49919 .31231 L
.49935 .31253 L
.49949 .3127 L
.49962 .31282 L
.49977 .31291 L
.49993 .31296 L
.50007 .31296 L
.50023 .31291 L
.50031 .31287 L
.50039 .31281 L
.50054 .31267 L
.50069 .31248 L
.50083 .31226 L
.50114 .31164 L
.50142 .31093 L
.50171 .31001 L
.50278 .30524 L
.50337 .30165 L
.50392 .2978 L
.50514 .28728 L
.50735 .26256 L
.51214 .1927 L
.51676 .12295 L
.51933 .0898 L
.52166 .06537 L
.52283 .05528 L
.5241 .04605 L
.52529 .03902 L
.52587 .03631 L
.52639 .03432 L
.52666 .03349 L
.52696 .03276 L
.52712 .03244 L
.52727 .03221 L
Mistroke
.52741 .03204 L
.52757 .03192 L
.5277 .03186 L
.52784 .03185 L
.52797 .03189 L
.52809 .03197 L
.52822 .0321 L
.52837 .03229 L
.52852 .03256 L
.52866 .03285 L
.52899 .03372 L
.5293 .03476 L
.52987 .0372 L
.53116 .04465 L
.53358 .06427 L
.5358 .08783 L
.54056 .15208 L
.54514 .22078 L
.54768 .25532 L
.55001 .28106 L
.55116 .2911 L
.55177 .29558 L
.55241 .29968 L
.55298 .30268 L
.5536 .30536 L
.55387 .30632 L
.55416 .30721 L
.55444 .30791 L
.5547 .30843 L
.55498 .30888 L
.55514 .30907 L
.55529 .3092 L
.55543 .30929 L
.55556 .30934 L
.5557 .30936 L
.55585 .30935 L
.556 .30929 L
.55608 .30924 L
.55616 .30919 L
.55631 .30905 L
.55645 .30889 L
.55676 .30839 L
.55711 .30764 L
.55775 .30572 L
.55843 .3029 L
.55965 .29592 L
.56089 .28647 L
.56224 .2738 L
.56467 .2452 L
.56962 .17053 L
Mistroke
.57208 .12742 L
.57438 .08412 L
.57659 .03948 L
.5769 .03312 L
.57723 .02624 L
.57738 .02317 L
.57747 .02157 L
.57754 .02017 L
.57768 .0184 L
.57783 .01879 L
.57797 .02095 L
.57812 .02381 L
.57838 .02934 L
.57896 .04244 L
.58356 .1574 L
.58846 .29894 L
.59317 .43808 L
.59557 .50075 L
.59684 .52935 L
.59817 .55535 L
.59937 .57431 L
.6 .58256 L
.60068 .58996 L
.60131 .59536 L
.60188 .5991 L
.60215 .60049 L
.60245 .60168 L
.60259 .60212 L
.60274 .60252 L
.60287 .60281 L
.603 .60303 L
.60315 .60321 L
.60323 .60327 L
.60331 .60331 L
.6034 .60332 L
.60349 .6033 L
.60365 .6032 L
.6038 .60303 L
.60393 .60279 L
.60408 .60245 L
.60424 .602 L
.60457 .60076 L
.60488 .59924 L
.60559 .59447 L
.6062 .58886 L
.60676 .58257 L
.60802 .56447 L
.61031 .51904 L
.61281 .45451 L
.61771 .30529 L
Mistroke
.62243 .17006 L
.62501 .11172 L
.62619 .0898 L
.62744 .07005 L
.62859 .0549 L
.62986 .04154 L
.63101 .03215 L
.63209 .02554 L
.63269 .02266 L
.63335 .02013 L
.63397 .01826 L
.63454 .01695 L
.63506 .01609 L
.6352 .0159 L
.63535 .01573 L
.63549 .0156 L
.63563 .01551 L
.63577 .01544 L
.63592 .01539 L
.63607 .01539 L
.63623 .01541 L
.63638 .01545 L
.63652 .0155 L
.63678 .0156 L
.63795 .0162 L
.63919 .01708 L
.64142 .01903 L
.64255 .01987 L
.64288 .02006 L
.64319 .02022 L
.64347 .02033 L
.64378 .02044 L
.64392 .02048 L
.64406 .02051 L
.6442 .02053 L
.64432 .02055 L
.64444 .02056 L
.64457 .02057 L
.64469 .02057 L
.64483 .02057 L
.64498 .02056 L
.64512 .02054 L
.64528 .02052 L
.64543 .02048 L
.64569 .02041 L
.64598 .0203 L
.64657 .02 L
.64712 .01962 L
.64837 .01845 L
.64961 .01707 L
Mistroke
.64991 .01674 L
.65023 .01644 L
.65041 .0163 L
.6505 .01625 L
.65058 .01621 L
.65066 .01618 L
.65075 .01616 L
.65091 .01615 L
.65105 .01618 L
.6512 .01625 L
.65134 .01634 L
.65147 .01645 L
.65209 .01714 L
.65334 .01887 L
.65443 .02032 L
.65558 .02166 L
.65614 .0222 L
.65677 .0227 L
.65734 .02304 L
.65759 .02317 L
.65787 .02327 L
.65818 .02336 L
.65835 .0234 L
.6585 .02342 L
.65865 .02343 L
.65878 .02344 L
.65893 .02344 L
.65908 .02343 L
.65924 .02342 L
.65931 .02341 L
.6594 .02339 L
.6597 .02332 L
.65987 .02326 L
.66005 .0232 L
.66038 .02304 L
.66101 .02265 L
.6616 .02217 L
.66293 .02073 L
.66409 .01914 L
.66535 .01728 L
.66567 .01683 L
.66601 .01641 L
.66615 .01627 L
.6663 .01615 L
.66639 .0161 L
.66647 .01607 L
.66662 .01604 L
.66678 .01607 L
.66692 .01614 L
.66708 .01626 L
Mistroke
.66724 .01643 L
.66782 .01718 L
.67007 .0204 L
.6712 .02173 L
.67179 .02229 L
.67242 .02277 L
.67297 .02309 L
.67328 .02323 L
.67357 .02333 L
.67371 .02337 L
.67384 .0234 L
.67395 .02343 L
.67408 .02344 L
.67421 .02346 L
.67434 .02347 L
.67447 .02347 L
.67462 .02346 L
.67478 .02345 L
.67492 .02343 L
.67508 .0234 L
.67525 .02336 L
.67557 .02326 L
.67585 .02315 L
.67643 .02283 L
.67697 .02244 L
.67818 .02126 L
.67949 .01962 L
.68074 .01783 L
.68134 .01696 L
.68161 .01661 L
.6819 .01628 L
.68205 .01613 L
.6822 .01603 L
.68234 .01597 L
.68248 .01595 L
.68264 .01598 L
.68278 .01605 L
.68294 .01617 L
.68311 .01634 L
.68444 .01811 L
.68559 .01966 L
.68682 .02108 L
.68752 .02173 L
.68816 .02221 L
.68847 .0224 L
.6888 .02257 L
.68912 .0227 L
.68941 .02279 L
.68969 .02286 L
.68984 .02288 L
Mistroke
.68999 .0229 L
.69014 .02291 L
.69023 .02291 L
.69031 .02291 L
.69046 .02291 L
.69062 .0229 L
.69077 .02288 L
.69093 .02285 L
.69123 .02278 L
.69158 .02265 L
.6919 .02251 L
.69243 .0222 L
.69302 .02178 L
.6942 .02066 L
.69551 .01908 L
.69676 .01741 L
.6973 .0167 L
.69759 .01635 L
.69787 .01608 L
.69802 .01598 L
.69817 .0159 L
.69826 .01588 L
.69834 .01587 L
.6985 .0159 L
.69865 .01596 L
.69878 .01605 L
.69908 .01633 L
.70151 .01936 L
.7027 .02063 L
.70379 .02151 L
.70437 .02185 L
.70466 .02199 L
.70498 .02211 L
.70515 .02216 L
.7053 .02221 L
.70545 .02224 L
.70559 .02227 L
.70576 .02229 L
.70585 .0223 L
.70594 .02231 L
.7061 .02231 L
.70618 .02231 L
.70627 .02231 L
.7064 .0223 L
.70654 .02229 L
.70669 .02227 L
.70683 .02225 L
.70708 .02219 L
.70735 .02211 L
.70796 .02185 L
Mistroke
.70851 .02153 L
.70972 .02057 L
.71083 .01942 L
.71212 .01785 L
.71276 .01706 L
.71334 .01638 L
.71361 .01612 L
.71375 .016 L
.7139 .0159 L
.71404 .01583 L
.71417 .01581 L
.71431 .01581 L
.71443 .01584 L
.71457 .01591 L
.71472 .01602 L
.71499 .01626 L
.7156 .01694 L
.7168 .01838 L
.71809 .01976 L
.71873 .02034 L
.71934 .0208 L
.71992 .02118 L
.72047 .02144 L
.72098 .02162 L
.72124 .02169 L
.72139 .02172 L
.72153 .02174 L
.72168 .02176 L
.72182 .02177 L
.72196 .02177 L
.72205 .02177 L
.72212 .02177 L
.72226 .02177 L
.72239 .02176 L
.72254 .02174 L
.72268 .02172 L
.72297 .02166 L
.72324 .02158 L
.72386 .02133 L
.72446 .021 L
.7251 .02056 L
.72733 .01841 L
.72856 .017 L
.7292 .01629 L
.72953 .01599 L
.72962 .01593 L
.72972 .01587 L
.72981 .01582 L
.72989 .01578 L
.73004 .01575 L
Mistroke
.73012 .01575 L
.73021 .01576 L
.7303 .01578 L
.73039 .01582 L
.73055 .01591 L
.73084 .01614 L
.73115 .01645 L
.73232 .01774 L
.73355 .01904 L
.73471 .02005 L
.73534 .02049 L
.73592 .02081 L
.73656 .02108 L
.73692 .02118 L
.73708 .02122 L
.73725 .02125 L
.73741 .02128 L
.73756 .02129 L
.73771 .0213 L
.73786 .02131 L
.738 .02131 L
.73812 .02131 L
.73826 .0213 L
.73841 .02128 L
.73857 .02126 L
.73874 .02123 L
.73906 .02115 L
.73936 .02105 L
.73964 .02094 L
.74072 .02036 L
.74186 .01948 L
.74302 .01837 L
.74424 .01706 L
.74475 .01653 L
.74528 .01602 L
.74544 .0159 L
.74559 .01581 L
.74573 .01575 L
.74587 .01571 L
.74601 .0157 L
.74616 .01573 L
.74628 .01577 L
.74642 .01585 L
.74673 .01607 L
.747 .01633 L
.74763 .01696 L
.74876 .01813 L
.75007 .01932 L
.75064 .01976 L
.75128 .02017 L
Mistroke
.75181 .02045 L
.75239 .02068 L
.75271 .02077 L
.75285 .02081 L
.753 .02084 L
.75313 .02086 L
.75328 .02089 L
.75343 .0209 L
.75357 .02091 L
.75366 .02092 L
.75374 .02092 L
.7539 .02092 L
.75398 .02092 L
.75406 .02091 L
.75415 .02091 L
.75425 .0209 L
.75442 .02088 L
.75458 .02085 L
.75488 .02078 L
.75518 .0207 L
.75545 .0206 L
.75608 .02033 L
.75669 .01997 L
.75735 .01951 L
.75855 .01849 L
.75971 .01735 L
.7608 .01627 L
.76108 .01602 L
.76135 .01582 L
.7615 .01574 L
.76158 .01571 L
.76166 .01568 L
.7618 .01566 L
.76194 .01566 L
.76209 .0157 L
.76218 .01573 L
.76225 .01577 L
.76254 .01596 L
.7632 .01654 L
.76452 .01784 L
.76574 .01892 L
.76685 .0197 L
.76747 .02004 L
.76803 .02028 L
.76833 .02038 L
.76864 .02046 L
.76881 .0205 L
.76899 .02053 L
.76916 .02056 L
.76931 .02057 L
Mistroke
.76947 .02058 L
.76962 .02059 L
.76975 .02059 L
.7699 .02058 L
.77005 .02057 L
.77014 .02057 L
.77022 .02056 L
.77038 .02054 L
.77052 .02051 L
.77081 .02045 L
.77111 .02037 L
.77174 .02013 L
.77227 .01987 L
.77285 .01952 L
.77536 .01744 L
.77659 .01627 L
.77693 .01598 L
.77712 .01585 L
.77729 .01574 L
.77744 .01568 L
.7776 .01563 L
.77769 .01562 L
.77777 .01562 L
.77785 .01563 L
.77793 .01565 L
.77801 .01567 L
.7781 .01571 L
.77825 .01579 L
.77854 .01599 L
.77919 .01656 L
.78036 .01765 L
.7816 .0187 L
.78276 .01948 L
.78335 .01978 L
.78397 .02003 L
.78433 .02014 L
.78467 .02022 L
.78482 .02024 L
.78497 .02027 L
.78505 .02028 L
.78514 .02029 L
.7853 .0203 L
.78545 .02031 L
.78559 .02031 L
.78574 .02031 L
.78582 .0203 L
.7859 .0203 L
.78605 .02029 L
.78622 .02027 L
.78637 .02024 L
Mistroke
.78652 .02022 L
.78706 .02008 L
.78733 .01999 L
.78763 .01987 L
.78893 .01917 L
.79015 .01827 L
.7914 .01717 L
.79202 .0166 L
.79259 .0161 L
.79286 .01589 L
.79311 .01573 L
.79325 .01567 L
.7934 .01561 L
.79354 .01559 L
.79366 .01559 L
.7938 .01561 L
.79393 .01566 L
.79408 .01572 L
.79423 .01581 L
.79483 .01627 L
.79722 .01833 L
.79788 .0188 L
.79857 .01923 L
.79917 .01954 L
.79949 .01967 L
.79982 .01979 L
.80012 .01988 L
.80044 .01996 L
.80058 .01999 L
.80073 .02001 L
.80087 .02003 L
.801 .02005 L
.80115 .02006 L
.8013 .02007 L
.80144 .02007 L
.80158 .02007 L
.80171 .02006 L
.80183 .02006 L
.80197 .02005 L
.80211 .02003 L
.80243 .01998 L
.80279 .0199 L
.80312 .0198 L
.80343 .01969 L
.80463 .01909 L
.80579 .01831 L
.80688 .01742 L
.80809 .01636 L
.80841 .0161 L
.80875 .01585 L
Mistroke
.80891 .01574 L
.80907 .01566 L
.80921 .01561 L
.80936 .01557 L
.8095 .01556 L
.80965 .01558 L
.80973 .0156 L
.80981 .01563 L
.80996 .01569 L
.81025 .01587 L
.81052 .01607 L
.81179 .01714 L
.81287 .01802 L
.81402 .01881 L
.81464 .01916 L
.81521 .01942 L
.81578 .01962 L
.81603 .0197 L
.81631 .01976 L
.81661 .01981 L
.81678 .01984 L
.81694 .01985 L
.81708 .01986 L
.81721 .01987 L
.81737 .01987 L
.81751 .01987 L
.81767 .01986 L
.81775 .01985 L
.81783 .01985 L
.81799 .01983 L
.81813 .01981 L
.81846 .01975 L
.81881 .01966 L
.81941 .01946 L
.81996 .01922 L
.82123 .01848 L
.82254 .0175 L
.82377 .01647 L
.82435 .01601 L
.82466 .01579 L
.82481 .0157 L
.82496 .01563 L
.82511 .01557 L
.82519 .01555 L
.82527 .01554 L
.82536 .01554 L
.82544 .01554 L
.82553 .01555 L
.82562 .01558 L
.8257 .0156 L
Mistroke
.82579 .01564 L
.82595 .01572 L
.82624 .01591 L
.82848 .0177 L
.82973 .01857 L
.83089 .01918 L
.83148 .0194 L
.83178 .01949 L
.8321 .01957 L
.83229 .01961 L
.83246 .01964 L
.83262 .01966 L
.83271 .01967 L
.8328 .01968 L
.83296 .01969 L
.83311 .0197 L
.83319 .0197 L
.83328 .0197 L
.83343 .01969 L
.83358 .01969 L
.83367 .01968 L
.83374 .01967 L
.83388 .01966 L
.83404 .01964 L
.8343 .01959 L
.83459 .01953 L
.83522 .01933 L
.83582 .01909 L
.83689 .0185 L
.83803 .01771 L
.83926 .01673 L
.83991 .01621 L
.84026 .01594 L
.84059 .01572 L
.84073 .01565 L
.84088 .01558 L
.84096 .01556 L
.84104 .01554 L
.84119 .01552 L
.84128 .01552 L
.84136 .01552 L
.84145 .01554 L
.84153 .01556 L
.84169 .01562 L
.84185 .01571 L
.84246 .01612 L
.84302 .01656 L
.8442 .0175 L
.84547 .01837 L
.84609 .01872 L
Mistroke
.84667 .01901 L
.84725 .01923 L
.84777 .01938 L
.84805 .01945 L
.84832 .01949 L
.84845 .01951 L
.8486 .01953 L
.84875 .01954 L
.8489 .01955 L
.84902 .01955 L
.84916 .01955 L
.84929 .01955 L
.8494 .01955 L
.84954 .01954 L
.84968 .01952 L
.84982 .01951 L
.84995 .01949 L
.85023 .01944 L
.8505 .01938 L
.85111 .0192 L
.8517 .01896 L
.85233 .01864 L
.8547 .01702 L
.85596 .01604 L
.85632 .01579 L
.8565 .01569 L
.85666 .0156 L
.85681 .01555 L
.85697 .01551 L
.85712 .0155 L
.85721 .0155 L
.8573 .01552 L
.85745 .01556 L
.85754 .01559 L
.85762 .01563 L
.85792 .0158 L
.85849 .0162 L
.85977 .0172 L
.86088 .01799 L
.86208 .01868 L
.86274 .01898 L
.86304 .01908 L
.86336 .01919 L
.86364 .01926 L
.86394 .01933 L
.86411 .01936 L
.86426 .01938 L
.86441 .0194 L
.86456 .01941 L
.8647 .01942 L
Mistroke
.86485 .01943 L
.86498 .01943 L
.86511 .01943 L
.86526 .01943 L
.8654 .01942 L
.86548 .01941 L
.86556 .0194 L
.86571 .01939 L
.86599 .01935 L
.86628 .01929 L
.86681 .01915 L
.86745 .01891 L
.86805 .01863 L
.86939 .01783 L
.87065 .01692 L
.87126 .01644 L
.87182 .01602 L
.87209 .01584 L
.87238 .01566 L
.87252 .0156 L
.87266 .01554 L
.87278 .01551 L
.87291 .01549 L
.87307 .01549 L
.87321 .01551 L
.87336 .01555 L
.87344 .01558 L
.87352 .01562 L
.87409 .01597 L
.87539 .01695 L
.87658 .0178 L
.87771 .01847 L
.87831 .01876 L
.87894 .019 L
.87927 .0191 L
.87962 .01919 L
.87994 .01925 L
.88024 .01929 L
.8804 .01931 L
.88055 .01932 L
.88069 .01933 L
.88084 .01933 L
.88092 .01933 L
.881 .01933 L
.88108 .01933 L
.88117 .01932 L
.88131 .01931 L
.88147 .0193 L
.88162 .01928 L
.88176 .01926 L
Mistroke
.88207 .01921 L
.88262 .01907 L
.88327 .01885 L
.88388 .01857 L
.8851 .01788 L
.88642 .01695 L
.88701 .0165 L
.88765 .01603 L
.88795 .01583 L
.88826 .01565 L
.88838 .01558 L
.88852 .01553 L
.88867 .01549 L
.88881 .01547 L
.88897 .01548 L
.88905 .01549 L
.88913 .01551 L
.88928 .01556 L
.88944 .01563 L
.89002 .01598 L
.89134 .01696 L
.89249 .01776 L
.89371 .01846 L
.8943 .01873 L
.89486 .01893 L
.89537 .01908 L
.89565 .01914 L
.89592 .01918 L
.89606 .0192 L
.89621 .01922 L
.89634 .01923 L
.89648 .01924 L
.89663 .01925 L
.89671 .01925 L
.89679 .01925 L
.89694 .01925 L
.89708 .01924 L
.89721 .01923 L
.89735 .01922 L
.8976 .01919 L
.89787 .01915 L
.89817 .01908 L
.89878 .01891 L
.89945 .01865 L
.90065 .01803 L
.90303 .01637 L
.90368 .01591 L
.90404 .01568 L
.90421 .01559 L
.90429 .01556 L
Mistroke
.90437 .01553 L
.90453 .01548 L
.90461 .01547 L
.90469 .01546 L
.90477 .01546 L
.90485 .01547 L
.90494 .01548 L
.90503 .0155 L
.90518 .01555 L
.90531 .01561 L
.90562 .01578 L
.9079 .01741 L
.90911 .01815 L
.90974 .01848 L
.91041 .01876 L
.91102 .01895 L
.91137 .01904 L
.91169 .0191 L
.91184 .01912 L
.91198 .01914 L
.91211 .01916 L
.91225 .01917 L
.9124 .01918 L
.91254 .01918 L
.91269 .01918 L
.91278 .01918 L
.91286 .01918 L
.913 .01917 L
.91315 .01916 L
.9133 .01915 L
.91343 .01913 L
.91369 .01909 L
.91396 .01904 L
.91458 .01887 L
.91515 .01867 L
.91636 .01808 L
.91748 .01738 L
.91878 .01645 L
.91941 .01599 L
.91969 .01581 L
.91999 .01563 L
.92013 .01557 L
.92028 .01551 L
.92041 .01547 L
.92055 .01545 L
.92069 .01545 L
.92083 .01547 L
.92096 .01551 L
.92109 .01556 L
.92138 .0157 L
Mistroke
.92169 .01589 L
.92226 .01629 L
.92357 .01723 L
.92476 .01799 L
.92534 .0183 L
.92598 .01859 L
.92653 .01879 L
.92713 .01896 L
.92746 .01903 L
.92777 .01908 L
.92794 .0191 L
.92809 .01911 L
.92818 .01912 L
.92827 .01913 L
.92836 .01913 L
.92845 .01913 L
.92859 .01913 L
.92872 .01913 L
.92887 .01912 L
.92896 .01912 L
.92903 .01911 L
.92934 .01908 L
.92949 .01906 L
.92966 .01903 L
.93029 .01888 L
.93089 .01868 L
.93202 .01816 L
.93323 .01743 L
.93455 .01651 L
.9351 .01611 L
.93569 .01572 L
.93586 .01563 L
.93602 .01555 L
.93617 .0155 L
.93626 .01548 L
.93633 .01546 L
.93649 .01545 L
.93663 .01546 L
.93671 .01547 L
.93679 .01549 L
.93694 .01554 L
.9371 .01561 L
.93725 .01569 L
.93758 .01589 L
.93826 .01637 L
.93948 .01723 L
.94074 .01802 L
.94136 .01834 L
.94194 .01859 L
.94245 .01877 L
Mistroke
.94301 .01893 L
.9433 .01899 L
.94357 .01904 L
.94371 .01905 L
.94386 .01907 L
.94394 .01908 L
.94403 .01908 L
.94417 .01909 L
.94425 .01909 L
.94433 .0191 L
.94448 .0191 L
.94464 .01909 L
.94473 .01909 L
.94481 .01908 L
.94496 .01907 L
.9451 .01906 L
.94541 .01902 L
.94569 .01896 L
.94599 .01889 L
.94654 .01873 L
.94718 .01848 L
.94785 .01816 L
.94907 .01744 L
.95031 .01657 L
.95097 .0161 L
.95133 .01586 L
.95166 .01566 L
.95181 .01559 L
.95195 .01553 L
.95203 .0155 L
.95212 .01548 L
.95226 .01545 L
.95234 .01544 L
.95243 .01544 L
.95252 .01545 L
.95261 .01547 L
.95276 .01551 L
.95293 .01558 L
.95324 .01575 L
.95354 .01594 L
.95409 .01633 L
.95534 .01721 L
.95651 .01794 L
.95756 .01847 L
.95815 .0187 L
.9587 .01886 L
.95897 .01893 L
.95925 .01898 L
.95941 .01901 L
.95956 .01903 L
Mistroke
.9597 .01905 L
.95985 .01906 L
.96001 .01907 L
.96015 .01907 L
.96031 .01908 L
.9604 .01908 L
.96048 .01907 L
.96063 .01907 L
.96076 .01906 L
.96091 .01905 L
.96107 .01903 L
.96137 .01898 L
.9617 .01892 L
.96228 .01876 L
.96297 .0185 L
.9636 .01821 L
.96611 .01663 L
.96721 .01585 L
.96751 .01567 L
.96768 .01559 L
.96784 .01552 L
.96798 .01548 L
.96807 .01546 L
.96814 .01545 L
.96828 .01544 L
.96842 .01546 L
.96858 .01549 L
.96872 .01554 L
.96903 .0157 L
.96961 .01606 L
.97068 .01683 L
.97191 .01765 L
.97306 .01829 L
.97378 .0186 L
.97455 .01885 L
.97476 .0189 L
.97499 .01895 L
.9752 .01899 L
.97541 .01902 L
.9756 .01904 L
.97571 .01905 L
.97582 .01906 L
.97592 .01906 L
.97601 .01907 L
.9761 .01907 L
.97619 .01907 L
Mfstroke
1 0 0 r
[ ] 0 setdash
.03968 .01472 m
.03968 .01908 L
s
.05556 .01472 m
.05556 .0191 L
s
.07143 .01472 m
.07143 .01913 L
s
.0873 .01472 m
.0873 .01918 L
s
.10317 .01472 m
.10317 .01925 L
s
.11905 .01472 m
.11905 .01933 L
s
.13492 .01472 m
.13492 .01943 L
s
.15079 .01472 m
.15079 .01955 L
s
.16667 .01472 m
.16667 .0197 L
s
.18254 .01472 m
.18254 .01987 L
s
.19841 .01472 m
.19841 .02007 L
s
.21429 .01472 m
.21429 .02031 L
s
.23016 .01472 m
.23016 .02059 L
s
.24603 .01472 m
.24603 .02092 L
s
.2619 .01472 m
.2619 .02131 L
s
.27778 .01472 m
.27778 .02177 L
s
.29365 .01472 m
.29365 .02231 L
s
.30952 .01472 m
.30952 .02291 L
s
.3254 .01472 m
.3254 .02347 L
s
.34127 .01472 m
.34127 .02344 L
s
.35714 .01472 m
.35714 .02005 L
s
.37302 .01472 m
.37302 .07684 L
s
.38889 .01472 m
.38889 .49981 L
s
.40476 .01472 m
.40476 .49268 L
s
.42063 .01472 m
.42063 .05165 L
s
.43651 .01472 m
.43651 .25988 L
s
.45238 .01472 m
.45238 .25452 L
s
.46825 .01472 m
.46825 .0488 L
s
.48413 .01472 m
.48413 .13555 L
s
.5 .01472 m
.5 .31296 L
s
.51587 .01472 m
.51587 .13555 L
s
.53175 .01472 m
.53175 .0488 L
s
.54762 .01472 m
.54762 .25452 L
s
.56349 .01472 m
.56349 .25988 L
s
.57937 .01472 m
.57937 .05165 L
s
.59524 .01472 m
.59524 .49268 L
s
.61111 .01472 m
.61111 .49981 L
s
.62698 .01472 m
.62698 .07684 L
s
.64286 .01472 m
.64286 .02005 L
s
.65873 .01472 m
.65873 .02344 L
s
.6746 .01472 m
.6746 .02347 L
s
.69048 .01472 m
.69048 .02291 L
s
.70635 .01472 m
.70635 .02231 L
s
.72222 .01472 m
.72222 .02177 L
s
.7381 .01472 m
.7381 .02131 L
s
.75397 .01472 m
.75397 .02092 L
s
.76984 .01472 m
.76984 .02059 L
s
.78571 .01472 m
.78571 .02031 L
s
.80159 .01472 m
.80159 .02007 L
s
.81746 .01472 m
.81746 .01987 L
s
.83333 .01472 m
.83333 .0197 L
s
.84921 .01472 m
.84921 .01955 L
s
.86508 .01472 m
.86508 .01943 L
s
.88095 .01472 m
.88095 .01933 L
s
.89683 .01472 m
.89683 .01925 L
s
.9127 .01472 m
.9127 .01918 L
s
.92857 .01472 m
.92857 .01913 L
s
.94444 .01472 m
.94444 .0191 L
s
.96032 .01472 m
.96032 .01908 L
s
.97619 .01472 m
.97619 .01907 L
s
.015 w
.03968 .01908 Mdot
.05556 .0191 Mdot
.07143 .01913 Mdot
.0873 .01918 Mdot
.10317 .01925 Mdot
.11905 .01933 Mdot
.13492 .01943 Mdot
.15079 .01955 Mdot
.16667 .0197 Mdot
.18254 .01987 Mdot
.19841 .02007 Mdot
.21429 .02031 Mdot
.23016 .02059 Mdot
.24603 .02092 Mdot
.2619 .02131 Mdot
.27778 .02177 Mdot
.29365 .02231 Mdot
.30952 .02291 Mdot
.3254 .02347 Mdot
.34127 .02344 Mdot
.35714 .02005 Mdot
.37302 .07684 Mdot
.38889 .49981 Mdot
.40476 .49268 Mdot
.42063 .05165 Mdot
.43651 .25988 Mdot
.45238 .25452 Mdot
.46825 .0488 Mdot
.48413 .13555 Mdot
.5 .31296 Mdot
.51587 .13555 Mdot
.53175 .0488 Mdot
.54762 .25452 Mdot
.56349 .25988 Mdot
.57937 .05165 Mdot
.59524 .49268 Mdot
.61111 .49981 Mdot
.62698 .07684 Mdot
.64286 .02005 Mdot
.65873 .02344 Mdot
.6746 .02347 Mdot
.69048 .02291 Mdot
.70635 .02231 Mdot
.72222 .02177 Mdot
.7381 .02131 Mdot
.75397 .02092 Mdot
.76984 .02059 Mdot
.78571 .02031 Mdot
.80159 .02007 Mdot
.81746 .01987 Mdot
.83333 .0197 Mdot
.84921 .01955 Mdot
.86508 .01943 Mdot
.88095 .01933 Mdot
.89683 .01925 Mdot
.9127 .01918 Mdot
.92857 .01913 Mdot
.94444 .0191 Mdot
.96032 .01908 Mdot
.97619 .01907 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{756, 146},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000;d0000TR000`400?l00000o`00003ooooooooo
ooooooKooooo003ooooooooooooom_ooool00?ooooooooooooofooooo`00ooooooooooooooKooooo
003ooooooooooooom_ooool002Kooooo0ol00004ooooo`;o0000:oooool3o`0002cooooo0_l0000^
ooooo`?o0000:_ooool3o`0000Cooooo0_l0000Zooooo`?o00001?ooool2o`0002_ooooo0ol0000]
ooooo`;o0000;oooool3o`0002_ooooo0ol00004ooooo`;o0000;Oooool3o`0000Cooooo0_l0000[
ooooo`?o0000:oooool2o`0002kooooo0ol0000[ooooo`?o00001?ooool2o`0001Wooooo000Woooo
o`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000:Oooool01Ol0003ooooooooooooo
oooo000002[ooooo00Co0000oooooooooooo0000;?ooool01Ol0003ooooooooooooooooo000002[o
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Zooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo0000:Oooool01Ol0003ooooooooooooooooo000002_ooooo00Co
0000oooooooooooo0000;Oooool01Ol0003ooooooooooooooooo000002_ooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool0000]ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo0000:Oooool01Ol0003ooooooooooooooooo000002Wooooo00Co0000oooooooooooo0000
;?ooool01Ol0003ooooooooooooooooo000002_ooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool0000Hooooo`007oooool5o`0000?ooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool0000Sooooo`Go00001Oooool00ol0003oooooooooo`0Xooooo`04o`000?oooooooooo
o`00033ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0002;ooooo1Ol00003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000
8oooool5o`0000Gooooo00?o0000ooooooooool0:Oooool01?l0003oooooooooool0000aooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Uoooo
o`Go00000oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0002?ooooo1Ol00005
ooooo`03o`000?oooooooooo02Oooooo00Co0000oooooooooooo0000<?ooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00006?ooool002Oooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool0000]ooooo`03o`000?oooooooooo02Sooooo
00Co0000oooooooooooo0000<?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo0000:_ooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0002gooooo00?o0000ooooooooool0:Oooool01?l0003oooooooooool0000aooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000]ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo0000;Oooool00ol0003oooooooooo`0Wooooo`04
o`000?ooooooooooo`00033ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0001Sooooo000Wooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo0000:Oooool4o`0002_ooooo00Co0000oooooooooooo0000;?ooool4o`0002_ooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool0000Zooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo0000:Oooool4o`0002cooooo00Co0000oooooooooooo0000;Oooool4o`00
02cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000]ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo0000:Oooool4o`0002[ooooo00Co0000oooooooooooo0000
;?ooool4o`0002cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Hooooo`00
9_ooool2o`0000Cooooo00Co0000oooooooooooo0000:Oooool00ol0003oooooooooo`0/ooooo`04
o`000?ooooooooooo`0002cooooo00?o0000ooooooooool0:oooool2o`0000Cooooo00Co0000oooo
oooooooo0000:Oooool2o`0000Cooooo00Co0000oooooooooooo0000:Oooool00ol0003ooooooooo
o`0]ooooo`04o`000?ooooooooooo`0002gooooo00?o0000ooooooooool0;?ooool2o`0000Cooooo
00Co0000oooooooooooo0000;?ooool2o`0000Cooooo00Co0000oooooooooooo0000:Oooool00ol0
003oooooooooo`0[ooooo`04o`000?ooooooooooo`0002cooooo00?o0000ooooooooool0;?ooool2
o`0000Cooooo00Co0000oooooooooooo00006?ooool002Oooooo00?o0000ooooooooool00oooool2
o`0002[ooooo1Ol0000[ooooo`;o0000;Oooool5o`0002[ooooo00?o0000ooooooooool00oooool2
o`0002_ooooo00?o0000ooooooooool00oooool2o`0002[ooooo1Ol0000/ooooo`;o0000;_ooool5
o`0002_ooooo00?o0000ooooooooool00oooool2o`0002kooooo00?o0000ooooooooool00oooool2
o`0002[ooooo1Ol0000Zooooo`;o0000;Oooool5o`0002_ooooo00?o0000ooooooooool00oooool2
o`0001Wooooo003ooooooooooooom_ooool00?ooooooooooooofooooo`00ooooooooooooooKooooo
003ooooooooooooom_ooool001gooooo0_l00005ooooolgo00008_ooool2o`0000Coooooc_l0000R
ooooo`;o00001?ooooo>o`0001Oooooo000Looooo`04o`000?ooooooooooo`0000Cooooo00Go0000
ooooooooooooooooo`00000`ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0;_oo
ool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07ooo
ool01?l0003oooooooooool00003ooooo`03o`000?oooooo0000033ooooo00?o0000ooooooooool0
;oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0Oooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02gooooo00?o0000oooooooo
ool0;_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool05Oooool001cooooo00Co0000oooooooooooo00001?ooool2o`0003Sooooo00?o003ooooooooo
ool0:Oooool00ol0003oooooooooo`0Vooooo`03o`00oooooooooooo01[ooooo00?o003ooooooooo
ool07?ooool2o`00027ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`3:oooo
o`03o`000?oooooooooo01oooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`04
ooooo`Koo`0000?oooooool00?oo00001ooo001?ooooo`03o`000?oooooooooo04kooooo3?oo0000
0oooooooo`00ool00004ool000?ooooo00?o0000ooooooooool05Oooool001cooooo00Co0000oooo
oooooooo00001?ooool01?l0003oooooooooooooool3o`00o`04ooooool00?oo003oooooo`?o003o
00Coooooo`00ool00?oooooo0_l00?l2ooooo`co003o00?oooooo`00ool00?l04ol00?l2ooooo`03
o`00oooooooooooo00;o003o00Coooooo`00ool00?oooooo0_l00?l3ooooo`?o003o2oooool00ol0
0?ooooooooooo`0=ooooo`03o`000?oooooooooo01Sooooo0_l00?l00ooooooo003oo`00o`02oooo
o`06o`00ooooooooooooooooool00?oooooo0_l00?l2ooooo`;o003o0_ooool01Ol00?oooooooooo
ool00?oooooo00;o003o00Koooooo`00ool00?ooooooo`00ooooool:o`00o`05ooooool00?oo003o
o`00ooooool01Ol00?l00ooooooo003oo`00o`04o`00o`03ooooool00?oo003o00Go003o00?ooooo
o`00ooooool00oooool00ol0003oooooooooo`0Oooooo`04o`000?ooooooooooo`0000?ooooo0ol0
00001Oooooooo`00ool00?oo003ooooo00coo`0000?oooooool00?oo00001ooo00000oooooooo`00
ool00007ool00003oooooooo003oo`0000[oo`0000?oooooool00?oo00001?oo00000oooooooo`00
ooooo`02ooooo`05ool00?ooooooooooool00?ooool00ooo0002ooooo`04ool00?ooooooooooool0
00;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?ooooooooooool000;ooooo00Go
o`00ooooooooooooooooool00002ooooo`04ool00?ooooooooooool000?ooooo00Coo`00oooooooo
ooooo`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`000_oo
ool00ooo003oooooooooo`03ool00005oooooooo003ooooooooooooo00000oooool00ooo003ooooo
ool00005ool00003oooooooo003oo`0000Ooo`0000?oooooool00?oo00002_oo00000oooooooo`00
ool00007ool00003oooooooo003oo`0000Ooo`0000?oooooool00?oo00001ooo0002ooooo`;o0000
8Oooool01?l0003oooooooooool00003ooooo`;o00000oooool2o`00o`Koo`0000?o003oool00?oo
00002_oo00000ol00?ooo`00ool0000:ool00003oooooooo003oo`0000[oo`0000?o003oool00?oo
00002_oo00000ol00?ooo`00ool00007ool00003o`00oooo003ooooo00;ooooo00Coo`00oooooooo
ooooo`000_ooool01?oo003ooooooooooooo0003ooooo`04ool00?ooooooooooool000;ooooo00Co
o`00ooooooooooooo`000oooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool0
00?ooooo00Coo`00ooooooooooooo`000_ooool01_oo003ooooooooooooo003oooooo`00o`coo`00
00?o003oool00?oo00002_oo00000ol00?ooo`00ool0000:ool00003o`00oooo003oo`0000[oo`00
00?o003oool00?oo00002_oo00000ol00?ooo`00ool00004ool000;ooooo0_l0000Gooooo`007?oo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo02Gooooo00?o003oooooooooool0
0_l00?l01?oooooo003oo`00ooooool2o`00o`;ooooo0_l00?l01?oooooo003oo`00ooooool2o`00
o`;ooooo0_l00?l2ooooo`06o`00oooooooo003oo`00oooooooo003o3Oooool00ol00?oooooooooo
o`0=ooooo`03o`000?oooooooooo00gooooo00?o003oooooooooool02?ooool00ol00?oooooooooo
o`02ooooo`;o003o00?oooooo`00ool00?l01?l00?l01?oooooo003oo`00ooooool2o`00o`04oooo
ool00?oo003oooooo`;o003o0_ooool2o`00o`04ooooool00?oo003oooooo`;o003o9oooool00ol0
003oooooooooo`0Oooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooooooo0ooo
00000oooooooo`00ool0000:ool00003oooooooo003oo`0000Ooo`0000?oooooool00?oo00001ooo
00000oooooooo`00ool0000:ool00003oooooooo003oo`0000Ooo`0000?oooooool00?oo00001ooo
0002ooooo`04ool00?ooooooooooool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04
ool00?ooooooooooool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?oooooo
ooooool000?ooooo00Coo`00ooooooooooooo`000_ooool01Ooo003oooooooooooooooooo`0000;o
oooo00Coo`00ooooooooooooo`000_ooool00ooo003oooooooooo`09ool00003oooooooo003oo`00
00Ooo`0000?oooooool00?oo00001ooo00000oooooooo`00ool0000:ool00003oooooooo003oo`00
00Ooo`0000?oooooool00?oo00001ooo00000oooooooo`00ool00007ool000?ooooo00?o0000oooo
ooooool07oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Cooooo1_oo0000
0oooooooo`00ool0000:ool00003oooooooo003oo`0000[oo`0000?oooooool00?oo00002_oo0000
0oooooooo`00ool0000:ool00003oooooooo003oo`0000Ooo`0000?oooooool00?ooool00_ooool0
1?oo003ooooooooooooo0002ooooo`04ool00?l00?ooooooool000?ooooo00Coo`00oooooooooooo
o`000_ooool01?oo003ooooooooooooo0003ooooo`04ool00?ooooooooooool000;ooooo00Coo`00
ooooooooooooo`000_ooool01Ol00?ooo`00ooooooooooooo`0000;ooooo00Coo`00oooooooooooo
o`000_ooool<ool00003oooooooo003oo`0000[oo`0000?oooooool00?oo00002_oo00000ooooooo
o`00ool0000:ool00003oooooooo003oo`0000[oo`0000?oooooool00?oo00001?oo0003ooooo`03
o`000?oooooooooo01Gooooo000Looooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool0B?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00gooooo00?o0000oooooooo
ool03Oooool00ol00?ooooooooooo`1Cooooo`03o`000?oooooooooo01oooooo00Co0000oooooooo
oooo00000oooool01?l0003oooooooooooooool3ool00003oooooooo003oo`0000[oo`0000?ooooo
ool00?oo00001ooo00000oooooooo`00ool00007ool00003oooooooo003oo`0000[oo`0000?ooooo
ool00?oo00001ooo00000oooooooo`00ool00007ool000;ooooo00Coo`00ooooooooooooo`000_oo
ool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`000_ooool01Ooo003o
ooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`000oooool01?oo003ooooooooooooo
0002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo0002ooooo`03
ool00?oooooooooo00Woo`0000?oooooool00?oo00001ooo00000oooooooo`00ool00007ool00003
oooooooo003oo`0000[oo`0000?oooooool00?oo00001ooo00000oooooooo`00ool00007ool00003
oooooooo003oo`0000Ooo`000oooool00ol0003oooooooooo`0Oooooo`04o`000?ooooooooooo`00
00?ooooo00?o0000ooooooooool05?ooool3ool00003oooooooo003oo`0000[oo`0000?oooooool0
0?oo00002_oo00000oooooooo`00ool0000:ool00003oooooooo003oo`0000Ooo`0000?o003oool0
0?ooool00_ooool01?oo003ooooooooooooo0002ooooo`04ool00?l00?ooooooool000?ooooo00Co
o`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0003ooooo`04ool00?ooooooooooool0
00;ooooo00Coo`00ooooooooooooo`000_ooool01Ol00?ooo`00ooooooooooooo`0000;ooooo00Ko
o`00ooooooooooooo`00ooooool00?l<ool00003oooooooo003oo`0000[oo`0000?oooooool00?oo
00002_oo00000oooooooo`00ool0000:ool001Oooooo00?o0000ooooooooool05Oooool001gooooo
0_l00005ooooo`03o`000?oooooooooo04Sooooo00?o003oooooooooool02?ooool00ol00?oooooo
ooooo`07ooooo`03o`00oooooooooooo00?ooooo00?o0000ooooooooool00_ooool2o`00o`Wooooo
00?o003oooooooooool02?ooool00ol00?ooooooooooo`18ooooo`03o`000?oooooooooo023ooooo
0_l00004ooooo`03o`000?oooooooooo03Wooooo0ooo00000oooooooo`00ool00004ool000Gooooo
00Coo`00ooooooooooooo`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00oooo
ooooooooo`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`00
0oooool01?oo003ooooooooooooo0002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo
003ooooooooooooo0002ooooo`03ool00?oooooooooo00?ooooo1_oo00001?ooooooo`00ool00?oo
000nooooo`03o`000?oooooooooo023ooooo0_l00004ooooo`;o0000B_ooool01Ooo003ooooooooo
ooooooooo`0000;ooooo00Ooo`00ooooooooooooo`00o`00ooooooooo`0000?ooooo00Ooo`00oooo
ooooooooo`00o`00ooooooooo`0000;ooooo00Soo`00ooooooooooooooooool00?oooooo003oool0
00;ooooo00Coo`00ooooooooooooo`000_ooool01Ol00?ooo`00ooooooooooooo`0000;ooooo00Go
o`00ooooooooooooo`00o`00o`1:ooooo`;o00005oooool002Cooooo00?o0000ooooooooool0B?oo
ool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Oooooo0_l00?l4ooooo`03o`000?oo
oooooooo00;ooooo0_l00?l9ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool0B?oo
ool00ol0003oooooooooo`0Vooooo`;o0000BOooool01?oo003ooooooooooooo0002ooooo`05ool0
0?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo0002ooooo`05ool00?oooooooooo
oooooooo00000_ooool01?oo003ooooooooooooo0003ooooo`04ool00?ooooooooooool000;ooooo
00Goo`00ooooooooooooooooool00002ooooo`04ool00?ooooooooooool000;ooooo00?oo`00oooo
ooooool0B_ooool2o`0002Sooooo00?o0000ooooooooool0BOooool01Ooo003ooooooooooooooooo
o`0000;ooooo00Coo`00ooooooooooooo`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo
00Coo`00o`00ooooooooo`000_ooool02?oo003oooooooooooooooooo`00ooooool00?ooo`000_oo
ool01?oo003ooooooooooooo0003ooooo`04ool00?ooooooooooool000;ooooo00Goo`00oooooooo
ooooo`00o`00o`1;ooooo`03o`000?oooooooooo01Gooooo000Tooooo`03o`000?oooooooooo05?o
oooo00?o003oooooooooool03Oooool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo00So
oooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`18ooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool0B?ooool01?oo003ooooooooooooo0002ooooo`05ool00?oooooooooo
oooooooo00000_ooool01?oo003ooooooooooooo0002ooooo`05ool00?oooooooooooooooooo0000
0_ooool01?oo003ooooooooooooo0003ooooo`04ool00?ooooooooooool000;ooooo00Goo`00oooo
ooooooooooooool00002ooooo`04ool00?ooooooooooool000;ooooo00?oo`00ooooooooool0Booo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo04Wooooo00Goo`00oooooooooooooooo
ool00002ooooo`07ool00?ooooooooooool00?l00?ooooooool00003ooooo`07ool00?oooooooooo
ool00?l00?ooooooool00002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooo
oooooooo0002ooooo`05ool00?ooooooooooo`00oooo00000_ooool01?oo003ooooooooooooo0002
ooooo`03ool00?oooooooooo04[ooooo00?o0000ooooooooool05Oooool002Cooooo00?o0000oooo
ooooool0B?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Oooooo0_l00?l4oooo
o`03o`000?oooooooooo00?ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`1Coooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0B?ooool01?oo003ooooooooooooo0002
ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo0002ooooo`05ool0
0?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo0003ooooo`04ool00?oooooooooo
ool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?ooooooooooool000;ooooo
00?oo`00ooooooooool0Boooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo04Wooooo
00Goo`00ooooooooooooooooool00002ooooo`03ool00?ooooooo`0000;oo`0000?oooooool00?oo
ool00_ooool00ooo003oooooool00002ool00005oooooooo003ooooooooooooo00000oooool00ooo
003o003oool00002ool00005oooooooo003ooooooooooooo00000_ooool3ool00005oooooooo003o
oooooooooooo00000_ooool00ooo003o003oooooo`1:ooooo`03o`000?oooooooooo01Gooooo000T
ooooo`03o`000?oooooooooo04Wooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`07
ooooo`;o003o1?ooool00ol0003oooooooooo`02ooooo`;o003o2Oooool00ol00?ooooooooooo`07
ooooo`03o`00oooooooooooo04Wooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`18
ooooo`04ool00?ooooooooooool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`05ool0
0?ooooooooooool00?ooool00ooo0002ooooo`04ool00?ooooooooooool000;ooooo00?oo`00oooo
ooooool00ooo00001Oooooooo`00ooooooooooooo`0000?ooooo00Coo`00ooooooooooooo`000_oo
ool01?oo003ooooooooooooo001=ooooo`03o`000?oooooooooo02Kooooo0_l0001:ooooo`05ool0
0?oooooooooooooooooo00000_ooool00ooo003oooooool00002ool00003oooooooo003ooooo00;o
oooo00?oo`00oooooooo00000_oo00001Ol00?ooo`00ooooooooooooo`0000?ooooo00?oo`00o`00
oooo00000_oo00001Oooooooo`00ooooooooooooo`0000;ooooo0ooo00001Oooooooo`00oooooooo
ooooo`0000;ooooo00?oo`00o`00ooooool0BOooool2o`0001Oooooo000Tooooo`03o`000?oooooo
oooo04Wooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
003o00Cooooo00?o0000ooooooooool00_ooool00ol00?ooooooo`00o`07ooooo`03o`00oooooooo
oooo00Sooooo00?o003oooooooooool0BOooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo04Sooooo00Coo`00ooooooooooooo`000_ooool00ooo003oooooooooo`03ool00006oooooooo
003ooooooooooooo003ooooo0ooo0002ooooo`04ool00?ooooooooooool000;ooooo00?oo`00oooo
ooooool00ooo00001Oooooooo`00ooooooooooooo`0000;ooooo0ooo00001Oooooooo`00oooooooo
ooooo`0000;ooooo00?oo`00ooooooooool0Boooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooooooo04Wooooo00Goo`00ooooooooooooooooool00002ooooo`03ool00?ooooooo`0000;oo`00
00?oooooool00?ooool00_ooool00ooo003oooooool00002ool00005o`00oooo003ooooooooooooo
00000oooool00ooo003o003oool00002ool00005oooooooo003ooooooooooooo00000_ooool3ool0
0005oooooooo003ooooooooooooo00000_ooool00ooo003o003oooooo`1:ooooo`03o`000?oooooo
oooo01Gooooo000Tooooo`03o`000?oooooooooo05?ooooo00?o003oooooooooool03Oooool01Ol0
003ooooooooooooooooo003o00_ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`19
ooooo`03o`000?oooooooooo02Kooooo0_l00019ooooo`04ool00?ooooooooooool000;ooooo00?o
o`00ooooooooool00ooo00001_ooooooo`00ooooooooooooo`00ooooo`?oo`000_ooool01?oo003o
oooooooooooo0002ooooo`03ool00?oooooooooo00?oo`0000Goooooool00?ooooooooooool00002
ooooo`?oo`0000Goooooool00?ooooooooooool00002ooooo`03ool00?oooooooooo04[ooooo0_l0
000Xooooo`03o`000?oooooooooo04Wooooo00Goo`00ooooooooooooooooool00002ooooo`07ool0
0?ooooooooooooooool00?ooooooool00003ooooo`07ool00?ooooooooooo`00oooooooo003oool0
0002ooooo`05ool00?oooooooooooooooooo00001Oooool01?oo003ooooooooooooo0002ooooo`05
o`00oooooooooooooooooooo00000_ooool01?oo003ooooooooooooo001<ooooo`03o`000?oooooo
oooo01Gooooo000Tooooo`03o`000?oooooooooo04Wooooo00?o003oooooooooool01oooool00ol0
0?ooooooooooo`06ooooo`04o`00ooooooooooooo`00o`?ooooo00?o0000ooooooooool01?ooool0
0ol00?ooooooooooo`05ooooo`;o003oEOooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo04Sooooo00Coo`00ooooooooooooo`000_ooool00ooo003oooooooooo`03ool00005oooooooo
003ooooooooooooo00001_ooool01?oo003ooooooooooooo0002ooooo`03ool00?oooooooooo00Co
oooo00Coo`00ooooooooooooo`000_ooool3ool00005oooooooo003ooooooooooooo00000_ooool0
0ooo003oooooooooo`1;ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0BOooool0
1Ooo003oooooooooooooooooo`0000;ooooo00?oo`00ooooooooool00_l00?l00oooooooo`00oooo
o`02ooooo`04ool00?ooooooooooo`00o`;ooooo00Coo`00ooooooooooooo`000oooool01?oo003o
003oooooool00?l2ooooo`04ool00?ooooooooooool000;ooooo0_l00?l2ooooo`04ool00?oooooo
ooooool000;ooooo00?oo`00o`00ooooool0B_ooool00ol0003oooooooooo`0Eooooo`009?ooool0
0ol0003oooooooooo`19ooooo`03o`00oooooooooooo00Oooooo0_l00?l7ooooo`04o`00oooooooo
ooooo`00o`?ooooo00Go0000ooooooooooooooooo`00o`02ooooo`03o`00oooooooooooo00Gooooo
0_l00?l9ooooo`03o`00oooooooooooo04Wooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`18ooooo`04ool00?ooooooooooool000;ooooo00?oo`00ooooooooool01?ooool01?oo003o
oooooooooooo0006ooooo`04ool00?ooooooooooool000;ooooo00?oo`00ooooooooool01?ooool0
1?oo003ooooooooooooo0006ooooo`04ool00?ooooooooooool000;ooooo00?oo`00ooooooooool0
Boooool00ol0003oooooooooo`0Vooooo`;o0000BOooool3ool000;ooooo00Coo`00oooooooooooo
o`000_ooool2o`00o`03oooooooo003ooooo00;ooooo00?oo`00ooooool00?l00_ooool01Ol00?oo
o`00ooooooooooooo`0000?ooooo00Coo`00o`00oooooooo003o0_ooool01?oo003ooooooooooooo
0002ooooo`;o003o0_ooool01Ooo003ooooooooooooo003ooooo00?oo`00B_ooool2o`0001Oooooo
000Tooooo`03o`000?oooooooooo04Wooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`07ooooo`04o`00ooooooooooooo`00o`?ooooo00Go0000ooooooooooooooooo`00o`02ooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`19ooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool0B?ooool01?oo003ooooooooooooo0002oooo
o`03ool00?oooooooooo00Cooooo00Coo`00ooooooooooooo`001_ooool01?oo003ooooooooooooo
0002ooooo`03ool00?oooooooooo00Cooooo00Coo`00ooooooooooooo`001_ooool01?oo003ooooo
oooooooo0002ooooo`03ool00?oooooooooo04_ooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`18ooooo`?oo`000_ooool01?oo003ooooooooooooo0002ooooo`04o`00oooooooooooo
ool000?ooooo00?oo`00ooooooooool00_ooool01Ol00?ooo`00ooooooooooooo`0000?ooooo00Oo
o`00o`00ooooooooooooo`00ooooooooo`0000;ooooo00Goo`00ooooooooooooooooo`00o`02oooo
o`05ool00?ooooooooooool00?ooool00ooo001;ooooo`03o`000?oooooooooo01Gooooo000Toooo
o`03o`000?oooooooooo05Cooooo00?o003oooooooooool03?ooool01Ol0003ooooooooooooooooo
003o00_ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`19ooooo`03o`000?oooooo
oooo02Kooooo0_l00019ooooo`04ool00?ooooooooooool000;ooooo00?oo`00ooooooooool01?oo
ool01?oo003ooooooooooooo0006ooooo`04ool00?ooooooooooool000;ooooo00?oo`00oooooooo
ool01?ooool01?oo003ooooooooooooo0006ooooo`04ool00?ooooooooooool000;ooooo00?oo`00
ooooooooool0B_ooool2o`0002Sooooo00?o0000ooooooooool0B?ooool3ool000;ooooo00Coo`00
ooooooooooooo`000oooool00ol00?ooooooool00003ooooo`03ool00?oooooo003o00;ooooo00Go
003oool00?ooooooooooool00003ooooo`03ool00?oooooooooo00?ooooo00Coo`00oooooooooooo
o`000_ooool01Ol00?ooooooooooooooooooo`0000;ooooo00?oo`00oooooooo00000_oo001;oooo
o`03o`000?oooooooooo01Gooooo000Tooooo`03o`000?oooooooooo04Wooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooo`00o`07ooooo`04o`00ooooooooooooo`00o`?ooooo00?o0000oooo
ooooool01?ooool00ol00?ooooooooooo`05ooooo`;o003oEOooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo04Oooooo0ooo00001Oooooooo`00ooooooooooooo`0000Kooooo00Coo`00
ooooooooooooo`001_ooool01?oo003ooooooooooooo0002ooooo`03ool00?oooooooooo00Cooooo
00Coo`00ooooooooooooo`001_ooool01Ooo003ooooooooooooo003ooooo00?oo`00C?ooool00ol0
003oooooooooo`0Vooooo`;o0000C_ooool01?oo003ooooooooooooo0002ooooo`;o003o00?ooooo
ool00?ooool00_ooool00ooo003oooooo`00o`03ooooo`04ool00?ooooooooooool000?ooooo00Oo
o`00ooooooooooooooooo`00ooooooooo`0000;ooooo00?oo`00ooooooooool00_l00?l2ooooo`04
ool00?ooooooooooool000;ooooo00?o003oooooooooool0BOooool2o`0001Oooooo000Tooooo`03
o`000?oooooooooo04Wooooo00?o003oooooooooool01_ooool00ol00?ooooooo`00o`07ooooo`04
o`00ooooooooooooo`00o`?ooooo00Go0000ooooooooooooooooo`00o`02ooooo`03o`00oooooooo
oooo00Gooooo0_l00?l9ooooo`03o`00oooooooooooo04Wooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`17ooooo`?oo`0000Goooooool00?ooooooooooool00006ooooo`04ool00?oo
ooooooooool000Kooooo00Coo`00ooooooooooooo`000_ooool00ooo003oooooooooo`04ooooo`04
ool00?ooooooooooool000Kooooo00Goo`00ooooooooooooo`00ooooo`03ool004cooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`1:ooooo`04o`00ooooooooooooool000;ooooo00?o
o`00ooooooooool00_l00?l00oooooooo`00ooooo`02ooooo`03ool00?oooooo003o00;ooooo00Go
003oool00?ooooooooooool00003ooooo`07ool00?ooooooooooooooool00?ooooooool00002oooo
o`03ool00?oooooooooo00;o003o0_ooool01?oo003ooooooooooooo0002ooooo`03o`00oooooooo
oooo04[ooooo00?o0000ooooooooool05Oooool001Kooooo0ol00004ooooo`;o00001Oooool00ol0
003oooooooooo`19ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go0000ooooooooooooooooo`00o`02ooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`19ooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool0Aoooool3ool00005oooooooo003ooooooooooooo0000
1_ooool01?oo003ooooooooooooo0006ooooo`04ool00?ooooooooooool000;ooooo00?oo`00oooo
ooooool01?ooool01?oo003ooooooooooooo0006ooooo`05ool00?ooooooooooool00?ooool00ooo
001<ooooo`03o`000?oooooooooo01Wooooo0ol00004ooooo`;o00001?ooool00ol0003ooooooooo
o`1:ooooo`04o`00ooooooooooooool000;ooooo00Coo`00oooooooooooo003o0_ooool01Ooo003o
ooooooooooooooooo`0000Cooooo00Go003oool00?ooooooooooool00003ooooo`07ool00?oooooo
ooooooooool00?ooooooool00002ooooo`05ool00?ooooooooooooooool00?l00_ooool01?oo003o
oooooooooooo0002ooooo`03o`00oooooooooooo04[ooooo00?o0000ooooooooool05Oooool001Oo
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo
05Cooooo00?o003oooooooooool03?ooool01Ol0003ooooooooooooooooo003o00cooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`19ooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool0Boooool01?oo003ooooooooooooo0006ooooo`04ool00?ooooooooooool000Kooooo
00Coo`00ooooooooooooo`000_ooool00ooo003oooooooooo`04ooooo`04ool00?ooooooooooool0
00Kooooo00Coo`00ooooooooooooo`00D?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`1:ooooo`04o`00oooo
ooooooooool000;ooooo00Ooo`00ooooooooooooooooo`00ooooooooo`0000?ooooo00?oo`00oooo
ool00?l00oooool01?oo003ooooooooooooo0003ooooo`03ool00?oooooooooo00?ooooo00Coo`00
ooooooooooooo`000_ooool01Ol00?ooooooooooooooooooo`0000;ooooo00?oo`00ooooooooool0
COooool00ol0003oooooooooo`0Eooooo`005oooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0000Cooooo0_l0001:ooooo`03o`00oooooooooooo00Kooooo00?o003oooooool00?l0
1_ooool00ol00?ooooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o003oooooooooool0
1Oooool00ol00?ooooooo`00o`1Cooooo`;o0000:?ooool2o`0004cooooo00Coo`00oooooooooooo
o`001_ooool01?oo003ooooooooooooo0006ooooo`04ool00?ooooooooooool000;ooooo00?oo`00
ooooooooool01?ooool01?oo003ooooooooooooo0006ooooo`04ool00?ooooooooooool004oooooo
0_l0000Looooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000oooool2o`0004ko
oooo00Coo`00ooooooooooooo`000_ooool2o`00o`03oooooooo003ooooo00;ooooo00?oo`00oooo
ool00?l00oooool01?oo003ooooooooooooo0003ooooo`03ool00?oooooooooo00?ooooo00Coo`00
ooooooooooooo`000_ooool2o`00o`;ooooo00Coo`00ooooooooooooo`000_ooool00ol00?oooooo
ooooo`19ooooo`;o00005oooool001Oooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo04Wooooo00?o003oooooooooool01_ooool00ol00?oooooo
o`00o`06ooooo`05o`00ooooooooooooooooool00?l00oooool01?l0003oooooooooool00?l3oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooool00?l02?ooool00ol00?ooooooooooo`19oooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0Boooool01?oo003ooooooooooooo0006
ooooo`04ool00?ooooooooooool000Kooooo00Coo`00ooooooooooooo`000_ooool00ooo003ooooo
ooooo`04ooooo`04ool00?ooooooooooool000Kooooo00Coo`00ooooooooooooo`00D?ooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000oooool0
0ol0003oooooooooo`1:ooooo`04o`00ooooooooooooool000;ooooo00Ooo`00oooooooooooo003o
ooooool00?ooo`0000?ooooo00?oo`00ooooool00?l00oooool01?oo003ooooooooooooo0003oooo
o`07ool00?ooooooooooooooool00?ooooooool00002ooooo`05ool00?oooooo003oooooool00?l0
0_ooool01?oo003ooooooooooooo0002ooooo`03o`00oooooooooooo04[ooooo00?o0000oooooooo
ool05Oooool001Oooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo04Wooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`05
o`00ooooooooooooooooool00?l00oooool01?l0003oooooooooool00?l4ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`19ooooo`03o`000?oooooo
oooo01Wooooo0ol00004ooooo`;o00001?ooool00ol0003oooooooooo`1;ooooo`04ool00?oooooo
ooooool000Kooooo00Coo`00ooooooooooooo`001_ooool01?oo003ooooooooooooo0002ooooo`03
ool00?oooooooooo00Cooooo00Coo`00ooooooooooooo`001_ooool01?oo003ooooooooooooo001@
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0003ooooo`03o`000?oooooooooo04[ooooo00Co003oooooooooooooo`000_ooool01?oo003ooooo
ooooool00?l2ooooo`05ool00?oooooooooooooooooo00001Oooool01?oo003ooooooooooooo0003
ooooo`07ool00?ooooooooooooooool00?ooooooool00002ooooo`05ool00?ooooooooooooooool0
0?l00_ooool01?oo003ooooooooooooo0002ooooo`03o`00oooooooooooo04[ooooo00?o0000oooo
ooooool05Oooool001Kooooo0_l00004ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooo
ooooool0E?ooool00ol00?ooooooooooo`08ooooo`05o`00ooooooooooooooooool000000_ooool0
0ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0B_ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000ooo
ool00ol0003oooooooooo`1;ooooo`04ool00?ooooooooooool000Kooooo00Coo`00oooooooooooo
o`001_ooool01?oo003ooooooooooooo0002ooooo`03ool00?oooooooooo00Cooooo00Coo`00oooo
ooooooooo`001_ooool01?oo003ooooooooooooo001@ooooo`03o`000?oooooooooo01Wooooo0_l0
0004ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0B_ooool01?l00?oooooo
oooooooo0002ooooo`03ool00?oooooooooo00;ooooo00?o003oool00?ooool00_ooool00ooo003o
ooooo`00o`03ooooo`04ool00?ooooooooooool000?ooooo00Ooo`00ooooooooooooooooo`00oooo
ooooo`0000;ooooo00?oo`00ooooool00?l01?ooool01?oo003ooooooooooooo001?ooooo`03o`00
0?oooooooooo01Gooooo000Gooooo`03o`000?oooooooooo00?ooooo0_l00005ooooo`03o`000?oo
oooooooo04Wooooo00?o003oooooooooool01_ooool00ol00?ooooooo`00o`06ooooo`03o`00oooo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooo003o05Cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0000?ooooo0ol0001;ooooo`04ool00?ooooooooooool000Kooooo00Coo`00oooooooo
ooooo`001_ooool01?oo003ooooooooooooo0002ooooo`03ool00?oooooooooo00Cooooo00Coo`00
ooooooooooooo`001_ooool01?oo003ooooooooooooo001?ooooo`;o00007?ooool00ol0003ooooo
ooooo`03ooooo`;o00001?ooool2o`0004kooooo00Coo`00ooooooooooooo`000_ooool01?l00?oo
ooooo`00oooo0003ooooo`03ool00?oooooo003o00?ooooo00Coo`00ooooooooooooo`000oooool0
0ooo003oooooooooo`03ooooo`08ool00?ooooooooooool00?oooooo003oooooool00?l2ooooo`04
ool00?ooooooooooool000;ooooo00?o003oooooooooool0BOooool2o`0001Oooooo000Tooooo`03
o`000?oooooooooo04[ooooo00?o003oooooooooool01Oooool00ol00?ooooooo`00o`06ooooo`03
o`00oooooooooooo00;ooooo00Co003ooooooooooooo00000_ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooool00?l01oooool00ol00?ooooooooooo`1:oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003
ooooo`03o`000?oooooooooo04_ooooo00Coo`00ooooooooooooo`001_ooool01?oo003ooooooooo
oooo0006ooooo`04ool00?ooooooooooool000;ooooo00?oo`00ooooooooool01?ooool01?oo003o
oooooooooooo0006ooooo`04ool00?ooooooooooool0053ooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`1:ooooo`04o`00ooooooooooooool000;ooooo00Ooo`00oooooooooooo003o
ooooool00?ooo`0000?ooooo00?oo`00o`00ooooool00_ooool3ool00004oooooooo003ooooooooo
o`?oo`000_ooool00ol00?ooooooool00002ooooo`05ool00?oooooo003oooooool00?l00_ooool0
1?oo003ooooooooooooo0002ooooo`03o`00oooooooooooo04[ooooo00?o0000ooooooooool05Ooo
ool002Cooooo00?o0000ooooooooool0B_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00002ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`07ooooo`03o`00oooo
oooooooo04[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool0Boooool01?oo003ooooooooooooo0006ooooo`04
ool00?ooooooooooool000Kooooo00Coo`00ooooooooooooo`000_ooool00ooo003oooooooooo`04
ooooo`04ool00?ooooooooooool000Kooooo00Coo`00ooooooooooooo`00D?ooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo04[ooooo00Co003oooooooooooooo`000_ooool01ooo003o
ooooooooool00?ooooooo`00oooo00000oooool00ooo003o003oooooo`02ooooo`?oo`0000Cooooo
ool00?oooooooooo0ooo0002ooooo`03o`00ooooooooo`0000;ooooo00Goo`00oooooooooooooooo
o`00o`02ooooo`04ool00?ooooooooooool000;ooooo00?o003oooooooooool0B_ooool00ol0003o
ooooooooo`0Eooooo`009?ooool00ol0003oooooooooo`1Booooo`03o`00oooooooo003o00_ooooo
00Co003ooooooooooooo00000_ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool0B_ooool00ol0003oooooooooo`0Iooooo`;o00001?ooool01?l0003o
ooooooooool00003ooooo`03o`000?oooooooooo04_ooooo00Coo`00ooooooooooooo`001_ooool0
1?oo003ooooooooooooo0006ooooo`04ool00?ooooooooooool000;ooooo00?oo`00ooooooooool0
1?ooool01?oo003ooooooooooooo0006ooooo`04ool00?ooooooooooool0053ooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`1:ooooo`04o`00ooooooooooooool000;ooooo00?oo`00
ooooooooool00oooool01Ooo003oooooooooooooooooo`0000Cooooo0ooo00001?ooooooo`00oooo
ooooool3ool000?ooooo00Oo003oool00?ooooooooooool00?oooooo003o00Cooooo00Coo`00oooo
ooooooooo`00Coooool00ol0003oooooooooo`0Eooooo`009?ooool00ol0003oooooooooo`1:oooo
o`03o`00oooooooooooo00Oooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05oooo
o`04o`000?ooooooooooo`00o`Cooooo00?o003oooooooooool00oooool01?l00?ooooooooooool0
0?mDooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool00oooool2o`0000Cooooo00?o
0000ooooooooool0Boooool01?oo003ooooooooooooo0006ooooo`04ool00?ooooooooooool000Ko
oooo00Coo`00ooooooooooooo`000_ooool00ooo003oooooooooo`04ooooo`04ool00?oooooooooo
ool000Kooooo00Coo`00ooooooooooooo`00D?ooool00ol0003oooooooooo`0Vooooo`;o0000C_oo
ool01_oo003ooooooooooooo003oooooo`00o`;ooooo00?o003oool00?ooool00_ooool00ooo003o
003oooooo`06ooooo`03ool00?oooooooooo00Oooooo00Koo`00ooooooooooooo`00ooooool00?l4
ooooo`04ool00?ooooooooooool000;ooooo00?o003oooooooooool0BOooool2o`0001Oooooo000T
ooooo`03o`000?oooooooooo04[ooooo00?o003oooooooooool01Oooool00ol00?ooooooo`00o`06
ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo00001oooool00ol00?oooooooooo
o`03ooooo`04o`00ooooooooooooo`00o`Oooooo00?o003oooooooooool0B_ooool00ol0003ooooo
ooooo`0Vooooo`;o0000C?ooool01?oo003ooooooooooooo0006ooooo`04ool00?ooooooooooool0
00Kooooo00Coo`00ooooooooooooo`000_ooool00ooo003oooooooooo`04ooooo`04ool00?oooooo
ooooool000Kooooo00Coo`00ooooooooooooo`00Coooool2o`0002Sooooo00?o0000ooooooooool0
B_ooool01?l00?oooooooooooooo0002ooooo`03ool00?oooooo003o00;ooooo00?o003oool00?oo
ool00_ooool00ooo003o003oooooo`06ooooo`05ool00?ooooooooooooooool00?l01?ooool02Ol0
0?ooo`00ooooooooooooo`00ooooool00?ooooooo`00o`02ooooo`04ool00?ooooooooooool000;o
oooo00?o003oooooooooool0B_ooool00ol0003oooooooooo`0Eooooo`009?ooool00ol0003ooooo
ooooo`1:ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`02ooooo`04o`00ooooooooooooo`0000;ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool0B_ooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo04_ooooo00Coo`00ooooooooooooo`001_ooool01?oo
003ooooooooooooo0006ooooo`04ool00?ooooooooooool000;ooooo00?oo`00ooooooooool01?oo
ool01?oo003ooooooooooooo0006ooooo`04ool00?ooooooooooool0053ooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`1:ooooo`04o`00ooooooooooooool000;ooooo00?oo`00oooo
ool00?l00_ooool00ol00?ooo`00ooooo`02ooooo`03ool00?l00?oooooo00?ooooo00Co003ooooo
ooooooooo`000oooool00ol00?ooooooooooo`02ooooo`05o`00oooo003ooooooooooooo00000ooo
ool01?l00?oooooooooooooo0002ooooo`04ool00?ooooooooooo`00odcooooo00?o0000oooooooo
ool05Oooool002Cooooo00?o0000ooooooooool0B_ooool00ol00?ooooooooooo`05ooooo`04o`00
ooooooooooooo`00o`[ooooo00Co003ooooooooooooo00000_ooool00ol00?ooooooooooo`0;oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool0B_ooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo04_ooooo00Coo`00ooooooooooooo`001_ooool01?oo003ooooooooooooo
0005ooooo`?oo`0000?oooooool00?ooool00ooo0005ooooo`04ool00?ooooooooooool000Kooooo
00Coo`00ooooooooooooo`00D?ooool00ol0003oooooooooo`0Vooooo`;o0000Boooool01?l00?oo
oooooooooooo0002ooooo`03ool00?oooooooooo00?ooooo00Goo`00ooooooooooooooooool00005
ooooo`04o`00ooooooooooooool000;ooooo00?o003oooooooooool00oooool01ol00?ooo`00oooo
ooooooooo`00ooooool00?l00_ooool00ol00?ooooooool00002ooooo`03ool00?oooooooooo04co
oooo0_l0000Gooooo`009?ooool00ol0003oooooooooo`1Eooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool01_ooool01?l0003oooooooooool00?l4ooooo`03o`00oooooooooooo00?o
oooo00Co003ooooooooooooo003oE?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
04_ooooo00Coo`00ooooooooooooo`001_ooool01?oo003ooooooooooooo0005ooooo`?oo`0000?o
ooooool00?ooool00ooo0005ooooo`04ool00?ooooooooooool000Kooooo00Coo`00oooooooooooo
o`00D?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo04gooooo00Koo`00oooooooo
ooooo`00ooooool00?l2ooooo`03o`00oooo003ooooo00;ooooo00?oo`00o`00ooooool01?ooool0
0ol00?ooooooool00009ooooo`06ool00?ooooooooooool00?oooooo003o1?ooool01?oo003ooooo
oooooooo0002ooooo`03o`00oooooooooooo04[ooooo00?o0000ooooooooool05Oooool002Cooooo
00?o0000ooooooooool0B_ooool00ol00?ooooooooooo`05ooooo`04o`00ooooooooooooo`00o`Co
oooo00?o003oooooooooool00oooool01?l00?ooooooooooool00007ooooo`03o`00oooooooooooo
00?ooooo00Co003ooooooooooooo003o1oooool00ol00?ooooooooooo`1:ooooo`03o`000?oooooo
oooo02Kooooo0_l0001<ooooo`04ool00?ooooooooooool000Kooooo00Coo`00ooooooooooooo`00
1Oooool3ool00003oooooooo003ooooo00?oo`001Oooool01?oo003ooooooooooooo0006ooooo`04
ool00?ooooooooooool004oooooo0_l0000Xooooo`03o`000?oooooooooo04[ooooo00Co003ooooo
ooooooooo`000_ooool00ooo003oooooo`00o`02ooooo`03o`00oooo003ooooo00;ooooo00?oo`00
o`00ooooool01_ooool01?oo003oooooooooool00?l5ooooo`07o`00oooo003ooooooooooooo003o
ooooo`00o`02ooooo`03o`00ooooooooo`0000;ooooo00Coo`00oooooooooooo003oC?ooool00ol0
003oooooooooo`0Eooooo`009?ooool00ol0003oooooooooo`1:ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`03ooooo`04o`00ooooooooooooo`00
00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
00Sooooo00?o003oooooooooool0B_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
04_ooooo00Coo`00ooooooooooooo`001_ooool01?oo003ooooooooooooo0009ooooo`03ool00?oo
oooooooo00Oooooo00Coo`00ooooooooooooo`001_ooool01?oo003ooooooooooooo001@ooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool0B_ooool01?l00?oooooooooooooo0002oooo
o`03ool00?oooooo003o00;ooooo00?o003oool00?ooool00_ooool00ooo003o003oooooo`04oooo
o`03o`00ooooooooo`0000;ooooo00?o003oooooooooool00oooool01ol00?ooo`00oooooooooooo
o`00ooooool00?l00_ooool00ol00?ooooooool00002ooooo`03ool00?oooooo003o04gooooo00?o
0000ooooooooool05Oooool002Cooooo00?o0000ooooooooool0B_ooool00ol00?ooooooooooo`05
ooooo`04o`00ooooooooooooo`00o`[ooooo00Co003ooooooooooooo00000_ooool00ol00?oooooo
ooooo`08ooooo`04o`00ooooooooooooo`00o`Oooooo00?o003oooooooooool0B_ooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo04_ooooo00Coo`00ooooooooooooo`001_ooool01?oo
003ooooooooooooo0009ooooo`03ool00?oooooooooo00Oooooo00Coo`00ooooooooooooo`001_oo
ool01?oo003ooooooooooooo001@ooooo`03o`000?oooooooooo02Kooooo0_l0001;ooooo`04o`00
ooooooooooooool000;ooooo00?oo`00ooooooooool00oooool01Ooo003oooooooooooooooooo`00
00Kooooo00?o003ooooooooo00000_ooool00ol00?ooooooooooo`03ooooo`05o`00oooo003ooooo
oooooooo00001?ooool00ol00?ooooooool00002ooooo`03ool00?oooooooooo04cooooo0_l0000G
ooooo`005Oooool5o`0000?ooooo0_l00005ooooo`03o`000?oooooooooo05Gooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`06ooooo`04o`000?ooooooooooo`00o`Gooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`1Booooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool0Boooool01?oo003ooooooooooooo0006ooooo`04ool00?ooooooooooool000Wooooo
00?oo`00ooooooooool01oooool01?oo003ooooooooooooo0006ooooo`04ool00?ooooooooooool0
053ooooo00?o0000ooooooooool06?ooool5o`0000?ooooo0_l00004ooooo`03o`000?oooooooooo
04gooooo00Koo`00ooooooooooooo`00ooooool00?l2ooooo`03o`00oooo003ooooo00;ooooo00?o
o`00o`00ooooool01?ooool00ol00?ooooooool00009ooooo`05ool00?ooooooooooool00?l00?l0
1Oooool01_oo003ooooooooooooo003oooooo`00odgooooo00?o0000ooooooooool05Oooool001Ko
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooo
oooo04[ooooo00?o003oooooooooool01Oooool01?l00?ooooooooooool00?l4ooooo`03o`00oooo
oooooooo00?ooooo00Co003ooooooooooooo00002?ooool00ol00?ooooooooooo`02ooooo`04o`00
ooooooooooooo`00o`Oooooo00?o003oooooooooool0B_ooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo04_ooooo00Coo`00ooooooooooooo`001_ooool01?oo003ooooooooooooo0009
ooooo`03ool00?oooooooooo00Oooooo00Coo`00ooooooooooooo`001_ooool01?oo003ooooooooo
oooo001@ooooo`03o`000?oooooooooo01Wooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00003ooooo`03o`000?oooooooooo04_ooooo00?o003ooooooooo00000_ooool00ooo
003oooooo`00o`02ooooo`03o`00oooo003ooooo00;ooooo00?oo`00o`00ooooool01_ooool01?oo
003oooooooooool00?l5ooooo`06o`00oooo003ooooooooooooo003o003o0oooool00ol00?oooooo
ool00002ooooo`03ool00?oooooo003o04gooooo00?o0000ooooooooool05Oooool001Oooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo04[ooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00?ooooo
00Ko003ooooooooooooo0000ooooool00?l6ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool02?ooool00ol00?ooooooooooo`1:ooooo`03o`000?oooooooooo02Kooooo0_l0001<oooo
o`04ool00?ooooooooooool000Kooooo00Coo`00ooooooooooooo`002Oooool00ooo003ooooooooo
o`07ooooo`04ool00?ooooooooooool000Kooooo00Coo`00ooooooooooooo`00Coooool2o`0001co
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo
04_ooooo00?o003ooooooooo00000_ooool00ooo003oooooo`00o`02ooooo`03o`00oooo003ooooo
00;ooooo00?oo`00o`00ooooool01?ooool00ol00?ooooooool00002ooooo`03o`00oooooooooooo
00?ooooo00Ko003oool00?ooooooooooool00?l00?l3ooooo`03o`00ooooooooo`0000;ooooo00?o
o`00ooooool00?l0COooool00ol0003oooooooooo`0Eooooo`006?ooool01Ol0003ooooooooooooo
oooo000000;ooooo00?o0000ooooooooool00_ooool2o`0004_ooooo00?o003oooooooooool01Ooo
ool01?l00?ooooooooooool00?l:ooooo`06o`00ooooooooooooo`000?oooooo003o2oooool01?l0
0?ooooooooooool00?l7ooooo`03o`00oooooooooooo04Wooooo0_l0000Xooooo`03o`000?oooooo
oooo04_ooooo00Coo`00ooooooooooooo`001_ooool01?oo003ooooooooooooo0009ooooo`03ool0
0?oooooooooo00Oooooo00Coo`00ooooooooooooo`001_ooool01?oo003ooooooooooooo001@oooo
o`03o`000?oooooooooo01_ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo
ooooooooo`;o0000C?ooool00ol00?ooooooool00002ooooo`03ool00?oooooooooo00?ooooo00Go
o`00ooooooooooooooooool00006ooooo`03o`00ooooooooo`0000;ooooo00?o003oooooooooool0
0oooool01Ol00?ooo`00ooooooooooooo`0000Cooooo00?o003ooooooooo00000_ooool00ooo003o
ooooooooo`1<ooooo`;o00005oooool001Gooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0EOooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo00Kooooo00?o0000ooooool00?l01_ooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo05;ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1;oooo
o`04ool00?ooooooooooool000Kooooo00Coo`00ooooooooooooo`002Oooool00ooo003ooooooooo
o`07ooooo`04ool00?ooooooooooool000Kooooo00Coo`00ooooooooooooo`00D?ooool00ol0003o
ooooooooo`0Hooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00003
ooooo`03o`000?oooooooooo04gooooo00Koo`00ooooooooooooo`00ooooool00?l3ooooo`05ool0
0?oooooooooooooooooo00001_ooool00ol00?ooooooool00009ooooo`04ool00?ooooooooooool0
00Kooooo00Koo`00ooooooooooooo`00ooooool00?m=ooooo`03o`000?oooooooooo01Gooooo000E
ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00004ooooo`03o`00
0?oooooooooo04[ooooo00?o003oooooooooool01?ooool01Ol00?oooooooooooooooooo003o00Co
oooo00?o003oooooooooool01?ooool00ol00?ooooooo`000008ooooo`03o`00oooooooooooo00;o
oooo00Co003ooooooooooooo003o1oooool00ol00?ooooooooooo`1:ooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool0Boooool01?oo003ooooooooooooo0006ooooo`04ool00?oooooo
ooooool000Wooooo00?oo`00ooooooooool01oooool01?oo003ooooooooooooo0006ooooo`04ool0
0?ooooooooooool0053ooooo00?o0000ooooooooool06?ooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`1;ooooo`03o`00oooooooo
o`0000;ooooo00?oo`00ooooool00?l00oooool01Ooo003oooooooooooooooooo`0000Sooooo00Co
o`00oooooooooooo003o1_ooool01Ooo003ooooooooooooo003o003o00?ooooo00?o003ooooooooo
00000_ooool00ooo003oooooo`00o`1=ooooo`03o`000?oooooooooo01Gooooo000Fooooo`?o0000
1?ooool2o`0000Gooooo00?o0000ooooooooool0B_ooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool01?ooool01Ol00?ooooooo`000?oooooo003o00Ko
oooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l7ooooo`03o`00oooooooooooo
04[ooooo00?o0000ooooooooool09_ooool2o`0004cooooo00Coo`00ooooooooooooo`001_ooool0
1?oo003ooooooooooooo0009ooooo`03ool00?oooooooooo00Oooooo00Coo`00ooooooooooooo`00
1_ooool01?oo003ooooooooooooo001?ooooo`;o00006oooool3o`0000Cooooo0_l00004ooooo`;o
0000C?ooool00ol00?ooooooool00002ooooo`03ool00?oooooo003o00?ooooo00Goo`00oooooooo
ooooooooool00006ooooo`03o`00ooooooooo`0000;ooooo00?o003oooooooooool01?ooool01Ooo
003ooooooooooooo003o003o00?ooooo00?o003ooooooooo00000_ooool00ooo003oooooo`00o`1<
ooooo`;o00005oooool002Cooooo00?o0000ooooooooool0B_ooool00ol00?ooooooooooo`04oooo
o`05o`00ooooooooooooooooool00?l02oooool01Ol00?ooooooo`000?oooooo003o00[ooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`1:ooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool0Boooool01?oo003ooooooooooooo0006ooooo`04ool00?ooooooooooool000Wo
oooo00?oo`00ooooooooool01oooool01?oo003ooooooooooooo0006ooooo`04ool00?oooooooooo
ool0053ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1;ooooo`03o`00oooooooo
o`0000;ooooo00?oo`00ooooooooool00oooool01Ooo003oooooooooooooooooo`0000Kooooo00?o
003ooooooooo00000_ooool00ol00?ooooooooooo`04ooooo`05ool00?ooooooooooool00?l00?l0
0oooool00ol00?ooooooool00002ooooo`03ool00?oooooooooo04gooooo00?o0000ooooooooool0
5Oooool002Cooooo00?o0000ooooooooool0EOooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo00Kooooo00?o0000ooooool00?l01_ooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo05;ooooo00?o0000ooooooooool06?ooool5o`0000?ooooo0_l00004ooooo`03o`000?oo
oooooooo04_ooooo00Coo`00ooooooooooooo`001_ooool01?oo003ooooooooooooo0009ooooo`03
ool00?oooooooooo00Oooooo00Coo`00ooooooooooooo`001_ooool01?oo003ooooooooooooo001@
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0COooool01_oo003ooooooooooooo
003oooooo`00o`?ooooo00Goo`00ooooooooooooooooool00006ooooo`03o`00ooooooooo`0000Wo
oooo00Coo`00ooooooooooooo`001_ooool01_oo003ooooooooooooo003oooooo`00odgooooo00?o
0000ooooooooool05Oooool002Cooooo00?o0000ooooooooool0B_ooool00ol00?ooooooooooo`04
ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooo000000Sooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo05;ooooo
00?o0000ooooooooool06Oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00?ooooo00?o0000ooooooooool0Boooool01?oo003ooooooooooooo0006ooooo`04ool00?oooooo
ooooool000Wooooo00?oo`00ooooooooool01oooool01?oo003ooooooooooooo0006ooooo`04ool0
0?ooooooooooool0053ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1;ooooo`03
o`00ooooooooo`0000;ooooo00?oo`00ooooool00?l00oooool01Ooo003oooooooooooooooooo`00
00Sooooo00?oo`00ooooool00?l01oooool01Ooo003ooooooooooooo003o003o00?ooooo00?o003o
oooooooo00000_ooool00ooo003oooooo`00o`1=ooooo`03o`000?oooooooooo01Gooooo000Toooo
o`03o`000?oooooooooo04[ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00Gooooo00Go003oooooool0003oooooo`00o`06ooooo`05o`00oooooooo
ooooooooool00?l01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo04[ooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo
00?o0000ooooooooool0Boooool01?oo003ooooooooooooo0006ooooo`04ool00?ooooooooooool0
00Wooooo00?oo`00ooooooooool01oooool01?oo003ooooooooooooo0006ooooo`04ool00?oooooo
ooooool0053ooooo00?o0000ooooooooool09_ooool2o`0004cooooo00?o003ooooooooo00000_oo
ool00ooo003oooooo`00o`03ooooo`05ool00?oooooooooooooooooo00001_ooool01Ol00?oooooo
ool00?oooooo003o00Oooooo00Goo`00ooooooooooooo`00o`00o`03ooooo`03o`00ooooooooo`00
00;ooooo00?oo`00ooooool00?l0C?ooool2o`0001Oooooo000Tooooo`03o`000?oooooooooo04[o
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00So
oooo00Go003oooooool0003oooooo`00o`0:ooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool0B_ooool00ol0003oooooooooo`0Kooooo`05o`000?ooooooooooooooool000000_ooool0
1?l0003oooooooooooooool3o`0004_ooooo00Coo`00ooooooooooooo`001_ooool01?oo003ooooo
oooooooo0009ooooo`03ool00?oooooooooo00Oooooo00Coo`00ooooooooooooo`001_ooool01?oo
003ooooooooooooo001?ooooo`;o0000:?ooool00ol0003oooooooooo`1;ooooo`03o`00oooooooo
o`0000;ooooo00?oo`00ooooool00?l00oooool01Ooo003oooooooooooooooooo`0000Kooooo00Go
003ooooooooo003oooooo`00o`07ooooo`05ool00?ooooooooooool00?l00?l00oooool00ol00?oo
ooooool00002ooooo`03ool00?oooooooooo04gooooo00?o0000ooooooooool05Oooool002Cooooo
00?o0000ooooooooool0E_ooool01?l00?ooooooooooool00?l9ooooo`03o`000?oooooo003o00Ko
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo04_o
oooo00?o0000ooooooooool06?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooo
oooooooo00000oooool00ol0003oooooooooo`1;ooooo`04ool00?ooooooooooool000Kooooo00Co
o`00ooooooooooooo`002Oooool00ooo003oooooooooo`07ooooo`04ool00?ooooooooooool000Ko
oooo00Coo`00ooooooooooooo`00D?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
04gooooo00Coo`00ooooooooooooo`001Oooool01Ooo003oooooooooooooooooo`0000Oooooo00?o
003oool00?ooool02?ooool01Ooo003ooooooooooooo003o003o00Gooooo00Koo`00oooooooooooo
o`00ooooool00?m=ooooo`03o`000?oooooooooo01Gooooo000Tooooo`03o`000?oooooooooo04[o
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00
o`Oooooo00?o003oooooool000002?ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003o
ooooooooool0DOooool00ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo04_ooooo00Coo`00oooooooooooo
o`001_ooool01?oo003ooooooooooooo0009ooooo`03ool00?oooooooooo00Oooooo00Coo`00oooo
ooooooooo`001_ooool01?oo003ooooooooooooo001@ooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool0Boooool00ol00?ooooooool00002ooooo`03ool00?oooooo003o00?ooooo00Go
o`00ooooooooooooooooool00008ooooo`03ool00?oooooo003o00Oooooo00Goo`00oooooooooooo
o`00o`00o`03ooooo`03o`00ooooooooo`0000;ooooo00?oo`00ooooool00?l0COooool00ol0003o
ooooooooo`0Eooooo`009?ooool00ol0003oooooooooo`1:ooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`05ooooo`05o`00oooooooo0000ooooool0
0?l01oooool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooooooo00?ooooo00?o003ooooo
ooooool0Boooool00ol0003oooooooooo`0Iooooo`?o00001?ooool2o`0000Cooooo00?o0000oooo
ooooool0Boooool01?oo003ooooooooooooo0006ooooo`04ool00?ooooooooooool000Wooooo00?o
o`00ooooooooool01oooool01?oo003ooooooooooooo0006ooooo`04ool00?ooooooooooool0053o
oooo00?o0000ooooooooool09_ooool2o`0004cooooo00?o003ooooooooo00000_ooool00ooo003o
ooooo`00o`03ooooo`03ool00?oooooooooo00?oo`001_ooool01?l00?ooo`00ooooool00?l6oooo
o`?oo`0000?oooooool00?l00?l00oooool00ol00?ooooooool00002ooooo`03ool00?oooooo003o
04cooooo0_l0000Gooooo`009?ooool00ol0003oooooooooo`1:ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l7ooooo`05o`00oooooooo0000
ooooool00?l02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo04_ooooo00?o0000
ooooooooool09_ooool2o`0004cooooo00Coo`00ooooooooooooo`001_ooool01?oo003ooooooooo
oooo0009ooooo`03ool00?oooooooooo00Oooooo00Coo`00ooooooooooooo`001_ooool01?oo003o
oooooooooooo001?ooooo`;o0000:?ooool00ol0003oooooooooo`1;ooooo`03o`00ooooooooo`00
00;ooooo00?oo`00ooooool00?l00_ooool3ool00004oooooooo003oo`00ool000Kooooo00Co003o
ool00?oooooo003o1_ooool6ool000?ooooo00?o003ooooooooo00000_ooool00ooo003oooooo`00
o`1=ooooo`03o`000?oooooooooo01Gooooo000Tooooo`03o`000?oooooooooo05Kooooo00?o003o
ooooooooool02_ooool00ol0003o003oooooo`07ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool00oooool00ol00?ooooooooooo`1;ooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool0Boooool01?oo003ooooooooooooo0006ooooo`04ool00?ooooooooooool000Wooooo
00?oo`00ooooooooool01oooool01?oo003ooooooooooooo0006ooooo`04ool00?ooooooooooool0
053ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1=ooooo`04ool00?oooooooooo
ool000Cooooo0ooo00001?ooooooo`00ool00?oo0006ooooo`03o`00oooo003ooooo00Oooooo1_oo
0005ooooo`04ool00?ooooooooooool004oooooo00?o0000ooooooooool05Oooool002Cooooo00?o
0000ooooooooool0Boooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00;ooooo00Co
003ooooooooooooo003o1oooool2o`00o`03o`000?oooooooooo00Oooooo00Co003ooooooooooooo
003o1?ooool00ol00?ooooooooooo`1Aooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool0Boooool01?oo003ooooooooooooo0006ooooo`04ool00?ooooooooooool000Wooooo00?oo`00
ooooooooool01oooool01?oo003ooooooooooooo0006ooooo`04ool00?ooooooooooool0053ooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`1;ooooo`03o`00ooooooooo`0000;ooooo
00?oo`00ooooool00?l00_ooool3ool000;ooooo00?o003oooooooooool01_ooool00ooo003ooooo
o`00o`07ooooo`03o`00ooooooooo`0000;oo`000oooool00ol00?ooooooool00002ooooo`03ool0
0?oooooo003o04gooooo00?o0000ooooooooool05Oooool002Cooooo00?o0000ooooooooool0Booo
ool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_oo
ool00ol00?oo0000o`00o`08ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool0
0oooool00ol00?ooooooooooo`1;ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
Boooool01?oo003ooooooooooooo0006ooooo`04ool00?ooooooooooool000Wooooo00?oo`00oooo
ooooool01oooool01?oo003ooooooooooooo0006ooooo`04ool00?ooooooooooool0053ooooo00?o
0000ooooooooool09_ooool2o`0004cooooo00?o003ooooooooo00000_ooool00ooo003oooooo`00
o`04ooooo`03o`00oooooooo003o00Sooooo00Co003oool00?oooooo003o1oooool01?l00?oooooo
ooooool00?l4ooooo`03o`00ooooooooo`0000;ooooo00?oo`00ooooool00?l0C?ooool2o`0001Oo
oooo000Fooooo`?o00001?ooool2o`0000Gooooo00?o0000ooooooooool0Boooool00ol00?oooooo
ooooo`03ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_ooool00ol00?oo0000
o`00o`0;ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool0Boooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo04_ooooo00Coo`00ooooooooooooo`001_ooool01?oo003o
oooooooooooo0009ooooo`03ool00?oooooooooo00Oooooo00Coo`00ooooooooooooo`001_ooool0
1?oo003ooooooooooooo001@ooooo`03o`000?oooooooooo01Wooooo0ol00004ooooo`;o00001?oo
ool00ol0003oooooooooo`1;ooooo`03o`00ooooooooo`0000;ooooo00?oo`00ooooool00?l03ooo
ool01?l00?ooo`00ooooool00?l8ooooo`03o`00oooooooo003o00Cooooo00?o003ooooooooo0000
0_ooool00ooo003oooooo`00o`1=ooooo`03o`000?oooooooooo01Gooooo000Eooooo`05o`000?oo
ooooooooooooool000000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo05Ko
oooo00?o003oooooooooool02_ooool00ol0003o003oooooo`07ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool00oooool00ol00?ooooooooooo`1;ooooo`03o`000?oooooooooo02Ko
oooo0_l0001<ooooo`04ool00?ooooooooooool000Kooooo00Coo`00ooooooooooooo`002Oooool0
0ooo003oooooooooo`07ooooo`04ool00?ooooooooooool000Kooooo00Coo`00ooooooooooooo`00
Coooool2o`0001[ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`00
00?ooooo00?o0000ooooooooool0Boooool00ol00?ooooooool00002ooooo`03ool00?oooooooooo
00Cooooo00?o003oooooool00?l02?ooool00ol00?ooo`00ooooo`0Booooo`04ool00?oooooooooo
ool004oooooo00?o0000ooooooooool05Oooool001Wooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`02ooooo`;o0000C?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo
oooo00;ooooo00Co003ooooooooooooo003o2?ooool00ol00?oo0000ooooo`08ooooo`03o`00oooo
oooo003o00Gooooo00?o003oooooooooool0D?ooool2o`0002Sooooo00?o0000ooooooooool0Booo
ool01?oo003ooooooooooooo0006ooooo`04ool00?ooooooooooool000Wooooo00?oo`00oooooooo
ool01oooool01?oo003ooooooooooooo0006ooooo`04ool00?ooooooooooool0053ooooo00?o0000
ooooooooool07?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooooooo`;o0000
C_ooool01Ooo003ooooooooooooo003o003o00Gooooo00?o003oooooool00?l02Oooool00ooo003o
ooooo`00o`08ooooo`03o`00oooooooo003o00Cooooo00?o003ooooooooo00000_ooool00ooo003o
ooooo`00o`1<ooooo`;o00005oooool001Oooooo0_l00003ooooo`04o`000?ooooooooooo`0000Co
oooo00?o0000ooooooooool0Boooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooool00?l02Oooool00ol00?oo0000o`00o`08ooooo`03o`00oooooooo003o00Go
oooo00?o003oooooooooool00oooool00ol00?ooooooooooo`1;ooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool0Boooool01?oo003ooooooooooooo0006ooooo`04ool00?oooooooooo
ool000Wooooo00?oo`00ooooooooool01oooool01?oo003ooooooooooooo0006ooooo`04ool00?oo
ooooooooool0053ooooo00?o0000ooooooooool06_ooool2o`0000?ooooo00Co0000oooooooooooo
00000oooool00ol0003oooooooooo`1;ooooo`03o`00ooooooooo`0000;ooooo00?oo`00o`00oooo
ool01?ooool00ol00?ooooooo`00o`08ooooo`04o`00oooo003oooooo`00o`Sooooo00?o003ooooo
ool00?l01?ooool00ol00?ooooooool00002ooooo`03ool00?oooooo003o04gooooo00?o0000oooo
ooooool05Oooool001Wooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo04_ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00Oooooo00?o003oo`000?l00?l02?ooool00ol00?ooooooo`00o`0;oooo
o`03o`00oooooooooooo04_ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1;oooo
o`04ool00?ooooooooooool000Kooooo00Coo`00ooooooooooooo`002Oooool00ooo003ooooooooo
o`07ooooo`04ool00?ooooooooooool000Kooooo00Coo`00ooooooooooooo`00D?ooool00ol0003o
ooooooooo`0Looooo`04o`000?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`00001=
ooooo`03o`00ooooooooo`0000;ooooo00?oo`00o`00ooooool04?ooool00ooo003o003oooooo`08
ooooo`03o`00oooooooo003o00Gooooo00Oo003oool00?ooooooooooool00?oooooo003o04gooooo
00?o0000ooooooooool05Oooool001Gooooo00Go0000ooooooooooooooooo`000002ooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool0Eoooool00ol00?ooooooooooo`09ooooo`03
o`000?l00?oooooo00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`1;ooooo`03
o`000?oooooooooo02Kooooo0_l0001<ooooo`04ool00?ooooooooooool000Kooooo00?oo`00oooo
oooo00000_oo0008ooooo`03ool00?oooooooooo00Kooooo0ooo00000oooooooo`00ooooo`05oooo
o`04ool00?ooooooooooool004oooooo0_l0000Jooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo04_ooooo00?o003ooooooooo0000
0_ooool00ooo003oooooooooo`04ooooo`03o`00oooooooo003o00Wooooo00?oo`00ooooooooool0
4Oooool01?oo003ooooooooooooo001?ooooo`03o`000?oooooooooo01Gooooo000Fooooo`?o0000
1?ooool2o`0000Gooooo00?o0000ooooooooool0Boooool00ol00?ooooooooooo`03ooooo`03o`00
oooooooooooo00?ooooo0_l00?l9ooooo`03o`00ool0003ooooo00Wooooo0_l00?l5ooooo`03o`00
oooooooooooo00?ooooo00?o003oooooooooool0Boooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo04_ooooo00Coo`00ooooooooooooo`001Oooool6ool000Sooooo00?oo`00oooooooo
ool01_ooool6ool000Gooooo00Coo`00ooooooooooooo`00D?ooool00ol0003oooooooooo`0Ioooo
o`?o00001?ooool2o`0000Cooooo0_l0001>ooooo`05ool00?ooooooooooool00?l00?l01Oooool3
o`00o`Wooooo00?oo`00o`00ooooool02?ooool2o`00o`Kooooo00Oo003oool00?ooooooooooool0
0?oooooo003o04cooooo0_l0000Gooooo`009?ooool00ol0003oooooooooo`1;ooooo`03o`00oooo
oooooooo00?ooooo00?o003oooooooooool00oooool2o`00o`[ooooo00?o003oooooooooool02?oo
ool2o`00o`Gooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`1;ooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool0Boooool01?oo003ooooooooooooo0005ooooo`Koo`00
2?ooool00ooo003oooooooooo`06ooooo`Koo`001Oooool01?oo003ooooooooooooo001@ooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool0Boooool00ol00?ooooooool00002ooooo`03
ool00?l00?oooooo00Gooooo00?o003oooooooooool01oooool3ool000[ooooo00?o003ooooooooo
ool01?ooool01_l00?ooo`00ooooooooooooo`00o`00odkooooo00?o0000ooooooooool05Oooool0
02Cooooo00?o0000ooooooooool0Boooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
00oooooo00?o003oooooooooool0Hoooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
04_ooooo00Coo`00ooooooooooooo`001Oooool3ool000_ooooo00?oo`00ooooooooool02Oooool3
ool000Gooooo00Coo`00ooooooooooooo`00D?ooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooooooo04_ooooo00?o003ooooooooo00000_ooool00ooo003o003oooooo`0?ooooo`?oo`004Ooo
ool01_l00?ooo`00ooooooooooooo`00o`00odkooooo00?o0000ooooooooool05Oooool002Cooooo
00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo
00?o003oooooooooool0Boooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo04_ooooo
00Coo`00ooooooooooooo`004oooool00ooo003oooooooooo`0Aooooo`04ool00?ooooooooooool0
053ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1;ooooo`03o`00ooooooooo`00
00;ooooo00?oo`00ooooooooool03oooool3ool001;ooooo00Goo`00ooooooooooooo`00o`00o`1>
ooooo`03o`000?oooooooooo01Gooooo000Tooooo`03o`000?oooooooooo04_ooooo00?o003ooooo
ooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`000?oooooooooo00oooooo00?o003ooooo
ooooool00oooool00ol00?ooooooooooo`1;ooooo`03o`000?oooooooooo02Kooooo0_l0001<oooo
o`04ool00?ooooooooooool001?ooooo00?oo`00ooooooooool04Oooool01?oo003ooooooooooooo
001?ooooo`;o0000:?ooool2o`0004kooooo00Goo`00ooooooooooooo`00o`00o`0Aooooo`03o`00
0?oooooooooo013ooooo00Go003oool00?ooooooooooool0001>ooooo`;o00005oooool002Cooooo
00?o0000ooooooooool0Boooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00oooooo
00?o0000ooooooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo04_ooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`1;ooooo`04ool00?ooooooooooool001?o
oooo00?oo`00ooooooooool04Oooool01?oo003ooooooooooooo001@ooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool0C?ooool01_l00?ooo`00ooooooooooooo`00o`00oa7ooooo00?o
0000ooooooooool04?ooool01Ol00?ooo`00ooooooooooooo`0004oooooo00?o0000ooooooooool0
5Oooool002Cooooo00?o0000ooooooooool0Boooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooooooo00oooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0Iooooo`?o00001?oo
ool2o`0000Cooooo00?o0000ooooooooool0Boooool01?oo003ooooooooooooo000Cooooo`03ool0
0?oooooooooo017ooooo00Coo`00ooooooooooooo`00D?ooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo04cooooo00Ko003oool00?ooooooooooool00?l00?lAooooo`03o`000?oooooo
oooo013ooooo00Ko003oool00?ooooooooooool00?l00?m>ooooo`03o`000?oooooooooo01Gooooo
000Tooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool03oooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo04_ooooo00?o0000ooooooooool06?ooool01Ol0003ooooooooo
oooooooo000000;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`1;ooooo`04
ool00?ooooooooooool001?ooooo00?oo`00ooooooooool04Oooool01?oo003ooooooooooooo001@
ooooo`03o`000?oooooooooo02Kooooo0_l0001=ooooo`05o`00oooo003ooooooooooooo00004_oo
ool00ol0003oooooooooo`0Aooooo`05ool00?ooooooooooool00?l00?l0COooool2o`0001Oooooo
000Tooooo`03o`000?oooooooooo04_ooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`0@ooooo`03o`000?oooooooooo00oooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`1;ooooo`03o`000?oooooooooo01cooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooooooool3o`0004_ooooo00Coo`00ooooooooooooo`004oooool00ooo003oooooooooo`0Aoooo
o`04ool00?ooooooooooool004oooooo0_l0000Xooooo`03o`000?oooooooooo04gooooo00Goo`00
ooooooooooooo`00o`00o`0Aooooo`03o`000?oooooooooo013ooooo00Ko003oool00?oooooooooo
ool00?l00?m>ooooo`03o`000?oooooooooo01Gooooo000Tooooo`03o`000?oooooooooo04_ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`0@ooooo`03o`000?oooooooooo00oooooo
00?o003oooooooooool00oooool00ol00?ooooooooooo`1;ooooo`03o`000?oooooooooo01[ooooo
0_l00003ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0Boooool01?oo003o
oooooooooooo000Cooooo`03ool00?oooooooooo017ooooo00Coo`00ooooooooooooo`00D?ooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo04cooooo00Ko003oool00?ooooooooooool0
0?l00?lAooooo`03o`000?oooooooooo013ooooo00Go003oool00?ooooooooooool0001?ooooo`03
o`000?oooooooooo01Gooooo000Tooooo`03o`000?oooooooooo04_ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`0@ooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool0
7?ooool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool00000COooool01?oo
003ooooooooooooo000Cooooo`03ool00?oooooooooo017ooooo00Coo`00ooooooooooooo`00D?oo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo04cooooo00Ko003oool00?oooooooooo
ool00?l00?lAooooo`03o`000?oooooooooo013ooooo00Ko003oool00?ooooooooooool00?l00?m>
ooooo`03o`000?oooooooooo01Gooooo000Tooooo`03o`000?oooooooooo053ooooo00?o003ooooo
ooooool04?ooool00ol0003oooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o003ooooo
ooooool0Boooool00ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool000000_ooool0
1?l0003oooooooooool00003ooooo`03o`000?oooooooooo04_ooooo00Coo`00ooooooooooooo`00
4oooool00ooo003oooooooooo`0Aooooo`04ool00?ooooooooooool0053ooooo00?o0000oooooooo
ool09_ooool2o`0004gooooo00Go003oool00?ooooooooooool0000Booooo`03o`000?oooooooooo
017ooooo00Goo`00ooooooooooooo`00o`00o`1=ooooo`;o00005oooool001Oooooo0ol00003oooo
o`;o00001Oooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo00oooooo00?o003ooooo
ooooool00oooool00ol00?ooooooooooo`1;ooooo`03o`000?oooooooooo01Wooooo0ol00004oooo
o`;o00001?ooool00ol0003oooooooooo`1;ooooo`04ool00?ooooooooooool001?ooooo00?oo`00
ooooooooool04Oooool01?oo003ooooooooooooo001@ooooo`03o`000?oooooooooo01[ooooo0ol0
0003ooooo`;o00001?ooool00ol0003oooooooooo`1=ooooo`05ool00?ooooooooooool00?l00?l0
4Oooool00ol0003oooooooooo`0Aooooo`05ool00?ooooooooooool00?l00?l0C_ooool00ol0003o
ooooooooo`0Eooooo`006?ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`1;ooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool04?ooool00ol0003oooooooooo`0@ooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool0Boooool00ol0003oooooooooo`0Vooooo`;o0000C?ooool01?oo003ooooooooooooo000Coooo
o`03ool00?oooooooooo017ooooo00Coo`00ooooooooooooo`00Coooool2o`0001gooooo00Go0000
ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool00000C_ooool01_l00?ooo`00
ooooooooooooo`00o`00oa7ooooo00?o0000ooooooooool04?ooool01Ol00?ooo`00oooooooooooo
o`0004oooooo00?o0000ooooooooool05Oooool001Gooooo1Ol00002ooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooooooool0Boooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo013ooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo04_ooooo00Coo`00ooooooooooooo`004_ooool3ool001;ooooo00Coo`00ooooooooooooo`00
D?ooool00ol0003oooooooooo`0Hooooo`Go00000_ooool01?l0003oooooooooool00003ooooo`03
o`000?oooooooooo04cooooo00Ko003oool00?ooooooooooool00?l00?lAooooo`03o`000?oooooo
oooo013ooooo00Ko003oool00?ooooooooooool00?l00?m>ooooo`03o`000?oooooooooo01Gooooo
000Eooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00001?ooool2o`0004co
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0@ooooo`03o`000?oooooooooo013o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1:ooooo`;o0000:?ooool00ol0003o
ooooooooo`1;ooooo`04ool00?ooooooooooool001;ooooo0ooo000Booooo`04ool00?oooooooooo
ool0053ooooo00?o0000ooooooooool06?ooool01?l0003oooooooooool00003ooooo`04o`000?oo
ooooooooo`0000?ooooo0_l0001=ooooo`05o`00oooo003ooooooooooooo00004_ooool00ol0003o
ooooooooo`0@ooooo`06o`00oooo003ooooooooooooo003o003oCOooool2o`0001Oooooo000Foooo
o`03o`000?oooooo000000?ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1S
ooooo`03o`000?oooooooooo013ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1;
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0Boooool01?oo003ooooooooooooo
000Booooo`?oo`004_ooool01?oo003ooooooooooooo001@ooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooool000000oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo04go
oooo00Goo`00ooooooooooooo`00o`00o`0Aooooo`03o`000?oooooooooo017ooooo00Goo`00oooo
ooooooooo`00o`00o`1>ooooo`03o`000?oooooooooo01Gooooo000Gooooo`;o00000oooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo04_ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00Go003oooooooooooooooooo`00
o`1>ooooo`03o`000?oooooooooo02Kooooo0_l0001<ooooo`04ool00?ooooooooooool002Oooooo
00Coo`00ooooooooooooo`00Coooool2o`0001cooooo0_l00003ooooo`04o`000?ooooooooooo`00
00?ooooo00?o0000ooooooooool0C?ooool01_l00?ooo`00ooooooooooooo`00o`00oa7ooooo00?o
0000ooooooooool04?ooool01Ol00?ooo`00ooooooooooooo`0004oooooo00?o0000ooooooooool0
5Oooool001Sooooo00?o0000ooooooooool00_ooool2o`0000Gooooo00?o0000ooooooooool0Booo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo013ooooo00?o0000ooooooooool0Hooo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo04_ooooo00Coo`00ooooooooooooo`00
9oooool01?oo003ooooooooooooo001@ooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool00_ooool2o`0000Cooooo00?o0000ooooooooool0C?ooool01_l00?ooo`00ooooooooooooo`00
o`00oa7ooooo00?o0000ooooooooool04?ooool01_l00?ooo`00ooooooooooooo`00o`00odkooooo
00?o0000ooooooooool05Oooool002Cooooo00?o0000ooooooooool0Boooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo013ooooo00?o0000ooooooooool04?ooool01Ol00?oooooooooo
oooooooo003o04kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1;ooooo`04ool0
0?ooooooooooool002Oooooo00Coo`00ooooooooooooo`00D?ooool00ol0003oooooooooo`0Voooo
o`;o0000COooool01Ol00?ooo`00ooooooooooooo`0001;ooooo00?o0000ooooooooool04?ooool0
1_l00?ooo`00ooooooooooooo`00o`00odgooooo0_l0000Gooooo`009?ooool00ol0003ooooooooo
o`1Sooooo`03o`000?oooooooooo013ooooo00Go003oooooooooooooooooo`00o`1>ooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool0Boooool01?oo003ooooooooooooo000Wooooo`04
ool00?ooooooooooool0053ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1=oooo
o`05ool00?ooooooooooool00?l00?l04Oooool00ol0003oooooooooo`0Aooooo`05ool00?oooooo
ooooool00?l00?l0C_ooool00ol0003oooooooooo`0Eooooo`009?ooool00ol0003oooooooooo`1;
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04?ooool00ol0003oooooooooo`0@
ooooo`05o`00ooooooooooooooooool00?l0C_ooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooooooo04_ooooo00Coo`00ooooooooooooo`009oooool01?oo003ooooooooooooo001@ooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool0C?ooool01_l00?ooo`00ooooooooooooo`00
o`00oa7ooooo00?o0000ooooooooool04?ooool01Ol00?ooo`00ooooooooooooo`0004oooooo00?o
0000ooooooooool05Oooool002Cooooo00?o0000ooooooooool0Boooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo013ooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0V
ooooo`;o0000C?ooool01?oo003ooooooooooooo000Wooooo`04ool00?ooooooooooool004oooooo
0_l0000Xooooo`;o0000COooool01_l00?ooo`00ooooooooooooo`00o`00oa7ooooo00?o0000oooo
ooooool04?ooool01_l00?ooo`00ooooooooooooo`00o`00odgooooo0_l0000Gooooo`009?ooool0
0ol0003oooooooooo`1<ooooo`05o`00ooooooooooooooooool00?l04_ooool00ol0003ooooooooo
o`0@ooooo`05o`00ooooooooooooooooool00?l0C_ooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo04_ooooo00Coo`00ooooooooooooo`009oooool01?oo003ooooooooooooo001@oooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0C?ooool01Ol00?ooo`00oooooooooooo
o`0001;ooooo00?o0000ooooooooool04?ooool01_l00?ooo`00ooooooooooooo`00o`00odkooooo
00?o0000ooooooooool05Oooool002Cooooo00?o0000ooooooooool0Hoooool00ol0003ooooooooo
o`0@ooooo`05o`00ooooooooooooooooool00?l0C_ooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo04_ooooo00Coo`00ooooooooooooo`009oooool01?oo003ooooooooooooo001@oooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0COooool01?oo003ooooooooooooo000B
ooooo`03o`000?oooooooooo017ooooo00Goo`00ooooooooooooo`00o`00o`1>ooooo`03o`000?oo
oooooooo01Gooooo000Tooooo`03o`000?oooooooooo04cooooo00Go003oooooooooooooooooo`00
o`0Booooo`03o`000?oooooooooo013ooooo00Go003oooooooooooooooooo`00o`1>ooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool0Boooool01?oo003ooooooooooooo000Wooooo`04
ool00?ooooooooooool0053ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1<oooo
o`05o`00oooo003ooooooooooooo00004_ooool00ol0003oooooooooo`0@ooooo`05o`00oooo003o
oooooooooooo0000Coooool00ol0003oooooooooo`0Eooooo`009?ooool00ol0003oooooooooo`1<
ooooo`05o`00ooooooooooooooooool00?l04_ooool00ol0003oooooooooo`0@ooooo`03o`00oooo
oooooooo053ooooo00?o0000ooooooooool09_ooool2o`0004cooooo00Coo`00ooooooooooooo`00
9oooool01?oo003ooooooooooooo001?ooooo`;o0000:?ooool2o`0004gooooo00Go003oool00?oo
ooooooooool0000Booooo`03o`000?oooooooooo013ooooo00Ko003oool00?ooooooooooool00?l0
0?m=ooooo`;o00005oooool002Cooooo00?o0000ooooooooool0C?ooool01Ol00?oooooooooooooo
oooo003o01;ooooo00?o0000ooooooooool05?ooool00ol00?ooooooooooo`1<ooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool0Boooool01?oo003ooooooooooooo000Wooooo`04ool0
0?ooooooooooool0053ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1<ooooo`05
o`00oooo003ooooooooooooo00004_ooool00ol0003oooooooooo`0@ooooo`06o`00oooo003ooooo
oooooooo003o003oC_ooool00ol0003oooooooooo`0Eooooo`009?ooool00ol0003oooooooooo`1S
ooooo`03o`000?oooooooooo013ooooo00Go003oooooooooooooooooo`00o`1>ooooo`03o`000?oo
oooooooo01[ooooo0ol00003ooooo`;o00001?ooool00ol0003oooooooooo`1;ooooo`04ool00?oo
ooooooooool002Oooooo00Coo`00ooooooooooooo`00D?ooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo04gooooo00Coo`00ooooooooooooo`004_ooool00ol0003oooooooooo`0Aoooo
o`05ool00?ooooooooooool00?l00?l0C_ooool00ol0003oooooooooo`0Eooooo`009?ooool00ol0
003oooooooooo`1<ooooo`05o`00ooooooooooooooooool00?l04_ooool00ol0003oooooooooo`0@
ooooo`05o`00ooooooooooooooooool00?l0C_ooool00ol0003oooooooooo`0Kooooo`05o`000?oo
ooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000004gooooo00Coo`00oooooooo
ooooo`009oooool01?oo003ooooooooooooo001@ooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool0C?ooool01Ol00?ooo`00ooooooooooooo`0001;ooooo00?o0000ooooooooool04Ooo
ool01?oo003ooooooooooooo001?ooooo`03o`000?oooooooooo01Gooooo000Tooooo`03o`000?oo
oooooooo04cooooo00Go003oooooooooooooooooo`00o`0Booooo`03o`000?oooooooooo013ooooo
00?o003oooooooooool0D?ooool00ol0003oooooooooo`0Hooooo`Go00000_ooool01?l0003ooooo
ooooool00003ooooo`03o`000?oooooooooo04_ooooo00Coo`00ooooooooooooo`009oooool01?oo
003ooooooooooooo001@ooooo`03o`000?oooooooooo02Kooooo0_l0001=ooooo`05o`00oooo003o
oooooooooooo00004_ooool00ol0003oooooooooo`0Aooooo`05ool00?ooooooooooool00?l00?l0
COooool2o`0001Oooooo000Fooooo`?o00001?ooool2o`0000Gooooo00?o0000ooooooooool0C?oo
ool01Ol00?oooooooooooooooooo003o01;ooooo00?o0000ooooooooool0Hoooool00ol0003ooooo
ooooo`0Hooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000oooool3o`00
04_ooooo00Coo`00ooooooooooooo`009oooool01?oo003ooooooooooooo001?ooooo`;o00006ooo
ool3o`0000Cooooo0_l00004ooooo`03o`000?oooooooooo04cooooo00Go003oool00?oooooooooo
ool0000Booooo`03o`000?oooooooooo017ooooo00Goo`00ooooooooooooo`00o`00o`1>ooooo`03
o`000?oooooooooo01Gooooo000Eooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00004ooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool04?ooool01Ol0
0?oooooooooooooooooo003o04kooooo00?o0000ooooooooool06Oooool00ol0003oooooo`000003
ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0Boooool01?oo003ooooooooo
oooo000Wooooo`04ool00?ooooooooooool0053ooooo00?o0000ooooooooool06?ooool01Ol0003o
oooooooooooooooo000000;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`1=
ooooo`04ool00?ooooooooooool001;ooooo00?o0000ooooooooool04Oooool01?oo003ooooooooo
oooo001?ooooo`03o`000?oooooooooo01Gooooo000Iooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooooooool00_ooool2o`0004gooooo00Go003oooooooooooooooooo`00o`0Booooo`03
o`000?oooooooooo013ooooo00Go003oooooooooooooooooo`00o`1=ooooo`;o00007?ooool2o`00
00?ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`1;ooooo`04ool00?oooooo
ooooool002Oooooo00Coo`00ooooooooooooo`00D?ooool00ol0003oooooooooo`0Looooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooooooo0_l0001=ooooo`05o`00oooo003ooooo
oooooooo00004_ooool00ol0003oooooooooo`0Aooooo`04ool00?ooooooooooool004kooooo0_l0
000Gooooo`006Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0C?ooool01Ol00?oooooooooooooooooo003o01;ooooo00?o0000ooooooooool0
4?ooool01Ol00?oooooooooooooooooo003o04kooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`02ooooo`;o00001?ooool00ol0003oooooooooo`1;ooooo`04ool00?ooooooooooool0
02Oooooo00Coo`00ooooooooooooo`00D?ooool00ol0003oooooooooo`0Looooo`04o`000?oooooo
ooooo`0000;ooooo00Go0000ooooooooooooooooo`00001>ooooo`05o`00oooo003ooooooooooooo
00004_ooool00ol0003oooooooooo`0Aooooo`04ool00?ooooooooooool004oooooo00?o0000oooo
ooooool05Oooool001Gooooo1?l00003ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooo
ooooool0C?ooool01Ol00?oooooooooooooooooo003o01;ooooo00?o0000ooooooooool0Hoooool0
0ol0003oooooooooo`0Vooooo`;o0000C?ooool01?oo003ooooooooooooo000Wooooo`04ool00?oo
ooooooooool004oooooo0_l0000Jooooo`Co00000oooool01?l0003oooooooooool00003ooooo`03
o`000?oooooooooo04gooooo00Coo`00ooooooooooooo`004_ooool00ol0003oooooooooo`0Aoooo
o`04ool00?ooooooooooool004oooooo00?o0000ooooooooool05Oooool001Gooooo00?o0000oooo
ooooool01?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo06?ooooo00?o0000
ooooooooool04?ooool01Ol00?oooooooooooooooooo003o04kooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`1;ooooo`04ool00?ooooooooooool002Oooooo00Coo`00oooooooooooo
o`00D?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooo
oooo00000oooool00ol0003oooooooooo`1=ooooo`04ool00?ooooooooooool001;ooooo00?o0000
ooooooooool04Oooool01?oo003ooooooooooooo001?ooooo`03o`000?oooooooooo01Gooooo000E
ooooo`Go00000oooool2o`0000Gooooo00?o0000ooooooooool0C?ooool01?l00?ooooooooooool0
0?lCooooo`03o`000?oooooooooo013ooooo00Go003oooooooooooooooooo`00o`1>ooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool0Boooool01?oo003ooooooooooooo000Wooooo`04
ool00?ooooooooooool0053ooooo00?o0000ooooooooool06?ooool5o`0000?ooooo0_l00004oooo
o`;o0000C_ooool00ooo003oooooool00002ool0017ooooo00?o0000ooooooooool04?ooool3ool0
0003oooooooo003ooooo04gooooo0_l0000Gooooo`009?ooool00ol0003oooooooooo`1<ooooo`04
o`00ooooooooooooo`00oa?ooooo00?o0000ooooooooool04?ooool01Ol00?oooooooooooooooooo
003o04kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1;ooooo`04ool00?oooooo
ooooool002Oooooo00Coo`00ooooooooooooo`00D?ooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo04gooooo00?oo`00oooooooo00000_oo000Aooooo`03o`000?oooooooooo013ooooo
0ooo00000oooooooo`00ooooo`1>ooooo`03o`000?oooooooooo01Gooooo000Tooooo`03o`000?oo
oooooooo04cooooo00Co003ooooooooooooo003o4oooool00ol0003oooooooooo`1Sooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool0Boooool01?oo003ooooooooooooo000Wooooo`04
ool00?ooooooooooool0053ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1<oooo
o`Koo`004Oooool00ol0003oooooooooo`0@ooooo`Koo`00C_ooool00ol0003oooooooooo`0Eoooo
o`009?ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo013ooooo00Go003ooooooooo
ooooooooo`00o`1>ooooo`03o`000?oooooooooo02Kooooo0_l0001<ooooo`04ool00?oooooooooo
ool002Oooooo00Coo`00ooooooooooooo`00Coooool2o`0002Sooooo00?o0000ooooooooool0C?oo
ool3ool001Cooooo00?o0000ooooooooool04oooool3ool004kooooo00?o0000ooooooooool05Ooo
ool002Cooooo00?o0000ooooooooool0C?ooool01?l00?ooooooooooool00?lCooooo`03o`000?oo
oooooooo013ooooo00Go003oooooooooooooooooo`00o`1>ooooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool0Boooool01?oo003ooooooooooooo000Wooooo`04ool00?ooooooooooool0
053ooooo00?o0000ooooooooool09_ooool2o`0004gooooo0ooo00000ooooooo003oooooo`0Aoooo
o`03o`000?oooooooooo017ooooo00?o003ooooooooo00000_oo001=ooooo`;o00005oooool002Co
oooo00?o0000ooooooooool0C?ooool01?l00?ooooooooooool00?lCooooo`03o`000?oooooooooo
017ooooo00Co003ooooooooooooo003oC_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo04_ooooo00Coo`00ooooooooooooo`009oooool01?oo003ooooooooooooo001@ooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool0COooool01?l00?ooooooooooool00?lBooooo`03
o`000?oooooooooo017ooooo00Co003ooooooooooooo003oCoooool00ol0003oooooooooo`0Eoooo
o`009?ooool00ol0003oooooooooo`1<ooooo`04o`00ooooooooooooo`00oa?ooooo00?o0000oooo
ooooool0Hoooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo04_ooooo00Coo`00oooo
ooooooooo`009oooool01?oo003ooooooooooooo001@ooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool0COooool01?l00?ooooooooooool00?lBooooo`03o`000?oooooooooo017ooooo
00Co003ooooooooooooo003oCoooool00ol0003oooooooooo`0Eooooo`009?ooool00ol0003ooooo
ooooo`1Sooooo`03o`000?oooooooooo017ooooo00Co003ooooooooooooo003oC_ooool00ol0003o
ooooooooo`0Vooooo`;o0000C?ooool01?oo003ooooooooooooo000Wooooo`04ool00?oooooooooo
ool004oooooo0_l0000Xooooo`03o`000?oooooooooo04gooooo00?o003oooooooooool04oooool0
0ol0003oooooooooo`0Dooooo`03o`00oooooooooooo04gooooo00?o0000ooooooooool05Oooool0
02Cooooo00?o0000ooooooooool0C?ooool01?l00?ooooooooooool00?lCooooo`03o`000?oooooo
oooo017ooooo00Co003ooooooooooooo003oC_ooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooooooo04_ooooo00Coo`00ooooooooooooo`009oooool01?oo003ooooooooooooo001@ooooo`03
o`000?oooooooooo02Kooooo0_l0001Aooooo`03o`00oooooooooooo013ooooo00?o0000oooooooo
ool04Oooool00ol00?ooooooooooo`1?ooooo`;o00005oooool002Cooooo00?o0000ooooooooool0
C?ooool01?l00?ooooooooooool00?lCooooo`03o`000?oooooooooo017ooooo00?o003oooooool0
0?l0Coooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo04_ooooo00Coo`00oooooooo
ooooo`009oooool01?oo003ooooooooooooo001@ooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool0COooool01?l00?ooooooooooool00?lBooooo`03o`000?oooooooooo017ooooo00Co
003ooooooooooooo003oCoooool00ol0003oooooooooo`0Eooooo`009?ooool00ol0003ooooooooo
o`1=ooooo`03o`00oooooooo003o01?ooooo00?o0000ooooooooool0Hoooool00ol0003ooooooooo
o`0Vooooo`03o`000?oooooooooo04_ooooo00Coo`00ooooooooooooo`009oooool01?oo003ooooo
oooooooo001@ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0COooool01?l00?oo
ooooooooool00?lBooooo`03o`000?oooooooooo017ooooo00Co003ooooooooooooo003oCoooool0
0ol0003oooooooooo`0Eooooo`009?ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo
017ooooo00?o003oooooool00?l0Coooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
04_ooooo00Coo`00ooooooooooooo`009oooool01?oo003ooooooooooooo001@ooooo`03o`000?oo
oooooooo02Kooooo0_l0001>ooooo`03o`00oooooooooooo01?ooooo00?o0000ooooooooool05?oo
ool00ol00?ooooooooooo`1<ooooo`;o00005oooool001Kooooo0ol00004ooooo`;o00001Oooool0
0ol0003oooooooooo`1=ooooo`03o`00oooooooo003o01?ooooo00?o0000ooooooooool04Oooool0
0ol00?ooooooo`00o`1?ooooo`03o`000?oooooooooo02Kooooo0_l0001<ooooo`04ool00?oooooo
ooooool002Oooooo00Coo`00ooooooooooooo`00Coooool2o`0001_ooooo0ol00004ooooo`;o0000
1?ooool00ol0003oooooooooo`1?ooooo`03o`00oooooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol00?ooooooooooo`1@ooooo`03o`000?oooooooooo01Gooooo000Eooooo`05o`000?oo
ooooooooooooool000000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo04go
oooo00?o003oooooool00?l04oooool00ol0003oooooooooo`0Aooooo`03o`00oooooooo003o04oo
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1;ooooo`04ool00?ooooooooooool0
02Oooooo00Coo`00ooooooooooooo`00D?ooool00ol0003oooooooooo`0Hooooo`05o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo04gooooo
00?o003oooooool00?l04oooool00ol0003oooooooooo`0Aooooo`03o`00oooooooooooo053ooooo
00?o0000ooooooooool05Oooool001Gooooo00Go0000ooooooooooooooooo`000002ooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool0COooool00ol00?ooooooo`00o`0Cooooo`03
o`000?oooooooooo06?ooooo00?o0000ooooooooool06Oooool3o`0000Cooooo0_l00004ooooo`03
o`000?oooooooooo04_ooooo00Coo`00ooooooooooooo`009oooool01?oo003ooooooooooooo001@
ooooo`03o`000?oooooooooo01Sooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool0COooool00ol00?ooooooo`00o`0Cooooo`03o`00
0?oooooooooo01;ooooo00?o003oooooool00?l0Coooool00ol0003oooooooooo`0Eooooo`005Ooo
ool4o`0000?ooooo00Co0000oooooooooooo00001?ooool2o`0006Cooooo00?o0000ooooooooool0
4Oooool00ol00?ooooooo`00o`1>ooooo`;o00006_ooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`1;ooooo`04ool00?oooooooooo
ool002Oooooo00Coo`00ooooooooooooo`00D?ooool00ol0003oooooooooo`0Hooooo`Co00000ooo
ool01?l0003oooooooooool00003ooooo`;o0000C_ooool00ol00?ooooooooooo`0Cooooo`03o`00
0?oooooooooo01Cooooo00?o003oooooooooool0C?ooool2o`0001Oooooo000Eooooo`03o`000?oo
oooooooo00Cooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1=ooooo`03o`00
oooooooo003o01?ooooo00?o0000ooooooooool04Oooool00ol00?ooooooo`00o`1?ooooo`03o`00
0?oooooooooo01cooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooooooool3o`00
04_ooooo00Coo`00ooooooooooooo`009oooool01?oo003ooooooooooooo001?ooooo`;o00006_oo
ool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0
Coooool00ol00?ooooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o003oooooool00?l0
Coooool00ol0003oooooooooo`0Eooooo`005_ooool00ol0003oooooooooo`03ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool0COooool00ol00?ooooooo`00o`0Cooooo`03o`00
0?oooooooooo017ooooo00?o003oooooool00?l0Coooool00ol0003oooooooooo`0Looooo`04o`00
0?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`00001=ooooo`04ool00?oooooooooo
ool002Oooooo00Coo`00ooooooooooooo`00D?ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo00?ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`1=ooooo`03o`00
oooooooo003o01?ooooo00?o0000ooooooooool04_ooool00ol00?ooooooooooo`1?ooooo`03o`00
0?oooooooooo01Gooooo000Gooooo`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool0COoo
ool00ol00?ooooooo`00o`0Cooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool06?oo
ool4o`0000?ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`1;ooooo`04ool0
0?ooooooooooool002Oooooo00Coo`00ooooooooooooo`00D?ooool00ol0003oooooooooo`0Joooo
o`;o00001?ooool2o`0000Cooooo00?o0000ooooooooool0COooool00ol00?ooooooo`00o`0Coooo
o`03o`000?oooooooooo01;ooooo0_l00?m@ooooo`03o`000?oooooooooo01Gooooo000Tooooo`03
o`000?oooooooooo06?ooooo00?o0000ooooooooool04Oooool00ol00?ooooooo`00o`1?ooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00003oooo
o`03o`000?oooooooooo04_ooooo00Coo`00ooooooooooooo`009oooool01?oo003ooooooooooooo
001@ooooo`03o`000?oooooooooo02Kooooo0_l0001?ooooo`03o`00oooooooooooo01;ooooo00?o
0000ooooooooool04oooool00ol00?ooooooooooo`1=ooooo`;o00005oooool002Cooooo00?o0000
ooooooooool0Hoooool00ol0003oooooooooo`0Aooooo`03o`00oooooooo003o04oooooo00?o0000
ooooooooool06?ooool5o`0000?ooooo0_l00004ooooo`03o`000?oooooooooo04_ooooo00Coo`00
ooooooooooooo`009oooool01?oo003ooooooooooooo001@ooooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool0C_ooool2o`00oa?ooooo00?o0000ooooooooool04oooool00ol00?oooooo
ooooo`1>ooooo`03o`000?oooooooooo01Gooooo000Tooooo`03o`000?oooooooooo04kooooo00?o
003oooooooooool04_ooool00ol0003oooooooooo`0Aooooo`03o`00oooooooo003o04oooooo00?o
0000ooooooooool09_ooool2o`0004cooooo00?oo`00oooooooo00000_oo000Uooooo`?oo`0000?o
ooooool00?ooool0C_ooool2o`0002Sooooo00?o0000ooooooooool0Coooool00ol00?oooooooooo
o`0Aooooo`03o`000?oooooooooo01;ooooo00?o003oooooooooool0Coooool00ol0003ooooooooo
o`0Eooooo`009?ooool00ol0003oooooooooo`1=ooooo`;o003o5?ooool00ol0003oooooooooo`1S
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0Boooool00ooo003oooooool00002
ool002Gooooo0ooo00000oooooooo`00ooooo`1?ooooo`03o`000?oooooooooo02Kooooo0_l0001?
ooooo`;o003o4oooool00ol0003oooooooooo`0Booooo`;o003oCoooool2o`0001Oooooo000Toooo
o`03o`000?oooooooooo04gooooo0_l00?lDooooo`03o`000?oooooooooo01;ooooo00?o003ooooo
ooooool0C_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo04[ooooo1_oo000Uoooo
o`Koo`00Coooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo04kooooo00?o003ooooo
ooooool04_ooool00ol0003oooooooooo`0Booooo`;o003oD?ooool00ol0003oooooooooo`0Eoooo
o`009?ooool00ol0003oooooooooo`1>ooooo`03o`00oooooooooooo01;ooooo00?o0000oooooooo
ool04_ooool00ol00?ooooooooooo`1>ooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool0B_ooool3ool002_ooooo0ooo001?ooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool0C_ooool00ol00?ooooooooooo`0Booooo`03o`000?oooooooooo01?ooooo00?o003ooooooooo
ool0C_ooool00ol0003oooooooooo`0Eooooo`009?ooool00ol0003oooooooooo`1Sooooo`03o`00
0?oooooooooo06?ooooo00?o0000ooooooooool09_ooool2o`0004_ooooo0ooo000[ooooo`?oo`00
C_ooool2o`0002Sooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`1Tooooo`03o`00
0?oooooooooo01Gooooo000Tooooo`05o`000?ooooooooooooooool000002Oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool09_ooool00ol0003ooooo
o`000009ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0Vooooo`;o00000oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00Co0000oooooooooooooooo0_l0000Gooooo`009?ooooo=o`0002Soooooc_l0000Xooooolko0000
5oooool00?ooooooooooooofooooo`00ooooooooooooooKooooo003ooooooooooooom_ooool00001
\
\>"],
  ImageRangeCache->{{{0, 755}, {145, 0}} -> {-0.0839304, -0.0144882, \
0.00419585, 0.00419585}, {{20, 243.438}, {141.5, 3.4375}} -> {-14.2028, \
-9.64816, 0.102596, 0.537987}, {{265.75, 489.188}, {141.5, 3.4375}} -> \
{-38.5921, -8.02158, 0.100886, 0.443887}, {{511.562, 734.938}, {141.5, \
3.4375}} -> {-64.6319, -9.73317, 0.102596, 0.538601}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Show all", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Show[gw1];\)\), "\[IndentingNewLine]", 
    \(\(Show[gw2];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .19314 
%%ImageSize: 756 146.011 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.00459847 0.31746 [
[ 0 0 0 0 ]
[ 1 .19314 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .19314 L
0 .19314 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00459847 0.321429 0.188537 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.047619 0.0108341 0.00484525 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01083 -6 -4.5 ]
[-0.0125 .01083 0 4.5 ]
[-0.0125 .10774 -12 -4.5 ]
[-0.0125 .10774 0 4.5 ]
[-0.0125 .20464 -12 -4.5 ]
[-0.0125 .20464 0 4.5 ]
[-0.0125 .30155 -12 -4.5 ]
[-0.0125 .30155 0 4.5 ]
[-0.0125 .39845 -12 -4.5 ]
[-0.0125 .39845 0 4.5 ]
[-0.0125 .49536 -18 -4.5 ]
[-0.0125 .49536 0 4.5 ]
[-0.0125 .59226 -18 -4.5 ]
[-0.0125 .59226 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01083 m
.00625 .01083 L
s
[(0)] -0.0125 .01083 1 0 Mshowa
0 .10774 m
.00625 .10774 L
s
[(20)] -0.0125 .10774 1 0 Mshowa
0 .20464 m
.00625 .20464 L
s
[(40)] -0.0125 .20464 1 0 Mshowa
0 .30155 m
.00625 .30155 L
s
[(60)] -0.0125 .30155 1 0 Mshowa
0 .39845 m
.00625 .39845 L
s
[(80)] -0.0125 .39845 1 0 Mshowa
0 .49536 m
.00625 .49536 L
s
[(100)] -0.0125 .49536 1 0 Mshowa
0 .59226 m
.00625 .59226 L
s
[(120)] -0.0125 .59226 1 0 Mshowa
.125 Mabswid
0 .03506 m
.00375 .03506 L
s
0 .05929 m
.00375 .05929 L
s
0 .08351 m
.00375 .08351 L
s
0 .13197 m
.00375 .13197 L
s
0 .15619 m
.00375 .15619 L
s
0 .18042 m
.00375 .18042 L
s
0 .22887 m
.00375 .22887 L
s
0 .2531 m
.00375 .2531 L
s
0 .27732 m
.00375 .27732 L
s
0 .32578 m
.00375 .32578 L
s
0 .35 m
.00375 .35 L
s
0 .37423 m
.00375 .37423 L
s
0 .42268 m
.00375 .42268 L
s
0 .44691 m
.00375 .44691 L
s
0 .47113 m
.00375 .47113 L
s
0 .51959 m
.00375 .51959 L
s
0 .54381 m
.00375 .54381 L
s
0 .56804 m
.00375 .56804 L
s
0 .61649 m
.00375 .61649 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01083 m
1 .01083 L
s
.99375 .10774 m
1 .10774 L
s
.99375 .20464 m
1 .20464 L
s
.99375 .30155 m
1 .30155 L
s
.99375 .39845 m
1 .39845 L
s
.99375 .49536 m
1 .49536 L
s
.99375 .59226 m
1 .59226 L
s
.125 Mabswid
.99625 .03506 m
1 .03506 L
s
.99625 .05929 m
1 .05929 L
s
.99625 .08351 m
1 .08351 L
s
.99625 .13197 m
1 .13197 L
s
.99625 .15619 m
1 .15619 L
s
.99625 .18042 m
1 .18042 L
s
.99625 .22887 m
1 .22887 L
s
.99625 .2531 m
1 .2531 L
s
.99625 .27732 m
1 .27732 L
s
.99625 .32578 m
1 .32578 L
s
.99625 .35 m
1 .35 L
s
.99625 .37423 m
1 .37423 L
s
.99625 .42268 m
1 .42268 L
s
.99625 .44691 m
1 .44691 L
s
.99625 .47113 m
1 .47113 L
s
.99625 .51959 m
1 .51959 L
s
.99625 .54381 m
1 .54381 L
s
.99625 .56804 m
1 .56804 L
s
.99625 .61649 m
1 .61649 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
0 0 1 r
.5 Mabswid
[ .01 ] 0 setdash
.02381 .03991 m
.02395 .03989 L
.02408 .03987 L
.02423 .03981 L
.02437 .03973 L
.02462 .03954 L
.02489 .03926 L
.02519 .03886 L
.02551 .03833 L
.02608 .03711 L
.02722 .03375 L
.02847 .02882 L
.02973 .02297 L
.03043 .01967 L
.03077 .01816 L
.03109 .01694 L
.03125 .01645 L
.03139 .01609 L
.03147 .01593 L
.03156 .0158 L
.03171 .01569 L
.03179 .01569 L
.03188 .01574 L
.03197 .01584 L
.03206 .01598 L
.03221 .01634 L
.03238 .01685 L
.03299 .01933 L
.03355 .02196 L
.03476 .02765 L
.03605 .03294 L
.03714 .03644 L
.03777 .03793 L
.03805 .03847 L
.03836 .03897 L
.03863 .03933 L
.03892 .03963 L
.03908 .03975 L
.03923 .03984 L
.03938 .0399 L
.03952 .03994 L
.03965 .03995 L
.03978 .03995 L
.0399 .03993 L
.04003 .03989 L
.04017 .03983 L
.04031 .03974 L
.04058 .03952 L
.04089 .03917 L
.04122 .03867 L
Mistroke
.04183 .03745 L
.04243 .03592 L
.04298 .0342 L
.04525 .02473 L
.04644 .01908 L
.04673 .01784 L
.04705 .01671 L
.04722 .0162 L
.04731 .01602 L
.04739 .01588 L
.04746 .01578 L
.04755 .01571 L
.0477 .01571 L
.04778 .01577 L
.04786 .01588 L
.04802 .01618 L
.04819 .01667 L
.04836 .01723 L
.04905 .02021 L
.05029 .02612 L
.05155 .03161 L
.05217 .0339 L
.05273 .03571 L
.05326 .03716 L
.05383 .03843 L
.05415 .03897 L
.05444 .03938 L
.05472 .03969 L
.05487 .03982 L
.05501 .03992 L
.05517 .04001 L
.05531 .04006 L
.05546 .04009 L
.05555 .0401 L
.05563 .0401 L
.05576 .04008 L
.05591 .04004 L
.05606 .03997 L
.0562 .03988 L
.05653 .03959 L
.05683 .03922 L
.05716 .03871 L
.05751 .03804 L
.05866 .03497 L
.05989 .03041 L
.0621 .02014 L
.0627 .01752 L
.063 .01649 L
.06309 .01627 L
.06318 .01607 L
Mistroke
.06326 .01592 L
.06334 .01581 L
.06342 .01574 L
.06351 .01572 L
.0636 .01575 L
.06369 .01584 L
.06378 .01598 L
.06387 .01616 L
.06403 .01658 L
.06434 .01767 L
.06467 .01909 L
.06583 .02463 L
.0671 .03043 L
.06827 .03483 L
.0689 .03677 L
.06951 .03824 L
.06984 .03889 L
.0702 .03946 L
.07052 .03985 L
.07068 .04 L
.07082 .04012 L
.07096 .0402 L
.07111 .04027 L
.07119 .0403 L
.07127 .04032 L
.07142 .04034 L
.07158 .04033 L
.07172 .0403 L
.0718 .04027 L
.07188 .04024 L
.07205 .04015 L
.0722 .04004 L
.07233 .03992 L
.07264 .03957 L
.07294 .03913 L
.07326 .03855 L
.07437 .03573 L
.07504 .03346 L
.07568 .03096 L
.07688 .02557 L
.07804 .01996 L
.07837 .01845 L
.07868 .01719 L
.07882 .01672 L
.07897 .01631 L
.07912 .01598 L
.07927 .0158 L
.07941 .01576 L
.07954 .01584 L
.07968 .01606 L
Mistroke
.07982 .01638 L
.08006 .01715 L
.08033 .0182 L
.08149 .0237 L
.08262 .02905 L
.08383 .03402 L
.08453 .03633 L
.08517 .03805 L
.08547 .03874 L
.08581 .03937 L
.0861 .03982 L
.08642 .04021 L
.08658 .04037 L
.08674 .04048 L
.08689 .04057 L
.08704 .04064 L
.08718 .04068 L
.08731 .04069 L
.08745 .04068 L
.08761 .04065 L
.08769 .04062 L
.08777 .04059 L
.08795 .04048 L
.08811 .04036 L
.08827 .0402 L
.08856 .03985 L
.08888 .03936 L
.08944 .03821 L
.09006 .03661 L
.09116 .03281 L
.09353 .02194 L
.09418 .01884 L
.09454 .01736 L
.09471 .01675 L
.09487 .0163 L
.09503 .016 L
.0951 .0159 L
.09519 .01583 L
.09527 .01582 L
.09536 .01585 L
.09545 .01594 L
.09553 .01606 L
.09567 .01638 L
.09583 .01685 L
.09612 .01793 L
.09863 .02991 L
.09972 .03438 L
.1009 .03809 L
.10154 .03952 L
.10182 .04001 L
Mistroke
.10212 .04045 L
.10241 .04077 L
.10255 .04089 L
.10268 .04098 L
.10283 .04106 L
.10297 .04111 L
.10312 .04114 L
.10328 .04115 L
.10343 .04112 L
.10358 .04108 L
.10366 .04104 L
.10374 .041 L
.10391 .04088 L
.10424 .04055 L
.10459 .04008 L
.10517 .03899 L
.10581 .03739 L
.10705 .03313 L
.10817 .0282 L
.10949 .0217 L
.11007 .01892 L
.11037 .01761 L
.11054 .01699 L
.1107 .0165 L
.11085 .01617 L
.11101 .01594 L
.11115 .01589 L
.11128 .01596 L
.11141 .01615 L
.11155 .01646 L
.11169 .01688 L
.11183 .01736 L
.11302 .02296 L
.11424 .02902 L
.11553 .03456 L
.11669 .03836 L
.11735 .03993 L
.11766 .04051 L
.11796 .04096 L
.11823 .04128 L
.11837 .04141 L
.11852 .04153 L
.11865 .04161 L
.11879 .04167 L
.11892 .04171 L
.11904 .04173 L
.11919 .04173 L
.11933 .0417 L
.11945 .04166 L
.11959 .04159 L
Mistroke
.11974 .04149 L
.1199 .04136 L
.12019 .04104 L
.1205 .04059 L
.12084 .03999 L
.12143 .03861 L
.12207 .03672 L
.12277 .03418 L
.12405 .02858 L
.12521 .02275 L
.12578 .01984 L
.12609 .01842 L
.12641 .01713 L
.12655 .01669 L
.1267 .01632 L
.12678 .01616 L
.12686 .01606 L
.12701 .01597 L
.12714 .01603 L
.12728 .01622 L
.12742 .01655 L
.12756 .01696 L
.1282 .01966 L
.12878 .0226 L
.13008 .02923 L
.13121 .03428 L
.1324 .03849 L
.13302 .04013 L
.13335 .04083 L
.1337 .04145 L
.13403 .04188 L
.13432 .04217 L
.13447 .04227 L
.13462 .04236 L
.13477 .04241 L
.1349 .04244 L
.13506 .04244 L
.13514 .04243 L
.13522 .04241 L
.13538 .04235 L
.13552 .04228 L
.13569 .04215 L
.13584 .04201 L
.13618 .04159 L
.13648 .04112 L
.1368 .04049 L
.13739 .03906 L
.13855 .03513 L
.13963 .03043 L
.14072 .02495 L
Mistroke
.14189 .01896 L
.14223 .01749 L
.1424 .0169 L
.14256 .01647 L
.1427 .01621 L
.14285 .01608 L
.14294 .01608 L
.14302 .01614 L
.14317 .01636 L
.14332 .01672 L
.14347 .01721 L
.14375 .01832 L
.14437 .02139 L
.1456 .02789 L
.14677 .03352 L
.1479 .03801 L
.1484 .0396 L
.14895 .04104 L
.1495 .04213 L
.1498 .04258 L
.15008 .04291 L
.15023 .04304 L
.15038 .04315 L
.15052 .04322 L
.15067 .04328 L
.15082 .0433 L
.15091 .0433 L
.15099 .0433 L
.15115 .04326 L
.1513 .04319 L
.15145 .0431 L
.15161 .04298 L
.15193 .04262 L
.15223 .04218 L
.15251 .04167 L
.15314 .04018 L
.15382 .03809 L
.15504 .03318 L
.15637 .02654 L
.15703 .02301 L
.15765 .01977 L
.15792 .01848 L
.1582 .01732 L
.15835 .01684 L
.15843 .01663 L
.15851 .01644 L
.15866 .01624 L
.1588 .0162 L
.15896 .01633 L
.1591 .01662 L
Mistroke
.15918 .01682 L
.15927 .01708 L
.15944 .01771 L
.16004 .02057 L
.16117 .02674 L
.16249 .03351 L
.1637 .03858 L
.16429 .04054 L
.16484 .04202 L
.16541 .04318 L
.16572 .04364 L
.16604 .044 L
.16621 .04414 L
.16636 .04424 L
.16645 .04427 L
.16654 .0443 L
.16663 .04433 L
.16672 .04434 L
.1668 .04434 L
.16688 .04433 L
.16703 .04429 L
.16718 .04422 L
.16727 .04417 L
.16736 .04411 L
.16766 .04382 L
.16794 .04346 L
.16856 .04231 L
.16915 .04077 L
.16977 .03873 L
.17088 .03409 L
.1721 .0279 L
.17277 .0242 L
.1734 .02071 L
.17369 .01923 L
.17399 .01783 L
.17415 .01724 L
.17424 .01697 L
.17433 .01673 L
.17441 .01655 L
.17449 .01644 L
.17464 .01634 L
.17478 .01642 L
.17492 .01663 L
.17506 .01701 L
.17522 .01754 L
.17577 .02011 L
.17799 .03236 L
.17923 .03817 L
.17988 .04064 L
.18057 .04275 L
Mistroke
.18117 .04414 L
.18151 .04472 L
.18168 .04495 L
.18183 .04513 L
.18198 .04527 L
.18213 .04539 L
.18227 .04547 L
.1824 .04553 L
.18254 .04556 L
.18269 .04557 L
.18277 .04556 L
.18285 .04554 L
.183 .04549 L
.18315 .0454 L
.18329 .0453 L
.1836 .04498 L
.18388 .04456 L
.18415 .04408 L
.18476 .04266 L
.18542 .04062 L
.18674 .03508 L
.18796 .02863 L
.18905 .02233 L
.18965 .01908 L
.18995 .01775 L
.19009 .01724 L
.19022 .01687 L
.19038 .01659 L
.19046 .01652 L
.19055 .01651 L
.19063 .01656 L
.19071 .01666 L
.1908 .01683 L
.1909 .01706 L
.19105 .01757 L
.19119 .01814 L
.19151 .01969 L
.19271 .02665 L
.19496 .03867 L
.19558 .04122 L
.19624 .04347 L
.1968 .04497 L
.1971 .04562 L
.19741 .04617 L
.19757 .0464 L
.19774 .04661 L
.1979 .04676 L
.19805 .04687 L
.19813 .04693 L
.19822 .04697 L
Mistroke
.19832 .047 L
.1984 .04703 L
.19849 .04704 L
.19858 .04704 L
.19874 .04701 L
.19888 .04696 L
.19904 .04686 L
.19919 .04674 L
.19933 .04661 L
.19966 .04617 L
.19998 .04561 L
.20058 .04419 L
.20114 .04245 L
.20241 .03718 L
.20358 .03093 L
.20484 .02334 L
.20543 .01996 L
.20574 .01838 L
.2059 .01773 L
.20604 .01726 L
.20617 .01694 L
.20629 .01675 L
.20642 .0167 L
.20656 .01682 L
.20671 .0171 L
.20686 .01758 L
.20714 .01875 L
.20933 .03186 L
.21054 .0385 L
.21168 .04352 L
.21227 .04551 L
.21258 .04638 L
.21292 .04716 L
.21322 .04775 L
.2135 .04818 L
.21363 .04834 L
.21378 .04849 L
.21391 .0486 L
.21404 .04869 L
.21418 .04875 L
.21431 .04878 L
.21446 .04879 L
.2146 .04877 L
.21475 .04872 L
.2149 .04863 L
.21505 .04851 L
.21519 .04837 L
.21544 .04806 L
.2157 .04761 L
.21625 .04641 L
Mistroke
.21684 .04463 L
.21747 .04227 L
.21858 .03693 L
.2198 .02981 L
.22047 .02556 L
.2211 .02159 L
.22139 .0199 L
.2217 .01835 L
.22186 .01771 L
.22195 .01744 L
.22204 .0172 L
.22212 .01704 L
.2222 .01696 L
.22235 .01695 L
.22249 .01714 L
.22263 .01747 L
.22277 .01799 L
.22293 .01868 L
.22348 .02179 L
.2257 .03596 L
.22694 .0426 L
.2276 .04542 L
.22829 .04781 L
.22889 .04937 L
.22924 .05002 L
.2294 .05026 L
.22956 .05046 L
.2297 .05061 L
.22985 .05074 L
.22999 .05082 L
.23012 .05087 L
.23026 .0509 L
.23041 .0509 L
.23049 .05088 L
.23057 .05085 L
.23072 .05078 L
.2308 .05072 L
.23088 .05066 L
.23103 .05052 L
.23135 .05009 L
.23163 .04958 L
.23194 .0489 L
.23263 .04686 L
.23327 .0444 L
.23445 .03852 L
.23569 .03082 L
.23683 .02313 L
.23713 .02119 L
.23746 .0193 L
.23761 .01856 L
Mistroke
.23777 .01791 L
.23791 .0175 L
.23806 .01724 L
.23821 .0172 L
.23834 .01736 L
.23849 .01774 L
.23865 .01834 L
.23892 .01967 L
.23921 .02143 L
.24027 .02867 L
.24159 .03753 L
.24283 .04461 L
.24395 .04939 L
.24425 .0504 L
.24458 .05132 L
.24488 .05204 L
.24516 .05257 L
.24529 .05279 L
.24544 .05299 L
.24559 .05315 L
.24572 .05327 L
.24587 .05337 L
.24595 .05341 L
.24603 .05344 L
.24617 .05346 L
.24632 .05346 L
.24645 .05342 L
.24659 .05335 L
.24674 .05324 L
.24688 .0531 L
.24713 .05277 L
.2474 .05232 L
.24772 .05162 L
.24806 .05069 L
.24869 .04853 L
.24986 .04299 L
.25221 .02755 L
.25285 .02295 L
.25318 .02072 L
.25337 .01963 L
.25354 .01875 L
.25369 .01813 L
.25377 .01787 L
.25385 .01768 L
.25393 .01755 L
.25402 .01749 L
.25411 .01752 L
.25419 .01761 L
.25433 .01794 L
.25448 .0185 L
Mistroke
.25479 .02011 L
.25727 .03804 L
.25835 .04499 L
.25953 .05097 L
.26015 .05334 L
.26043 .05419 L
.26073 .05498 L
.261 .05555 L
.26129 .05603 L
.26144 .05623 L
.26159 .05638 L
.26173 .05649 L
.26188 .05657 L
.26203 .05661 L
.26218 .05661 L
.26226 .05659 L
.26234 .05656 L
.2625 .05648 L
.26265 .05636 L
.2628 .05619 L
.26308 .05578 L
.2634 .05514 L
.26371 .05438 L
.2644 .05207 L
.265 .04945 L
.26565 .04598 L
.26684 .03826 L
.26799 .02955 L
.26855 .02513 L
.26907 .02131 L
.26936 .01955 L
.26952 .01875 L
.26967 .0182 L
.26982 .01789 L
.26991 .01784 L
.26999 .01787 L
.27007 .01798 L
.27016 .01818 L
.27024 .01846 L
.27032 .01877 L
.27058 .02016 L
.27086 .0221 L
.27145 .02662 L
.27277 .03732 L
.27398 .04617 L
.27511 .0529 L
.27568 .05556 L
.27631 .05786 L
.27664 .0588 L
.27694 .05948 L
Mistroke
.27711 .05979 L
.27729 .06007 L
.27746 .06027 L
.27761 .06041 L
.27776 .0605 L
.27789 .06055 L
.27804 .06056 L
.27812 .06055 L
.2782 .06052 L
.27835 .06044 L
.27844 .06038 L
.27852 .06031 L
.27882 .05992 L
.27898 .05965 L
.27914 .05932 L
.27944 .05861 L
.2801 .05641 L
.28068 .05387 L
.2813 .05046 L
.28355 .03391 L
.28413 .02893 L
.28476 .02361 L
.28505 .02141 L
.28521 .02034 L
.28536 .01948 L
.28548 .0189 L
.28562 .01846 L
.28577 .01825 L
.28591 .01833 L
.28599 .01849 L
.28607 .01875 L
.28622 .01939 L
.28639 .02042 L
.28655 .02153 L
.28723 .02716 L
.28843 .03797 L
.28956 .04735 L
.29075 .05563 L
.29137 .05908 L
.29206 .06209 L
.29236 .06313 L
.29268 .06405 L
.29298 .06473 L
.29313 .06499 L
.29326 .06519 L
.2934 .06536 L
.29354 .06548 L
.29368 .06558 L
.29384 .06563 L
.29398 .06563 L
Mistroke
.29414 .06558 L
.29422 .06553 L
.2943 .06547 L
.29445 .06532 L
.2946 .06514 L
.29475 .06489 L
.29503 .06431 L
.29556 .06278 L
.29619 .06021 L
.29686 .05664 L
.29806 .04829 L
.29929 .03768 L
.30045 .02662 L
.30095 .02217 L
.3011 .02107 L
.30123 .02017 L
.30136 .01951 L
.30149 .019 L
.30164 .01874 L
.3018 .01885 L
.30193 .01925 L
.30208 .01997 L
.30222 .02085 L
.30236 .02195 L
.30263 .02423 L
.30497 .04736 L
.30628 .05841 L
.30749 .06613 L
.30809 .06887 L
.30839 .06998 L
.30872 .07095 L
.30889 .07136 L
.30905 .07167 L
.30921 .07193 L
.30935 .07212 L
.30944 .07221 L
.30952 .07227 L
.3096 .07233 L
.30969 .07237 L
.30978 .07238 L
.30988 .07238 L
.30997 .07236 L
.31005 .07232 L
.31019 .07223 L
.31034 .07207 L
.31049 .07187 L
.31062 .07165 L
.31093 .07094 L
.31123 .07005 L
.31183 .06765 L
Mistroke
.31248 .06414 L
.31373 .05495 L
.31486 .04428 L
.31618 .0301 L
.31676 .02406 L
.31692 .02259 L
.31709 .02122 L
.31717 .02065 L
.31725 .02018 L
.31739 .01956 L
.31753 .01931 L
.31767 .01944 L
.3178 .01987 L
.31794 .02063 L
.31808 .02171 L
.31824 .0231 L
.31852 .02598 L
.31972 .03975 L
.32102 .05436 L
.32223 .06595 L
.32345 .07482 L
.32409 .07815 L
.32445 .07957 L
.32478 .08056 L
.32493 .08093 L
.32509 .08125 L
.32523 .08148 L
.32538 .08166 L
.32546 .08174 L
.32554 .08179 L
.32563 .08183 L
.32572 .08185 L
.32587 .08184 L
.32595 .0818 L
.32603 .08175 L
.32617 .08162 L
.3263 .08145 L
.32644 .08121 L
.3266 .08088 L
.32691 .08002 L
.3272 .07898 L
.32778 .07629 L
.32839 .07246 L
.32949 .06328 L
.33198 .03406 L
.33258 .02651 L
.33274 .02468 L
.33291 .0229 L
.33307 .02152 L
.33322 .02055 L
Mistroke
.3333 .0202 L
.33339 .02001 L
.33355 .02016 L
.33364 .02052 L
.33374 .0211 L
.33391 .02256 L
.33425 .02631 L
.33455 .03026 L
.33699 .06338 L
.33812 .07639 L
.33931 .08704 L
.33993 .09111 L
.34029 .09291 L
.34062 .09425 L
.34078 .09476 L
.34092 .09518 L
.34106 .09549 L
.3412 .09577 L
.34136 .09599 L
.3415 .09612 L
.34165 .0962 L
.34174 .0962 L
.34182 .09618 L
.34196 .0961 L
.34212 .09594 L
.34226 .09571 L
.34239 .09545 L
.34271 .09457 L
.34301 .09343 L
.34361 .09026 L
.34426 .08553 L
.34542 .07387 L
.34649 .05993 L
.34759 .04328 L
.34819 .03361 L
.34876 .02508 L
.34892 .02319 L
.349 .02232 L
.34908 .02166 L
.34917 .02114 L
.34926 .02085 L
.34935 .02084 L
.34943 .0211 L
.34959 .02215 L
.34967 .02293 L
.34975 .02392 L
.35005 .02807 L
.35125 .04897 L
.35257 .07195 L
.35381 .09115 L
Mistroke
.35493 .10509 L
.35556 .11124 L
.35614 .11566 L
.35641 .11729 L
.3567 .11872 L
.35697 .11975 L
.35709 .12012 L
.35722 .12043 L
.35738 .12072 L
.35752 .1209 L
.3576 .12096 L
.35769 .121 L
.35784 .12098 L
.35798 .12088 L
.35812 .1207 L
.35827 .12042 L
.35842 .12002 L
.35871 .119 L
.35902 .1175 L
.35957 .11376 L
.36024 .10758 L
.36084 .10035 L
.36334 .05634 L
.36444 .0324 L
.36474 .02645 L
.36482 .02505 L
.36491 .02377 L
.36506 .0222 L
.36521 .02186 L
.36534 .02264 L
.36549 .02453 L
.36565 .02734 L
.36789 .08306 L
.37027 .13762 L
.37151 .15854 L
.3722 .16721 L
.37254 .17044 L
.37285 .17291 L
.37312 .17461 L
.37326 .17531 L
.37341 .17595 L
.3735 .17624 L
.37358 .17648 L
.37373 .17682 L
.37388 .177 L
.37403 .17705 L
.37411 .17701 L
.37419 .17693 L
.37428 .1768 L
.37437 .17661 L
Mistroke
.37452 .17618 L
.37468 .17552 L
.37499 .17382 L
.37528 .17167 L
.37588 .16524 L
.37654 .15538 L
.37716 .1433 L
.37774 .12979 L
.37998 .05711 L
.38054 .03552 L
.3807 .02977 L
.38085 .02527 L
.38099 .02315 L
.38114 .02418 L
.38129 .02795 L
.38142 .03267 L
.38171 .04513 L
.38223 .07015 L
.38472 .20321 L
.38724 .34282 L
.38955 .458 L
.39072 .5064 L
.39181 .54384 L
.39295 .57377 L
.39355 .58556 L
.39386 .59053 L
.3942 .59493 L
.3945 .59812 L
.39466 .59951 L
.39483 .60077 L
.39499 .6017 L
.39514 .60237 L
.39528 .60284 L
.39542 .60317 L
.39558 .60332 L
.39567 .60331 L
.39575 .60324 L
.39591 .60296 L
.39606 .6025 L
.39614 .60216 L
.39623 .60173 L
.39639 .6008 L
.39676 .59793 L
.39704 .5949 L
.39735 .5909 L
.39791 .5818 L
.39918 .55251 L
.4004 .51427 L
.40173 .4632 L
.40416 .35316 L
Mistroke
.40673 .22812 L
.40906 .12361 L
.41023 .07864 L
.41085 .05783 L
.41118 .04755 L
.4115 .03888 L
.41179 .03189 L
.41192 .02942 L
.41207 .02731 L
.41222 .02587 L
.41237 .02551 L
.41245 .02572 L
.41254 .02624 L
.41269 .02779 L
.41282 .02952 L
.41296 .03165 L
.41321 .03586 L
.41379 .04561 L
.41435 .05412 L
.41494 .06169 L
.41529 .06527 L
.4156 .06803 L
.41589 .07021 L
.41621 .07208 L
.41636 .07284 L
.41653 .07354 L
.41669 .07408 L
.41684 .07447 L
.41701 .07482 L
.4171 .07496 L
.41719 .07505 L
.41735 .07515 L
.41743 .07515 L
.41752 .07513 L
.41759 .07509 L
.41768 .07501 L
.41783 .07481 L
.41798 .07453 L
.41812 .0742 L
.41843 .0732 L
.41875 .0718 L
.41935 .06838 L
.4199 .06444 L
.42113 .05339 L
.42334 .03007 L
.42392 .02415 L
.42454 .01849 L
.4248 .01656 L
.42494 .01569 L
.42507 .01507 L
Mistroke
.42523 .01472 L
.42537 .01479 L
.4255 .01516 L
.42565 .01581 L
.42816 .02967 L
.42938 .03563 L
.43053 .04353 L
.43117 .04968 L
.43186 .05802 L
.43306 .07678 L
.43546 .12734 L
.438 .19041 L
.4404 .2472 L
.44145 .26829 L
.44258 .28733 L
.44321 .29577 L
.44379 .30214 L
.44435 .30686 L
.44463 .30871 L
.44494 .31034 L
.4451 .311 L
.44526 .31157 L
.44541 .31195 L
.44556 .31226 L
.44565 .31238 L
.44573 .31245 L
.44582 .3125 L
.44591 .31251 L
.44607 .31243 L
.44616 .31234 L
.44624 .31222 L
.44638 .31192 L
.44652 .31155 L
.44683 .31037 L
.44713 .30877 L
.44746 .30656 L
.44809 .30082 L
.44868 .29385 L
.45001 .27252 L
.45119 .24803 L
.45244 .21722 L
.45485 .14924 L
.45612 .1125 L
.45746 .07655 L
.45804 .06314 L
.45836 .05678 L
.45866 .05169 L
.45883 .0493 L
.45902 .04718 L
.4591 .04642 L
Mistroke
.45919 .04573 L
.45934 .04482 L
.4595 .04434 L
.45964 .04426 L
.45973 .04438 L
.45981 .04459 L
.45989 .04492 L
.45998 .04537 L
.46012 .04633 L
.46026 .0474 L
.46055 .05036 L
.46109 .05682 L
.4623 .07216 L
.46288 .07859 L
.4635 .08424 L
.46403 .08799 L
.46433 .08966 L
.46461 .09094 L
.46477 .09152 L
.46494 .09204 L
.46508 .09239 L
.46524 .0927 L
.46533 .09283 L
.46541 .09292 L
.46549 .093 L
.46559 .09305 L
.46567 .09307 L
.46576 .09306 L
.46591 .09298 L
.46606 .09283 L
.46621 .09258 L
.46636 .09228 L
.46649 .09193 L
.46682 .09085 L
.46712 .08951 L
.46768 .08637 L
.46829 .08196 L
.46953 .07076 L
.47067 .05949 L
.47124 .05449 L
.47176 .05076 L
.47204 .04928 L
.4722 .04865 L
.47234 .04822 L
.4725 .04789 L
.47259 .04779 L
.47267 .04774 L
.47282 .04776 L
.47298 .04796 L
.47312 .04826 L
Mistroke
.47326 .0487 L
.47352 .04981 L
.47382 .05158 L
.4741 .05356 L
.47541 .06529 L
.47662 .07631 L
.4772 .08076 L
.47774 .08423 L
.4783 .08698 L
.4786 .08804 L
.47877 .08851 L
.47892 .08886 L
.47907 .08912 L
.47923 .0893 L
.47932 .08937 L
.4794 .08941 L
.47956 .08941 L
.47964 .08938 L
.47973 .08932 L
.47988 .08914 L
.47997 .089 L
.48005 .08884 L
.48023 .0884 L
.48053 .08739 L
.48081 .08616 L
.48143 .08233 L
.482 .07744 L
.48262 .07088 L
.48372 .05597 L
.4844 .04556 L
.48473 .04054 L
.48504 .03637 L
.48518 .0347 L
.48531 .03339 L
.48545 .03238 L
.48561 .03176 L
.48576 .03174 L
.48591 .0323 L
.48598 .03284 L
.48607 .0336 L
.48622 .03541 L
.48651 .03988 L
.48681 .04591 L
.48736 .0588 L
.48862 .09294 L
.49115 .16889 L
.49353 .2367 L
.49478 .26758 L
.49612 .29484 L
.49679 .30588 L
Mistroke
.49742 .31453 L
.49799 .32078 L
.49828 .32341 L
.4986 .32585 L
.49889 .32757 L
.49919 .329 L
.49935 .3296 L
.49951 .33002 L
.49966 .33034 L
.4998 .33053 L
.49994 .33061 L
.50008 .33061 L
.5002 .33052 L
.50033 .33035 L
.50048 .33006 L
.50063 .32965 L
.50091 .32859 L
.5012 .32711 L
.50151 .32507 L
.50206 .32026 L
.50272 .31268 L
.50332 .3041 L
.50463 .28028 L
.50587 .25212 L
.51051 .11881 L
.51174 .08271 L
.5129 .05237 L
.51348 .04003 L
.51365 .0372 L
.51381 .03495 L
.51395 .03337 L
.51411 .03221 L
.5142 .03183 L
.51429 .03168 L
.51444 .03191 L
.51453 .03231 L
.51461 .03283 L
.5148 .03448 L
.51511 .0383 L
.51544 .04309 L
.51658 .06047 L
.51721 .06887 L
.51781 .07561 L
.51837 .08072 L
.51866 .08295 L
.51897 .08495 L
.51923 .08634 L
.51952 .08758 L
.51964 .08802 L
.51978 .08842 L
Mistroke
.5199 .08874 L
.52002 .08898 L
.52018 .08921 L
.52031 .08935 L
.52046 .08942 L
.52055 .08942 L
.52062 .0894 L
.52075 .08932 L
.52089 .08917 L
.52104 .08893 L
.52118 .08864 L
.5215 .08773 L
.52179 .0866 L
.52244 .08316 L
.52307 .0788 L
.52375 .07312 L
.52499 .06149 L
.52553 .05654 L
.52612 .05197 L
.52646 .04995 L
.5266 .04925 L
.52676 .04862 L
.52692 .04817 L
.52706 .04789 L
.52721 .04775 L
.52729 .04773 L
.52737 .04776 L
.52753 .04794 L
.52761 .0481 L
.52769 .04832 L
.52785 .04883 L
.52799 .04944 L
.52832 .05125 L
.52867 .05376 L
.5299 .06515 L
.53112 .07698 L
.53177 .08242 L
.53245 .0872 L
.53279 .08909 L
.53311 .09056 L
.5334 .0916 L
.53355 .09203 L
.53371 .09242 L
.53386 .09271 L
.534 .0929 L
.53415 .09302 L
.53424 .09306 L
.53432 .09307 L
.53445 .09303 L
.5346 .09291 L
Mistroke
.53474 .09272 L
.53487 .09248 L
.53502 .09215 L
.53517 .09172 L
.53543 .09075 L
.53572 .0894 L
.53604 .08757 L
.5366 .08339 L
.53713 .07851 L
.5384 .06344 L
.53903 .05531 L
.53931 .05194 L
.53961 .04864 L
.53975 .04731 L
.53991 .04609 L
.54005 .04519 L
.54019 .04461 L
.54034 .04428 L
.54042 .04425 L
.5405 .04433 L
.54064 .04475 L
.5408 .0456 L
.54088 .04626 L
.54096 .04698 L
.54114 .04897 L
.54147 .05373 L
.54208 .06568 L
.54432 .12509 L
.54679 .19627 L
.54909 .25422 L
.55023 .27691 L
.55131 .29366 L
.5519 .30075 L
.55221 .30383 L
.55255 .3066 L
.55283 .30852 L
.55313 .3102 L
.55327 .31079 L
.55341 .31133 L
.55355 .31175 L
.55368 .31205 L
.55383 .31232 L
.55397 .31246 L
.55412 .31251 L
.5542 .31249 L
.55428 .31245 L
.55441 .3123 L
.55455 .31205 L
.5547 .31169 L
.55483 .31126 L
Mistroke
.55515 .30992 L
.55544 .30828 L
.5561 .30318 L
.55672 .29654 L
.55741 .28748 L
.55865 .26659 L
.56356 .15107 L
.566 .09479 L
.5672 .07238 L
.56829 .05606 L
.56936 .0445 L
.56989 .04019 L
.57048 .03641 L
.57284 .02471 L
.57348 .02105 L
.57408 .01733 L
.57434 .01585 L
.57447 .01525 L
.57462 .01481 L
.57478 .01472 L
.57492 .01505 L
.57506 .01567 L
.57521 .01657 L
.57588 .02229 L
.57652 .02869 L
.57773 .04152 L
.57889 .05356 L
.58012 .06462 L
.58072 .06887 L
.58102 .07061 L
.58129 .07198 L
.58153 .07302 L
.58179 .07394 L
.58192 .07429 L
.58206 .07461 L
.5822 .07486 L
.58234 .07503 L
.58249 .07513 L
.58257 .07515 L
.58265 .07515 L
.58281 .07506 L
.5829 .07496 L
.58298 .07484 L
.58312 .07458 L
.58327 .0742 L
.58357 .07313 L
.5839 .07147 L
.58426 .06912 L
.5849 .06335 L
.58556 .05543 L
Mistroke
.58618 .04619 L
.58677 .03611 L
.58707 .03126 L
.58719 .02934 L
.58733 .02753 L
.58747 .0262 L
.5876 .02556 L
.58775 .02573 L
.58789 .02681 L
.58805 .02895 L
.58819 .03156 L
.58851 .03896 L
.58975 .07798 L
.59197 .1682 L
.59682 .39929 L
.59904 .49395 L
.6003 .53743 L
.60091 .55517 L
.60147 .5691 L
.60203 .58078 L
.60264 .59081 L
.60297 .5951 L
.60328 .59828 L
.60357 .6006 L
.60372 .6015 L
.60389 .60229 L
.60397 .6026 L
.60406 .60287 L
.60414 .60307 L
.60422 .6032 L
.60436 .60332 L
.60452 .60325 L
.60461 .60311 L
.6047 .6029 L
.60479 .60263 L
.60488 .60232 L
.60503 .60157 L
.6052 .60055 L
.6055 .5981 L
.60579 .59513 L
.60643 .5859 L
.60703 .5742 L
.60769 .55823 L
.60888 .521 L
.61112 .42685 L
.61346 .305 L
.61604 .16105 L
.61721 .09813 L
.61783 .06695 L
.61817 .05083 L
Mistroke
.61848 .03685 L
.61862 .03117 L
.61876 .02663 L
.61891 .0234 L
.61905 .02354 L
.61921 .0269 L
.61935 .03154 L
.61968 .04374 L
.62077 .08471 L
.62186 .11912 L
.62304 .14747 L
.62371 .15947 L
.62432 .1677 L
.62462 .17073 L
.62494 .17335 L
.62509 .17431 L
.62524 .17518 L
.62539 .17583 L
.62552 .17631 L
.62567 .17671 L
.62575 .17685 L
.62584 .17697 L
.62593 .17703 L
.62601 .17705 L
.62617 .17695 L
.62632 .17672 L
.62646 .17638 L
.62661 .17588 L
.62677 .17519 L
.6271 .17329 L
.62741 .17093 L
.62811 .16359 L
.62872 .15514 L
.62928 .14589 L
.63055 .12058 L
.63174 .09223 L
.63302 .05956 L
.63365 .04368 L
.63395 .0362 L
.63423 .02978 L
.63449 .02487 L
.63462 .02307 L
.63476 .02196 L
.6349 .02199 L
.63505 .02327 L
.6352 .02534 L
.63533 .02767 L
.63649 .0526 L
.63772 .07745 L
.63886 .09622 L
Mistroke
.63993 .10933 L
.64046 .11401 L
.64102 .11772 L
.64133 .11915 L
.6415 .11976 L
.64165 .12022 L
.64178 .12053 L
.64193 .12077 L
.64209 .12094 L
.64223 .121 L
.64238 .12097 L
.64246 .12091 L
.64255 .12082 L
.6427 .12058 L
.64285 .12027 L
.64301 .11979 L
.64317 .11926 L
.64352 .1177 L
.64414 .11371 L
.64473 .1086 L
.64589 .09527 L
.64712 .07706 L
.64934 .03842 L
.64994 .02822 L
.65025 .02391 L
.65033 .02295 L
.65042 .02208 L
.6505 .02144 L
.65058 .02104 L
.65067 .02082 L
.65075 .02088 L
.65084 .0212 L
.65094 .02183 L
.65102 .02256 L
.6511 .02338 L
.65128 .02561 L
.65192 .0354 L
.65436 .07122 L
.65554 .08383 L
.65614 .0886 L
.65648 .09082 L
.65679 .09251 L
.65706 .09372 L
.65735 .09476 L
.65751 .09521 L
.65766 .09555 L
.6578 .09581 L
.65795 .09602 L
.65808 .09613 L
.65821 .09619 L
Mistroke
.65834 .0962 L
.65846 .09615 L
.6586 .09604 L
.65875 .09585 L
.65889 .0956 L
.65902 .09531 L
.65934 .09437 L
.65964 .09323 L
.6603 .0897 L
.66089 .08553 L
.6615 .08015 L
.66375 .05378 L
.6649 .03782 L
.66553 .02915 L
.66584 .02525 L
.66597 .02371 L
.66612 .02221 L
.66626 .02109 L
.66639 .02036 L
.66653 .02 L
.66668 .02014 L
.66676 .02042 L
.66684 .02088 L
.667 .02202 L
.66728 .02493 L
.66834 .03819 L
.66956 .05318 L
.67071 .0651 L
.67135 .07048 L
.67203 .0752 L
.67234 .0769 L
.67266 .07843 L
.67294 .07952 L
.67324 .08047 L
.6734 .08087 L
.67354 .08118 L
.67368 .08142 L
.67383 .08163 L
.67397 .08175 L
.6741 .08183 L
.67423 .08185 L
.67438 .08183 L
.67453 .08174 L
.67461 .08167 L
.67469 .08158 L
.67485 .08135 L
.67502 .08104 L
.67533 .08027 L
.6756 .07936 L
.67615 .07701 L
Mistroke
.67674 .07364 L
.67781 .06554 L
.68016 .04112 L
.68141 .0267 L
.68177 .02303 L
.68194 .0215 L
.68203 .02087 L
.68211 .02036 L
.68226 .01965 L
.68241 .01931 L
.6825 .01933 L
.68259 .01949 L
.68267 .01978 L
.68275 .02015 L
.68289 .02104 L
.68304 .02224 L
.68332 .02479 L
.68394 .03142 L
.6852 .04491 L
.68639 .05599 L
.6875 .06401 L
.68809 .06729 L
.68873 .06991 L
.68905 .0709 L
.68936 .0716 L
.68954 .07191 L
.6897 .07212 L
.68978 .07221 L
.68988 .07228 L
.68997 .07234 L
.69006 .07237 L
.69021 .07238 L
.6903 .07237 L
.69038 .07234 L
.69052 .07224 L
.69068 .07209 L
.69082 .0719 L
.69094 .07169 L
.69124 .07106 L
.69155 .07017 L
.69184 .06916 L
.69249 .06623 L
.69368 .05869 L
.69479 .04958 L
.69608 .03713 L
.69671 .03071 L
.69729 .02499 L
.69756 .02256 L
.69781 .02063 L
.69794 .01984 L
Mistroke
.69808 .01921 L
.69823 .0188 L
.69837 .01875 L
.69852 .01903 L
.69866 .01958 L
.69881 .02043 L
.69897 .02156 L
.69954 .02646 L
.70073 .03784 L
.70202 .04892 L
.70265 .05353 L
.70325 .05729 L
.70383 .06032 L
.70437 .06255 L
.70489 .06411 L
.70517 .06475 L
.70543 .06517 L
.70558 .06536 L
.70571 .06548 L
.70586 .06558 L
.70602 .06563 L
.70616 .06563 L
.70629 .06559 L
.70643 .06551 L
.70658 .06538 L
.70673 .0652 L
.70689 .06496 L
.70722 .0643 L
.70752 .0635 L
.70781 .06258 L
.70845 .05994 L
.70914 .05626 L
.71157 .03795 L
.71282 .0267 L
.71314 .024 L
.71343 .02165 L
.7137 .01986 L
.71385 .01909 L
.71399 .01857 L
.71412 .01829 L
.71427 .01828 L
.71443 .01859 L
.71457 .01915 L
.71473 .01999 L
.71488 .02091 L
.7152 .02333 L
.71653 .0346 L
.71764 .04344 L
.71883 .05122 L
.71951 .05474 L
Mistroke
.72012 .05725 L
.72042 .05821 L
.72074 .05907 L
.72105 .05971 L
.72133 .06014 L
.72148 .06031 L
.72162 .06043 L
.72175 .0605 L
.7219 .06055 L
.72205 .06056 L
.72213 .06054 L
.72221 .06051 L
.72236 .06043 L
.7225 .06031 L
.72264 .06017 L
.72278 .05997 L
.72303 .05954 L
.72331 .05894 L
.7236 .05814 L
.72423 .05593 L
.72489 .05286 L
.7261 .04569 L
.7285 .02704 L
.72916 .02191 L
.72949 .01974 L
.72958 .01924 L
.72968 .01877 L
.72977 .01841 L
.72986 .01814 L
.72994 .01797 L
.73002 .01786 L
.7301 .01784 L
.73019 .01791 L
.73027 .01806 L
.73036 .01829 L
.73051 .01889 L
.73066 .01966 L
.73082 .02062 L
.73111 .02258 L
.73232 .03193 L
.73361 .04135 L
.73483 .04857 L
.73537 .05109 L
.73594 .05328 L
.73622 .05416 L
.73652 .05497 L
.73681 .05558 L
.73707 .05602 L
.73721 .05621 L
.73737 .05638 L
Mistroke
.73746 .05645 L
.73754 .05651 L
.73762 .05655 L
.7377 .05658 L
.73778 .0566 L
.73786 .05661 L
.73801 .0566 L
.73816 .05655 L
.7383 .05647 L
.73843 .05637 L
.73856 .05622 L
.73881 .05588 L
.73911 .05533 L
.73938 .0547 L
.73997 .05292 L
.74053 .05074 L
.74169 .04475 L
.74293 .03666 L
.74409 .02808 L
.7446 .02429 L
.74489 .02224 L
.74515 .02047 L
.7453 .01959 L
.74544 .01886 L
.74558 .01827 L
.7457 .01785 L
.74584 .01757 L
.74598 .01749 L
.74613 .01764 L
.74628 .01804 L
.74643 .0186 L
.74658 .01936 L
.74686 .02102 L
.7475 .02544 L
.74971 .04054 L
.75093 .04695 L
.75162 .04968 L
.75195 .05073 L
.75226 .05157 L
.75256 .05224 L
.75288 .05279 L
.75302 .05298 L
.75317 .05315 L
.7533 .05327 L
.75344 .05336 L
.75352 .05341 L
.7536 .05344 L
.75375 .05346 L
.75383 .05346 L
.75391 .05345 L
Mistroke
.754 .05343 L
.75409 .05339 L
.75423 .0533 L
.75437 .05319 L
.75453 .05303 L
.75469 .05281 L
.75499 .05229 L
.75532 .05158 L
.75591 .04989 L
.7566 .04724 L
.75724 .04427 L
.75966 .02918 L
.76079 .02142 L
.76106 .01977 L
.76136 .0183 L
.76144 .01795 L
.76152 .01768 L
.76168 .01732 L
.76182 .01719 L
.76198 .01728 L
.76214 .01762 L
.76223 .0179 L
.76231 .01822 L
.76266 .01996 L
.76329 .02392 L
.76449 .03201 L
.76568 .03919 L
.76632 .04253 L
.76692 .04519 L
.76748 .04724 L
.76799 .04872 L
.76826 .04936 L
.76855 .04993 L
.76871 .05019 L
.76886 .05039 L
.769 .05055 L
.76915 .05069 L
.76931 .0508 L
.76945 .05086 L
.76959 .0509 L
.76972 .0509 L
.76987 .05088 L
.77001 .05082 L
.77009 .05078 L
.77017 .05072 L
.77032 .05059 L
.7706 .05026 L
.77089 .04979 L
.77142 .04864 L
.77203 .04679 L
Mistroke
.7726 .04462 L
.77391 .03824 L
.77616 .02409 L
.77677 .02025 L
.77711 .01849 L
.77728 .0178 L
.77743 .01732 L
.77756 .01705 L
.7777 .01693 L
.77784 .01699 L
.77799 .01725 L
.77814 .01772 L
.77831 .01837 L
.7786 .01987 L
.77995 .02823 L
.78117 .03558 L
.78243 .04185 L
.78299 .04403 L
.7836 .04599 L
.78388 .04672 L
.78418 .04739 L
.78444 .04786 L
.78472 .04827 L
.78489 .04845 L
.78504 .04859 L
.78519 .04869 L
.78534 .04876 L
.78548 .04879 L
.78561 .04879 L
.78576 .04877 L
.78591 .04871 L
.78607 .04862 L
.78622 .0485 L
.78655 .04811 L
.78687 .04758 L
.78722 .04685 L
.78785 .04512 L
.78842 .04312 L
.78962 .03768 L
.79073 .0315 L
.79203 .02351 L
.79266 .01979 L
.79294 .0184 L
.79308 .01778 L
.79324 .01725 L
.79339 .01689 L
.79353 .01672 L
.79367 .01672 L
.7938 .01688 L
.79393 .01717 L
Mistroke
.79405 .01756 L
.79433 .01871 L
.7955 .02542 L
.79679 .03298 L
.79799 .039 L
.79908 .04319 L
.7997 .0449 L
.80026 .04604 L
.80058 .0465 L
.80073 .04667 L
.80087 .0468 L
.80102 .04691 L
.80111 .04695 L
.80119 .04699 L
.80128 .04702 L
.80137 .04703 L
.80145 .04704 L
.80154 .04703 L
.8017 .047 L
.80184 .04694 L
.80192 .04689 L
.80201 .04683 L
.80217 .0467 L
.80247 .04634 L
.80275 .0459 L
.80331 .04471 L
.80392 .04298 L
.80501 .03877 L
.8075 .02537 L
.8081 .02188 L
.80873 .01852 L
.80891 .01772 L
.809 .01738 L
.80909 .01711 L
.80925 .01673 L
.80933 .0166 L
.80942 .01652 L
.80957 .01655 L
.80972 .01676 L
.80981 .01695 L
.80988 .01717 L
.81006 .01778 L
.81065 .02069 L
.8113 .02439 L
.81248 .03109 L
.81372 .03718 L
.81487 .04158 L
.81545 .04321 L
.81575 .04389 L
.81608 .0445 L
Mistroke
.81626 .04479 L
.81643 .04502 L
.81661 .04521 L
.81677 .04535 L
.81693 .04545 L
.81708 .04552 L
.81724 .04556 L
.81733 .04557 L
.81741 .04557 L
.81756 .04554 L
.8177 .04549 L
.81783 .04542 L
.81797 .04531 L
.81829 .04499 L
.81858 .04457 L
.81911 .04354 L
.81968 .04207 L
.82086 .03781 L
.82217 .03156 L
.8233 .02527 L
.82392 .02176 L
.8245 .01875 L
.8248 .01746 L
.82497 .0169 L
.82512 .01655 L
.82521 .01642 L
.82529 .01636 L
.82538 .01634 L
.82548 .0164 L
.82564 .01665 L
.82573 .01687 L
.82581 .01712 L
.82611 .01829 L
.82639 .01961 L
.82701 .02296 L
.82822 .02959 L
.8295 .03582 L
.83012 .03833 L
.83071 .04034 L
.83123 .0418 L
.83153 .04249 L
.83181 .04304 L
.8321 .04351 L
.83237 .04386 L
.8325 .04399 L
.83265 .04412 L
.83281 .04422 L
.83296 .04429 L
.83309 .04432 L
.83323 .04434 L
Mistroke
.83337 .04433 L
.83351 .04429 L
.83364 .04423 L
.83376 .04417 L
.83402 .04395 L
.83431 .04361 L
.83458 .0432 L
.83519 .04195 L
.83578 .04031 L
.83642 .03814 L
.83882 .02678 L
.84008 .01992 L
.84039 .01844 L
.84072 .01712 L
.84082 .01682 L
.84091 .01658 L
.84099 .01641 L
.84108 .01628 L
.84117 .01621 L
.84126 .0162 L
.84135 .01625 L
.84142 .01634 L
.84158 .01665 L
.84166 .01686 L
.84175 .01714 L
.84205 .01831 L
.84272 .02165 L
.84393 .02817 L
.84512 .03393 L
.84625 .03833 L
.84684 .04014 L
.84715 .04093 L
.84748 .04166 L
.84776 .04217 L
.84807 .04262 L
.84835 .04293 L
.84848 .04305 L
.84861 .04314 L
.84876 .04322 L
.84885 .04326 L
.84893 .04328 L
.84902 .0433 L
.8491 .0433 L
.84924 .04329 L
.84939 .04326 L
.84952 .0432 L
.84967 .04312 L
.84983 .043 L
.85015 .04266 L
.85045 .04222 L
Mistroke
.85113 .04084 L
.85174 .03919 L
.85239 .03696 L
.85359 .0319 L
.85583 .02036 L
.85637 .01781 L
.85652 .01724 L
.85668 .01673 L
.85681 .0164 L
.85696 .01616 L
.85704 .01609 L
.85712 .01608 L
.85721 .01611 L
.85729 .0162 L
.85744 .01647 L
.85753 .01668 L
.8576 .01691 L
.85821 .01943 L
.85952 .02619 L
.86074 .03216 L
.86193 .0369 L
.86244 .03857 L
.86301 .04006 L
.86333 .04075 L
.86362 .04129 L
.86392 .04174 L
.86421 .04206 L
.86436 .04219 L
.86453 .04231 L
.86469 .04238 L
.86483 .04242 L
.86499 .04244 L
.86507 .04244 L
.86515 .04243 L
.86524 .04241 L
.86532 .04238 L
.86541 .04234 L
.8655 .0423 L
.86563 .04221 L
.86578 .04208 L
.86605 .04179 L
.86637 .04133 L
.86666 .04081 L
.86727 .03943 L
.8679 .03756 L
.86896 .03357 L
.87012 .02822 L
.87134 .02196 L
.87194 .01899 L
.87221 .01784 L
Mistroke
.87249 .01679 L
.87257 .01657 L
.87265 .01636 L
.8728 .01609 L
.87289 .01601 L
.87297 .01597 L
.87313 .01604 L
.87321 .01615 L
.8733 .01631 L
.87346 .01672 L
.87363 .01729 L
.87382 .01803 L
.87502 .02392 L
.87625 .02999 L
.87755 .0354 L
.87865 .03883 L
.87896 .03956 L
.87928 .04022 L
.87957 .0407 L
.87987 .04111 L
.88002 .04128 L
.88018 .04143 L
.88033 .04154 L
.88047 .04162 L
.88055 .04166 L
.88063 .04169 L
.88071 .04171 L
.88081 .04172 L
.88088 .04173 L
.88097 .04173 L
.88112 .0417 L
.88128 .04164 L
.88136 .0416 L
.88144 .04155 L
.88174 .0413 L
.88202 .04099 L
.88231 .04056 L
.88286 .0395 L
.88337 .03821 L
.88453 .03434 L
.88678 .02399 L
.88739 .02088 L
.88773 .01925 L
.88805 .01785 L
.88832 .01685 L
.88847 .01642 L
.88861 .01612 L
.88875 .01593 L
.88891 .01589 L
.88899 .01594 L
Mistroke
.88907 .01603 L
.88922 .01631 L
.88931 .01653 L
.88939 .01679 L
.88955 .01734 L
.88991 .01883 L
.89057 .02198 L
.89179 .02801 L
.89296 .03314 L
.8936 .03553 L
.89421 .03744 L
.8948 .03893 L
.89512 .03957 L
.89545 .04014 L
.89575 .04055 L
.89603 .04083 L
.89617 .04094 L
.89631 .04103 L
.89645 .04109 L
.89657 .04113 L
.8967 .04115 L
.89684 .04115 L
.89697 .04113 L
.89709 .04109 L
.89723 .04103 L
.89738 .04094 L
.89765 .04071 L
.89794 .04038 L
.89824 .03992 L
.89878 .03886 L
.89938 .03735 L
.89992 .03566 L
.90114 .03094 L
.90334 .02035 L
.90392 .01776 L
.90408 .01713 L
.90424 .01662 L
.90438 .01625 L
.90453 .01597 L
.90466 .01584 L
.90481 .01583 L
.90496 .01598 L
.9051 .01625 L
.90524 .0166 L
.90536 .01699 L
.90563 .01803 L
.90813 .02987 L
.90925 .03434 L
.90986 .03635 L
.91043 .03792 L
Mistroke
.91105 .03923 L
.91138 .03976 L
.91173 .0402 L
.91204 .04047 L
.91219 .04057 L
.91228 .04061 L
.91236 .04064 L
.9125 .04068 L
.91266 .04069 L
.9128 .04068 L
.91294 .04065 L
.91307 .04059 L
.91322 .04051 L
.91336 .04041 L
.91349 .0403 L
.91381 .03994 L
.91411 .03951 L
.9147 .03836 L
.91535 .03669 L
.9165 .03275 L
.91757 .02818 L
.91885 .02203 L
.91948 .01905 L
.91975 .01787 L
.92005 .01676 L
.92018 .01637 L
.92032 .01605 L
.92046 .01585 L
.92058 .01577 L
.92071 .01579 L
.92086 .01595 L
.921 .01623 L
.92113 .01657 L
.9214 .0175 L
.9217 .01873 L
.9223 .02155 L
.92353 .02748 L
.92483 .03297 L
.92594 .03662 L
.92657 .03818 L
.92715 .03926 L
.92744 .03967 L
.9276 .03984 L
.92776 .04 L
.9279 .04011 L
.92806 .04021 L
.9282 .04028 L
.92833 .04032 L
.92847 .04034 L
.9286 .04034 L
Mistroke
.92872 .04032 L
.92885 .04029 L
.92899 .04023 L
.92914 .04014 L
.92941 .03992 L
.92969 .0396 L
.93 .03916 L
.93055 .0381 L
.93121 .03644 L
.93182 .03455 L
.93429 .02404 L
.93491 .02104 L
.9355 .01835 L
.93575 .01732 L
.93602 .01643 L
.93616 .01608 L
.93632 .01583 L
.93646 .01573 L
.93659 .01575 L
.93673 .0159 L
.93688 .01619 L
.93702 .01656 L
.93715 .01698 L
.93766 .01905 L
.93881 .02452 L
.93995 .02973 L
.94118 .03446 L
.94185 .03648 L
.94246 .03797 L
.94304 .03904 L
.94334 .03944 L
.9435 .03962 L
.94366 .03977 L
.9438 .03988 L
.94395 .03997 L
.94409 .04004 L
.94422 .04007 L
.94436 .0401 L
.94451 .04009 L
.94459 .04008 L
.94467 .04007 L
.94482 .04001 L
.94495 .03994 L
.94509 .03985 L
.94538 .03959 L
.94565 .03926 L
.9459 .03889 L
.94651 .03771 L
.94717 .03601 L
.94837 .03192 L
Mistroke
.95061 .02181 L
.95116 .01923 L
.95147 .01792 L
.95175 .01684 L
.95192 .01635 L
.952 .01614 L
.95209 .01595 L
.95218 .01582 L
.95225 .01574 L
.9524 .0157 L
.95255 .0158 L
.95264 .01592 L
.95271 .01607 L
.95286 .01642 L
.95301 .01688 L
.95422 .02219 L
.95555 .0284 L
.95676 .03328 L
.9579 .03682 L
.95854 .03824 L
.9589 .03886 L
.95923 .03931 L
.9595 .0396 L
.95966 .03972 L
.95981 .03982 L
.95997 .03989 L
.96011 .03993 L
.96026 .03995 L
.96034 .03995 L
.96043 .03995 L
.96051 .03993 L
.96059 .03991 L
.96074 .03985 L
.96089 .03976 L
.96107 .03963 L
.96138 .03932 L
.96167 .03893 L
.96222 .03796 L
.9628 .03659 L
.96412 .03231 L
.96533 .02725 L
.96644 .022 L
.96705 .01914 L
.96735 .01785 L
.96763 .01683 L
.96777 .0164 L
.96792 .01603 L
.96808 .01578 L
.96817 .01571 L
.96824 .01568 L
Mistroke
.96833 .0157 L
.96842 .01577 L
.96857 .01601 L
.96866 .01621 L
.96874 .01642 L
.96893 .017 L
.97013 .02232 L
.97131 .02785 L
.97258 .03304 L
.9732 .03511 L
.97378 .03676 L
.97435 .03806 L
.97488 .03896 L
.97518 .03935 L
.97534 .0395 L
.97551 .03965 L
.9756 .03971 L
.97569 .03977 L
.97577 .03981 L
.97587 .03985 L
.97602 .03989 L
.97611 .0399 L
.97619 .03991 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.00459847 0.64881 0.188537 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.491929 0.0484262 0.0147151 0.00684776 [
[.00767 -0.0125 -9 -9 ]
[.00767 -0.0125 9 0 ]
[.2498 -0.0125 -6 -9 ]
[.2498 -0.0125 6 0 ]
[.49193 -0.0125 -3 -9 ]
[.49193 -0.0125 3 0 ]
[.73406 -0.0125 -3 -9 ]
[.73406 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .15167 -12 -4.5 ]
[-0.0125 .15167 0 4.5 ]
[-0.0125 .28863 -12 -4.5 ]
[-0.0125 .28863 0 4.5 ]
[-0.0125 .42558 -12 -4.5 ]
[-0.0125 .42558 0 4.5 ]
[-0.0125 .56254 -12 -4.5 ]
[-0.0125 .56254 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.00767 0 m
.00767 .00625 L
s
[(-10)] .00767 -0.0125 0 1 Mshowa
.2498 0 m
.2498 .00625 L
s
[(-5)] .2498 -0.0125 0 1 Mshowa
.49193 0 m
.49193 .00625 L
s
[(0)] .49193 -0.0125 0 1 Mshowa
.73406 0 m
.73406 .00625 L
s
[(5)] .73406 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05609 0 m
.05609 .00375 L
s
.10452 0 m
.10452 .00375 L
s
.15295 0 m
.15295 .00375 L
s
.20137 0 m
.20137 .00375 L
s
.29822 0 m
.29822 .00375 L
s
.34665 0 m
.34665 .00375 L
s
.39508 0 m
.39508 .00375 L
s
.4435 0 m
.4435 .00375 L
s
.54036 0 m
.54036 .00375 L
s
.58878 0 m
.58878 .00375 L
s
.63721 0 m
.63721 .00375 L
s
.68563 0 m
.68563 .00375 L
s
.78249 0 m
.78249 .00375 L
s
.83091 0 m
.83091 .00375 L
s
.87934 0 m
.87934 .00375 L
s
.92776 0 m
.92776 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .15167 m
.00625 .15167 L
s
[(20)] -0.0125 .15167 1 0 Mshowa
0 .28863 m
.00625 .28863 L
s
[(40)] -0.0125 .28863 1 0 Mshowa
0 .42558 m
.00625 .42558 L
s
[(60)] -0.0125 .42558 1 0 Mshowa
0 .56254 m
.00625 .56254 L
s
[(80)] -0.0125 .56254 1 0 Mshowa
.125 Mabswid
0 .04895 m
.00375 .04895 L
s
0 .08319 m
.00375 .08319 L
s
0 .11743 m
.00375 .11743 L
s
0 .18591 m
.00375 .18591 L
s
0 .22015 m
.00375 .22015 L
s
0 .25439 m
.00375 .25439 L
s
0 .32286 m
.00375 .32286 L
s
0 .3571 m
.00375 .3571 L
s
0 .39134 m
.00375 .39134 L
s
0 .45982 m
.00375 .45982 L
s
0 .49406 m
.00375 .49406 L
s
0 .5283 m
.00375 .5283 L
s
0 .59677 m
.00375 .59677 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.00767 .61178 m
.00767 .61803 L
s
.2498 .61178 m
.2498 .61803 L
s
.49193 .61178 m
.49193 .61803 L
s
.73406 .61178 m
.73406 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.05609 .61428 m
.05609 .61803 L
s
.10452 .61428 m
.10452 .61803 L
s
.15295 .61428 m
.15295 .61803 L
s
.20137 .61428 m
.20137 .61803 L
s
.29822 .61428 m
.29822 .61803 L
s
.34665 .61428 m
.34665 .61803 L
s
.39508 .61428 m
.39508 .61803 L
s
.4435 .61428 m
.4435 .61803 L
s
.54036 .61428 m
.54036 .61803 L
s
.58878 .61428 m
.58878 .61803 L
s
.63721 .61428 m
.63721 .61803 L
s
.68563 .61428 m
.68563 .61803 L
s
.78249 .61428 m
.78249 .61803 L
s
.83091 .61428 m
.83091 .61803 L
s
.87934 .61428 m
.87934 .61803 L
s
.92776 .61428 m
.92776 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .15167 m
1 .15167 L
s
.99375 .28863 m
1 .28863 L
s
.99375 .42558 m
1 .42558 L
s
.99375 .56254 m
1 .56254 L
s
.125 Mabswid
.99625 .04895 m
1 .04895 L
s
.99625 .08319 m
1 .08319 L
s
.99625 .11743 m
1 .11743 L
s
.99625 .18591 m
1 .18591 L
s
.99625 .22015 m
1 .22015 L
s
.99625 .25439 m
1 .25439 L
s
.99625 .32286 m
1 .32286 L
s
.99625 .3571 m
1 .3571 L
s
.99625 .39134 m
1 .39134 L
s
.99625 .45982 m
1 .45982 L
s
.99625 .49406 m
1 .49406 L
s
.99625 .5283 m
1 .5283 L
s
.99625 .59677 m
1 .59677 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .01472 m
.02381 .05587 L
s
.03995 .01472 m
.03995 .05607 L
s
.05609 .01472 m
.05609 .05642 L
s
.07224 .01472 m
.07224 .05691 L
s
.08838 .01472 m
.08838 .05756 L
s
.10452 .01472 m
.10452 .05838 L
s
.12066 .01472 m
.12066 .05938 L
s
.1368 .01472 m
.1368 .0606 L
s
.15295 .01472 m
.15295 .06206 L
s
.16909 .01472 m
.16909 .0638 L
s
.18523 .01472 m
.18523 .06587 L
s
.20137 .01472 m
.20137 .06834 L
s
.21751 .01472 m
.21751 .07132 L
s
.23366 .01472 m
.23366 .07493 L
s
.2498 .01472 m
.2498 .07937 L
s
.26594 .01472 m
.26594 .08492 L
s
.28208 .01472 m
.28208 .09206 L
s
.29822 .01472 m
.29822 .10155 L
s
.31437 .01472 m
.31437 .11484 L
s
.33051 .01472 m
.33051 .1349 L
s
.34665 .01472 m
.34665 .16934 L
s
.36279 .01472 m
.36279 .24534 L
s
.37893 .01472 m
.37893 .60332 L
s
.39508 .01472 m
.39508 .45716 L
s
.41122 .01472 m
.41122 .08156 L
s
.42736 .01472 m
.42736 .21533 L
s
.4435 .01472 m
.4435 .30844 L
s
.45964 .01472 m
.45964 .11568 L
s
.47579 .01472 m
.47579 .06978 L
s
.49193 .01472 m
.49193 .46667 L
s
.50807 .01472 m
.50807 .06978 L
s
.52421 .01472 m
.52421 .11568 L
s
.54036 .01472 m
.54036 .30844 L
s
.5565 .01472 m
.5565 .21533 L
s
.57264 .01472 m
.57264 .08156 L
s
.58878 .01472 m
.58878 .45716 L
s
.60492 .01472 m
.60492 .60332 L
s
.62107 .01472 m
.62107 .24534 L
s
.63721 .01472 m
.63721 .16934 L
s
.65335 .01472 m
.65335 .1349 L
s
.66949 .01472 m
.66949 .11484 L
s
.68563 .01472 m
.68563 .10155 L
s
.70178 .01472 m
.70178 .09206 L
s
.71792 .01472 m
.71792 .08492 L
s
.73406 .01472 m
.73406 .07937 L
s
.7502 .01472 m
.7502 .07493 L
s
.76634 .01472 m
.76634 .07132 L
s
.78249 .01472 m
.78249 .06834 L
s
.79863 .01472 m
.79863 .06587 L
s
.81477 .01472 m
.81477 .0638 L
s
.83091 .01472 m
.83091 .06206 L
s
.84705 .01472 m
.84705 .0606 L
s
.8632 .01472 m
.8632 .05938 L
s
.87934 .01472 m
.87934 .05838 L
s
.89548 .01472 m
.89548 .05756 L
s
.91162 .01472 m
.91162 .05691 L
s
.92776 .01472 m
.92776 .05642 L
s
.94391 .01472 m
.94391 .05607 L
s
.96005 .01472 m
.96005 .05587 L
s
.97619 .01472 m
.97619 .0558 L
s
.015 w
.02381 .05587 Mdot
.03995 .05607 Mdot
.05609 .05642 Mdot
.07224 .05691 Mdot
.08838 .05756 Mdot
.10452 .05838 Mdot
.12066 .05938 Mdot
.1368 .0606 Mdot
.15295 .06206 Mdot
.16909 .0638 Mdot
.18523 .06587 Mdot
.20137 .06834 Mdot
.21751 .07132 Mdot
.23366 .07493 Mdot
.2498 .07937 Mdot
.26594 .08492 Mdot
.28208 .09206 Mdot
.29822 .10155 Mdot
.31437 .11484 Mdot
.33051 .1349 Mdot
.34665 .16934 Mdot
.36279 .24534 Mdot
.37893 .60332 Mdot
.39508 .45716 Mdot
.41122 .08156 Mdot
.42736 .21533 Mdot
.4435 .30844 Mdot
.45964 .11568 Mdot
.47579 .06978 Mdot
.49193 .46667 Mdot
.50807 .06978 Mdot
.52421 .11568 Mdot
.54036 .30844 Mdot
.5565 .21533 Mdot
.57264 .08156 Mdot
.58878 .45716 Mdot
.60492 .60332 Mdot
.62107 .24534 Mdot
.63721 .16934 Mdot
.65335 .1349 Mdot
.66949 .11484 Mdot
.68563 .10155 Mdot
.70178 .09206 Mdot
.71792 .08492 Mdot
.73406 .07937 Mdot
.7502 .07493 Mdot
.76634 .07132 Mdot
.78249 .06834 Mdot
.79863 .06587 Mdot
.81477 .0638 Mdot
.83091 .06206 Mdot
.84705 .0606 Mdot
.8632 .05938 Mdot
.87934 .05838 Mdot
.89548 .05756 Mdot
.91162 .05691 Mdot
.92776 .05642 Mdot
.94391 .05607 Mdot
.96005 .05587 Mdot
.97619 .0558 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.00459847 0.97619 0.188537 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.047619 0.0147151 0.00481352 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .11099 -12 -4.5 ]
[-0.0125 .11099 0 4.5 ]
[-0.0125 .20726 -12 -4.5 ]
[-0.0125 .20726 0 4.5 ]
[-0.0125 .30353 -12 -4.5 ]
[-0.0125 .30353 0 4.5 ]
[-0.0125 .3998 -12 -4.5 ]
[-0.0125 .3998 0 4.5 ]
[-0.0125 .49607 -18 -4.5 ]
[-0.0125 .49607 0 4.5 ]
[-0.0125 .59234 -18 -4.5 ]
[-0.0125 .59234 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .11099 m
.00625 .11099 L
s
[(20)] -0.0125 .11099 1 0 Mshowa
0 .20726 m
.00625 .20726 L
s
[(40)] -0.0125 .20726 1 0 Mshowa
0 .30353 m
.00625 .30353 L
s
[(60)] -0.0125 .30353 1 0 Mshowa
0 .3998 m
.00625 .3998 L
s
[(80)] -0.0125 .3998 1 0 Mshowa
0 .49607 m
.00625 .49607 L
s
[(100)] -0.0125 .49607 1 0 Mshowa
0 .59234 m
.00625 .59234 L
s
[(120)] -0.0125 .59234 1 0 Mshowa
.125 Mabswid
0 .03878 m
.00375 .03878 L
s
0 .06285 m
.00375 .06285 L
s
0 .08692 m
.00375 .08692 L
s
0 .13505 m
.00375 .13505 L
s
0 .15912 m
.00375 .15912 L
s
0 .18319 m
.00375 .18319 L
s
0 .23132 m
.00375 .23132 L
s
0 .25539 m
.00375 .25539 L
s
0 .27946 m
.00375 .27946 L
s
0 .32759 m
.00375 .32759 L
s
0 .35166 m
.00375 .35166 L
s
0 .37573 m
.00375 .37573 L
s
0 .42386 m
.00375 .42386 L
s
0 .44793 m
.00375 .44793 L
s
0 .472 m
.00375 .472 L
s
0 .52013 m
.00375 .52013 L
s
0 .5442 m
.00375 .5442 L
s
0 .56827 m
.00375 .56827 L
s
0 .6164 m
.00375 .6164 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .11099 m
1 .11099 L
s
.99375 .20726 m
1 .20726 L
s
.99375 .30353 m
1 .30353 L
s
.99375 .3998 m
1 .3998 L
s
.99375 .49607 m
1 .49607 L
s
.99375 .59234 m
1 .59234 L
s
.125 Mabswid
.99625 .03878 m
1 .03878 L
s
.99625 .06285 m
1 .06285 L
s
.99625 .08692 m
1 .08692 L
s
.99625 .13505 m
1 .13505 L
s
.99625 .15912 m
1 .15912 L
s
.99625 .18319 m
1 .18319 L
s
.99625 .23132 m
1 .23132 L
s
.99625 .25539 m
1 .25539 L
s
.99625 .27946 m
1 .27946 L
s
.99625 .32759 m
1 .32759 L
s
.99625 .35166 m
1 .35166 L
s
.99625 .37573 m
1 .37573 L
s
.99625 .42386 m
1 .42386 L
s
.99625 .44793 m
1 .44793 L
s
.99625 .472 m
1 .472 L
s
.99625 .52013 m
1 .52013 L
s
.99625 .5442 m
1 .5442 L
s
.99625 .56827 m
1 .56827 L
s
.99625 .6164 m
1 .6164 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
0 0 1 r
.5 Mabswid
[ .01 ] 0 setdash
.02381 .0436 m
.02395 .04359 L
.02408 .04356 L
.02423 .0435 L
.02437 .04342 L
.02462 .04324 L
.02489 .04295 L
.02519 .04255 L
.02551 .04203 L
.02608 .04082 L
.02722 .03748 L
.02847 .03259 L
.02973 .02678 L
.03043 .0235 L
.03077 .02199 L
.03109 .02078 L
.03125 .0203 L
.03139 .01994 L
.03147 .01978 L
.03156 .01965 L
.03171 .01954 L
.03179 .01954 L
.03188 .01958 L
.03197 .01969 L
.03206 .01983 L
.03221 .02019 L
.03238 .02069 L
.03299 .02316 L
.03355 .02577 L
.03476 .03143 L
.03605 .03668 L
.03714 .04015 L
.03777 .04164 L
.03805 .04217 L
.03836 .04267 L
.03863 .04302 L
.03892 .04332 L
.03908 .04344 L
.03923 .04353 L
.03938 .04359 L
.03952 .04363 L
.03965 .04364 L
.03978 .04364 L
.0399 .04362 L
.04003 .04358 L
.04017 .04352 L
.04031 .04343 L
.04058 .04321 L
.04089 .04286 L
.04122 .04236 L
Mistroke
.04183 .04116 L
.04243 .03963 L
.04298 .03792 L
.04525 .02852 L
.04644 .02291 L
.04673 .02167 L
.04705 .02055 L
.04722 .02005 L
.04731 .01987 L
.04739 .01973 L
.04746 .01963 L
.04755 .01956 L
.0477 .01956 L
.04778 .01962 L
.04786 .01973 L
.04802 .02002 L
.04819 .02051 L
.04836 .02107 L
.04905 .02403 L
.05029 .0299 L
.05155 .03536 L
.05217 .03763 L
.05273 .03943 L
.05326 .04087 L
.05383 .04213 L
.05415 .04267 L
.05444 .04308 L
.05472 .04338 L
.05487 .04351 L
.05501 .04361 L
.05517 .0437 L
.05531 .04375 L
.05546 .04378 L
.05555 .04379 L
.05563 .04379 L
.05576 .04377 L
.05591 .04373 L
.05606 .04366 L
.0562 .04357 L
.05653 .04328 L
.05683 .04292 L
.05716 .04241 L
.05751 .04174 L
.05866 .0387 L
.05989 .03416 L
.0621 .02396 L
.0627 .02136 L
.063 .02034 L
.06309 .02012 L
.06318 .01991 L
Mistroke
.06326 .01976 L
.06334 .01966 L
.06342 .01959 L
.06351 .01957 L
.0636 .0196 L
.06369 .01969 L
.06378 .01983 L
.06387 .02 L
.06403 .02043 L
.06434 .02151 L
.06467 .02292 L
.06583 .02842 L
.0671 .03418 L
.06827 .03855 L
.0689 .04048 L
.06951 .04194 L
.06984 .04258 L
.0702 .04315 L
.07052 .04354 L
.07068 .04369 L
.07082 .04381 L
.07096 .04389 L
.07111 .04396 L
.07119 .04399 L
.07127 .04401 L
.07142 .04403 L
.07158 .04402 L
.07172 .04399 L
.0718 .04396 L
.07188 .04393 L
.07205 .04383 L
.0722 .04373 L
.07233 .04361 L
.07264 .04326 L
.07294 .04282 L
.07326 .04225 L
.07437 .03945 L
.07504 .03719 L
.07568 .03471 L
.07688 .02935 L
.07804 .02378 L
.07837 .02228 L
.07868 .02103 L
.07882 .02057 L
.07897 .02016 L
.07912 .01982 L
.07927 .01965 L
.07941 .01961 L
.07954 .01969 L
.07968 .01991 L
Mistroke
.07982 .02022 L
.08006 .02099 L
.08033 .02203 L
.08149 .0275 L
.08262 .03281 L
.08383 .03775 L
.08453 .04005 L
.08517 .04176 L
.08547 .04243 L
.08581 .04306 L
.0861 .04351 L
.08642 .0439 L
.08658 .04405 L
.08674 .04417 L
.08689 .04426 L
.08704 .04433 L
.08718 .04436 L
.08731 .04438 L
.08745 .04437 L
.08761 .04434 L
.08769 .04431 L
.08777 .04427 L
.08795 .04417 L
.08811 .04405 L
.08827 .04389 L
.08856 .04354 L
.08888 .04305 L
.08944 .04192 L
.09006 .04032 L
.09116 .03655 L
.09353 .02574 L
.09418 .02267 L
.09454 .0212 L
.09471 .0206 L
.09487 .02015 L
.09503 .01985 L
.0951 .01975 L
.09519 .01968 L
.09527 .01966 L
.09536 .0197 L
.09545 .01979 L
.09553 .01991 L
.09567 .02023 L
.09583 .02069 L
.09612 .02176 L
.09863 .03366 L
.09972 .03811 L
.1009 .0418 L
.10154 .04322 L
.10182 .0437 L
Mistroke
.10212 .04414 L
.10241 .04446 L
.10255 .04457 L
.10268 .04466 L
.10283 .04474 L
.10297 .04479 L
.10312 .04483 L
.10328 .04483 L
.10343 .04481 L
.10358 .04476 L
.10366 .04472 L
.10374 .04468 L
.10391 .04456 L
.10424 .04424 L
.10459 .04377 L
.10517 .04269 L
.10581 .0411 L
.10705 .03687 L
.10817 .03197 L
.10949 .02551 L
.11007 .02275 L
.11037 .02145 L
.11054 .02083 L
.1107 .02035 L
.11085 .02001 L
.11101 .01979 L
.11115 .01973 L
.11128 .01981 L
.11141 .01999 L
.11155 .0203 L
.11169 .02072 L
.11183 .0212 L
.11302 .02676 L
.11424 .03278 L
.11553 .03828 L
.11669 .04206 L
.11735 .04362 L
.11766 .0442 L
.11796 .04464 L
.11823 .04496 L
.11837 .04509 L
.11852 .04521 L
.11865 .04529 L
.11879 .04535 L
.11892 .04539 L
.11904 .0454 L
.11919 .0454 L
.11933 .04538 L
.11945 .04534 L
.11959 .04527 L
Mistroke
.11974 .04517 L
.1199 .04504 L
.12019 .04473 L
.1205 .04428 L
.12084 .04368 L
.12143 .04231 L
.12207 .04043 L
.12277 .03791 L
.12405 .03235 L
.12521 .02655 L
.12578 .02366 L
.12609 .02225 L
.12641 .02097 L
.12655 .02053 L
.1267 .02016 L
.12678 .02001 L
.12686 .0199 L
.12701 .01982 L
.12714 .01987 L
.12728 .02006 L
.12742 .02039 L
.12756 .0208 L
.1282 .02348 L
.12878 .0264 L
.13008 .03299 L
.13121 .03801 L
.1324 .04219 L
.13302 .04382 L
.13335 .04452 L
.1337 .04513 L
.13403 .04556 L
.13432 .04585 L
.13447 .04595 L
.13462 .04603 L
.13477 .04609 L
.1349 .04611 L
.13506 .04611 L
.13514 .0461 L
.13522 .04608 L
.13538 .04603 L
.13552 .04595 L
.13569 .04583 L
.13584 .04569 L
.13618 .04527 L
.13648 .0448 L
.1368 .04418 L
.13739 .04275 L
.13855 .03885 L
.13963 .03418 L
.14072 .02874 L
Mistroke
.14189 .02279 L
.14223 .02133 L
.1424 .02074 L
.14256 .02031 L
.1427 .02005 L
.14285 .01993 L
.14294 .01993 L
.14302 .01998 L
.14317 .02021 L
.14332 .02056 L
.14347 .02105 L
.14375 .02215 L
.14437 .0252 L
.1456 .03166 L
.14677 .03725 L
.1479 .04172 L
.1484 .04329 L
.14895 .04473 L
.1495 .04581 L
.1498 .04626 L
.15008 .04658 L
.15023 .04671 L
.15038 .04682 L
.15052 .04689 L
.15067 .04694 L
.15082 .04697 L
.15091 .04697 L
.15099 .04696 L
.15115 .04693 L
.1513 .04686 L
.15145 .04677 L
.15161 .04665 L
.15193 .04629 L
.15223 .04585 L
.15251 .04535 L
.15314 .04387 L
.15382 .04179 L
.15504 .03692 L
.15637 .03032 L
.15703 .02681 L
.15765 .02359 L
.15792 .02231 L
.1582 .02116 L
.15835 .02068 L
.15843 .02047 L
.15851 .02029 L
.15866 .02009 L
.1588 .02005 L
.15896 .02018 L
.1591 .02046 L
Mistroke
.15918 .02066 L
.15927 .02092 L
.15944 .02154 L
.16004 .02439 L
.16117 .03052 L
.16249 .03724 L
.1637 .04228 L
.16429 .04422 L
.16484 .04569 L
.16541 .04685 L
.16572 .04731 L
.16604 .04767 L
.16621 .0478 L
.16636 .0479 L
.16645 .04794 L
.16654 .04797 L
.16663 .04799 L
.16672 .048 L
.1668 .048 L
.16688 .04799 L
.16703 .04795 L
.16718 .04789 L
.16727 .04783 L
.16736 .04777 L
.16766 .04749 L
.16794 .04713 L
.16856 .04598 L
.16915 .04446 L
.16977 .04243 L
.17088 .03782 L
.1721 .03167 L
.17277 .02799 L
.1734 .02453 L
.17369 .02305 L
.17399 .02167 L
.17415 .02108 L
.17424 .02081 L
.17433 .02057 L
.17441 .0204 L
.17449 .02028 L
.17464 .02019 L
.17478 .02026 L
.17492 .02047 L
.17506 .02085 L
.17522 .02138 L
.17577 .02393 L
.17799 .0361 L
.17923 .04187 L
.17988 .04433 L
.18057 .04643 L
Mistroke
.18117 .0478 L
.18151 .04838 L
.18168 .04861 L
.18183 .04879 L
.18198 .04893 L
.18213 .04905 L
.18227 .04913 L
.1824 .04918 L
.18254 .04921 L
.18269 .04922 L
.18277 .04921 L
.18285 .0492 L
.183 .04914 L
.18315 .04906 L
.18329 .04895 L
.1836 .04863 L
.18388 .04822 L
.18415 .04774 L
.18476 .04633 L
.18542 .0443 L
.18674 .0388 L
.18796 .03239 L
.18905 .02614 L
.18965 .0229 L
.18995 .02159 L
.19009 .02108 L
.19022 .02072 L
.19038 .02044 L
.19046 .02037 L
.19055 .02035 L
.19063 .0204 L
.19071 .0205 L
.1908 .02067 L
.1909 .0209 L
.19105 .0214 L
.19119 .02197 L
.19151 .02351 L
.19271 .03043 L
.19496 .04237 L
.19558 .0449 L
.19624 .04713 L
.1968 .04863 L
.1971 .04927 L
.19741 .04982 L
.19757 .05004 L
.19774 .05025 L
.1979 .05041 L
.19805 .05052 L
.19813 .05057 L
.19822 .05061 L
Mistroke
.19832 .05065 L
.1984 .05067 L
.19849 .05068 L
.19858 .05068 L
.19874 .05066 L
.19888 .0506 L
.19904 .05051 L
.19919 .05039 L
.19933 .05025 L
.19966 .04982 L
.19998 .04927 L
.20058 .04785 L
.20114 .04613 L
.20241 .04089 L
.20358 .03468 L
.20484 .02714 L
.20543 .02379 L
.20574 .02221 L
.2059 .02157 L
.20604 .0211 L
.20617 .02078 L
.20629 .0206 L
.20642 .02055 L
.20656 .02066 L
.20671 .02094 L
.20686 .02141 L
.20714 .02257 L
.20933 .0356 L
.21054 .0422 L
.21168 .04719 L
.21227 .04916 L
.21258 .05002 L
.21292 .0508 L
.21322 .05139 L
.2135 .05181 L
.21363 .05198 L
.21378 .05213 L
.21391 .05223 L
.21404 .05232 L
.21418 .05238 L
.21431 .05242 L
.21446 .05243 L
.2146 .0524 L
.21475 .05235 L
.2149 .05226 L
.21505 .05214 L
.21519 .052 L
.21544 .05169 L
.2157 .05125 L
.21625 .05005 L
Mistroke
.21684 .04829 L
.21747 .04595 L
.21858 .04064 L
.2198 .03357 L
.22047 .02935 L
.2211 .0254 L
.22139 .02372 L
.2217 .02218 L
.22186 .02155 L
.22195 .02127 L
.22204 .02104 L
.22212 .02089 L
.2222 .0208 L
.22235 .02079 L
.22249 .02098 L
.22263 .02131 L
.22277 .02182 L
.22293 .02251 L
.22348 .0256 L
.2257 .03967 L
.22694 .04628 L
.2276 .04908 L
.22829 .05145 L
.22889 .053 L
.22924 .05364 L
.2294 .05389 L
.22956 .05408 L
.2297 .05423 L
.22985 .05436 L
.22999 .05444 L
.23012 .05449 L
.23026 .05452 L
.23041 .05452 L
.23049 .0545 L
.23057 .05447 L
.23072 .0544 L
.2308 .05434 L
.23088 .05428 L
.23103 .05414 L
.23135 .05371 L
.23163 .05321 L
.23194 .05253 L
.23263 .05051 L
.23327 .04806 L
.23445 .04222 L
.23569 .03457 L
.23683 .02693 L
.23713 .02501 L
.23746 .02312 L
.23761 .02239 L
Mistroke
.23777 .02175 L
.23791 .02134 L
.23806 .02108 L
.23821 .02104 L
.23834 .0212 L
.23849 .02158 L
.23865 .02217 L
.23892 .02349 L
.23921 .02524 L
.24027 .03244 L
.24159 .04124 L
.24283 .04827 L
.24395 .05302 L
.24425 .05402 L
.24458 .05494 L
.24488 .05565 L
.24516 .05618 L
.24529 .05639 L
.24544 .05659 L
.24559 .05675 L
.24572 .05687 L
.24587 .05697 L
.24595 .05701 L
.24603 .05704 L
.24617 .05706 L
.24632 .05706 L
.24645 .05702 L
.24659 .05695 L
.24674 .05684 L
.24688 .0567 L
.24713 .05638 L
.2474 .05592 L
.24772 .05524 L
.24806 .05431 L
.24869 .05216 L
.24986 .04666 L
.25221 .03132 L
.25285 .02675 L
.25318 .02453 L
.25337 .02345 L
.25354 .02258 L
.25369 .02197 L
.25377 .0217 L
.25385 .02152 L
.25393 .02138 L
.25402 .02132 L
.25411 .02135 L
.25419 .02145 L
.25433 .02178 L
.25448 .02233 L
Mistroke
.25479 .02393 L
.25727 .04174 L
.25835 .04865 L
.25953 .05459 L
.26015 .05694 L
.26043 .05778 L
.26073 .05857 L
.261 .05914 L
.26129 .05961 L
.26144 .05982 L
.26159 .05996 L
.26173 .06007 L
.26188 .06015 L
.26203 .06019 L
.26218 .06019 L
.26226 .06018 L
.26234 .06015 L
.2625 .06006 L
.26265 .05994 L
.2628 .05977 L
.26308 .05937 L
.2634 .05873 L
.26371 .05798 L
.2644 .05568 L
.265 .05308 L
.26565 .04963 L
.26684 .04196 L
.26799 .03331 L
.26855 .02892 L
.26907 .02513 L
.26936 .02337 L
.26952 .02258 L
.26967 .02204 L
.26982 .02173 L
.26991 .02167 L
.26999 .0217 L
.27007 .02181 L
.27016 .02202 L
.27024 .02229 L
.27032 .0226 L
.27058 .02398 L
.27086 .0259 L
.27145 .03039 L
.27277 .04103 L
.27398 .04982 L
.27511 .0565 L
.27568 .05915 L
.27631 .06144 L
.27664 .06237 L
.27694 .06305 L
Mistroke
.27711 .06335 L
.27729 .06363 L
.27746 .06383 L
.27761 .06397 L
.27776 .06406 L
.27789 .0641 L
.27804 .06411 L
.27812 .0641 L
.2782 .06408 L
.27835 .064 L
.27844 .06394 L
.27852 .06386 L
.27882 .06348 L
.27898 .06322 L
.27914 .06289 L
.27944 .06218 L
.2801 .05999 L
.28068 .05747 L
.2813 .05409 L
.28355 .03764 L
.28413 .03269 L
.28476 .02741 L
.28505 .02522 L
.28521 .02416 L
.28536 .02331 L
.28548 .02273 L
.28562 .02229 L
.28577 .02208 L
.28591 .02217 L
.28599 .02232 L
.28607 .02258 L
.28622 .02322 L
.28639 .02424 L
.28655 .02534 L
.28723 .03093 L
.28843 .04167 L
.28956 .05099 L
.29075 .05922 L
.29137 .06265 L
.29206 .06564 L
.29236 .06667 L
.29268 .06759 L
.29298 .06826 L
.29313 .06851 L
.29326 .06871 L
.2934 .06889 L
.29354 .06901 L
.29368 .0691 L
.29384 .06915 L
.29398 .06915 L
Mistroke
.29414 .0691 L
.29422 .06906 L
.2943 .06899 L
.29445 .06885 L
.2946 .06866 L
.29475 .06841 L
.29503 .06784 L
.29556 .06632 L
.29619 .06377 L
.29686 .06023 L
.29806 .05192 L
.29929 .04139 L
.30045 .0304 L
.30095 .02597 L
.3011 .02488 L
.30123 .02399 L
.30136 .02333 L
.30149 .02283 L
.30164 .02257 L
.3018 .02268 L
.30193 .02308 L
.30208 .0238 L
.30222 .02466 L
.30236 .02576 L
.30263 .02802 L
.30497 .051 L
.30628 .06198 L
.30749 .06965 L
.30809 .07237 L
.30839 .07348 L
.30872 .07444 L
.30889 .07484 L
.30905 .07515 L
.30921 .07541 L
.30935 .0756 L
.30944 .07569 L
.30952 .07575 L
.3096 .0758 L
.30969 .07584 L
.30978 .07586 L
.30988 .07586 L
.30997 .07584 L
.31005 .0758 L
.31019 .07571 L
.31034 .07555 L
.31049 .07535 L
.31062 .07513 L
.31093 .07443 L
.31123 .07354 L
.31183 .07116 L
Mistroke
.31248 .06767 L
.31373 .05854 L
.31486 .04795 L
.31618 .03385 L
.31676 .02785 L
.31692 .0264 L
.31709 .02503 L
.31717 .02446 L
.31725 .024 L
.31739 .02338 L
.31753 .02313 L
.31767 .02327 L
.3178 .02369 L
.31794 .02445 L
.31808 .02552 L
.31824 .0269 L
.31852 .02977 L
.31972 .04344 L
.32102 .05795 L
.32223 .06947 L
.32345 .07829 L
.32409 .08159 L
.32445 .083 L
.32478 .08399 L
.32493 .08435 L
.32509 .08467 L
.32523 .08489 L
.32538 .08508 L
.32546 .08515 L
.32554 .08521 L
.32563 .08525 L
.32572 .08527 L
.32587 .08525 L
.32595 .08522 L
.32603 .08517 L
.32617 .08504 L
.3263 .08487 L
.32644 .08463 L
.3266 .0843 L
.32691 .08344 L
.3272 .08242 L
.32778 .07974 L
.32839 .07594 L
.32949 .06682 L
.33198 .03779 L
.33258 .03028 L
.33274 .02847 L
.33291 .0267 L
.33307 .02533 L
.33322 .02437 L
Mistroke
.3333 .02402 L
.33339 .02383 L
.33355 .02398 L
.33364 .02433 L
.33374 .02491 L
.33391 .02636 L
.33425 .03009 L
.33455 .03401 L
.33699 .06692 L
.33812 .07984 L
.33931 .09042 L
.33993 .09446 L
.34029 .09625 L
.34062 .09758 L
.34078 .09809 L
.34092 .0985 L
.34106 .09882 L
.3412 .09909 L
.34136 .09931 L
.3415 .09945 L
.34165 .09952 L
.34174 .09952 L
.34182 .09951 L
.34196 .09942 L
.34212 .09926 L
.34226 .09904 L
.34239 .09878 L
.34271 .0979 L
.34301 .09677 L
.34361 .09362 L
.34426 .08892 L
.34542 .07734 L
.34649 .06348 L
.34759 .04695 L
.34819 .03734 L
.34876 .02886 L
.34892 .02699 L
.349 .02613 L
.34908 .02547 L
.34917 .02496 L
.34926 .02466 L
.34935 .02466 L
.34943 .02491 L
.34959 .02596 L
.34967 .02673 L
.34975 .02771 L
.35005 .03184 L
.35125 .0526 L
.35257 .07543 L
.35381 .09451 L
Mistroke
.35493 .10836 L
.35556 .11446 L
.35614 .11886 L
.35641 .12047 L
.3567 .12189 L
.35697 .12292 L
.35709 .12328 L
.35722 .1236 L
.35738 .12388 L
.35752 .12406 L
.3576 .12412 L
.35769 .12416 L
.35784 .12414 L
.35798 .12404 L
.35812 .12386 L
.35827 .12358 L
.35842 .12318 L
.35871 .12217 L
.35902 .12069 L
.35957 .11697 L
.36024 .11083 L
.36084 .10365 L
.36334 .05993 L
.36444 .03614 L
.36474 .03023 L
.36482 .02884 L
.36491 .02757 L
.36506 .026 L
.36521 .02566 L
.36534 .02645 L
.36549 .02832 L
.36565 .03111 L
.36789 .08647 L
.37027 .14067 L
.37151 .16145 L
.3722 .17007 L
.37254 .17328 L
.37285 .17573 L
.37312 .17742 L
.37326 .17812 L
.37341 .17875 L
.3735 .17904 L
.37358 .17927 L
.37373 .17961 L
.37388 .17979 L
.37403 .17984 L
.37411 .1798 L
.37419 .17972 L
.37428 .1796 L
.37437 .17941 L
Mistroke
.37452 .17897 L
.37468 .17832 L
.37499 .17664 L
.37528 .17449 L
.37588 .16811 L
.37654 .15831 L
.37716 .14631 L
.37774 .13289 L
.37998 .06069 L
.38054 .03924 L
.3807 .03352 L
.38085 .02906 L
.38099 .02695 L
.38114 .02797 L
.38129 .03172 L
.38142 .0364 L
.38171 .04879 L
.38223 .07364 L
.38472 .20583 L
.38724 .34453 L
.38955 .45895 L
.39072 .50703 L
.39181 .54423 L
.39295 .57396 L
.39355 .58567 L
.39386 .59061 L
.3942 .59498 L
.3945 .59816 L
.39466 .59954 L
.39483 .60079 L
.39499 .60171 L
.39514 .60237 L
.39528 .60285 L
.39542 .60317 L
.39558 .60332 L
.39567 .60331 L
.39575 .60324 L
.39591 .60296 L
.39606 .6025 L
.39614 .60217 L
.39623 .60174 L
.39639 .60082 L
.39676 .59797 L
.39704 .59495 L
.39735 .59099 L
.39791 .58194 L
.39918 .55284 L
.4004 .51486 L
.40173 .46412 L
.40416 .3548 L
Mistroke
.40673 .23058 L
.40906 .12675 L
.41023 .08208 L
.41085 .06141 L
.41118 .05119 L
.4115 .04258 L
.41179 .03563 L
.41192 .03318 L
.41207 .03108 L
.41222 .02966 L
.41237 .02929 L
.41245 .02951 L
.41254 .03002 L
.41269 .03156 L
.41282 .03328 L
.41296 .03539 L
.41321 .03958 L
.41379 .04926 L
.41435 .05772 L
.41494 .06524 L
.41529 .06879 L
.4156 .07153 L
.41589 .07371 L
.41621 .07556 L
.41636 .07631 L
.41653 .07701 L
.41669 .07755 L
.41684 .07793 L
.41701 .07828 L
.4171 .07842 L
.41719 .07851 L
.41735 .07861 L
.41743 .07861 L
.41752 .07859 L
.41759 .07855 L
.41768 .07847 L
.41783 .07827 L
.41798 .07799 L
.41812 .07766 L
.41843 .07667 L
.41875 .07528 L
.41935 .07189 L
.4199 .06797 L
.42113 .05699 L
.42334 .03383 L
.42392 .02795 L
.42454 .02233 L
.4248 .0204 L
.42494 .01954 L
.42507 .01893 L
Mistroke
.42523 .01857 L
.42537 .01864 L
.4255 .01902 L
.42565 .01966 L
.42816 .03342 L
.42938 .03935 L
.43053 .0472 L
.43117 .0533 L
.43186 .06159 L
.43306 .08023 L
.43546 .13045 L
.438 .19311 L
.4404 .24953 L
.44145 .27049 L
.44258 .28939 L
.44321 .29778 L
.44379 .30411 L
.44435 .3088 L
.44463 .31064 L
.44494 .31226 L
.4451 .31292 L
.44526 .31348 L
.44541 .31386 L
.44556 .31416 L
.44565 .31428 L
.44573 .31436 L
.44582 .31441 L
.44591 .31441 L
.44607 .31434 L
.44616 .31424 L
.44624 .31412 L
.44638 .31383 L
.44652 .31346 L
.44683 .31228 L
.44713 .3107 L
.44746 .3085 L
.44809 .3028 L
.44868 .29588 L
.45001 .27468 L
.45119 .25036 L
.45244 .21975 L
.45485 .15222 L
.45612 .11571 L
.45746 .08 L
.45804 .06668 L
.45836 .06036 L
.45866 .0553 L
.45883 .05293 L
.45902 .05082 L
.4591 .05006 L
Mistroke
.45919 .04938 L
.45934 .04848 L
.4595 .048 L
.45964 .04793 L
.45973 .04804 L
.45981 .04825 L
.45989 .04857 L
.45998 .04902 L
.46012 .04998 L
.46026 .05104 L
.46055 .05398 L
.46109 .0604 L
.4623 .07564 L
.46288 .08203 L
.4635 .08764 L
.46403 .09137 L
.46433 .09303 L
.46461 .09429 L
.46477 .09487 L
.46494 .09539 L
.46508 .09574 L
.46524 .09604 L
.46533 .09617 L
.46541 .09627 L
.46549 .09634 L
.46559 .09639 L
.46567 .09641 L
.46576 .0964 L
.46591 .09632 L
.46606 .09617 L
.46621 .09593 L
.46636 .09562 L
.46649 .09528 L
.46682 .09421 L
.46712 .09288 L
.46768 .08976 L
.46829 .08537 L
.46953 .07425 L
.47067 .06305 L
.47124 .05808 L
.47176 .05438 L
.47204 .05291 L
.4722 .05228 L
.47234 .05185 L
.4725 .05153 L
.47259 .05143 L
.47267 .05138 L
.47282 .0514 L
.47298 .0516 L
.47312 .05189 L
Mistroke
.47326 .05233 L
.47352 .05343 L
.47382 .0552 L
.4741 .05716 L
.47541 .06881 L
.47662 .07976 L
.4772 .08418 L
.47774 .08763 L
.4783 .09036 L
.4786 .09142 L
.47877 .09188 L
.47892 .09223 L
.47907 .09248 L
.47923 .09267 L
.47932 .09274 L
.4794 .09278 L
.47956 .09278 L
.47964 .09275 L
.47973 .09268 L
.47988 .0925 L
.47997 .09237 L
.48005 .09221 L
.48023 .09177 L
.48053 .09077 L
.48081 .08955 L
.48143 .08574 L
.482 .08088 L
.48262 .07437 L
.48372 .05956 L
.4844 .04921 L
.48473 .04422 L
.48504 .04008 L
.48518 .03842 L
.48531 .03713 L
.48545 .03612 L
.48561 .0355 L
.48576 .03549 L
.48591 .03604 L
.48598 .03657 L
.48607 .03733 L
.48622 .03913 L
.48651 .04357 L
.48681 .04956 L
.48736 .06236 L
.48862 .09628 L
.49115 .17173 L
.49353 .2391 L
.49478 .26978 L
.49612 .29686 L
.49679 .30782 L
Mistroke
.49742 .31642 L
.49799 .32263 L
.49828 .32525 L
.4986 .32766 L
.49889 .32938 L
.49919 .3308 L
.49935 .33139 L
.49951 .33181 L
.49966 .33212 L
.4998 .33231 L
.49994 .3324 L
.50008 .33239 L
.5002 .33231 L
.50033 .33214 L
.50048 .33185 L
.50063 .33144 L
.50091 .33039 L
.5012 .32891 L
.50151 .32689 L
.50206 .32212 L
.50272 .31458 L
.50332 .30606 L
.50463 .28239 L
.50587 .25443 L
.51051 .12199 L
.51174 .08612 L
.5129 .05598 L
.51348 .04372 L
.51365 .0409 L
.51381 .03867 L
.51395 .0371 L
.51411 .03595 L
.5142 .03558 L
.51429 .03542 L
.51444 .03565 L
.51453 .03605 L
.51461 .03657 L
.5148 .03821 L
.51511 .042 L
.51544 .04676 L
.51658 .06403 L
.51721 .07237 L
.51781 .07907 L
.51837 .08415 L
.51866 .08636 L
.51897 .08834 L
.51923 .08973 L
.51952 .09095 L
.51964 .09139 L
.51978 .09179 L
Mistroke
.5199 .09211 L
.52002 .09235 L
.52018 .09258 L
.52031 .09272 L
.52046 .09279 L
.52055 .09279 L
.52062 .09277 L
.52075 .09269 L
.52089 .09254 L
.52104 .0923 L
.52118 .09201 L
.5215 .0911 L
.52179 .08999 L
.52244 .08656 L
.52307 .08223 L
.52375 .07659 L
.52499 .06504 L
.52553 .06012 L
.52612 .05558 L
.52646 .05358 L
.5266 .05288 L
.52676 .05225 L
.52692 .05181 L
.52706 .05153 L
.52721 .05138 L
.52729 .05137 L
.52737 .0514 L
.52753 .05158 L
.52761 .05173 L
.52769 .05195 L
.52785 .05246 L
.52799 .05307 L
.52832 .05487 L
.52867 .05736 L
.5299 .06867 L
.53112 .08043 L
.53177 .08584 L
.53245 .09058 L
.53279 .09246 L
.53311 .09392 L
.5334 .09495 L
.53355 .09538 L
.53371 .09577 L
.53386 .09605 L
.534 .09624 L
.53415 .09636 L
.53424 .0964 L
.53432 .09641 L
.53445 .09637 L
.5346 .09625 L
Mistroke
.53474 .09607 L
.53487 .09583 L
.53502 .0955 L
.53517 .09507 L
.53543 .0941 L
.53572 .09276 L
.53604 .09095 L
.5366 .08679 L
.53713 .08195 L
.5384 .06698 L
.53903 .0589 L
.53931 .05555 L
.53961 .05227 L
.53975 .05095 L
.53991 .04974 L
.54005 .04885 L
.54019 .04827 L
.54034 .04794 L
.54042 .04791 L
.5405 .04799 L
.54064 .04841 L
.5408 .04925 L
.54088 .04991 L
.54096 .05062 L
.54114 .0526 L
.54147 .05733 L
.54208 .0692 L
.54432 .12823 L
.54679 .19894 L
.54909 .25651 L
.55023 .27905 L
.55131 .29569 L
.5519 .30273 L
.55221 .30579 L
.55255 .30854 L
.55283 .31045 L
.55313 .31212 L
.55327 .31271 L
.55341 .31325 L
.55355 .31366 L
.55368 .31396 L
.55383 .31422 L
.55397 .31437 L
.55412 .31442 L
.5542 .3144 L
.55428 .31435 L
.55441 .31421 L
.55455 .31396 L
.5547 .3136 L
.55483 .31317 L
Mistroke
.55515 .31184 L
.55544 .31021 L
.5561 .30515 L
.55672 .29855 L
.55741 .28955 L
.55865 .26879 L
.56356 .15404 L
.566 .09812 L
.5672 .07585 L
.56829 .05965 L
.56936 .04816 L
.56989 .04388 L
.57048 .04013 L
.57284 .0285 L
.57348 .02487 L
.57408 .02117 L
.57434 .0197 L
.57447 .0191 L
.57462 .01866 L
.57478 .01857 L
.57492 .01891 L
.57506 .01952 L
.57521 .02041 L
.57588 .0261 L
.57652 .03245 L
.57773 .0452 L
.57889 .05716 L
.58012 .06814 L
.58072 .07237 L
.58102 .0741 L
.58129 .07546 L
.58153 .07649 L
.58179 .0774 L
.58192 .07776 L
.58206 .07807 L
.5822 .07833 L
.58234 .07849 L
.58249 .07859 L
.58257 .07861 L
.58265 .07861 L
.58281 .07852 L
.5829 .07842 L
.58298 .0783 L
.58312 .07804 L
.58327 .07767 L
.58357 .07661 L
.5839 .07496 L
.58426 .07262 L
.5849 .06688 L
.58556 .05902 L
Mistroke
.58618 .04984 L
.58677 .03982 L
.58707 .035 L
.58719 .0331 L
.58733 .0313 L
.58747 .02998 L
.5876 .02934 L
.58775 .02951 L
.58789 .03059 L
.58805 .03272 L
.58819 .03531 L
.58851 .04266 L
.58975 .08142 L
.59197 .17105 L
.59682 .40063 L
.59904 .49467 L
.6003 .53786 L
.60091 .55548 L
.60147 .56933 L
.60203 .58093 L
.60264 .59089 L
.60297 .59515 L
.60328 .59831 L
.60357 .60062 L
.60372 .60151 L
.60389 .60229 L
.60397 .6026 L
.60406 .60287 L
.60414 .60307 L
.60422 .6032 L
.60436 .60332 L
.60452 .60325 L
.60461 .60312 L
.6047 .6029 L
.60479 .60263 L
.60488 .60232 L
.60503 .60158 L
.6052 .60057 L
.6055 .59814 L
.60579 .59518 L
.60643 .58602 L
.60703 .57439 L
.60769 .55852 L
.60888 .52154 L
.61112 .428 L
.61346 .30695 L
.61604 .16395 L
.61721 .10144 L
.61783 .07047 L
.61817 .05445 L
Mistroke
.61848 .04056 L
.61862 .03492 L
.61876 .0304 L
.61891 .02719 L
.61905 .02734 L
.61921 .03067 L
.61935 .03529 L
.61968 .04741 L
.62077 .08811 L
.62186 .1223 L
.62304 .15045 L
.62371 .16238 L
.62432 .17056 L
.62462 .17356 L
.62494 .17617 L
.62509 .17712 L
.62524 .17798 L
.62539 .17863 L
.62552 .17911 L
.62567 .1795 L
.62575 .17965 L
.62584 .17976 L
.62593 .17982 L
.62601 .17984 L
.62617 .17975 L
.62632 .17952 L
.62646 .17918 L
.62661 .17868 L
.62677 .178 L
.6271 .17611 L
.62741 .17376 L
.62811 .16647 L
.62872 .15808 L
.62928 .14889 L
.63055 .12374 L
.63174 .09558 L
.63302 .06312 L
.63365 .04735 L
.63395 .03991 L
.63423 .03354 L
.63449 .02866 L
.63462 .02687 L
.63476 .02576 L
.6349 .0258 L
.63505 .02707 L
.6352 .02913 L
.63533 .03145 L
.63649 .0562 L
.63772 .08089 L
.63886 .09955 L
Mistroke
.63993 .11256 L
.64046 .11721 L
.64102 .1209 L
.64133 .12233 L
.6415 .12293 L
.64165 .12338 L
.64178 .12369 L
.64193 .12393 L
.64209 .1241 L
.64223 .12416 L
.64238 .12413 L
.64246 .12407 L
.64255 .12398 L
.6427 .12374 L
.64285 .12343 L
.64301 .12296 L
.64317 .12243 L
.64352 .12088 L
.64414 .11692 L
.64473 .11184 L
.64589 .0986 L
.64712 .08051 L
.64934 .04212 L
.64994 .03198 L
.65025 .0277 L
.65033 .02675 L
.65042 .02588 L
.6505 .02525 L
.65058 .02485 L
.65067 .02464 L
.65075 .02469 L
.65084 .02501 L
.65094 .02563 L
.65102 .02636 L
.6511 .02718 L
.65128 .02939 L
.65192 .03912 L
.65436 .07471 L
.65554 .08724 L
.65614 .09197 L
.65648 .09418 L
.65679 .09586 L
.65706 .09706 L
.65735 .09809 L
.65751 .09854 L
.65766 .09888 L
.6578 .09914 L
.65795 .09934 L
.65808 .09945 L
.65821 .09952 L
Mistroke
.65834 .09952 L
.65846 .09947 L
.6586 .09936 L
.65875 .09917 L
.65889 .09892 L
.65902 .09864 L
.65934 .09771 L
.65964 .09657 L
.6603 .09306 L
.66089 .08892 L
.6615 .08358 L
.66375 .05738 L
.6649 .04153 L
.66553 .03291 L
.66584 .02903 L
.66597 .0275 L
.66612 .02602 L
.66626 .02491 L
.66639 .02418 L
.66653 .02382 L
.66668 .02396 L
.66676 .02424 L
.66684 .02469 L
.667 .02583 L
.66728 .02872 L
.66834 .04189 L
.66956 .05679 L
.67071 .06863 L
.67135 .07397 L
.67203 .07866 L
.67234 .08034 L
.67266 .08186 L
.67294 .08295 L
.67324 .08389 L
.6734 .08429 L
.67354 .0846 L
.67368 .08484 L
.67383 .08504 L
.67397 .08517 L
.6741 .08524 L
.67423 .08527 L
.67438 .08524 L
.67453 .08516 L
.67461 .08508 L
.67469 .085 L
.67485 .08477 L
.67502 .08446 L
.67533 .0837 L
.6756 .08279 L
.67615 .08045 L
Mistroke
.67674 .07711 L
.67781 .06907 L
.68016 .0448 L
.68141 .03048 L
.68177 .02684 L
.68194 .02532 L
.68203 .02468 L
.68211 .02418 L
.68226 .02347 L
.68241 .02314 L
.6825 .02315 L
.68259 .02332 L
.68267 .0236 L
.68275 .02397 L
.68289 .02486 L
.68304 .02604 L
.68332 .02858 L
.68394 .03517 L
.6852 .04857 L
.68639 .05958 L
.6875 .06754 L
.68809 .0708 L
.68873 .0734 L
.68905 .07439 L
.68936 .07509 L
.68954 .07539 L
.6897 .0756 L
.68978 .07568 L
.68988 .07576 L
.68997 .07582 L
.69006 .07585 L
.69021 .07586 L
.6903 .07584 L
.69038 .07581 L
.69052 .07572 L
.69068 .07557 L
.69082 .07538 L
.69094 .07517 L
.69124 .07455 L
.69155 .07366 L
.69184 .07266 L
.69249 .06975 L
.69368 .06226 L
.69479 .0532 L
.69608 .04084 L
.69671 .03446 L
.69729 .02878 L
.69756 .02637 L
.69781 .02444 L
.69794 .02366 L
Mistroke
.69808 .02303 L
.69823 .02263 L
.69837 .02258 L
.69852 .02286 L
.69866 .0234 L
.69881 .02425 L
.69897 .02537 L
.69954 .03024 L
.70073 .04155 L
.70202 .05255 L
.70265 .05713 L
.70325 .06087 L
.70383 .06388 L
.70437 .06609 L
.70489 .06764 L
.70517 .06827 L
.70543 .0687 L
.70558 .06888 L
.70571 .06901 L
.70586 .0691 L
.70602 .06915 L
.70616 .06915 L
.70629 .06911 L
.70643 .06903 L
.70658 .0689 L
.70673 .06873 L
.70689 .06849 L
.70722 .06783 L
.70752 .06703 L
.70781 .06612 L
.70845 .0635 L
.70914 .05985 L
.71157 .04165 L
.71282 .03048 L
.71314 .02779 L
.71343 .02546 L
.7137 .02369 L
.71385 .02291 L
.71399 .0224 L
.71412 .02213 L
.71427 .02211 L
.71443 .02242 L
.71457 .02298 L
.71473 .02381 L
.71488 .02472 L
.7152 .02713 L
.71653 .03833 L
.71764 .04711 L
.71883 .05484 L
.71951 .05834 L
Mistroke
.72012 .06082 L
.72042 .06178 L
.72074 .06264 L
.72105 .06327 L
.72133 .06369 L
.72148 .06386 L
.72162 .06399 L
.72175 .06406 L
.7219 .06411 L
.72205 .06411 L
.72213 .0641 L
.72221 .06407 L
.72236 .06399 L
.7225 .06387 L
.72264 .06372 L
.72278 .06353 L
.72303 .0631 L
.72331 .06251 L
.7236 .06171 L
.72423 .05952 L
.72489 .05647 L
.7261 .04934 L
.7285 .03081 L
.72916 .02572 L
.72949 .02356 L
.72958 .02307 L
.72968 .0226 L
.72977 .02224 L
.72986 .02198 L
.72994 .0218 L
.73002 .0217 L
.7301 .02167 L
.73019 .02175 L
.73027 .02189 L
.73036 .02212 L
.73051 .02272 L
.73066 .02349 L
.73082 .02444 L
.73111 .02638 L
.73232 .03567 L
.73361 .04503 L
.73483 .0522 L
.73537 .05471 L
.73594 .05688 L
.73622 .05775 L
.73652 .05857 L
.73681 .05917 L
.73707 .0596 L
.73721 .05979 L
.73737 .05996 L
Mistroke
.73746 .06003 L
.73754 .06009 L
.73762 .06013 L
.7377 .06016 L
.73778 .06018 L
.73786 .06019 L
.73801 .06018 L
.73816 .06013 L
.7383 .06005 L
.73843 .05995 L
.73856 .05981 L
.73881 .05946 L
.73911 .05892 L
.73938 .05829 L
.73997 .05653 L
.74053 .05436 L
.74169 .04841 L
.74293 .04037 L
.74409 .03185 L
.7446 .02808 L
.74489 .02604 L
.74515 .02429 L
.7453 .02342 L
.74544 .02269 L
.74558 .0221 L
.7457 .02168 L
.74584 .02141 L
.74598 .02133 L
.74613 .02148 L
.74628 .02188 L
.74643 .02243 L
.74658 .02319 L
.74686 .02484 L
.7475 .02922 L
.74971 .04422 L
.75093 .05059 L
.75162 .05331 L
.75195 .05435 L
.75226 .05519 L
.75256 .05584 L
.75288 .0564 L
.75302 .05659 L
.75317 .05676 L
.7533 .05687 L
.75344 .05697 L
.75352 .05701 L
.7536 .05704 L
.75375 .05707 L
.75383 .05706 L
.75391 .05705 L
Mistroke
.754 .05703 L
.75409 .057 L
.75423 .05691 L
.75437 .05679 L
.75453 .05663 L
.75469 .05642 L
.75499 .0559 L
.75532 .0552 L
.75591 .05352 L
.7566 .05088 L
.75724 .04794 L
.75966 .03294 L
.76079 .02524 L
.76106 .02359 L
.76136 .02213 L
.76144 .02179 L
.76152 .02152 L
.76168 .02116 L
.76182 .02103 L
.76198 .02112 L
.76214 .02145 L
.76223 .02173 L
.76231 .02205 L
.76266 .02378 L
.76329 .02772 L
.76449 .03575 L
.76568 .04289 L
.76632 .04621 L
.76692 .04885 L
.76748 .05088 L
.76799 .05235 L
.76826 .05299 L
.76855 .05355 L
.76871 .05381 L
.76886 .05401 L
.769 .05417 L
.76915 .05431 L
.76931 .05441 L
.76945 .05448 L
.76959 .05452 L
.76972 .05452 L
.76987 .0545 L
.77001 .05444 L
.77009 .0544 L
.77017 .05434 L
.77032 .05421 L
.7706 .05389 L
.77089 .05342 L
.77142 .05227 L
.77203 .05044 L
Mistroke
.7726 .04828 L
.77391 .04194 L
.77616 .02789 L
.77677 .02407 L
.77711 .02232 L
.77728 .02163 L
.77743 .02116 L
.77756 .02089 L
.7777 .02077 L
.77784 .02083 L
.77799 .02109 L
.77814 .02155 L
.77831 .02221 L
.7786 .02369 L
.77995 .032 L
.78117 .0393 L
.78243 .04552 L
.78299 .0477 L
.7836 .04964 L
.78388 .05037 L
.78418 .05103 L
.78444 .0515 L
.78472 .05191 L
.78489 .05209 L
.78504 .05222 L
.78519 .05232 L
.78534 .05239 L
.78548 .05242 L
.78561 .05243 L
.78576 .0524 L
.78591 .05234 L
.78607 .05225 L
.78622 .05213 L
.78655 .05174 L
.78687 .05122 L
.78722 .0505 L
.78785 .04878 L
.78842 .04678 L
.78962 .04139 L
.79073 .03524 L
.79203 .02731 L
.79266 .02361 L
.79294 .02223 L
.79308 .02162 L
.79324 .02109 L
.79339 .02073 L
.79353 .02056 L
.79367 .02056 L
.7938 .02072 L
.79393 .02101 L
Mistroke
.79405 .02139 L
.79433 .02254 L
.7955 .02921 L
.79679 .03672 L
.79799 .0427 L
.79908 .04686 L
.7997 .04856 L
.80026 .04969 L
.80058 .05014 L
.80073 .05031 L
.80087 .05044 L
.80102 .05055 L
.80111 .0506 L
.80119 .05063 L
.80128 .05066 L
.80137 .05068 L
.80145 .05068 L
.80154 .05068 L
.8017 .05065 L
.80184 .05058 L
.80192 .05054 L
.80201 .05048 L
.80217 .05034 L
.80247 .04999 L
.80275 .04956 L
.80331 .04837 L
.80392 .04665 L
.80501 .04247 L
.8075 .02916 L
.8081 .02569 L
.80873 .02235 L
.80891 .02156 L
.809 .02122 L
.80909 .02095 L
.80925 .02057 L
.80933 .02044 L
.80942 .02037 L
.80957 .02039 L
.80972 .0206 L
.80981 .02079 L
.80988 .02101 L
.81006 .02161 L
.81065 .0245 L
.8113 .02818 L
.81248 .03484 L
.81372 .04089 L
.81487 .04526 L
.81545 .04688 L
.81575 .04755 L
.81608 .04816 L
Mistroke
.81626 .04845 L
.81643 .04867 L
.81661 .04886 L
.81677 .049 L
.81693 .04911 L
.81708 .04918 L
.81724 .04921 L
.81733 .04922 L
.81741 .04922 L
.81756 .04919 L
.8177 .04914 L
.81783 .04907 L
.81797 .04897 L
.81829 .04865 L
.81858 .04823 L
.81911 .04721 L
.81968 .04575 L
.82086 .04151 L
.82217 .03531 L
.8233 .02906 L
.82392 .02557 L
.8245 .02257 L
.8248 .02129 L
.82497 .02075 L
.82512 .02039 L
.82521 .02027 L
.82529 .0202 L
.82538 .02019 L
.82548 .02024 L
.82564 .02049 L
.82573 .02071 L
.82581 .02096 L
.82611 .02212 L
.82639 .02343 L
.82701 .02676 L
.82822 .03335 L
.8295 .03953 L
.83012 .04203 L
.83071 .04403 L
.83123 .04548 L
.83153 .04616 L
.83181 .04671 L
.8321 .04718 L
.83237 .04752 L
.8325 .04766 L
.83265 .04778 L
.83281 .04788 L
.83296 .04795 L
.83309 .04798 L
.83323 .048 L
Mistroke
.83337 .04799 L
.83351 .04795 L
.83364 .0479 L
.83376 .04783 L
.83402 .04761 L
.83431 .04727 L
.83458 .04687 L
.83519 .04562 L
.83578 .044 L
.83642 .04185 L
.83882 .03056 L
.84008 .02375 L
.84039 .02227 L
.84072 .02096 L
.84082 .02066 L
.84091 .02042 L
.84099 .02026 L
.84108 .02013 L
.84117 .02006 L
.84126 .02005 L
.84135 .02009 L
.84142 .02018 L
.84158 .02049 L
.84166 .0207 L
.84175 .02097 L
.84205 .02214 L
.84272 .02546 L
.84393 .03194 L
.84512 .03766 L
.84625 .04203 L
.84684 .04383 L
.84715 .04462 L
.84748 .04534 L
.84776 .04584 L
.84807 .04629 L
.84835 .0466 L
.84848 .04672 L
.84861 .04681 L
.84876 .04689 L
.84885 .04693 L
.84893 .04695 L
.84902 .04697 L
.8491 .04697 L
.84924 .04696 L
.84939 .04693 L
.84952 .04687 L
.84967 .04679 L
.84983 .04667 L
.85015 .04633 L
.85045 .0459 L
Mistroke
.85113 .04453 L
.85174 .04288 L
.85239 .04067 L
.85359 .03564 L
.85583 .02418 L
.85637 .02165 L
.85652 .02108 L
.85668 .02057 L
.85681 .02024 L
.85696 .02 L
.85704 .01994 L
.85712 .01992 L
.85721 .01996 L
.85729 .02004 L
.85744 .02031 L
.85753 .02053 L
.8576 .02076 L
.85821 .02325 L
.85952 .02997 L
.86074 .0359 L
.86193 .04061 L
.86244 .04227 L
.86301 .04375 L
.86333 .04444 L
.86362 .04497 L
.86392 .04542 L
.86421 .04573 L
.86436 .04587 L
.86453 .04598 L
.86469 .04606 L
.86483 .0461 L
.86499 .04612 L
.86507 .04611 L
.86515 .0461 L
.86524 .04608 L
.86532 .04606 L
.86541 .04602 L
.8655 .04597 L
.86563 .04588 L
.86578 .04576 L
.86605 .04547 L
.86637 .04501 L
.86666 .0445 L
.86727 .04313 L
.8679 .04127 L
.86896 .03731 L
.87012 .03199 L
.87134 .02577 L
.87194 .02282 L
.87221 .02167 L
Mistroke
.87249 .02063 L
.87257 .02041 L
.87265 .02021 L
.8728 .01994 L
.87289 .01985 L
.87297 .01982 L
.87313 .01989 L
.87321 .02 L
.8733 .02016 L
.87346 .02056 L
.87363 .02112 L
.87382 .02186 L
.87502 .02771 L
.87625 .03375 L
.87755 .03912 L
.87865 .04253 L
.87896 .04325 L
.87928 .04391 L
.87957 .04439 L
.87987 .0448 L
.88002 .04496 L
.88018 .04511 L
.88033 .04522 L
.88047 .0453 L
.88055 .04534 L
.88063 .04537 L
.88071 .04539 L
.88081 .0454 L
.88088 .04541 L
.88097 .0454 L
.88112 .04538 L
.88128 .04532 L
.88136 .04528 L
.88144 .04523 L
.88174 .04498 L
.88202 .04467 L
.88231 .04425 L
.88286 .04319 L
.88337 .04191 L
.88453 .03806 L
.88678 .02779 L
.88739 .02469 L
.88773 .02307 L
.88805 .02168 L
.88832 .0207 L
.88847 .02026 L
.88861 .01996 L
.88875 .01978 L
.88891 .01974 L
.88899 .01978 L
Mistroke
.88907 .01988 L
.88922 .02016 L
.88931 .02037 L
.88939 .02063 L
.88955 .02117 L
.88991 .02266 L
.89057 .02579 L
.89179 .03178 L
.89296 .03688 L
.8936 .03925 L
.89421 .04115 L
.8948 .04263 L
.89512 .04327 L
.89545 .04383 L
.89575 .04424 L
.89603 .04452 L
.89617 .04462 L
.89631 .04471 L
.89645 .04477 L
.89657 .04481 L
.8967 .04483 L
.89684 .04483 L
.89697 .04481 L
.89709 .04478 L
.89723 .04472 L
.89738 .04463 L
.89765 .0444 L
.89794 .04406 L
.89824 .04361 L
.89878 .04256 L
.89938 .04105 L
.89992 .03938 L
.90114 .03468 L
.90334 .02417 L
.90392 .0216 L
.90408 .02097 L
.90424 .02047 L
.90438 .0201 L
.90453 .01982 L
.90466 .01969 L
.90481 .01968 L
.90496 .01983 L
.9051 .02009 L
.90524 .02044 L
.90536 .02083 L
.90563 .02186 L
.90813 .03362 L
.90925 .03806 L
.90986 .04006 L
.91043 .04162 L
Mistroke
.91105 .04293 L
.91138 .04345 L
.91173 .04389 L
.91204 .04416 L
.91219 .04425 L
.91228 .04429 L
.91236 .04433 L
.9125 .04436 L
.91266 .04438 L
.9128 .04436 L
.91294 .04433 L
.91307 .04428 L
.91322 .0442 L
.91336 .0441 L
.91349 .04398 L
.91381 .04363 L
.91411 .0432 L
.9147 .04206 L
.91535 .0404 L
.9165 .03649 L
.91757 .03195 L
.91885 .02584 L
.91948 .02288 L
.91975 .0217 L
.92005 .0206 L
.92018 .02022 L
.92032 .0199 L
.92046 .0197 L
.92058 .01962 L
.92071 .01964 L
.92086 .0198 L
.921 .02008 L
.92113 .02042 L
.9214 .02134 L
.9217 .02256 L
.9223 .02536 L
.92353 .03125 L
.92483 .0367 L
.92594 .04033 L
.92657 .04188 L
.92715 .04295 L
.92744 .04336 L
.9276 .04353 L
.92776 .04369 L
.9279 .0438 L
.92806 .0439 L
.9282 .04396 L
.92833 .04401 L
.92847 .04403 L
.9286 .04403 L
Mistroke
.92872 .04401 L
.92885 .04398 L
.92899 .04392 L
.92914 .04383 L
.92941 .04361 L
.92969 .0433 L
.93 .04286 L
.93055 .04181 L
.93121 .04015 L
.93182 .03827 L
.93429 .02783 L
.93491 .02485 L
.9355 .02218 L
.93575 .02116 L
.93602 .02027 L
.93616 .01993 L
.93632 .01968 L
.93646 .01957 L
.93659 .0196 L
.93673 .01975 L
.93688 .02003 L
.93702 .0204 L
.93715 .02082 L
.93766 .02288 L
.93881 .02831 L
.93995 .03348 L
.94118 .03818 L
.94185 .04019 L
.94246 .04167 L
.94304 .04274 L
.94334 .04313 L
.9435 .04332 L
.94366 .04346 L
.9438 .04357 L
.94395 .04366 L
.94409 .04373 L
.94422 .04376 L
.94436 .04378 L
.94451 .04378 L
.94459 .04377 L
.94467 .04375 L
.94482 .0437 L
.94495 .04364 L
.94509 .04354 L
.94538 .04328 L
.94565 .04296 L
.9459 .04259 L
.94651 .04142 L
.94717 .03973 L
.94837 .03566 L
Mistroke
.95061 .02562 L
.95116 .02305 L
.95147 .02175 L
.95175 .02068 L
.95192 .0202 L
.952 .01998 L
.95209 .0198 L
.95218 .01967 L
.95225 .01959 L
.9524 .01955 L
.95255 .01965 L
.95264 .01977 L
.95271 .01991 L
.95286 .02026 L
.95301 .02072 L
.95422 .026 L
.95555 .03217 L
.95676 .03702 L
.9579 .04053 L
.95854 .04194 L
.9589 .04255 L
.95923 .043 L
.9595 .04329 L
.95966 .04341 L
.95981 .04351 L
.95997 .04358 L
.96011 .04362 L
.96026 .04364 L
.96034 .04364 L
.96043 .04364 L
.96051 .04362 L
.96059 .0436 L
.96074 .04354 L
.96089 .04345 L
.96107 .04333 L
.96138 .04301 L
.96167 .04263 L
.96222 .04167 L
.9628 .0403 L
.96412 .03605 L
.96533 .03103 L
.96644 .0258 L
.96705 .02296 L
.96735 .02169 L
.96763 .02068 L
.96777 .02025 L
.96792 .01987 L
.96808 .01963 L
.96817 .01956 L
.96824 .01953 L
Mistroke
.96833 .01955 L
.96842 .01962 L
.96857 .01986 L
.96866 .02006 L
.96874 .02027 L
.96893 .02084 L
.97013 .02612 L
.97131 .03162 L
.97258 .03677 L
.9732 .03883 L
.97378 .04047 L
.97435 .04176 L
.97488 .04266 L
.97518 .04304 L
.97534 .0432 L
.97551 .04334 L
.9756 .04341 L
.97569 .04346 L
.97577 .0435 L
.97587 .04354 L
.97602 .04358 L
.97611 .04359 L
.97619 .0436 L
Mfstroke
1 0 0 r
[ ] 0 setdash
.03968 .01472 m
.03968 .04364 L
s
.05556 .01472 m
.05556 .04379 L
s
.07143 .01472 m
.07143 .04403 L
s
.0873 .01472 m
.0873 .04437 L
s
.10317 .01472 m
.10317 .04483 L
s
.11905 .01472 m
.11905 .04541 L
s
.13492 .01472 m
.13492 .04611 L
s
.15079 .01472 m
.15079 .04697 L
s
.16667 .01472 m
.16667 .04799 L
s
.18254 .01472 m
.18254 .04922 L
s
.19841 .01472 m
.19841 .05067 L
s
.21429 .01472 m
.21429 .05241 L
s
.23016 .01472 m
.23016 .0545 L
s
.24603 .01472 m
.24603 .05704 L
s
.2619 .01472 m
.2619 .06016 L
s
.27778 .01472 m
.27778 .06407 L
s
.29365 .01472 m
.29365 .06908 L
s
.30952 .01472 m
.30952 .07576 L
s
.3254 .01472 m
.3254 .08509 L
s
.34127 .01472 m
.34127 .0992 L
s
.35714 .01472 m
.35714 .12341 L
s
.37302 .01472 m
.37302 .17683 L
s
.38889 .01472 m
.38889 .42846 L
s
.40476 .01472 m
.40476 .32573 L
s
.42063 .01472 m
.42063 .0617 L
s
.43651 .01472 m
.43651 .15573 L
s
.45238 .01472 m
.45238 .22118 L
s
.46825 .01472 m
.46825 .08568 L
s
.48413 .01472 m
.48413 .05342 L
s
.5 .01472 m
.5 .33241 L
s
.51587 .01472 m
.51587 .05342 L
s
.53175 .01472 m
.53175 .08568 L
s
.54762 .01472 m
.54762 .22118 L
s
.56349 .01472 m
.56349 .15573 L
s
.57937 .01472 m
.57937 .0617 L
s
.59524 .01472 m
.59524 .32573 L
s
.61111 .01472 m
.61111 .42846 L
s
.62698 .01472 m
.62698 .17683 L
s
.64286 .01472 m
.64286 .12341 L
s
.65873 .01472 m
.65873 .0992 L
s
.6746 .01472 m
.6746 .08509 L
s
.69048 .01472 m
.69048 .07576 L
s
.70635 .01472 m
.70635 .06908 L
s
.72222 .01472 m
.72222 .06407 L
s
.7381 .01472 m
.7381 .06016 L
s
.75397 .01472 m
.75397 .05704 L
s
.76984 .01472 m
.76984 .0545 L
s
.78571 .01472 m
.78571 .05241 L
s
.80159 .01472 m
.80159 .05067 L
s
.81746 .01472 m
.81746 .04922 L
s
.83333 .01472 m
.83333 .04799 L
s
.84921 .01472 m
.84921 .04697 L
s
.86508 .01472 m
.86508 .04611 L
s
.88095 .01472 m
.88095 .04541 L
s
.89683 .01472 m
.89683 .04483 L
s
.9127 .01472 m
.9127 .04437 L
s
.92857 .01472 m
.92857 .04403 L
s
.94444 .01472 m
.94444 .04379 L
s
.96032 .01472 m
.96032 .04364 L
s
.97619 .01472 m
.97619 .0436 L
s
.015 w
.03968 .04364 Mdot
.05556 .04379 Mdot
.07143 .04403 Mdot
.0873 .04437 Mdot
.10317 .04483 Mdot
.11905 .04541 Mdot
.13492 .04611 Mdot
.15079 .04697 Mdot
.16667 .04799 Mdot
.18254 .04922 Mdot
.19841 .05067 Mdot
.21429 .05241 Mdot
.23016 .0545 Mdot
.24603 .05704 Mdot
.2619 .06016 Mdot
.27778 .06407 Mdot
.29365 .06908 Mdot
.30952 .07576 Mdot
.3254 .08509 Mdot
.34127 .0992 Mdot
.35714 .12341 Mdot
.37302 .17683 Mdot
.38889 .42846 Mdot
.40476 .32573 Mdot
.42063 .0617 Mdot
.43651 .15573 Mdot
.45238 .22118 Mdot
.46825 .08568 Mdot
.48413 .05342 Mdot
.5 .33241 Mdot
.51587 .05342 Mdot
.53175 .08568 Mdot
.54762 .22118 Mdot
.56349 .15573 Mdot
.57937 .0617 Mdot
.59524 .32573 Mdot
.61111 .42846 Mdot
.62698 .17683 Mdot
.64286 .12341 Mdot
.65873 .0992 Mdot
.6746 .08509 Mdot
.69048 .07576 Mdot
.70635 .06908 Mdot
.72222 .06407 Mdot
.7381 .06016 Mdot
.75397 .05704 Mdot
.76984 .0545 Mdot
.78571 .05241 Mdot
.80159 .05067 Mdot
.81746 .04922 Mdot
.83333 .04799 Mdot
.84921 .04697 Mdot
.86508 .04611 Mdot
.88095 .04541 Mdot
.89683 .04483 Mdot
.9127 .04437 Mdot
.92857 .04403 Mdot
.94444 .04379 Mdot
.96032 .04364 Mdot
.97619 .0436 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{756, 146},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000;d0000TR000`400?l00000o`00003ooooooooo
ooooooKooooo003ooooooooooooom_ooool00?ooooooooooooofooooo`00ooooooooooooooKooooo
003ooooooooooooom_ooool00?oooooo6_ooool3o`0000Cooooo0_l0000[ooooo`?o0000;Oooool2
o`0002oooooo0ol0000[ooooo`?o00001?ooool2o`000?oooooo4?ooool002_ooooo0ol00004oooo
o`;o0000:_ooool3o`0002_ooooo0_l0000]ooooo`?o0000:_ooool3o`0000Cooooo0_l0000Yoooo
o`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000:Oooool01Ol0003ooooooooooooo
oooo000002_ooooo00Co0000oooooooooooo0000;Oooool01Ol0003ooooooooooooooooo000002_o
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000`ooooo`?o00001?ooool2o`00
02[ooooo0ol0000[ooooo`;o0000;Oooool3o`0002[ooooo0ol00004ooooo`;o00006?ooool002co
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Xooooo`05o`000?oooooooooo
ooooool00000:Oooool01?l0003oooooooooool0000[ooooo`05o`000?ooooooooooooooool00000
:_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00023ooooo1Ol00003ooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00008oooool5o`0000Gooooo00?o0000oooo
ooooool0:Oooool01?l0003oooooooooool0000aooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool0000aooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo0000:?ooool01Ol0003ooooooooooooooooo000002Wooooo00Co0000oooooooo
oooo0000:oooool01Ol0003ooooooooooooooooo000002[ooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool0000Gooooo`009?ooool5o`0000?ooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool0000Rooooo`Go00001Oooool00ol0003oooooooooo`0Wooooo`04o`000?oo
ooooooooo`0002oooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0002Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000]oooo
o`03o`000?oooooooooo02Wooooo00Co0000oooooooooooo0000<Oooool00ol0003oooooooooo`0Y
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000:Oooool5o`0000?ooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool0000Rooooo`Go00001Oooool00ol0003ooooo
ooooo`0Wooooo`04o`000?ooooooooooo`0002oooooo00?o0000ooooooooool0:?ooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0001Oooooo000/ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo0000;?ooool00ol0003oooooooooo`0Wooooo`04o`000?oooooooooo
o`0002oooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0002Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Yooooo`Co0000
;?ooool01?l0003oooooooooool0000]ooooo`Co0000;?ooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`00037ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000/
ooooo`03o`000?oooooooooo02Oooooo00Co0000oooooooooooo0000;oooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00005oooool002cooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool0000Xooooo`Co0000:_ooool01?l0003ooooo
ooooool0000[ooooo`Co0000:oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
02Oooooo0_l00004ooooo`04o`000?ooooooooooo`0002Wooooo00?o0000ooooooooool0;Oooool0
1?l0003oooooooooool0000]ooooo`03o`000?oooooooooo02cooooo0_l00004ooooo`04o`000?oo
ooooooooo`00037ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Xooooo`Co
0000:_ooool01?l0003oooooooooool0000[ooooo`Co0000:oooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0001Oooooo000[ooooo`;o00001?ooool01?l0003oooooooooool0000X
ooooo`03o`000?oooooooooo02_ooooo00Co0000oooooooooooo0000:oooool00ol0003ooooooooo
o`0[ooooo`;o00001?ooool01?l0003oooooooooool0000Xooooo`03o`000?oooooooooo00?ooooo
0_l0000Zooooo`Go0000;?ooool2o`0002kooooo1Ol0000[ooooo`03o`000?oooooooooo00?ooooo
0_l0000aooooo`;o00001?ooool01?l0003oooooooooool0000Xooooo`03o`000?oooooooooo02_o
oooo00Co0000oooooooooooo0000:oooool00ol0003oooooooooo`0[ooooo`;o00001?ooool01?l0
003oooooooooool0000Gooooo`00;?ooool00ol0003oooooooooo`03ooooo`;o0000:Oooool5o`00
02[ooooo0_l0000/ooooo`Go0000:_ooool00ol0003oooooooooo`03ooooo`;o0000oooooolWoooo
o`03o`000?oooooooooo00?ooooo0_l0000Yooooo`Go0000:_ooool2o`0002cooooo1Ol0000Zoooo
o`03o`000?oooooooooo00?ooooo0_l0000Hooooo`00ooooooooooooooKooooo003ooooooooooooo
m_ooool00?ooooooooooooofooooo`008_ooool2o`0000Cooooobol0000Pooooo`;o00001?ooooo>
o`0002gooooob_l0000Fooooo`008Oooool01?l0003oooooooooool00003ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool07Oooool01?l0003oooooooooool00003ooooo`03o`000?oo
oooo0000033ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0_ooooo`03o`000?oo
oooooooo02kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Tooooo`;o00001Ooo
ool01Ol0003ooooooooooooooooo000000Wooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo01Cooooo000Qooooo`04o`000?ooooooooooo`0000?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02gooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool07Oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo0<[o
oooo00?o0000ooooooooool08oooool01?l0003oooooooooool00004ooooo`05o`000?oooooooooo
ooooool00000;oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02gooooo00?o0000
ooooooooool0;Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Cooooo000Qoooo
o`04o`000?ooooooooooo`0000?ooooo0_l0001Dooooo`03o`00oooooooooooo00cooooo00?o0000
ooooooooool0H?ooool3o`0001oooooo00Co0000oooooooooooo00000oooool3o`0000;ooooo00Go
o`00ooooooooooooooooool00002ooooo`04ool00?ooooooooooool000;ooooo00Goo`00oooooooo
ooooooooool00002ooooo`04ool00?ooooooooooool000?ooooo00Coo`00ooooooooooooo`000_oo
ool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`000_ooool01Ooo003o
ooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`000oooool01?oo003ooooooooooooo
0002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo0003ooooo`04
ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000oooool01?oo003ooooooooooooo
0002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo0003ooooo`04
ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000oooool01?oo003ooooooooooooo
0002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo0003ooooo`04
ool00?ooooooooooool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?oooooo
ooooool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?ooooooooooool000?o
oooo00Coo`00ooooooooooooo`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00
ooooooooooooo`000oooool2o`0002Gooooo00Co0000oooooooooooo00001?ooool2o`0000Kooooo
00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`05ool00?oooooooooo
oooooooo00000_ooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000?ooooo
00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`05ool00?oooooooooo
oooooooo00000_ooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000?ooooo
00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`05ool00?oooooooooo
oooooooo00000_ooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000?ooooo
00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`05ool00?oooooooooo
oooooooo00000_ooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000?ooooo
00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`05ool00?oooooooooo
oooooooo00000_ooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000?ooooo
00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`05ool00?oooooooooo
oooooooo00000_ooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000?ooooo
0_l0000Fooooo`008Oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00?ooooo
0_l00?l2ooooo`04o`00ooooooooooooo`00o`;ooooo00Co003ooooooooooooo003o0_ooool00ol0
0?ooooooooooo`02o`00o`Gooooo00Co003ooooooooooooo003o1_ooool01?l00?ooooooooooool0
0?l2ooooo`04o`00ooooooooooooo`00o`;ooooo0_l00?l2ooooo`04o`00ooooooooooooo`00oaSo
oooo00?o003oooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`00oooooooooooo00oo
oooo00Go003oooooooooooooooooo`00o`02ooooo`04o`00ooooooooooooo`00o`;ooooo00?o003o
ooooooooool01?ooool01?l00?ooooooooooool00?l2ooooo`04o`00ooooooooooooo`00o`;ooooo
0_l00?l2ooooo`04o`00ooooooooooooo`00o`;ooooo00Co003ooooooooooooo003o0_ooool2o`00
o`;ooooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooooooo`04ooooo`03o`000?oooooo
oooo01gooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`02ooooo`05ool00?oo
oooooooooooooooo00000_ooool01?oo003ooooooooooooo0002ooooo`05ool00?oooooooooooooo
oooo00000_ooool01?oo003ooooooooooooo0003ooooo`04ool00?ooooooooooool000;ooooo00Go
o`00ooooooooooooooooool00002ooooo`04ool00?ooooooooooool000;ooooo00Goo`00oooooooo
ooooooooool00002ooooo`04ool00?ooooooooooool000?ooooo00Coo`00ooooooooooooo`000_oo
ool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`000oooool01?oo003o
oooooooooooo0002ooooo`04ool00?ooooooooooool000?ooooo00Coo`00ooooooooooooo`000_oo
ool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`000oooool01?oo003o
oooooooooooo0002ooooo`04ool00?ooooooooooool000?ooooo00Coo`00ooooooooooooo`000_oo
ool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`000oooool01?oo003o
oooooooooooo0002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo
0002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo0003ooooo`04
ool00?ooooooooooool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?oooooo
ooooool000Cooooo00?o0000ooooooooool08oooool01?l0003oooooooooool00004ooooo`03o`00
0?oooooooooo00?ooooo00?o003ooooooooo00000_ooool01ooo003o003ooooooooo003oooooo`00
oooo00000_ooool02?oo003oooooooooooooooooo`00o`00ooooooooo`000_ooool01ooo003ooooo
oooooooo003oooooo`00oooo00000oooool01?oo003ooooooooooooo0002ooooo`04ool00?oooooo
ooooool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?ooooooooooool000;o
oooo00Coo`00ooooooooooooo`000oooool01?oo003ooooooooooooo0002ooooo`04ool00?oooooo
ooooool000;ooooo00Goo`00o`00ooooooooooooool00002ooooo`04ool00?ooooooooooool000;o
oooo00Coo`00ooooooooooooo`000oooool01?oo003ooooooooooooo0002ooooo`07ool00?oooooo
ooooool00?oooooo003oool00003ooooo`04ool00?ooooooooooool000;ooooo00Coo`00oooooooo
ooooo`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`000_oo
ool01?oo003ooooooooooooo0003ooooo`07ool00?ooooooooooool00?oooooo003oool00002oooo
o`04ool00?ooooooooooool000?ooooo00Ooo`00ooooooooooooo`00o`00ooooooooo`0000;ooooo
00_oo`00ooooooooooooo`00ooooool00?ooooooool00?l00?ooooooool00002o`00o`07ool00?oo
oooo003oool00?oooooo003oool00004ooooo`03o`000?oooooooooo01Cooooo000Qooooo`04o`00
0?ooooooooooo`0000?ooooo00?o0000ooooooooool01?ooool01Ol00?ooooooo`00ool00?oooooo
00;o003o0_ooool01?l00?ooooooooooool00?l2ooooo`;o003o00Coooooo`00ool00?oooooo0_l0
0?l2ooooo`04o`00ooooooooooooo`00o`;ooooo0_l00?l2ooooo`04o`00ooooooooooooo`00o`;o
oooo00Co003ooooooooooooo003o0_ooool00ol00?ooooooooooo`02o`00o`;ooooo00Co003ooooo
oooooooo003o0_ooool00ol00?ooooooooooo`02o`00o`;ooooo00Co003ooooooooooooo003o2?oo
ool00ol00?ooooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o003oooooooooool01_oo
ool01?l00?ooooooooooool00?l2ooooo`03o`00oooooooooooo00;o003o0_ooool01?l00?oooooo
ooooool00?l2ooooo`04o`00ooooooooooooo`00o`;ooooo0_l00?l00ooooooo003oooooo`02oooo
o`04o`00ooooooooooooo`00o`;ooooo00Go003oooooooooooooooooo`00o`02ooooo`04o`00oooo
oooo003oo`00o`;ooooo0_l00?l00ooooooo003oooooo`02ooooo`05o`00oooooooo003oo`00oooo
ool00_l00?l2ooooo`;o003o00?oooooo`00ool00?l01Oooool00ol0003oooooooooo`0Mooooo`04
o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_ooool01Ooo003ooooooooooooooooo
o`0000;ooooo00Coo`00ooooooooooooo`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo
00Coo`00ooooooooooooo`000oooool01?oo003ooooooooooooo0002ooooo`05ool00?oooooooooo
oooooooo00000_ooool01?oo003ooooooooooooo0002ooooo`05ool00?oooooooooooooooooo0000
0_ooool01?oo003ooooooooooooo0003ooooo`04ool00?ooooooooooool000;ooooo00Goo`00oooo
ooooooooooooool00002ooooo`04ool00?ooooooooooool000?ooooo00Coo`00ooooooooooooo`00
0_ooool01?oo003ooooooooooooo0003ooooo`04ool00?ooooooooooool000;ooooo00Goo`00oooo
ooooooooooooool00002ooooo`04ool00?ooooooooooool000?ooooo00Coo`00ooooooooooooo`00
0_ooool01?oo003ooooooooooooo0003ooooo`04ool00?ooooooooooool000;ooooo00Goo`00oooo
ooooooooooooool00002ooooo`04ool00?ooooooooooool000?ooooo00Coo`00ooooooooooooo`00
0_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`000_ooool01Ooo
003oooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`000oooool01?oo003ooooooooo
oooo0002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo0004oooo
o`03o`000?oooooooooo02?ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`03
ooooo`06o`00ooooooooo`00o`00ooooooooo`000_l00?l04Ooo003oooooo`00oooo003oooooo`00
oooo003oooooo`00ooooooooo`00o`00ooooooooo`00o`00ooooooooo`0000;o003o00koo`00oooo
ool00?ooo`00ooooool00?ooooooool00?l00?ooooooool00?oooooo003oool000;o003o00_oo`00
ooooool00?ooo`00ooooool00?ooooooool00?l00?ooooooool00002ooooo`07ool00?oooooo003o
ool00?oooooo003oool00003ooooo`04ool00?ooooooooooool000;ooooo00Coo`00oooooooooooo
o`000_ooool01Ooo003o003oooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`000_ooool0
1?oo003ooooooooooooo0003ooooo`04ool00?ooooooooooool000;ooooo00Coo`00oooooooooooo
o`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`000_ooool0
1?oo003ooooooooooooo0003ooooo`0:ool00?ooooooooooool00?l00?ooooooool00?oooooo003o
ool000;ooooo00_oo`00ooooool00?ooooooool00?l00?ooooooool00?l00?ooooooool00002oooo
o`0;ool00?oooooo003oool00?oooooo003ooooooooo003o003ooooooooo00000_l00?l05ooo003o
ooooo`00oooo003oooooo`00oooo003oooooo`00ooooooooo`00o`00ooooooooo`00ooooool00?oo
o`00ooooool00?ooo`00ooooool00?ooo`0000Cooooo00?o0000ooooooooool05?ooool002;ooooo
0_l00004ooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool00_l00?l2ooooo`04o`00
ooooooooooooo`00o`;ooooo0_l00?l00ooooooo003oo`00o`04ooooo`;o003o00Goooooo`00ool0
0?oo003oooooo`02o`00o`05ooooool00?oo003oooooool00?l00_ooool2o`00o`;ooooo00Ko003o
ooooooooooooooooo`00ooooool2o`00o`03ooooool00?oo003o00;ooooo00Co003ooooooooooooo
003o0_ooool01?l00?ooooooooooool00?l3ooooo`04o`00ooooooooooooo`00o`Gooooo00Co003o
ooooool00?oo003o3_ooool00ol0003oooooooooo`0<ooooo`04o`00oooooooo003oo`00o`Gooooo
00Co003ooooooooooooo003o0_ooool01ol00?oooooooooooooooooo003oooooool00?l00oooool0
1?l00?ooooooooooool00?l5ooooo`;o003o00Goooooo`00ool00?ooooooo`00o`03ooooo`03o`00
oooooooooooo00;o003o00Coooooo`00ool00?oooooo0_l00?l00ooooooo003oo`00o`02ooooo`;o
003o0_ooool00ol00?ooooooo`00o`02ooooo`;o003o00Goooooo`00oooooooo003oooooo`02o`00
o`;ooooo00?o003oooooooooool00oooool00ol0003oooooooooo`0Nooooo`;o00001?ooool00ol0
003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo
0002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo0003ooooo`04
ool00?ooooooooooool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?oooooo
ooooool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?ooooooooooool000?o
oooo00Coo`00ooooooooooooo`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00
ooooooooooooo`000oooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000?o
oooo00Coo`00ooooooooooooo`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00
ooooooooooooo`000oooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000?o
oooo00Coo`00ooooooooooooo`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00
ooooooooooooo`000oooool01?oo003ooooooooooooo0002ooooo`05ool00?oooooooooooooooooo
00000_ooool01?oo003ooooooooooooo0002ooooo`05ool00?oooooooooooooooooo00000_ooool0
1?oo003ooooooooooooo0003ooooo`04ool00?ooooooooooool000;ooooo00Goo`00oooooooooooo
ooooool00002ooooo`04ool00?ooooooooooool000Cooooo00?o0000ooooooooool08oooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo00?ooooo00Wo003ooooooooo003o003ooooo
oooo003o003ooooooooo00000_l00?l02ooo003o003oo`00oooo003oooooo`00ooooooooo`00oooo
ool00?ooo`0000;o003o00koo`00o`00ool00?ooo`00o`00ooooooooo`00ooooool00?ooooooool0
0?l00?ooooooool000;o003o00koo`00o`00ool00?ooo`00ooooool00?ooo`00ooooool00?oooooo
ool00?l00?ooooooool000;o003o017oo`00o`00ool00?ooo`00ooooool00?ooo`00ooooool00?oo
ooooool00?l00?ooooooool00?l00?ooooooool00002ooooo`04ool00?oooooo003oool000?ooooo
00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`05ool00?oooooooooo
oooooooo00000_ooool01?oo003ooooooooooooo0002ooooo`08ool00?oooooo003oool00?oooooo
003ooooooooo0002ooooo`04ool00?ooooooooooool000;o003o00_oo`00ooooool00?ooo`00oooo
ool00?ooooooool00?l00?ooooooool00002o`00o`0;ool00?l00?ooooooool00?oooooo003oool0
0?oooooo003ooooooooo00000_l00?l01?oo003o003ooooooooo0002o`00o`0Aool00?l00?oo003o
ool00?oooooo003ooooooooo003o003ooooooooo003oooooo`00oooo003oooooo`00oooo00000_l0
0?l02?oo003oooooo`00ooooooooo`00ooooool00?ooo`000_l00?l01?oo003o003oo`00oooo0002
o`00o`03ool00?oooooooooo00;ooooo00?o0000ooooooooool05?ooool002Sooooo00?o0000oooo
ooooool00oooool2o`00o`06ooooool00?ooooooooooool00?oooooo0_l00?l00ooooooo003oo`00
o`04ooooo`08o`00oooooooo003oo`00oooooooo003oooooool00?l2ooooo`05o`00oooooooooooo
o`00ooooool00_l00?l01Ooooooo003oo`00oooooooo003o00?ooooo00?o003oooooooooool00_l0
0?l2ooooo`04o`00ooooooooooooo`00o`;ooooo00Co003ooooooooooooo003o0_ooool2o`00o`;o
oooo00Co003oooooool00?oo003o0_ooool00ol00?ooooooooooo`03ooooo`04o`00oooooooo003o
o`00o`_ooooo00Co003ooooooooooooo00003Oooool00ol00?ooooooooooo`02o`00o`Gooooo00Co
003ooooooooooooo003o0_ooool01?l00?ooooooooooool00?l3ooooo`04o`00oooooooo003oo`00
o`;ooooo00?o003oooooooooool00_l00?l00ooooooo003oo`00o`02ooooo`05o`00oooooooo003o
ooooool00?l00_ooool01_l00?ooooooooooool00?ooooooo`00o`;ooooo00Co003ooooooooooooo
003o0_ooool00ol00?ooooooo`00o`03o`00o`05ooooool00?oo003oooooool00?l01?ooool2o`00
o`;ooooo00?o003oooooooooool01Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
00;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?ooooooooooool000;ooooo00Go
o`00ooooooooooooooooool00002ooooo`04ool00?ooooooooooool000?ooooo00Coo`00oooooooo
ooooo`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`000_oo
ool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`000oooool01?oo003o
oooooooooooo0002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo
0003ooooo`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000oooool01?oo003o
oooooooooooo0002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo
0003ooooo`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000oooool01?oo003o
oooooooooooo0002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo
0003ooooo`04ool00?ooooooooooool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04
ool00?ooooooooooool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?oooooo
ooooool000?ooooo00Coo`00ooooooooooooo`000_ooool01Ooo003oooooooooooooooooo`0000;o
oooo00Coo`00ooooooooooooo`001?ooool00ol0003oooooooooo`0Tooooo`;o00001Oooool00ol0
003oooooooooo`02ooooo`0=o`00ooooooooooooool00?oooooo003oool00?oooooo003oool00?l0
0?ooooooool00002o`00o`08ool00?l00?ooooooo`00oooo003o003ooooooooo0002o`00o`07ool0
0?l00?oo003oool00?oooooo003oool00002o`00o`05oooooooo003o003oo`00oooo00000_l00?l0
1ooo003ooooooooooooo003o003ooooooooo00000oooool01?oo003ooooooooooooo0002o`00o`0A
ool00?l00?oo003oool00?oooooo003oool00?oooooo003ooooooooo003o003ooooooooo003o003o
oooooooo00000_ooool01?oo003oooooo`00oooo0002o`00o`05oooooooo003ooooooooooooo0000
0_ooool01?oo003ooooooooooooo0002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo
003ooooooooooooo0002ooooo`08ool00?oooooo003oool00?oooooo003ooooooooo0002ooooo`0D
ool00?l00?ooooooool00?oooooo003oool00?oooooo003oool00?oooooo003ooooooooo003o003o
oooooooo003oooooo`00oooo0002o`00o`08ool00?l00?oo003oool00?oooooo003ooooooooo0002
o`00o`04ool00?l00?oo003oool000;o003o00Coo`00o`00ool00?ooo`000_ooool01Ol00?ooo`00
ooooool00?ooo`0000;o003o00Coo`00o`00ool00?ooo`000_l00?l04Ooo003oooooooooool00?oo
o`00o`00ooooooooo`00o`00ooooooooo`00o`00ooooooooo`00o`00ooooooooo`0000Cooooo00?o
0000ooooooooool05?ooool002Sooooo0_l00003ooooo`03o`00oooooooooooo00;o003o00Cooooo
o`00ool00?oooooo0_l00?l01?oooooo003oooooooooool3o`00o`;ooooo00Co003oooooool00?oo
003o0_ooool01?l00?ooooooooooool00?l6ooooo`;o003o00?oooooo`00ooooool00_l00?l00ooo
oooo003oooooo`02o`00o`04ooooool00?oo003oooooo`;o003o00?oooooo`00ool00?l00_ooool0
0ol00?ooooooooooo`02o`00o`03ooooool00?oo003o00;ooooo00Co003ooooooooooooo003o1Ooo
ool00ol00?ooooooo`00o`0<ooooo`04o`00ooooooooooooo`0000;ooooo00?o003oooooooooool0
2Oooool01?l00?ooooooo`00ool00?l5ooooo`04o`00ooooooooooooo`00o`;ooooo0_l00?l01?oo
oooo003oo`00ooooool2o`00o`;ooooo00?o003oooooooooool00_l00?l00ooooooo003oo`00o`04
ooooo`;o003o00?oooooo`00ooooool00_l00?l00ooooooo003oo`00o`02o`00o`07ooooool00?oo
003oooooool00?ooooooo`00o`02ooooo`06o`00ooooooooooooooooool00?oooooo0ol00?l01?oo
oooo003oo`00ooooool2o`00o`;ooooo00Go003oooooool00?oo003oooooo`02o`00o`?ooooo0_l0
000Vooooo`03o`000?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool0
0?ooooooooooool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?oooooooooo
ool000?ooooo00Coo`00ooooooooooooo`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo
00Coo`00ooooooooooooo`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00oooo
ooooooooo`000oooool01?oo003ooooooooooooo0002ooooo`05ool00?oooooooooooooooooo0000
0_ooool01?oo003ooooooooooooo0003ooooo`04ool00?ooooooooooool000;ooooo00Coo`00oooo
ooooooooo`000oooool01?oo003ooooooooooooo0002ooooo`05ool00?oooooooooooooooooo0000
0_ooool01?oo003ooooooooooooo0003ooooo`04ool00?ooooooooooool000;ooooo00Coo`00oooo
ooooooooo`000oooool01?oo003ooooooooooooo0002ooooo`05ool00?oooooooooooooooooo0000
0_ooool01?oo003ooooooooooooo0003ooooo`04ool00?ooooooooooool000;ooooo00Goo`00oooo
ooooooooooooool00002ooooo`04ool00?ooooooooooool000;ooooo00Goo`00oooooooooooooooo
ool00002ooooo`04ool00?ooooooooooool000?ooooo00Coo`00ooooooooooooo`000_ooool01Ooo
003oooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`001?ooool00ol0003ooooooooo
o`0[ooooo`03o`000?oooooooooo00;ooooo00?o003ooooooooo00002ooo00002Oooooooo`00oooo
oooooooo003oool00?oooooo003oool00002o`00o`04ool00?oooooo003oool000;o003o00Goo`00
oooooooooooo003oool00002ooooo`04ool00?l00?ooooooool000;o003o00Soo`00o`00ool00?oo
o`00ooooool00?ooooooool000;o003o00Ooo`00o`00ool00?ooo`00ooooool00?ooo`0000;o003o
00_oo`00ooooool00?ooooooool00?l00?ooooooool00?l00?ooooooool00002ooooo`04ool00?oo
oooo003oool000;o003o00Goooooool00?ooooooooooool00002ooooo`07ool00?ooooooooooool0
0?l00?ooooooool00002ooooo`05o`00oooo003ooooooooooooo00000_ooool02ooo003ooooooooo
oooo003oooooo`00oooo003oooooo`00ooooooooo`0000;ooooo00koo`00o`00ooooooooo`00o`00
ooooooooo`00ooooool00?ooo`00ooooool00?ooooooool000;o003o00Ooo`00o`00ool00?ooo`00
ooooool00?ooo`0000;o003o00_oo`00ooooool00?oo003oool00?l00?ooooooool00?oooooo003o
ool00002o`00o`08ool00?l00?ooooooool00?l00?ooooooo`00oooo0002o`00o`07ool00?l00?oo
003oool00?l00?ooooooool00002ooooo`03ool00?l00?oooooo00ooo`000_ooool2o`0001Kooooo
000Xooooo`03o`000?oooooooooo00Gooooo00Co003ooooooooooooo003o1Oooool01Ol00?oooooo
oooooooooooo003o00;ooooo00Co003ooooooooooooo003o0_ooool2o`00o`03ooooool00?oo003o
00;ooooo00Co003oooooool00?oo003o0_ooool00ol00?ooooooooooo`02o`00o`;ooooo00Go003o
ooooooooooooooooo`00o`02ooooo`03o`00oooooooooooo00;o003o0oooool00ol00?ooooooo`00
o`02ooooo`;o003o00?oooooo`00ool00?l00_ooool00ol00?ooooooooooo`03ooooo`05o`00oooo
ooooooooooooool00?l02_ooool01?l00?ooooooooooool00002ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool00oooool01Ol00?ooooooo`00oooooooo003o00Gooooo00Co003ooooo
oooooooo003o0_ooool2o`00o`04ooooool00?oo003oooooo`;o003o0_ooool01_l00?ooooooo`00
oooooooo003oooooo`;o003o00Goooooo`00ool00?ooooooo`00o`04ooooo`;o003o00?oooooo`00
ool00?l00_ooool01?l00?ooooooooooool00?l2ooooo`;o003o00?oooooo`00ool00?l00_ooool0
0ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00;o003o00?oooooo`00ool00?l00_ooool0
1?l00?ooooooooooool00?l4ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool00_oo
ool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`000_ooool01Ooo003o
ooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`000oooool01?oo003ooooooooooooo
0002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo0002ooooo`05
ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo0003ooooo`04ool00?oooooo
ooooool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?ooooooooooool000?o
oooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0003ooooo`04ool00?oooooo
ooooool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?ooooooooooool000?o
oooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0003ooooo`04ool00?oooooo
ooooool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?ooooooooooool000?o
oooo00Coo`00ooooooooooooo`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00
ooooooooooooo`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00oooooooooooo
o`000oooool01?oo003ooooooooooooo0002ooooo`05ool00?oooooooooooooooooo00000_ooool0
1?oo003ooooooooooooo0004ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool00_oo
ool00ol00?ooooooool0000>ool00003oooooooo003oo`0000goo`000_ooool01ooo003oooooo`00
oooo003oooooo`00oooo00000_l00?l02?oo003o003oo`00oooo003o003oooooool00?ooo`000_l0
0?l01?oo003ooooooooooooo0002o`00o`0>ool00?oooooo003oool00?oooooo003ooooooooo003o
003ooooooooo003o003ooooooooo0002ooooo`04ool00?oooooo003oool000;o003o00Goooooool0
0?ooooooooooool00002ooooo`07ool00?ooooooooooool00?l00?ooooooool00002ooooo`05o`00
oooo003ooooooooooooo00000_ooool01?oo003ooooooooooooo0002ooooo`05ool00?oooooo003o
oooooooo00000_ooool01?oo003o003ooooooooo0002o`00o`0>ool00?oooooo003oool00?oooooo
003ooooooooo003o003ooooooooo003o003ooooooooo0002o`00o`0;ool00?ooooooooooool00?l0
0?ooooooo`00oooo003oooooo`00oooo00000_l00?l01Ooo003ooooooooooooo003ooooo00?oo`00
00?oooooool00?oo00003Ooo00000oooooooo`00ool0000=ool000?ooooo00?o0000ooooooooool0
5?ooool002Sooooo00?o0000ooooooooool08_ooool01?l00?ooooooooooool00?l3ooooo`06o`00
oooooooo003oo`00oooooooo003o0_ooool4o`00o`03ooooool00?oo003o00;ooooo00Go003ooooo
ool00?ooooooo`00o`02ooooo`03o`00oooooooo003o00;ooooo00Go003oooooooooooooooooo`00
o`05ooooo`05o`00oooooooo003oooooool00?l01oooool01?l00?ooooooooooool00?l2ooooo`05
o`000?ooooooooooo`00ooooool00_l00?l00ooooooo003oooooo`04ooooo`04o`00oooooooo003o
o`00o`Kooooo00Co003ooooooooooooo003o0oooool01_l00?ooooooooooool00?ooooooo`00o`;o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`Co003o00?oooooo`00ool0
0?l00_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo02;ooooo00?o0000oooooooo
ool09?ooool2o`0000;ooooo0ooo00000oooooooo`00ool0000:ool000;ooooo00Coo`00oooooooo
ooooo`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`000ooo
ool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000?ooooo00Coo`00oooooooo
ooooo`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`000ooo
ool01?oo003ooooooooooooo0002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003o
oooooooooooo0002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo
0003ooooo`04ool00?ooooooooooool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04
ool00?ooooooooooool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?oooooo
ooooool000?ooooo00Coo`00ooooooooooooo`000_ooool01Ooo003oooooooooooooooooo`0000;o
oooo00Coo`00ooooooooooooo`000oooool01?oo003ooooooooooooo0002ooooo`04ool00?oooooo
ooooool000?ooooo00Coo`00ooooooooooooo`000_ooool00ooo003oooooooooo`09ool00003oooo
oooo003oo`0000Ooo`000_ooool2o`0002gooooo00?o0000ooooooooool01?ooool?ool00003oooo
oooo003oo`0000goo`0000?oooooool00?oo00001ooo00003?l00?ooo`00ooooooooooooo`00o`00
oooooooo003oool00?oooooo003oool000;o003o00koo`00o`00ooooooooo`00ooooool00?ooo`00
ooooool00?ooooooool00?l00?ooooooool000;o003o00Ooo`00ooooooooooooo`00ooooool00?oo
o`0000?ooooo00Soo`00ooooooooooooo`00o`00ooooooooo`00ooooo`?oo`0000Coooooool00?oo
oooooooo0ooo00001Oooooooo`00ooooooooooooo`0000;ooooo00Soo`00o`00ooooooooo`00oooo
ool00?ooooooool000;ooooo00Coo`00ooooooooooooo`000_l00?l02ooo003oooooo`00oooo003o
ooooo`00ooooooooo`00ooooool00?ooo`0000;o003o00Ooo`00o`00ooooooooo`00o`00oooooooo
o`0000;ooooo00?o003oool00?ooool03?oo00000oooooooo`00ool0000=ool00003oooooooo003o
o`0000goo`000oooool00ol0003oooooooooo`0Dooooo`00:?ooool00ol0003oooooooooo`0^oooo
o`;o003o00?oooooo`00ool00?l00_ooool01Ol00?ooooooo`00oooooooo003o00;ooooo00Co003o
ooooool00?oooooo0_l00?l2ooooo`04o`00oooooooo003oo`00o`;ooooo00?o003oooooooooool0
0oooool3o`00o`03ooooool00?oooooo00Cooooo00Ko003oooooool00?oo003oooooool00?l2oooo
o`03o`000?oooooooooo00;ooooo0_l00?l00ooooooo003oooooo`04ooooo`03o`00oooooooooooo
00;o003o1Oooool01?l00?ooooooooooool00?l2ooooo`04o`00ooooooooooooo`00o`?ooooo00Co
003oooooool00?oooooo0_l00?l2ooooo`04o`00oooooooo003oo`00o`;ooooo00Co003ooooooooo
oooo003o;_ooool00ol0003oooooooooo`0Tooooo`04o`000?ooooooooooooooo`?oo`0000?ooooo
ool00?oo00002_oo00000oooooooo`00ool00007ool00006oooooooo003oo`00ool00?ooooooo`00
0_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`000_ooool01Ooo
003oooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`000oooool01?oo003ooooooooo
oooo0002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo0003oooo
o`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000oooool01?oo003ooooooooo
oooo0002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo0003oooo
o`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000oooool01?oo003ooooooooo
oooo0002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo0003oooo
o`04ool00?ooooooooooool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`05ool00?oo
ooooooooool00?ooool00ooo00000oooooooo`00ool00007ool00003oooooooo003oo`0000Ooo`00
00?oooooool00?oo00001ooo0003ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0
4?ooool3ool00003oooooooo003oo`0000goo`0000?oooooool00?oo00002_oo00000oooooooo`00
o`00o`02ooooo`04ool00?ooooooooooool000;o003o017oo`00o`00ool00?ooo`00o`00oooooooo
o`00ooooool00?ooooooool00?l00?ooooooool00?oooooo003oool00002ooooo`04ool00?oooooo
003oool000?o003o00Soo`00ooooooooooooo`00o`00ooooooooo`00o`00o`?oo`0000Coooooool0
0?oooooooooo0ooo00001Oooooooo`00ooooool00?ooo`0000;ooooo00Soo`00o`00ooooooooo`00
ooooool00?ooooooool000;ooooo00Ooo`00o`00ool00?ooo`00ooooool00?ooo`0000;o003o00Go
o`00ooooool00?ooooooool00002o`00o`04ool00?oooooo003oool000;o003o00Koo`00o`00oooo
ooooo`00o`00ooooool?ool00003oooooooo003oo`0000goo`004oooool00ol0003oooooooooo`0D
ooooo`00:?ooool2o`0003?ooooo00Co003ooooooooooooo003o0_ooool2o`00o`03ooooool00?oo
003o00?ooooo0_l00?l00ooooooo003oo`00o`02ooooo`04o`00ooooooooooooo`00o`Gooooo0ol0
0?l6ooooo`;o003o00Goooooo`00ooooooooooooo`00o`02ooooo`04o`000?oooooo003oo`00o`Co
oooo00?o003oooooooooool01Oooool3o`00o`Gooooo00Co003ooooooooooooo003o0_ooool2o`00
o`04ooooool00?oo003oooooo`;o003o00?oooooo`00ooooool00_l00?l00ooooooo003oo`00o`02
ooooo`03o`00oooooooooooo037ooooo0_l0000Vooooo`04o`000?ooooooooooooooo`?oo`0000?o
ooooool00?oo00002_oo00000oooooooo`00ool00007ool00003oooooooo003oo`0000Ooo`000_oo
ool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000?ooooo00Coo`00oooooooo
ooooo`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`000ooo
ool01?oo003ooooooooooooo0002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003o
oooooooooooo0002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo
0003ooooo`04ool00?ooooooooooool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04
ool00?ooooooooooool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?oooooo
ooooool000?ooooo00Coo`00ooooooooooooo`000_ooool01Ooo003oooooooooooooooooo`0000;o
oooo00Coo`00ooooooooooooo`000oooool00ooo003oooooool00008ool00003oooooooo003oo`00
00Ooo`0000?oooooool00?oo00001ooo00000oooooooo`00ool00007ool000?ooooo00?o0000oooo
ooooool0:oooool00ol0003oooooooooo`0Tooooo`ooo`0000Koooooool00?oo003oo`00o`00oooo
0002o`00o`04ool00?oooooo003oool000;o003o00Goo`00ooooool00?ooooooool00002o`00o`04
ool00?l00?oo003oool000;ooooo00?oo`00o`00oooo00000_oo00000ooooooo003oool00002oooo
o`05ool00?l00?oo003oool00?l00?l00ooo00001?ooooooo`00ooooooooool3ool00005o`00oooo
003o003oo`00oooo00000_ooool00ooo003o003oool00002ool00003o`00ooooooooo`0000;ooooo
00Ooo`00o`00ool00?ooo`00o`00ooooooooo`0000;o003o00Goo`00o`00oooooooo003oool00002
o`00o`05ool00?l00?oo003oool00?ooool01_oo00000oooooooo`00ool0000:ool002Kooooo00?o
0000ooooooooool05?ooool002Sooooo00?o0000ooooooooool0=Oooool01ol00?oooooooooooooo
oooo003oooooool00?l00_ooool2o`00o`?ooooo0_l00?l00ooooooo003oo`00o`02ooooo`03o`00
oooooooooooo00Cooooo00Co003ooooooooooooo003o1?ooool2o`00o`;ooooo00?o003oooooool0
0?l00_ooool01Ol0003oooooo`00ool00?oooooo00;o003o00?oooooo`00ooooool01?ooool01Ol0
0?ooooooo`00oooooooo003o00Gooooo00Co003ooooooooooooo003o0_ooool2o`00o`07ooooool0
0?oo003oooooool00?ooooooo`00o`02ooooo`;o003o00?oooooo`00ool00?l0=oooool00ol0003o
ooooooooo`0Tooooo`03o`000?oooooooooo01;ooooo2Ooo00000oooooooo`00ool00007ool00003
oooooooo003oo`0000Coo`0000Goooooool00?ooooooooooool00003ooooo`04ool00?oooooooooo
ool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?ooooooooooool000?ooooo
00Coo`00ooooooooooooo`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00oooo
ooooooooo`000_ooool00ooo003oooooooooo`03ool00003oooooooo003ooooo00?oo`000_ooool0
1?oo003ooooooooooooo0002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooo
oooooooo0002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo0003
ooooo`04ool00?ooooooooooool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`03ool0
0?ooooooo`0000;oo`0000?oooooool00?oo00002_oo00000oooooooo`00ool00007ool001Oooooo
00?o0000ooooooooool0:oooool00ol0003oooooooooo`0]ooooo`Koo`0000?oooooool00?oo0000
1?oo00001Oooooooo`00o`00ool00?ooo`0000;o003o00_oo`00o`00ooooooooooooool00?l00?oo
ooooool00?l00?ooooooool00002ooooo`03ool00?ooooooo`0000;oo`0000?oooooo`00oooo0000
0_ooool01_oo003o003oo`00oooo003o003oooooo`;o003o00?oooooool00?ooool00_ooool01?l0
0?ooooooo`00oooo0002o`00o`05ool00?ooooooooooool00?ooool00ooo00000ol00?ooooooool0
0002ooooo`04ool00?l00?oo003oool000;o003o00Coo`00o`00ooooooooo`000_ooool01_l00?oo
o`00ooooooooooooo`00ooooo`Woo`0000Coooooool00?oo003oo`00;_ooool2o`0001Kooooo000X
ooooo`03o`000?oooooooooo03_ooooo0_l00?l01ooooooo003ooooooooooooo003oooooool00?l0
0_ooool01Ol00?oooooooooooooooooo003o00Gooooo00Go003oooooool00?ooooooo`00o`04oooo
o`03o`00oooooooooooo00Co003o0_ooool01Ol0003oooooo`00ool00?oooooo00;o003o00?ooooo
o`00ooooool01?ooool01?l00?ooooooo`00ool00?l6ooooo`04o`00ooooooooooooo`00o`?ooooo
00Ko003ooooooooooooo003oooooool00?l2ooooo`03o`00oooooooooooo03_ooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`0Oooooo`Koo`0000?oooooool00?oo00001ooo00000ooo
ooooo`00ooooo`02ooooo`04ool00?ooooooooooool000;ooooo00Goo`00ooooooooooooooooool0
0002ooooo`04ool00?ooooooooooool000?ooooo00Coo`00ooooooooooooo`000_ooool01Ooo003o
ooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`000_ooool00ooo003oooooooooo`03
ool00003oooooooo003ooooo00?oo`000_ooool01?oo003ooooooooooooo0002ooooo`05ool00?oo
oooooooooooooooo00000_ooool01?oo003ooooooooooooo0002ooooo`05ool00?oooooooooooooo
oooo00000_ooool01?oo003ooooooooooooo0003ooooo`04ool00?ooooooooooool000;ooooo00Ko
o`00ooooooooooooooooool00?ooool6ool00003oooooooo003oo`0000Ooo`009?ooool00ol0003o
ooooooooo`0[ooooo`03o`000?oooooooooo033ooooo0ooo00000oooooooo`00ool00004ool00005
o`00oooo003o003ooooooooo00000_ooool02?oo003oooooooooool00?ooo`00ooooool00?ooo`00
0_l00?l01Ooo003ooooooooooooo003ooooo00?oo`000_ooool01ooo003ooooooooooooo003ooooo
o`00oooo00000_ooool2o`00o`06oooooooo003oooooooooool00?oooooo0_l00?l01?oo003o003o
oooooooo0002ooooo`03ool00?l00?ooo`0000;oo`0000?o003ooooooooo00000_ooool01?oo003o
003ooooooooo0002o`00o`05ool00?oooooo003oool00?l00?l00_ooool01Ooo003oooooo`00oooo
003ooooo00Woo`00<oooool00ol0003oooooooooo`0Dooooo`00:?ooool00ol0003oooooooooo`0l
ooooo`06o`00oooooooo003oo`00oooooooo003o0_ooool01?l00?ooooooo`00ool00?l2ooooo`03
o`00oooooooooooo00?ooooo0_l00?l2ooooo`03o`00oooooooooooo00?ooooo00?o003oooooool0
0?l00ol00?l2ooooo`03o`000?oooooooooo00;ooooo1?l00?l4ooooo`04o`00oooooooooooooooo
o`;o003o1Oooool00ol00?ooooooooooo`02o`00o`05ooooool00?ooooooooooool00?l01?ooool2
o`00ocgooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Vooooo`coo`000_ooool0
1?oo003ooooooooooooo0002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooo
oooooooo0003ooooo`04ool00?ooooooooooool000;ooooo00?oo`00ooooooooool00ooo00001Ooo
ooooo`00ooooooooooooo`0000;ooooo00?oo`00ooooooooool00ooo00000oooooooo`00ooooo`03
ool000;ooooo00Coo`00ooooooooooooo`000_ooool00ooo003oooooooooo`03ool00005oooooooo
003ooooooooooooo00000_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00oooooooo
ooooo`000oooool01?oo003ooooooooooooo0002ooooo`03ool00?oooooooooo00Woo`0000Cooooo
ool00?oo003oo`00:_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo03Oooooo1_oo
00002Oooooooo`00o`00ooooooooo`00o`00oooooooo003oool00002o`00o`04ool00?oooooo003o
ool000;ooooo00Coo`00o`00oooooooo003o0_ooool02Ol00?ooo`00ooooooooooooo`00o`00oooo
ooooo`00ooooo`02o`00o`;ooooo00?oo`00ooooooooool00_l00?l2ooooo`04ool00?oooooo003o
ool000;ooooo00Coo`00o`00oooooooooooo0_l00?l02oooooooo`00ooooooooooooo`00ooooool0
0?ooo`00ooooool00?ooo`0000;o003o00Koo`00o`00oooooooo003oool00?ooool6ool003Wooooo
00?o0000ooooooooool05?ooool002Sooooo00?o0000ooooooooool0?oooool01?l00?ooooooo`00
ooooool2o`00o`;ooooo00Co003ooooooooooooo003o1Oooool2o`00o`Oooooo0_l00?l01?oooooo
003oooooool00?l3ooooo`04o`000?oooooo003oo`00o`Cooooo00?o003oooooooooool01_ooool2
o`00o`Gooooo00Ko003oooooooooooooooooo`00ooooool2o`00o`04ooooool00?ooooooo`00od7o
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0/ooooo`Koo`0000Koooooool00?oo
003oo`00oooooooo0002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooo
oooo0003ooooo`04ool00?ooooooooooool000;ooooo00?oo`00ooooooooool00ooo00001Ooooooo
o`00ooooooooooooo`0000;ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04oooo
o`04ool00?ooooooooooool000;ooooo00?oo`00ooooooooool00ooo00001Oooooooo`00oooooooo
ooooo`0000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?ooooooooooool000?o
oooo00Goo`00ooooooooooooo`00ooooo`03ool00003oooooooo003oo`0000Coo`00<Oooool00ol0
003oooooooooo`0[ooooo`03o`000?oooooooooo03[ooooo0ooo00002Oooooooo`00o`00oooooooo
o`00o`00oooooooo003oool00002o`00o`04ool00?l00?oo003oool000;ooooo00Coo`00o`00oooo
oooo003o0_ooool01Ol00?ooo`00ooooooooooooo`0000;o003o00Ooo`00ooooool00?ooooooo`00
ooooooooo`0000;ooooo0ol00?l01Oooooooo`00o`00ool00?ooo`0000;ooooo00Goo`00o`00oooo
ooooooooo`00o`02ooooo`04ool00?ooooooooooool000;o003o00coo`00o`00ooooooooo`00o`00
ooooooooo`00o`00oooooooo003oool00?ooool3ool003cooooo00?o0000ooooooooool05?ooool0
02Sooooo0_l00010ooooo`04o`00ooooooooooooooooo`;o003o00Coooooo`00ool00?oooooo0_l0
0?l9ooooo`03o`00oooooooooooo00;ooooo0_l00?l2ooooo`03o`00oooooooooooo00;ooooo00Ko
0000ooooool00?ooooooo`00ooooool3o`00o`Cooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooooooo00?o003o00?oooooo`00ool00?l00_ooool00ol00?oo
ooooooooo`0nooooo`;o00009_ooool2o`00033ooooo0ooo00000oooooooo`00ool00004ool00003
oooooooo003ooooo00;ooooo00Coo`00ooooooooooooo`000_ooool01Ooo003ooooooooooooooooo
o`0000;ooooo00Coo`00ooooooooooooo`000_ooool3ool00005oooooooo003ooooooooooooo0000
0_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00Coo`00oooooooooooo
o`000_ooool00ooo003oooooooooo`03ool00005oooooooo003ooooooooooooo00000_ooool01Ooo
003oooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`000oooool00ooo003oooooool0
0005ool00004oooooooo003oo`00ool003?ooooo0_l0000]ooooo`03o`000?oooooooooo03[ooooo
1_oo00000oooooooo`00o`00o`02ooooo`07ool00?l00?ooooooool00?l00?ooooooool00002oooo
o`03ool00?l00?oooooo00?ooooo00Ko003oool00?ooooooooooool00?l00?l3ool00005o`00oooo
oooo003ooooooooo00000oooool2o`00o`?oo`0000Go003oool00?ooooooooooool00004ooooo`;o
003o00Coo`00ooooooooooooo`000_l00?l01ooo003o003oo`00oooo003o003ooooooooo00000_oo
ool6ool003cooooo00?o0000ooooooooool05?ooool002Sooooo00?o0000ooooooooool0@Oooool2
o`00o`?ooooo00Go003oooooooooooooooooo`00o`05ooooo`05o`00ooooooooooooooooool00?l0
1?ooool00ol00?ooooooo`00o`02ooooo`0:o`00oooooooo003oooooool0003oooooo`00oooooooo
003oooooo`?o003o1?ooool00ol00?ooooooooooo`08ooooo`04o`00ooooooooooooo`00o`?ooooo
00?o003oooooooooool0@oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo03?ooooo
1_oo00000oooooooo`00ooooo`02ooooo`04ool00?ooooooooooool000;ooooo00Goo`00oooooooo
ooooooooool00002ooooo`04ool00?ooooooooooool000Kooooo00Coo`00ooooooooooooo`000_oo
ool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00Coo`00ooooooooooooo`00
0_ooool00ooo003oooooooooo`04ooooo`04ool00?ooooooooooool000;ooooo00Goo`00oooooooo
ooooooooool00002ooooo`04ool00?ooooooooooool000?ooooo00?oo`00oooooooo00001Ooo000h
ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0?Oooool3ool00009oooooooo003o
ooooooooool00?ooo`00ooooool00?ooo`0000;o003o00Coo`00ooooooooooooo`001_ooool01Ooo
003ooooooooooooo003ooooo00?oo`0000Goooooo`00ool00?ooooooool00002ooooo`03o`00oooo
oooo003o00?oo`0000Koooooool00?ooooooooooool00?l00?l4ooooo`08o`00oooo003ooooooooo
oooo003o003ooooooooo0002o`00o`06ool00?ooooooooooool00?l00?oooooo0ooo000nooooo`;o
00005_ooool002Sooooo00?o0000ooooooooool0@_ooool01?l00?ooooooo`00ooooool2o`00o`03
ooooool00?oo003o00Gooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`03ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooool000001_ooool00ol00?ooooooooooo`03ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool00oooool01?l00?ooooooo`00ooooool2o`00
o`;ooooo00?o003oooooooooool0@_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
03Kooooo1_oo0002ooooo`04ool00?ooooooooooool000;ooooo00Goo`00ooooooooooooooooool0
0002ooooo`04ool00?ooooooooooool000Kooooo00Coo`00ooooooooooooo`000_ooool00ooo003o
ooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00Coo`00ooooooooooooo`000_ooool00ooo
003oooooooooo`04ooooo`04ool00?ooooooooooool000;ooooo00Goo`00ooooooooooooooooool0
0002ooooo`04ool00?ooooooooooool000;ooooo1_oo000kooooo`03o`000?oooooooooo02_ooooo
00?o0000ooooooooool0?Oooool6ool00009ooooool00?ooo`00ooooool00?ooo`00ooooool00?oo
o`0000;ooooo00?oo`00o`00ooooool00oooool01_l00?ooo`00ooooooooooooo`00o`00o`?oo`00
0_l00?l2ooooo`03ool00?oooooooooo00;o003o00Koooooool00?oo003oo`00o`00oooo0002oooo
o`03ool00?l00?oooooo00?ooooo00co003oool00?ooooooooooool00?oooooo003oool00?oooooo
003oool00?l00?l3ool00004oooooooo003oo`00ool003oooooo00?o0000ooooooooool05?ooool0
01[ooooo1Ol00003ooooo`;o00001?ooool00ol0003oooooooooo`12ooooo`03o`00oooooooo003o
00;ooooo00?o003oooooool00?l01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
00Cooooo00Go003oooooool0003oooooo`00o`06ooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool00oooool01?l00?ooooooooooooooool2o`00o`;ooooo00?o003oooooooooool0@_oo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo03Wooooo0ooo0002ooooo`04ool00?oo
ooooooooool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?ooooooooooool0
00Kooooo00Coo`00ooooooooooooo`000_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooo
oooo00Cooooo00Coo`00ooooooooooooo`000_ooool00ooo003oooooooooo`04ooooo`04ool00?oo
ooooooooool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?ooooooooooool0
00;ooooo0ooo000nooooo`03o`000?oooooooooo01cooooo1Ol00003ooooo`;o00001Oooool00ol0
003oooooooooo`10ooooo`?oo`0000Koooooo`00oooo003oooooo`00oooo0002o`00o`05ool00?oo
ooooooooool00?l00?l01?ooool02?l00?ooo`00ooooooooooooo`00o`00oooooooo003o0oooool0
0ol00?ooooooool00002ooooo`04o`00ooooooooooooooooo`?o003o00Goo`00ooooooooooooo`00
o`00o`05ooooo`04ool00?ooooooooooool000;o003o00Goo`00o`00ooooooooo`00o`00o`03ool0
04?ooooo00?o0000ooooooooool05?ooool001_ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00003ooooo`03o`000?oooooooooo04Gooooo0ol00?l00ooooooo003oo`00o`0:
ooooo`05o`00ooooooooooooooooool00?l02?ooool00ol0003oooooo`00o`06ooooo`05o`00oooo
ooooooooooooool00?l01?ooool00ol00?ooooooooooo`03ooooo`04o`00oooooooo003oooooo`;o
003oAoooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo03Wooooo0ooo0002ooooo`04
ool00?ooooooooooool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?oooooo
ooooool000Kooooo00Coo`00ooooooooooooo`000_ooool00ooo003oooooooooo`04ooooo`03ool0
0?oooooooooo00Cooooo00Coo`00ooooooooooooo`000_ooool00ooo003oooooooooo`04ooooo`04
ool00?ooooooooooool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?oooooo
ooooool000;ooooo0ooo000nooooo`03o`000?oooooooooo01gooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo043ooooo0ooo0002ooooo`07
ool00?ooooooooooool00?l00?ooooooool00002ooooo`03ool00?l00?oooooo00?ooooo00Ko003o
ool00?ooooooooooool00?l00?l5ooooo`03o`00ooooooooo`0000Sooooo00Go003oool00?oooooo
ooooool00005ooooo`05o`00oooo003ooooooooooooo00000_l00?l01Ooo003o003oo`00oooo003o
003o00?oo`00@oooool00ol0003oooooooooo`0Dooooo`007?ooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0000?ooooo0_l00017ooooo`05o`00ooooooooooooooooool00?l01Ooo
ool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l01_ooool01Ol00?oooooo
o`000?oooooo003o00Kooooo00Go003oooooooooooooooooo`00o`09ooooo`;o003o00Coooooo`00
oooooooo003oA_ooool3o`0002Kooooo00?o0000ooooooooool0?Oooool3ool00005oooooooo003o
oooooooooooo00000oooool01?oo003ooooooooooooo0002ooooo`03ool00?oooooooooo00Cooooo
00Goo`00ooooooooooooo`00ooooo`03ool000Gooooo00?oo`00ooooooooool00oooool3ool00005
oooooooo003ooooooooooooo00001_ooool01?oo003ooooooooooooo0002ooooo`05ool00?oooooo
oooooooooooo00000_ooool00ooo003oooooool00002ool004;ooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0
A?ooool01Ol00?ooo`00ooooool00?ooo`0000;o003o00Coo`00ooooooooooooo`001_ooool01?oo
003ooooooooooooo0006ooooo`03o`00ooooooooo`0000;ooooo00?o003oooooooooool01?ooool0
1Ooo003ooooooooooooo003o003o00Cooooo00_o003oool00?ooooooooooool00?l00?ooooooool0
0?l00?ooooooool00017ooooo`03o`000?oooooooooo01Cooooo000Mooooo`05o`000?oooooooooo
ooooool000000_ooool01Ol0003ooooooooooooooooo000004Oooooo0ol00?l00ooooooo003oo`00
o`05ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool02?ooool00ol00?ooooooo`00
000<ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool2o`00o`03ooooool0
0?oooooo00;o003oAoooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo03gooooo0ooo
00001Oooooooo`00ooooooooooooo`0000?ooooo00Coo`00ooooooooooooo`000_ooool00ooo003o
ooooooooo`04ooooo`05ool00?ooooooooooool00?ooool00ooo0005ooooo`03ool00?oooooooooo
00?ooooo0ooo00001Oooooooo`00ooooooooooooo`0000Kooooo00Coo`00ooooooooooooo`000_oo
ool01Ooo003oooooooooooooooooo`0000;ooooo00?oo`00oooooooo00000_oo0012ooooo`03o`00
0?oooooooooo01oooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00;o
oooo0_l00015ooooo`08o`00oooo003oooooo`00oooo003oooooo`00oooo0002ooooo`03ool00?l0
0?oooooo00?ooooo00Ko003oool00?ooooooooooool00?l00?l7ooooo`04ool00?ooooooooooo`00
o`Gooooo00Ko003oool00?ooooooooooool00?l00?l4ooooo`08o`00oooo003ooooooooooooo003o
ooooo`00oooo0002ooooo`03ool00?l00?oooooo04Cooooo0_l0000Fooooo`006_ooool01Ol0003o
oooooooooooooooo000000;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`15
ooooo`05o`00oooooooo003oooooool00?l01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo00Cooooo00Go003oooooool0003oooooo`00o`06ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo04Gooooo
00?o0000ooooooooool09?ooool2o`0003kooooo0ooo00001Oooooooo`00ooooooooooooo`0000?o
oooo00Coo`00ooooooooooooo`000_ooool00ooo003oooooooooo`04ooooo`05ool00?oooooooooo
ool00?ooool00ooo0005ooooo`03ool00?oooooooooo00?ooooo0ooo00001Oooooooo`00oooooooo
ooooo`0000Kooooo00Coo`00ooooooooooooo`000_ooool01Ooo003oooooooooooooooooo`0000;o
oooo00?oo`00oooooooo00000_oo0011ooooo`;o00007_ooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`14ooooo`?oo`0000Go003o
ool00?l00?oo003oool00002ooooo`03ool00?l00?oooooo00?ooooo00Ko003oool00?oooooooooo
ool00?l00?l5ooooo`03o`00ooooooooo`0000;ooooo00?o003oooooooooool00oooool01_l00?oo
o`00ooooooooooooo`00o`00o`Gooooo00Coo`00ooooooooooooo`000_l00?l00ooo003oooooool0
0002ool004Kooooo00?o0000ooooooooool05?ooool001[ooooo00Go0000ooooooooooooooooo`00
0002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0AOooool00ol00?oooooo
ooooo`02o`00o`_ooooo00Go003oooooooooooooooooo`00o`08ooooo`03o`000?oooooo003o00Ko
oooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo00?ooooo00Co003ooooo
ool00?oooooo0_l00?m7ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0@Oooool0
1?oo003ooooooooooooo0003ooooo`04ool00?ooooooooooool000;ooooo00?oo`00ooooooooool0
1?ooool01?oo003ooooooooooooo0009ooooo`03ool00?oooooooooo00Oooooo00Coo`00oooooooo
ooooo`001_ooool01?oo003ooooooooooooo0002ooooo`05ool00?oooooooooooooooooo00000_oo
ool00ooo003oooooooooo`14ooooo`03o`000?oooooooooo01cooooo00Go0000oooooooooooooooo
o`000002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0A?ooool3ool00005
oooooooo003o003ooooooooo00000_ooool00ooo003o003oooooo`03ooooo`06o`00oooo003ooooo
oooooooo003o003o1Oooool00ol00?ooooooool00008ooooo`06o`00oooo003ooooooooooooo003o
003o1?ooool01Ol00?ooo`00ooooooooooooo`0000;o003o00?oo`00o`00oooo00000_oo0016oooo
o`03o`000?oooooooooo01Cooooo000Kooooo`?o00001?ooool2o`0000Cooooo00?o0000oooooooo
ool0B_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00?ooooo00Go003ooooooooo
ooooooooo`00o`06ooooo`05o`00oooooooo0000ooooool00?l01_ooool01Ol00?oooooooooooooo
oooo003o00Wooooo0_l00?l00ooooooo003oooooo`19ooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool0@?ooool3ool00003oooooooo003ooooo00;ooooo00Coo`00ooooooooooooo`00
0_ooool00ooo003oooooooooo`04ooooo`04ool00?ooooooooooool000Wooooo00?oo`00oooooooo
ool01oooool01?oo003ooooooooooooo0006ooooo`04ool00?ooooooooooool000;ooooo00Koo`00
ooooooooooooooooool00?ooool3ool004Gooooo00?o0000ooooooooool07Oooool3o`0000Cooooo
0_l00005ooooo`03o`000?oooooooooo04Cooooo0ooo00001Ol00?ooo`00o`00ool00?ooo`0000;o
oooo00?oo`00ooooooooool01?ooool01?oo003ooooooooooooo0006ooooo`05o`00ooooooooo`00
ooooool00?l01oooool01?oo003ooooooooooooo0005ooooo`09o`00oooo003ooooooooooooo003o
003ooooooooo003o003o00?oo`00A_ooool00ol0003oooooooooo`0Dooooo`00:?ooool2o`0004Wo
oooo0ol00?l4ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool02?ooool00ol00?oo
ooooo`00000<ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool01?l00?oo
ooooo`00ool00?m9ooooo`;o00009_ooool00ol0003oooooooooo`10ooooo`?oo`0000?oooooool0
0?ooool00_ooool01?oo003ooooooooooooo0002ooooo`03ool00?oooooooooo00Cooooo00Coo`00
ooooooooooooo`002Oooool00ooo003oooooooooo`07ooooo`04ool00?ooooooooooool000Kooooo
00Coo`00ooooooooooooo`000_ooool01_oo003oooooooooooooooooo`00ooooo`?oo`00AOooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo04Oooooo00Go003oool00?oooooo003oool0
0002ooooo`03ool00?l00?oooooo00?ooooo00Go003oool00?ooooooooooool00008ooooo`03ool0
0?oooooo003o00Kooooo00Go003oool00?ooooooooooool00005ooooo`09o`00oooo003ooooooooo
oooo003oooooo`00oooo003o003o04Wooooo00?o0000ooooooooool05?ooool002Sooooo00?o0000
ooooooooool0B?ooool3o`00o`Cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`04
ooooo`05o`00oooooooo0000ooooool00?l01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool0Boooool00ol0003oooooooooo`0Fooooo`Go00000ooo
ool2o`0000Cooooo00?o0000ooooooooool0@?ooool3ool00003oooooooo003ooooo00;ooooo00Co
o`00ooooooooooooo`000_ooool00ooo003oooooooooo`04ooooo`04ool00?ooooooooooool000Wo
oooo00?oo`00ooooooooool01oooool01?oo003ooooooooooooo0006ooooo`04ool00?oooooooooo
ool000;ooooo00Koo`00ooooooooooooooooool00?ooool3ool004Gooooo00?o0000ooooooooool0
:oooool00ol0003oooooooooo`17ooooo`05o`00oooo003o003oo`00oooo00000_ooool00ooo003o
003oooooo`03ooooo`05o`00oooo003ooooooooooooo00001_ooool01Ol00?ooooooool00?oooooo
003o00Kooooo00Go003oool00?ooooooooooool00006ooooo`04ool00?ooooooooooool000;o003o
00?oo`00ooooooooool0Aoooool2o`0001Kooooo000Xooooo`03o`000?oooooooooo04Sooooo0_l0
0?l;ooooo`05o`00ooooooooooooooooool00?l02?ooool00ol0003oooooo`00o`06ooooo`05o`00
ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`04ooooo`;o003oB_ooool00ol0003o
ooooooooo`0Gooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool0
0ol0003oooooooooo`14ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooo
oooo0006ooooo`04ool00?ooooooooooool000Wooooo00?oo`00ooooooooool01oooool01?oo003o
oooooooooooo0006ooooo`04ool00?ooooooooooool000;ooooo00Goo`00ooooooooooooooooool0
0019ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0B?ooool01?oo003o003ooooo
oooo0002ooooo`03ool00?l00?oooooo00?ooooo00Go003oool00?ooooooooooool00006ooooo`03
o`00ooooooooo`0000Sooooo00Go003oool00?ooooooooooool00005ooooo`05o`00oooo003ooooo
oooooooo00000_l00?l00ooo003o003oooooo`18ooooo`03o`000?oooooooooo01Cooooo000Xoooo
o`03o`000?oooooooooo04[ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`03oooo
o`05o`00ooooooooooooooooool00?l01_ooool01Ol00?ooooooo`000?oooooo003o00Kooooo00Go
003oooooooooooooooooo`00o`09ooooo`04o`00oooooooo003oo`00od[ooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooo
ooooool0A?ooool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`001_oo
ool01?oo003ooooooooooooo0009ooooo`03ool00?oooooooooo00Oooooo00Coo`00oooooooooooo
o`001_ooool01?oo003ooooooooooooo0002ooooo`05ool00?oooooooooooooooooo0000BOooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo04Oooooo00Go003oool00?l00?oo003oool0
0002ooooo`03ool00?oooooooooo00Cooooo00Coo`00ooooooooooooo`001_ooool01Ol00?oooooo
ool00?oooooo003o00Oooooo00Coo`00ooooooooooooo`001Oooool02?l00?ooo`00oooooooooooo
o`00o`00ooooooooo`00B_ooool00ol0003oooooooooo`0Dooooo`00:?ooool00ol0003ooooooooo
o`18ooooo`?o003o1?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Sooooo00?o
003oooooool000003?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00Co
003oooooool00?oo003oB_ooool00ol0003oooooooooo`0Iooooo`05o`000?ooooooooooooooool0
00000_ooool01?l0003oooooooooooooool3o`0004Cooooo00Goo`00ooooooooooooooooool00002
ooooo`04ool00?ooooooooooool000Kooooo00Coo`00ooooooooooooo`002Oooool00ooo003ooooo
ooooo`07ooooo`04ool00?ooooooooooool000Kooooo00Coo`00ooooooooooooo`000_ooool01Ooo
003oooooooooooooooooo`0004Sooooo0_l0000]ooooo`03o`000?oooooooooo04Oooooo00Go003o
ool00?oooooo003oool00002ooooo`03ool00?l00?oooooo00?ooooo0ooo00000oooooooo`00oooo
o`07ooooo`03ool00?oooooo003o00Kooooo00?o003oool00?ooool00ooo0004ooooo`08o`00oooo
003ooooooooooooo003oooooo`00oooo001:ooooo`03o`000?oooooooooo01Cooooo000Xooooo`;o
0000BOooool3o`00o`Cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`04ooooo`05
o`00oooooooo0000ooooool00?l01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool0B_ooool2o`0001Sooooo00Go0000ooooooooooooooooo`000002
ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0A?ooool01Ooo003ooooooooo
ooooooooo`0000;ooooo00Coo`00ooooooooooooo`001_ooool01?oo003ooooooooooooo0009oooo
o`03ool00?oooooooooo00Oooooo00Coo`00ooooooooooooo`001_ooool01?oo003ooooooooooooo
0002ooooo`05ool00?oooooooooooooooooo0000BOooool00ol0003oooooooooo`0[ooooo`03o`00
0?oooooooooo04Oooooo00Go003oool00?l00?oo003oool00002ooooo`03ool00?l00?oooooo00?o
oooo0ooo00000oooooooo`00ooooo`06ooooo`04o`00oooo003oooooo`00o`Kooooo00?o003oool0
0?ooool00ooo0005ooooo`04ool00?ooooooooooool000;o003o00?oo`00ooooooooool0B?ooool0
0ol0003oooooooooo`0Dooooo`00:?ooool00ol0003oooooooooo`18ooooo`;o003o2oooool01Ol0
0?oooooooooooooooooo003o00Sooooo00?o0000ooooool00?l01_ooool01Ol00?oooooooooooooo
oooo003o00Cooooo00?o003oooooooooool01?ooool2o`00od[ooooo00?o0000ooooooooool05_oo
ool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000oooool00ol0003o
ooooooooo`13ooooo`?oo`000_ooool01?oo003ooooooooooooo0002ooooo`03ool00?oooooooooo
00Cooooo00Coo`00ooooooooooooo`002Oooool00ooo003oooooooooo`07ooooo`04ool00?oooooo
ooooool000Kooooo00Coo`00ooooooooooooo`000_ooool00ooo003oooooooooo`03ool004Sooooo
00?o0000ooooooooool0:oooool00ol0003oooooooooo`18ooooo`04ool00?l00?ooooooool000;o
oooo00?oo`00o`00ooooool00oooool3ool00003oooooooo003ooooo00Kooooo00?o003oool00?oo
ool02?ooool00ooo003oooooool00002ool000Cooooo00Go003oool00?ooooooooooool00002o`00
o`03ool00?oooooooooo04Oooooo0_l0000Fooooo`00:?ooool00ol0003oooooooooo`1:ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool00oooool01Ol00?oooooooooooooooooo003o
00Kooooo00Go003oooooool0003oooooo`00o`06ooooo`05o`00ooooooooooooooooool00?l02Ooo
ool01?l00?ooooooo`00ool00?m:ooooo`03o`000?oooooooooo01Oooooo0ol00004ooooo`;o0000
1?ooool00ol0003oooooooooo`13ooooo`?oo`000_ooool01?oo003ooooooooooooo0002ooooo`03
ool00?oooooooooo00Cooooo00Coo`00ooooooooooooo`002Oooool00ooo003oooooooooo`07oooo
o`04ool00?ooooooooooool000Kooooo00Coo`00ooooooooooooo`000_ooool00ooo003ooooooooo
o`03ool004Sooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`18ooooo`04ool00?oo
oooo003oool000;ooooo00?oo`00ooooooooool01oooool00ooo003oooooooooo`05ooooo`04o`00
oooo003oooooo`00o`Oooooo00?oo`00ooooooooool01_ooool02?l00?ooo`00ooooooooooooo`00
o`00ooooooooo`00B_ooool00ol0003oooooooooo`0Dooooo`00:?ooool00ol0003oooooooooo`18
ooooo`?o003o1?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Sooooo00?o003o
ooooool000003?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00Co003o
ooooool00?oo003oB_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo04?ooooo0ooo
0002ooooo`04ool00?ooooooooooool000;ooooo00?oo`00ooooooooool01?ooool01?oo003ooooo
oooooooo0009ooooo`03ool00?oooooooooo00Oooooo00Coo`00ooooooooooooo`001_ooool01?oo
003ooooooooooooo0002ooooo`03ool00?oooooooooo00?oo`00B?ooool00ol0003oooooooooo`0[
ooooo`03o`000?oooooooooo04Oooooo0ooo00001_l00?ooo`00ooooooooooooo`00o`00o`Gooooo
00Co003oooooooooooooo`002?ooool00ooo003oooooo`00o`07ooooo`04ool00?ooooooooooo`00
o`Gooooo00Ko003oool00?ooooooooooool00?ooool3ool004Wooooo00?o0000ooooooooool05?oo
ool002Sooooo00?o0000ooooooooool0B?ooool2o`00o`03ooooool00?oooooo00;ooooo00?o003o
ooooooooool01oooool00ol00?ooooooooooo`04ooooo`05o`00oooooooo0000ooooool00?l01_oo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0Booo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo04Sooooo00Coo`00ooooooooooooo`00
0_ooool00ooo003oooooooooo`04ooooo`04ool00?ooooooooooool000Wooooo00?oo`00oooooooo
ool01oooool01?oo003ooooooooooooo0006ooooo`04ool00?ooooooooooool000;ooooo00?oo`00
ooooooooool0Boooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo04Oooooo0ooo0000
1_l00?ooo`00ooooooooooooo`00o`00o`Gooooo00Co003oooooooooooooo`001oooool01?l00?oo
o`00ooooool00?l7ooooo`04ool00?ooooooooooo`00o`Kooooo00Goo`00ooooooooooooo`00o`00
o`03ool004Wooooo00?o0000ooooooooool05?ooool002Sooooo0_l0001Fooooo`05o`00oooooooo
ooooooooool00?l02?ooool00ol0003oooooo`00o`06ooooo`04o`00ooooooooooooo`00o`Gooooo
00?o003oooooooooool0Coooool2o`0002Kooooo00?o0000ooooooooool0B?ooool01?oo003ooooo
oooooooo0002ooooo`03ool00?oooooooooo00Cooooo00Coo`00ooooooooooooo`002Oooool00ooo
003oooooooooo`07ooooo`04ool00?ooooooooooool000Kooooo00Coo`00ooooooooooooo`000_oo
ool00ooo003oooooooooo`1;ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0Aooo
ool3ool00006oooooooo003ooooooooooooo003o003o1Oooool01?l00?oooooooooooooo0007oooo
o`03o`00oooo003ooooo00Sooooo00Coo`00oooooooooooo003o1Oooool01_l00?ooo`00oooooooo
ooooo`00o`00o`?oo`00B?ooool2o`0001Kooooo000Xooooo`03o`000?oooooooooo04_ooooo00Go
003oooooooooooooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`Oooooo00Go003oooooool0
003oooooo`00o`06ooooo`04o`00ooooooooooooo`00o`[ooooo00?o003oooooooooool0Boooool0
0ol0003oooooooooo`0Tooooo`;o0000BOooool01?oo003ooooooooooooo0002ooooo`03ool00?oo
oooooooo00Cooooo00Coo`00ooooooooooooo`002Oooool00ooo003oooooooooo`07ooooo`04ool0
0?ooooooooooool000Kooooo00Coo`00ooooooooooooo`000_ooool00ooo003oooooooooo`1:oooo
o`;o0000;Oooool00ol0003oooooooooo`1:ooooo`05o`00oooo003ooooooooooooo00002Oooool0
0ooo003oooooooooo`05ooooo`04o`00oooo003oooooo`00o`Oooooo00?oo`00ooooooooool01_oo
ool01_l00?ooo`00ooooooooooooo`00o`00odcooooo00?o0000ooooooooool05?ooool001cooooo
0ol00003ooooo`;o00001?ooool00ol0003oooooooooo`1;ooooo`05o`00ooooooooooooooooool0
0?l01Oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooo000000_ooooo00?o003ooooooooo
ool00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo04_ooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`18ooooo`04ool00?ooooooooooool000;ooooo00?oo`00oooo
ooooool01?ooool01?oo003ooooooooooooo0009ooooo`03ool00?oooooooooo00Oooooo00Coo`00
ooooooooooooo`001_ooool01?oo003ooooooooooooo0002ooooo`03ool00?oooooooooo04_ooooo
00?o0000ooooooooool0:oooool00ol0003oooooooooo`1:ooooo`06o`00oooo003ooooooooooooo
003o003o1Oooool01?l00?oooooooooooooo0008ooooo`03ool00?oooooo003o00Oooooo00Coo`00
oooooooooooo003o1Oooool01Ol00?ooo`00ooooooooooooo`0004gooooo00?o0000ooooooooool0
5?ooool001gooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool0
0000COooool01Ol00?oooooooooooooooooo003o00Sooooo00?o003oooooooooool01Oooool01?l0
0?ooooooo`000?l00?l7ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`1;ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0B?ooool0
1?oo003ooooooooooooo0002ooooo`03ool00?oooooooooo00Cooooo00Coo`00ooooooooooooo`00
2Oooool00ooo003oooooooooo`07ooooo`04ool00?ooooooooooool000Kooooo00Coo`00oooooooo
ooooo`000_ooool00ooo003oooooooooo`1;ooooo`03o`000?oooooooooo01kooooo0ol00003oooo
o`;o00001Oooool00ol0003oooooooooo`1:ooooo`06o`00oooo003ooooooooooooo003o003o1Ooo
ool01?l00?oooooooooooooo0007ooooo`04o`00oooo003oooooo`00o`Oooooo00Coo`00oooooooo
oooo003o1_ooool01Ooo003ooooooooooooo003o003o04cooooo00?o0000ooooooooool05?ooool0
01[ooooo1Ol00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0Coooool0
0ol00?ooooooooooo`03ooooo`04o`00ooooooooooooo`00o`Wooooo00?o0000o`00ooooool01_oo
ool01?l00?ooooooooooool00?l6ooooo`03o`00oooooooooooo04oooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`18ooooo`04ool00?ooooooooooool000;ooooo00?oo`00oooooooo
ool01?ooool01?oo003ooooooooooooo0009ooooo`03ool00?oooooooooo00Oooooo00Coo`00oooo
ooooooooo`001_ooool01?oo003ooooooooooooo0002ooooo`03ool00?oooooooooo04_ooooo00?o
0000ooooooooool07oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`1;ooooo`05ool00?ooooooooooool00?l00?l01Oooool01?l00?oo
oooooooooooo0007ooooo`03o`00oooo003ooooo00Sooooo00Coo`00oooooooooooo003o1Oooool0
1_l00?ooo`00ooooooooooooo`00o`00odcooooo00?o0000ooooooooool05?ooool001[ooooo00Co
0000oooooooooooo00000oooool01?l0003oooooooooool00003ooooo`;o0000C?ooool00ol00?oo
ooooooooo`07ooooo`04o`00ooooooooooooo`00o`Oooooo00Co003oooooool0003o003o1oooool0
1?l00?ooooooooooool00?l:ooooo`03o`00oooooooooooo04Wooooo0ol0000Vooooo`03o`000?oo
oooooooo04Sooooo00Coo`00ooooooooooooo`000_ooool00ooo003oooooooooo`04ooooo`04ool0
0?ooooooooooool000Wooooo00?oo`00ooooooooool01oooool01?oo003ooooooooooooo0006oooo
o`04ool00?ooooooooooool000;ooooo00?oo`00ooooooooool0Boooool00ol0003oooooooooo`0L
ooooo`Go00000_ooool01?l0003oooooooooool00004ooooo`;o0000Boooool01Ol00?ooo`00oooo
ooooooooo`0000Wooooo00?oo`00ooooooooool01Oooool01?l00?ooo`00ooooool00?l7ooooo`03
ool00?oooooooooo00Kooooo00Ko003oool00?ooooooooooool00?l00?m;ooooo`;o00005_ooool0
01_ooooo00?o0000ooooool000000oooool01?l0003oooooooooool00003ooooo`03o`000?oooooo
oooo04_ooooo00Go003oooooooooooooooooo`00o`06ooooo`03o`00oooooooooooo00Oooooo00?o
003oooooool000002oooool00ol00?ooooooooooo`04ooooo`05o`00ooooooooooooooooool00?l0
COooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo04Sooooo00Coo`00oooooooooooo
o`000_ooool00ooo003oooooooooo`03ooooo`?oo`0000?oooooool00?ooool02?ooool00ooo003o
ooooooooo`07ooooo`03ool00?ooooooo`0000;oo`001Oooool01?oo003ooooooooooooo0002oooo
o`03ool00?oooooooooo04_ooooo00?o0000ooooooooool07?ooool01?l0003oooooooooool00003
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0B_ooool01_l00?ooo`00oooo
ooooooooo`00o`00o`Gooooo00Co003oooooooooooooo`002?ooool00ooo003oooooo`00o`07oooo
o`04ool00?ooooooooooo`00o`Gooooo00Go003oool00?ooooooooooool0001=ooooo`03o`000?oo
oooooooo01Cooooo000Looooo`;o00000oooool01?l0003oooooooooool00003ooooo`03o`000?oo
oooooooo04_ooooo00Go003oooooooooooooooooo`00o`08ooooo`03o`00oooooooooooo00Gooooo
00Co003oooooool0003o003o1oooool00ol00?ooooooooooo`07ooooo`05o`00oooooooooooooooo
ool00?l0COooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo04Sooooo00Coo`00oooo
ooooooooo`000_ooool00ooo003oooooooooo`03ooooo`?oo`0000?oooooool00?ooool02?ooool0
0ooo003oooooooooo`07ooooo`03ool00?ooooooo`0000;oo`001Oooool01?oo003ooooooooooooo
0002ooooo`03ool00?oooooooooo04_ooooo00?o0000ooooooooool07Oooool00ol0003oooooo`00
0003ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0B_ooool01_l00?ooo`00
ooooooooooooo`00o`00o`Gooooo00?o003ooooooooo00000_oo0006ooooo`04o`00oooo003ooooo
o`00o`Kooooo0ooo00000ooooooo003oooooo`05ooooo`05ool00?ooooooooooool00?l00?l0C?oo
ool00ol0003oooooooooo`0Dooooo`007Oooool00ol0003oooooooooo`02ooooo`;o00001?ooool0
0ol0003oooooooooo`1?ooooo`03o`00oooooooooooo00Cooooo00?o003oooooool00?l02Oooool0
0ol0003o003oooooo`06ooooo`04o`00ooooooooooooo`00o`Kooooo00?o003oooooooooool0Cooo
ool00ol0003oooooooooo`0Tooooo`;o0000BOooool01?oo003ooooooooooooo0002ooooo`03ool0
0?oooooooooo00?ooooo0ooo00000oooooooo`00ooooo`08ooooo`03ool00?oooooooooo00Oooooo
00?oo`00oooooooo00000_oo0005ooooo`04ool00?ooooooooooool000;ooooo00?oo`00oooooooo
ool0B_ooool2o`00023ooooo0_l00003ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooo
ooooool0Boooool01Ooo003ooooooooooooo003o003o00Gooooo00?o003ooooooooo00000_oo0006
ooooo`03o`00oooo003ooooo00Oooooo0ooo00000ooooooo003oooooo`04ooooo`06o`00oooo003o
oooooooooooo003o003oC?ooool00ol0003oooooooooo`0Dooooo`00:?ooool00ol0003ooooooooo
o`1;ooooo`03o`00oooooooooooo00Sooooo00?o003oooooool00?l01oooool01?l00?ooooooo`00
0?l00?l8ooooo`03o`00oooooooo003o00[ooooo00?o003oooooooooool0Boooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo04Sooooo00Coo`00ooooooooooooo`000_ooool00ooo003o
ooooooooo`07ooooo`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool01oooool00ooo003o
ooooooooo`07ooooo`04ool00?ooooooooooool000;ooooo00?oo`00ooooooooool0Boooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo00;ooooo0_l00005ooooo`03o`000?oooooooooo
04[ooooo00Go003oool00?ooooooooooool00008ooooo`?oo`001_ooool01?l00?ooo`00ooooool0
0?l6ooooo`?oo`001oooool01_l00?ooo`00ooooooooooooo`00o`00odcooooo00?o0000oooooooo
ool05?ooool002Sooooo0_l0001<ooooo`05o`00ooooooooooooooooool00?l01_ooool00ol00?oo
ooooooooo`07ooooo`03o`00oooooooo000000_ooooo00?o003oooooooooool02?ooool00ol00?oo
ooooooooo`1:ooooo`;o00009_ooool00ol0003oooooooooo`18ooooo`04ool00?ooooooooooool0
00;ooooo00?oo`00ooooooooool01oooool00ooo003oooooooooo`07ooooo`03ool00?oooooooooo
00Oooooo00?oo`00ooooooooool01oooool01?oo003ooooooooooooo0002ooooo`03ool00?oooooo
oooo04_ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`1:ooooo`06o`00oooo003o
oooooooooooo003o003o1Oooool01?l00?ooooooooooool00?l8ooooo`03ool00?oooooo003o00Oo
oooo00Co003ooooooooooooo003o1Oooool01Ol00?ooo`00ooooooooooooo`0004cooooo0_l0000F
ooooo`00:?ooool00ol0003oooooooooo`1;ooooo`05o`00ooooooooooooooooool00?l02?ooool0
0ol00?ooooooooooo`06ooooo`03o`00ool0003o003o00Sooooo00?o003oooooooooool01_ooool0
1Ol00?oooooooooooooooooo003o04gooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`18ooooo`04ool00?ooooooooooool000;ooooo00?oo`00ooooooooool01oooool00ooo003ooooo
ooooo`07ooooo`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool01oooool01?oo003ooooo
oooooooo0002ooooo`03ool00?oooooooooo04_ooooo00?o0000ooooooooool0:oooool00ol0003o
ooooooooo`1:ooooo`06o`00oooo003ooooooooooooo003o003o1Oooool01?l00?ooooooooooool0
0?l7ooooo`04o`00oooo003oooooo`00o`Oooooo00Co003ooooooooooooo003o1_ooool01Ooo003o
oooooooooooo003o003o04cooooo00?o0000ooooooooool05?ooool002Sooooo00?o0000oooooooo
ool0Coooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo003o00Wooooo00?o0000o`00oooo
ool01oooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooooooo04oooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`17ooooo`?oo`0000Goooooool00?ooooooooooool00009oooo
o`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool01oooool00ooo003oooooooooo`07oooo
o`05ool00?ooooooooooool00?ooool00ooo001<ooooo`03o`000?oooooooooo02_ooooo00?o0000
ooooooooool0Boooool01Ooo003ooooooooooooo003o003o00Gooooo00Co003ooooooooooooo003o
1oooool00ol00?ooo`00ooooo`08ooooo`03o`00oooooooo003o00Kooooo00Ko003oool00?oooooo
ooooool00?l00?m<ooooo`03o`000?oooooooooo01Cooooo000Xooooo`03o`000?oooooooooo04_o
oooo00?o003oooooooooool02?ooool00ol00?ooooooo`00o`08ooooo`03o`00ool0003o003o00So
oooo00?o003oooooool00?l01_ooool01Ol00?oooooooooooooooooo003o04gooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`17ooooo`?oo`0000Goooooool00?ooooooooooool00009
ooooo`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool01oooool00ooo003oooooooooo`07
ooooo`05ool00?ooooooooooool00?ooool00ooo001<ooooo`03o`000?oooooooooo02_ooooo00?o
0000ooooooooool0B_ooool01Ol00?ooo`00ooooooooooooo`00017ooooo00Co003oool00?oooooo
003o4?ooool01Ol00?ooo`00ooooooooooooo`0004gooooo00?o0000ooooooooool05?ooool002So
oooo00?o0000ooooooooool0Boooool01Ol00?oooooooooooooooooo003o00Kooooo00?o003ooooo
ooooool02?ooool00ol00?oo0000ooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003ooooo
ooooool0Boooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo04Oooooo0ooo00001Ooo
ooooo`00ooooooooooooo`0000Wooooo00?oo`00ooooooooool01oooool00ooo003oooooooooo`07
ooooo`03ool00?oooooooooo00Oooooo00Goo`00ooooooooooooo`00ooooo`03ool004cooooo00?o
0000ooooooooool0:oooool00ol0003oooooooooo`1:ooooo`05o`00oooo003ooooooooooooo0000
1_ooool2o`00o`03ooooool00?oooooo00Oooooo00?oo`00ooooool00?l01oooool00ol00?oooooo
o`00o`06ooooo`05o`00oooo003ooooooooooooo0000COooool00ol0003oooooooooo`0Dooooo`00
:?ooool2o`0004cooooo00Go003oooooooooooooooooo`00o`08ooooo`03o`00oooooooooooo00Ko
oooo00?o003oo`000?l00?l02?ooool00ol00?ooooooooooo`06ooooo`05o`00oooooooooooooooo
ool00?l0C?ooool2o`0002Kooooo0_l0001<ooooo`04ool00?ooooooooooool000Wooooo00?oo`00
ooooooooool01oooool00ooo003oooooooooo`07ooooo`03ool00?oooooooooo00Oooooo00Coo`00
ooooooooooooo`00Coooool2o`0002gooooo00?o0000ooooooooool0B_ooool01Ol00?ooo`00oooo
ooooooooo`0000Kooooo00Co003ooooooooooooo003o1oooool01?l00?ooo`00ooooool00?l7oooo
o`03o`00oooooooo003o00Oooooo00Coo`00ooooooooooooo`00C?ooool2o`0001Kooooo000Xoooo
o`03o`000?oooooooooo04oooooo00?o003oooooooooool01?ooool00ol00?ooooooo`00o`09oooo
o`03o`000?l00?oooooo00Oooooo00?o003oooooool00?l01_ooool00ol00?ooooooooooo`1?oooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0Boooool01?oo003ooooooooooooo0009
ooooo`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool01oooool00ooo003oooooooooo`07
ooooo`04ool00?ooooooooooool0053ooooo00?o0000ooooooooool0:oooool00ol0003ooooooooo
o`1;ooooo`04ool00?ooooooooooool000Kooooo00?o003oooooool00?l02?ooool00ol00?ooo`00
ooooo`08ooooo`03o`00oooooooo003o00Kooooo00Go003oool00?ooooooooooool0001=ooooo`03
o`000?oooooooooo01Cooooo000Xooooo`03o`000?oooooooooo04_ooooo00?o003oooooooooool0
2?ooool00ol00?ooooooo`00o`08ooooo`03o`00ool0003o003o00Sooooo00?o003oooooool00?l0
1_ooool01Ol00?oooooooooooooooooo003o04gooooo00?o0000ooooooooool09?ooool00ol0003o
ooooooooo`1;ooooo`04ool00?ooooooooooool000Wooooo00?oo`00ooooooooool01oooool00ooo
003oooooooooo`07ooooo`03ool00?oooooooooo00Oooooo00Coo`00ooooooooooooo`00D?ooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo04[ooooo00Go003oool00?ooooooooooool0
000Aooooo`03o`00oooo003o003o017ooooo00Go003oool00?ooooooooooool0001=ooooo`03o`00
0?oooooooooo01Cooooo000Xooooo`03o`000?oooooooooo04_ooooo00Go003ooooooooooooooooo
o`00o`06ooooo`03o`00oooooooooooo00Sooooo00?o003oo`000?ooool02_ooool00ol00?oooooo
ooooo`08ooooo`03o`00oooooooooooo04_ooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`1;ooooo`04ool00?ooooooooooool000Wooooo00?oo`00ooooooooool01oooool00ooo003o
ooooooooo`07ooooo`03ool00?oooooooooo00Oooooo00Coo`00ooooooooooooo`00D?ooool00ol0
003oooooooooo`0[ooooo`03o`000?oooooooooo04[ooooo00Go003oool00?ooooooooooool00007
ooooo`;o003o2Oooool00ooo003o003oooooo`07ooooo`03o`00oooooooo003o00Kooooo00Go003o
ool00?ooooooooooool0001=ooooo`03o`000?oooooooooo01Cooooo000Xooooo`;o0000C?ooool0
1Ol00?oooooooooooooooooo003o00Sooooo00?o003oooooooooool01_ooool00ol00?oo0000o`00
o`08ooooo`03o`00oooooooooooo00Kooooo00Go003oooooooooooooooooo`00o`1<ooooo`;o0000
6_ooool3o`0000?ooooo0_l00004ooooo`03o`000?oooooooooo04_ooooo00Coo`00oooooooooooo
o`002Oooool00ooo003oooooooooo`07ooooo`03ool00?oooooooooo00Oooooo00?oo`00oooooooo
ool01oooool01?oo003ooooooooooooo001@ooooo`03o`000?oooooooooo02_ooooo00?o0000oooo
ooooool0B_ooool01Ol00?ooo`00ooooooooooooo`0000Oooooo0_l00?l8ooooo`03o`00oooo003o
003o00Sooooo00?o003oooooool00?l01oooool01?oo003ooooooooooooo001=ooooo`03o`000?oo
oooooooo01Cooooo000Xooooo`03o`000?oooooooooo04oooooo00?o003oooooooooool01?ooool0
0ol00?ooooooo`00o`09ooooo`03o`000?l00?oooooo00Oooooo00?o003oooooool00?l01_ooool0
0ol00?ooooooooooo`1?ooooo`03o`000?oooooooooo01Wooooo00Go0000ooooooooooooooooo`00
0002ooooo`05o`000?ooooooooooooooool00000COooool01?oo003ooooooooooooo0009ooooo`03
ool00?oooooooooo00Oooooo00?oo`00ooooooooool01oooool00ooo003oooooooooo`07ooooo`04
ool00?ooooooooooool0053ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`1;oooo
o`04ool00?ooooooooooool000Oooooo0_l00?l8ooooo`03o`00oooo003ooooo00Wooooo0_l00?l6
ooooo`05o`00oooo003ooooooooooooo0000C?ooool2o`0001Kooooo000Xooooo`03o`000?oooooo
oooo04_ooooo00?o003oooooooooool02?ooool00ol00?ooooooo`00o`08ooooo`03o`00ool0003o
003o00Sooooo0_l00?l7ooooo`05o`00ooooooooooooooooool00?l0COooool00ol0003ooooooooo
o`0Fooooo`Go00000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo04_ooooo
00Coo`00ooooooooooooo`002Oooool00ooo003oooooooooo`07ooooo`03ool00?oooooooooo00Oo
oooo00?oo`00ooooooooool01oooool01?oo003ooooooooooooo001@ooooo`03o`000?oooooooooo
02_ooooo00?o0000ooooooooool0B_ooool01Ol00?ooo`00ooooooooooooo`0001;ooooo00?oo`00
o`00ooooool04?ooool01Ol00?ooo`00ooooooooooooo`0004gooooo00?o0000ooooooooool05?oo
ool001_ooooo0ol00004ooooo`;o00001?ooool00ol0003oooooooooo`1;ooooo`05o`00oooooooo
ooooooooool00?l01_ooool00ol00?ooooooooooo`08ooooo`03o`00ool0003ooooo00Wooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`1;ooooo`03o`000?oooooooooo01Kooooo00Co
0000oooooooooooo00000oooool01?l0003oooooooooool00003ooooo`?o0000Boooool01?oo003o
oooooooooooo0009ooooo`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool01oooool00ooo
003oooooooooo`07ooooo`04ool00?ooooooooooool004oooooo0_l0000Oooooo`?o00001?ooool2
o`0000Gooooo00?o0000ooooooooool0B_ooool01Ol00?ooo`00ooooooooooooo`0000Oooooo0_l0
0?l9ooooo`03ool00?l00?oooooo00Sooooo0_l00?l6ooooo`05o`00oooo003ooooooooooooo0000
COooool00ol0003oooooooooo`0Dooooo`006_ooool01Ol0003ooooooooooooooooo000000;ooooo
00Co0000oooooooooooo00000oooool00ol0003oooooooooo`1;ooooo`05o`00oooooooooooooooo
ool00?l01oooool00ol00?ooooooooooo`07ooooo`03o`00ool0003o003o00Sooooo00?o003ooooo
ooooool01_ooool01Ol00?oooooooooooooooooo003o04gooooo00?o0000ooooooooool05oooool0
0ol0003oooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0Booo
ool01?oo003ooooooooooooo0009ooooo`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool0
1oooool00ooo003oooooooooo`07ooooo`04ool00?ooooooooooool0053ooooo00?o0000oooooooo
ool07?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00001?ooool0
0ol0003oooooooooo`1:ooooo`05o`00oooo003ooooooooooooo00001oooool2o`00o`Wooooo00?o
o`00o`00ooooool02?ooool2o`00o`Oooooo00Coo`00ooooooooooooo`00COooool00ol0003ooooo
ooooo`0Dooooo`006_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo
00000oooool2o`00053ooooo00?o003oooooooooool01?ooool2o`00o`[ooooo00?o0000o`00oooo
ool01oooool2o`00o`Oooooo00?o003oooooooooool0COooool3o`0001[ooooo0_l00003ooooo`04
o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0Boooool01?oo003ooooooooooooo0009
ooooo`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool01oooool00ooo003oooooooooo`07
ooooo`04ool00?ooooooooooool0053ooooo00?o0000ooooooooool07?ooool01Ol0003ooooooooo
oooooooo000000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1;ooooo`04
ool00?ooooooooooool000Oooooo0_l00?l9ooooo`03ool00?oooooooooo00Sooooo0_l00?l6oooo
o`05o`00oooo003ooooooooooooo0000COooool00ol0003oooooooooo`0Dooooo`006_ooool4o`00
00?ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`1;ooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool01oooool3o`00o`Sooooo0_l00?l7ooooo`05o`00oooooooo
ooooooooool00?l0COooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00;ooooo0_l0
0004ooooo`03o`000?oooooooooo04_ooooo00Coo`00ooooooooooooo`002?ooool3ool000Sooooo
00?oo`00ooooooooool01_ooool3ool000Sooooo00Coo`00ooooooooooooo`00D?ooool00ol0003o
ooooooooo`0Looooo`Co00000oooool01?l0003oooooooooool00004ooooo`;o0000Boooool01Ol0
0?ooo`00ooooooooooooo`0001;ooooo00?oo`00o`00ooooool04?ooool01Ol00?ooo`00oooooooo
ooooo`0004cooooo0_l0000Fooooo`006_ooool00ol0003oooooooooo`04ooooo`04o`000?oooooo
ooooo`0000?ooooo00?o0000ooooooooool0Boooool01Ol00?oooooooooooooooooo003o00Oooooo
00?o003oooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool0Boooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo04_ooooo
00Coo`00ooooooooooooo`002?ooool3ool000Sooooo00?oo`00ooooooooool01_ooool3ool000So
oooo00Coo`00ooooooooooooo`00D?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
00Cooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1:ooooo`05o`00oooo003o
oooooooooooo00001oooool2o`00o`Wooooo00?oo`00o`00ooooool02?ooool2o`00o`Oooooo00Co
o`00ooooooooooooo`00COooool00ol0003oooooooooo`0Dooooo`006oooool00ol0003ooooooooo
o`03ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0Boooool01Ol00?oooooo
oooooooooooo003o017ooooo0_l00?lBooooo`05o`00ooooooooooooooooool00?l0COooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo04_ooooo00Coo`00ooooooooooooo`002?ooool3
ool000Sooooo00?oo`00ooooooooool01_ooool3ool000Sooooo00Coo`00ooooooooooooo`00D?oo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`1;ooooo`04ool00?ooooooooooool000Oooooo0_l00?l9ooooo`03
ool00?l00?oooooo00Sooooo00?o003oooooooooool01_ooool01?oo003ooooooooooooo001=oooo
o`03o`000?oooooooooo01Cooooo000Looooo`;o00001?ooool2o`0000Cooooo00?o0000oooooooo
ool0Coooool00ol00?ooooooooooo`0?ooooo`;o003o4_ooool00ol00?ooooooooooo`1?ooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool0Boooool01?oo003ooooooooooooo000Coooo
o`03ool00?oooooooooo017ooooo00Coo`00ooooooooooooo`00D?ooool00ol0003oooooooooo`0N
ooooo`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool0Boooool00ooo003oooooool00002
ool0017ooooo00?oo`00ooooooooool04?ooool3ool00003oooooooo003ooooo04cooooo00?o0000
ooooooooool05?ooool002Sooooo0_l0001<ooooo`03o`00oooooooooooo01Cooooo00?o003ooooo
ooooool04?ooool01Ol00?oooooooooooooooooo003o04cooooo0_l0000Vooooo`;o0000C?ooool0
1?oo003ooooooooooooo000Cooooo`03ool00?oooooooooo017ooooo00Coo`00ooooooooooooo`00
Coooool2o`0002gooooo00?o0000ooooooooool0Boooool00ooo003oooooool00002ool0017ooooo
00?oo`00o`00ooooool04?ooool3ool00003oooooooo003ooooo04cooooo00?o0000ooooooooool0
5?ooool002Sooooo00?o0000ooooooooool0Boooool01Ol00?oooooooooooooooooo003o01;ooooo
00?o0000ooooooooool05?ooool00ol00?ooooooooooo`1;ooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool0Boooool01?oo003ooooooooooooo000Cooooo`03ool00?oooooooooo017o
oooo00Coo`00ooooooooooooo`00D?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
04_ooooo00?oo`00oooooooo00000_oo000@ooooo`?oo`004Oooool3ool00003oooooooo003ooooo
04_ooooo0_l0000Fooooo`00:?ooool00ol0003oooooooooo`1;ooooo`05o`00oooooooooooooooo
ool00?l04_ooool00ol0003oooooooooo`0@ooooo`05o`00ooooooooooooooooool00?l0COooool0
0ol0003oooooooooo`0Tooooo`03o`000?oooooooooo04_ooooo00Coo`00ooooooooooooo`004ooo
ool00ooo003oooooooooo`0Aooooo`04ool00?ooooooooooool0053ooooo00?o0000ooooooooool0
:oooool00ol0003oooooooooo`1;ooooo`04ool00?ooooooooooo`00oa7ooooo0ooo000Eooooo`03
ool00?oooooooooo04_ooooo00?o0000ooooooooool05?ooool002Sooooo00?o0000ooooooooool0
Coooool00ol00?ooooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o003oooooooooool0
Coooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo04_ooooo00Coo`00oooooooooooo
o`004oooool00ooo003oooooooooo`0Aooooo`04ool00?ooooooooooool0053ooooo00?o0000oooo
ooooool0:oooool00ol0003oooooooooo`1;ooooo`04ool00?ooooooooooo`00oa7ooooo0ooo000B
ooooo`04o`00ooooooooooooool004gooooo00?o0000ooooooooool05?ooool002Sooooo00?o0000
ooooooooool0Boooool00ol00?ooooooooooo`0Dooooo`03o`000?oooooooooo013ooooo00Go003o
ooooooooooooooooo`00o`1=ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0Booo
ool01?oo003ooooooooooooo000Cooooo`03ool00?oooooooooo017ooooo00Coo`00oooooooooooo
o`00D?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo04_ooooo00?oo`00oooooooo
ool04oooool00ol0003oooooooooo`0Aooooo`04o`00ooooooooooooool004gooooo00?o0000oooo
ooooool05?ooool002Sooooo0_l0001<ooooo`05o`00ooooooooooooooooool00?l04_ooool00ol0
003oooooooooo`0Dooooo`03o`00oooooooooooo04[ooooo0_l0000Vooooo`03o`000?oooooooooo
04_ooooo00Coo`00ooooooooooooo`004oooool00ooo003oooooooooo`0Aooooo`04ool00?oooooo
ooooool0053ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`1;ooooo`04ool00?oo
ooooooooo`00oa;ooooo00?o0000ooooooooool04Oooool01?l00?oooooooooooooo001<ooooo`;o
00005_ooool002Sooooo00?o0000ooooooooool0Boooool00ol00?ooooooooooo`02o`00oa;ooooo
00?o0000ooooooooool04?ooool01Ol00?oooooooooooooooooo003o04gooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`1;ooooo`04ool00?ooooooooooool001?ooooo00?oo`00oooo
ooooool04Oooool01?oo003ooooooooooooo001@ooooo`03o`000?oooooooooo02_ooooo00?o0000
ooooooooool0Boooool01?oo003oooooooooool00?lBooooo`03o`000?oooooooooo01Cooooo00?o
o`00ooooooooool0Boooool00ol0003oooooooooo`0Dooooo`00:?ooool00ol0003oooooooooo`1>
ooooo`03o`00oooooooooooo017ooooo00?o0000ooooooooool04?ooool00ol00?ooooooooooo`1?
ooooo`03o`000?oooooooooo02Cooooo0_l0001<ooooo`04ool00?ooooooooooool001?ooooo00?o
o`00ooooooooool04Oooool01?oo003ooooooooooooo001?ooooo`;o0000;Oooool00ol0003ooooo
ooooo`1;ooooo`04ool00?ooooooooooo`00oa;ooooo00?o0000ooooooooool04Oooool01?l00?oo
oooooooooooo001=ooooo`03o`000?oooooooooo01Cooooo000Xooooo`03o`000?oooooooooo04_o
oooo00Co003ooooooooooooo003o4oooool00ol0003oooooooooo`0@ooooo`05o`00oooooooooooo
ooooool00?l0COooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo04_ooooo00Coo`00
ooooooooooooo`004oooool00ooo003oooooooooo`0Aooooo`04ool00?ooooooooooool0053ooooo
00?o0000ooooooooool0:oooool00ol0003oooooooooo`1;ooooo`03ool00?oooooooooo01?ooooo
00?o0000ooooooooool04Oooool01?l00?oooooooooooooo001=ooooo`03o`000?oooooooooo01Co
oooo000Xooooo`03o`000?oooooooooo04_ooooo00?o003oooooooooool05?ooool00ol0003ooooo
ooooo`0Dooooo`03o`00oooooooooooo04_ooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`1;ooooo`04ool00?ooooooooooool001?ooooo00?oo`00ooooooooool04Oooool01?oo003o
oooooooooooo001@ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0Boooool01?oo
003oooooooooool00?lBooooo`03o`000?oooooooooo017ooooo00Co003oooooooooooooo`00COoo
ool00ol0003oooooooooo`0Dooooo`00:?ooool2o`0004cooooo00Co003ooooooooooooo003o4ooo
ool00ol0003oooooooooo`0@ooooo`04o`00ooooooooooooo`00odgooooo0_l0000Vooooo`03o`00
0?oooooooooo04_ooooo00Coo`00ooooooooooooo`004oooool00ooo003oooooooooo`0Aooooo`04
ool00?ooooooooooool0053ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`1;oooo
o`04ool00?ooooooooooo`00oa;ooooo00?o0000ooooooooool05?ooool00ooo003oooooooooo`1:
ooooo`;o00005_ooool002Sooooo00?o0000ooooooooool0C_ooool00ol00?ooooooooooo`0Aoooo
o`03o`000?oooooooooo013ooooo00?o003oooooooooool0Coooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo04_ooooo00Coo`00ooooooooooooo`004oooool00ooo003oooooooooo`0A
ooooo`04ool00?ooooooooooool0053ooooo00?o0000ooooooooool0:oooool00ol0003ooooooooo
o`1;ooooo`04ool00?ooooooooooo`00oa;ooooo00?o0000ooooooooool04Oooool01?l00?oooooo
oooooooo001=ooooo`03o`000?oooooooooo01Cooooo000Kooooo`?o00001?ooool2o`0000Cooooo
00?o0000ooooooooool0Boooool01?l00?ooooooooooool00?lCooooo`03o`000?oooooooooo013o
oooo00Co003ooooooooooooo003oC_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
04_ooooo00Coo`00ooooooooooooo`004oooool00ooo003oooooooooo`0Aooooo`04ool00?oooooo
ooooool0053ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`1;ooooo`03ool00?oo
oooooooo01?ooooo00?o0000ooooooooool04Oooool01?l00?oooooooooooooo001=ooooo`03o`00
0?oooooooooo01Cooooo000Jooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooo
ooooool00003ooooo`03o`000?oooooooooo04_ooooo00?o003oooooooooool05?ooool00ol0003o
ooooooooo`0Cooooo`03o`00oooooooooooo04cooooo00?o0000ooooooooool09?ooool00ol0003o
ooooooooo`1;ooooo`04ool00?ooooooooooool001?ooooo00?oo`00ooooooooool04Oooool01?oo
003ooooooooooooo001@ooooo`03o`000?oooooooooo01gooooo0ol00004ooooo`;o00001Oooool0
0ol0003oooooooooo`1;ooooo`04ool00?ooooooooooo`00oa;ooooo00?o0000ooooooooool04Ooo
ool01?l00?oooooooooooooo001=ooooo`03o`000?oooooooooo01Cooooo000Jooooo`05o`000?oo
ooooooooooooool000000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo04_o
oooo00Co003ooooooooooooo003o4oooool00ol0003oooooooooo`0@ooooo`04o`00oooooooooooo
o`00odkooooo00?o0000ooooooooool09?ooool2o`0004cooooo00Coo`00ooooooooooooo`004ooo
ool00ooo003oooooooooo`0Aooooo`04ool00?ooooooooooool004oooooo0_l0000Nooooo`05o`00
0?ooooooooooooooool000000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo
04_ooooo00Coo`00oooooooooooo003o4_ooool00ol0003oooooooooo`0Dooooo`03ool00?oooooo
oooo04_ooooo00?o0000ooooooooool05?ooool001_ooooo0ol00003ooooo`04o`000?oooooooooo
o`0000?ooooo0_l0001?ooooo`03o`00oooooooooooo017ooooo00?o0000ooooooooool04?ooool0
0ol00?ooooooooooo`1=ooooo`?o00009_ooool00ol0003oooooooooo`1;ooooo`04ool00?oooooo
ooooool001?ooooo00?oo`00ooooooooool04Oooool01?oo003ooooooooooooo001@ooooo`03o`00
0?oooooooooo01cooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`00
00Cooooo0_l0001<ooooo`04ool00?ooooooooooo`00oa;ooooo00?o0000ooooooooool04Oooool0
1?l00?oooooooooooooo001<ooooo`;o00005_ooool001[ooooo00Go0000ooooooooooooooooo`00
0002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0Boooool01?l00?oooooo
ooooool00?lCooooo`03o`000?oooooooooo013ooooo00Co003ooooooooooooo003oC_ooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo04_ooooo00Coo`00ooooooooooooo`004oooool0
0ooo003oooooooooo`0Aooooo`04ool00?ooooooooooool0053ooooo00?o0000ooooooooool07Ooo
ool3o`0000?ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1;ooooo`03ool0
0?oooooooooo01?ooooo00?o0000ooooooooool04Oooool01?l00?oooooooooooooo001=ooooo`03
o`000?oooooooooo01Cooooo000Jooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00003ooooo`03o`000?oooooooooo04_ooooo00?o003oooooooooool05?ooool00ol0
003oooooooooo`0Cooooo`03o`00oooooooooooo04cooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`1;ooooo`04ool00?ooooooooooool001?ooooo00?oo`00ooooooooool04Oooool0
1?oo003ooooooooooooo001@ooooo`03o`000?oooooooooo01cooooo00Go0000oooooooooooooooo
o`000002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0Boooool01?oo003o
ooooooooool00?lBooooo`03o`000?oooooooooo017ooooo00Co003oooooooooooooo`00COooool0
0ol0003oooooooooo`0Dooooo`006oooool3o`0000Cooooo0_l00004ooooo`03o`000?oooooooooo
04_ooooo00Co003ooooooooooooo003o4oooool00ol0003oooooooooo`0@ooooo`04o`00oooooooo
ooooo`00odkooooo00?o0000ooooooooool05oooool3o`0000Cooooo0_l00004ooooo`03o`000?oo
oooooooo04_ooooo00Coo`00ooooooooooooo`004oooool00ooo003oooooooooo`0Aooooo`04ool0
0?ooooooooooool0053ooooo00?o0000ooooooooool07?ooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1;ooooo`04ool00?oooooo
ooooo`00oa;ooooo00?o0000ooooooooool05?ooool00ooo003oooooooooo`1;ooooo`03o`000?oo
oooooooo01Cooooo000Xooooo`03o`000?oooooooooo04kooooo00?o003oooooooooool04Oooool0
0ol0003oooooooooo`0@ooooo`03o`00oooooooooooo04oooooo00?o0000ooooooooool05_ooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000oooool00ol0003ooooo
ooooo`1;ooooo`04ool00?ooooooooooool001?ooooo00?oo`00ooooooooool04Oooool01?oo003o
oooooooooooo001@ooooo`03o`000?oooooooooo01gooooo0ol00004ooooo`;o00001Oooool00ol0
003oooooooooo`1;ooooo`04ool00?ooooooooooo`00oa;ooooo00?o0000ooooooooool04Oooool0
1?l00?oooooooooooooo001=ooooo`03o`000?oooooooooo01Cooooo000Xooooo`;o0000C?ooool0
1?l00?ooooooooooool00?lCooooo`03o`000?oooooooooo013ooooo00Co003ooooooooooooo003o
COooool2o`0001Sooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`00
00?ooooo00?o0000ooooooooool0Boooool01?oo003ooooooooooooo000Cooooo`03ool00?oooooo
oooo017ooooo00Coo`00ooooooooooooo`00D?ooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo04[ooooo0ooo000Dooooo`03o`000?oooooooooo017ooooo00?o003ooooooooo00000_oo
001;ooooo`;o00005_ooool002Sooooo00?o0000ooooooooool0Boooool00ol00?ooooooooooo`0D
ooooo`03o`000?oooooooooo01?ooooo00?o003oooooooooool0C?ooool00ol0003oooooooooo`0F
ooooo`Co00000oooool01?l0003oooooooooool00003ooooo`?o0000Boooool01?oo003ooooooooo
oooo000Cooooo`03ool00?oooooooooo017ooooo00Coo`00ooooooooooooo`00Coooool2o`0002go
oooo00?o0000ooooooooool0B_ooool3ool00003ooooool00?oooooo017ooooo00?o0000oooooooo
ool04Oooool00ol00?ooooooool00002ool004cooooo00?o0000ooooooooool05?ooool002Sooooo
00?o0000ooooooooool0Boooool01?l00?ooooooooooool00?lCooooo`03o`000?oooooooooo017o
oooo00?o003oooooool00?l0C_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Co
oooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`1;ooooo`04ool00?oooooooooo
ool001?ooooo00?oo`00ooooooooool04Oooool01?oo003ooooooooooooo001@ooooo`03o`000?oo
oooooooo02_ooooo00?o0000ooooooooool0B_ooool3ool00003ooooool00?oooooo017ooooo00?o
0000ooooooooool04oooool3ool004cooooo00?o0000ooooooooool05?ooool002Sooooo00?o0000
ooooooooool0C_ooool00ol00?ooooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o003o
ooooooooool0C_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00?ooooo00Co0000
oooooooooooo00000oooool00ol0003oooooooooo`1;ooooo`04ool00?ooooooooooool001?ooooo
00?oo`00ooooooooool04Oooool01?oo003ooooooooooooo001@ooooo`03o`000?oooooooooo02_o
oooo00?o0000ooooooooool0C_ooool00ol00?ooooooooooo`0@ooooo`03o`000?oooooooooo017o
oooo00Co003ooooooooooooo003oCOooool00ol0003oooooooooo`0Dooooo`00:?ooool00ol0003o
ooooooooo`1<ooooo`03o`00oooooooo003o01?ooooo00?o0000ooooooooool04Oooool00ol00?oo
ooooo`00o`1>ooooo`03o`000?oooooooooo01Sooooo0_l00004ooooo`;o00001?ooool00ol0003o
ooooooooo`1;ooooo`04ool00?ooooooooooool001?ooooo00?oo`00ooooooooool04Oooool01?oo
003ooooooooooooo001@ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0Boooool0
1?l00?ooooooooooool00?lBooooo`03o`000?oooooooooo017ooooo00Co003ooooooooooooo003o
COooool00ol0003oooooooooo`0Dooooo`00:?ooool2o`0004gooooo00?o003oooooooooool04ooo
ool00ol0003oooooooooo`0Cooooo`03o`00oooooooooooo04_ooooo0_l0000Vooooo`03o`000?oo
oooooooo04_ooooo00Coo`00ooooooooooooo`004oooool00ooo003oooooooooo`0Aooooo`04ool0
0?ooooooooooool0053ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`1;ooooo`03
o`00oooooooooooo01?ooooo00?o0000ooooooooool04Oooool01?l00?ooooooooooool00?m<oooo
o`;o00005_ooool002Sooooo00?o0000ooooooooool0C?ooool00ol00?ooooooo`00o`0Cooooo`03
o`000?oooooooooo017ooooo00?o003oooooool00?l0C_ooool00ol0003oooooooooo`0Tooooo`03
o`000?oooooooooo04_ooooo00?oo`00oooooooo00000_oo000Booooo`03ool00?oooooooooo013o
oooo0ooo00000oooooooo`00ooooo`1?ooooo`03o`000?oooooooooo02_ooooo00?o0000oooooooo
ool0Boooool01?l00?ooooooooooool00?lBooooo`03o`000?oooooooooo06;ooooo00?o0000oooo
ooooool05?ooool002Sooooo00?o0000ooooooooool0C_ooool00ol00?ooooooooooo`0Aooooo`03
o`000?oooooooooo017ooooo00?o003oooooooooool0C_ooool00ol0003oooooooooo`0Tooooo`03
o`000?oooooooooo04_ooooo00?oo`00oooooooo00000_oo000Booooo`03ool00?oooooooooo013o
oooo0ooo00000oooooooo`00ooooo`1?ooooo`03o`000?oooooooooo02_ooooo00?o0000oooooooo
ool0C_ooool00ol00?ooooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00Co003ooooooooo
oooo003oCOooool00ol0003oooooooooo`0Dooooo`00:?ooool00ol0003oooooooooo`1<ooooo`03
o`00oooooooo003o01?ooooo00?o0000ooooooooool04Oooool00ol00?ooooooo`00o`1>ooooo`03
o`000?oooooooooo02Cooooo0_l0001<ooooo`03ool00?ooooooo`0000;oo`004Oooool3ool0017o
oooo0ooo00000oooooooo`00ooooo`1>ooooo`;o0000;Oooool00ol0003oooooooooo`1>ooooo`03
o`00oooooooooooo013ooooo00?o0000ooooooooool04Oooool01?l00?ooooooooooool00?m=oooo
o`03o`000?oooooooooo01Cooooo000Xooooo`;o0000COooool00ol00?ooooooooooo`0Cooooo`03
o`000?oooooooooo01?ooooo00?o003oooooooooool0Boooool2o`0002Kooooo00?o0000oooooooo
ool0Boooool00ooo003oooooooooo`0Cooooo`?oo`005Oooool00ooo003oooooooooo`1>ooooo`03
o`000?oooooooooo02_ooooo00?o0000ooooooooool0Boooool00ol00?ooooooooooo`0Cooooo`03
o`000?oooooooooo017ooooo00Co003ooooooooooooo003oCOooool00ol0003oooooooooo`0Doooo
o`00:?ooool00ol0003oooooooooo`1<ooooo`03o`00oooooooo003o01?ooooo00?o0000oooooooo
ool04Oooool00ol00?ooooooo`00o`1>ooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool0Boooool00ooo003oooooooooo`0Cooooo`?oo`005Oooool00ooo003oooooooooo`1>ooooo`03
o`000?oooooooooo02_ooooo00?o0000ooooooooool0Boooool01?l00?ooooooooooool00?lBoooo
o`03o`000?oooooooooo067ooooo0_l0000Fooooo`00:?ooool00ol0003oooooooooo`1>ooooo`03
o`00oooooooooooo017ooooo00?o0000ooooooooool04Oooool00ol00?ooooooooooo`1>ooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool0Boooool00ooo003oooooooooo`0[ooooo`03
ool00?oooooooooo04kooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`1;ooooo`04
o`00ooooooooooooo`00oa;ooooo00?o0000ooooooooool04Oooool01?l00?ooooooooooool00?m=
ooooo`03o`000?oooooooooo01Cooooo000Eooooo`?o00001?ooool2o`0000Cooooo0_l00004oooo
o`03o`000?oooooooooo04cooooo00?o003oooooool00?l04oooool00ol0003oooooooooo`0Aoooo
o`03o`00oooooooo003o04kooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1;oooo
o`03ool00?oooooooooo02_ooooo00?oo`00ooooooooool0C_ooool00ol0003oooooooooo`0Goooo
o`?o00001?ooool2o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo04gooooo00?o003ooooo
ooooool04Oooool00ol0003oooooooooo`0Aooooo`04o`00ooooooooooooo`00odgooooo00?o0000
ooooooooool05?ooool001Kooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0C?ooool00ol00?oooooooooo
o`0Cooooo`03o`000?oooooooooo01?ooooo00?o003oooooooooool0C?ooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo04_ooooo00?oo`00ooooooooool0:oooool00ooo003ooooooooo
o`1>ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0Boooool00ol00?oo
ooooooooo`0Cooooo`03o`000?oooooooooo017ooooo00?o003oooooool00?l0C_ooool00ol0003o
ooooooooo`0Dooooo`005_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00000oooool2o`0004gooooo00?o003oooooool00?l04oooool00ol0
003oooooooooo`0Aooooo`03o`00oooooooo003o04cooooo0ol0000Vooooo`03o`000?oooooooooo
04_ooooo00?oo`00ooooooooool0:oooool00ooo003oooooooooo`1>ooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool0Boooool00ol00?ooooooo`00o`0Cooooo`03o`000?oo
oooooooo06;ooooo00?o0000ooooooooool05?ooool001Kooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0
C_ooool00ol00?ooooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o003oooooooooool0
C_ooool00ol0003oooooooooo`0Tooooo`;o0000C?ooool00ooo003oooooooooo`0[ooooo`03ool0
0?oooooooooo04gooooo0_l0000Jooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00004ooooo`;o0000C?ooool00ol00?ooooooo`00o`0Coooo
o`03o`000?oooooooooo017ooooo00?o003oooooool00?l0COooool2o`0001Kooooo000Fooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00003
ooooo`03o`000?oooooooooo04cooooo00?o003oooooool00?l04oooool00ol0003oooooooooo`0A
ooooo`03o`00oooooooo003o04kooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1;
ooooo`03ool00?oooooooooo02_ooooo00?oo`00ooooooooool0C_ooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo04gooooo00?o003oooooooooool04Oooool00ol0003ooooo
ooooo`0Aooooo`03o`00oooooooo003o04kooooo00?o0000ooooooooool05?ooool001Gooooo0_l0
0004ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003o
ooooooooo`1<ooooo`03o`00oooooooooooo01?ooooo00?o0000ooooooooool04oooool00ol00?oo
ooooooooo`1<ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0Boooool00ooo003o
ooooooooo`0[ooooo`03ool00?oooooooooo04kooooo00?o0000ooooooooool05oooool2o`0000Co
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooo
oooo04_ooooo00?o003oooooooooool04oooool00ol0003oooooooooo`0Aooooo`03o`00oooooooo
003o04kooooo00?o0000ooooooooool05?ooool001Kooooo00?o0000ooooooooool00oooool2o`00
00Cooooo0_l00004ooooo`03o`000?oooooooooo04cooooo00?o003oooooool00?l04oooool00ol0
003oooooooooo`0Aooooo`03o`00oooooooo003o04kooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`1;ooooo`03ool00?oooooooooo02_ooooo00?oo`00ooooooooool0C_ooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`;o00001Oooool00ol0
003oooooooooo`1;ooooo`03o`00oooooooo003o01?ooooo00?o0000ooooooooool0H_ooool00ol0
003oooooooooo`0Dooooo`00:?ooool2o`0004oooooo00?o003oooooooooool04Oooool00ol0003o
ooooooooo`0Aooooo`03o`00oooooooooooo04gooooo0_l0000Vooooo`03o`000?oooooooooo04_o
oooo00?oo`00ooooooooool0:oooool00ooo003oooooooooo`1>ooooo`03o`000?oooooooooo02_o
oooo00?o0000ooooooooool0Boooool00ol00?ooooooo`00o`0Cooooo`03o`000?oooooooooo01;o
oooo0_l00?m=ooooo`;o00005_ooool002Sooooo00?o0000ooooooooool0C?ooool00ol00?oooooo
o`00o`0Cooooo`03o`000?oooooooooo017ooooo00?o003oooooool00?l0C_ooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo04_ooooo00?oo`00ooooooooool0:oooool00ooo003ooooo
ooooo`1>ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0COooool00ol00?oooooo
ooooo`0Aooooo`03o`000?oooooooooo01;ooooo0_l00?m>ooooo`03o`000?oooooooooo01Cooooo
000Xooooo`03o`000?oooooooooo04cooooo00?o003oooooooooool04oooool00ol0003ooooooooo
o`0Cooooo`03o`00oooooooooooo04cooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`1;ooooo`03ool00?oooooooooo02_ooooo00?oo`00ooooooooool0C_ooool00ol0003ooooooooo
o`0[ooooo`03o`000?oooooooooo04_ooooo00?o003oooooooooool04oooool00ol0003ooooooooo
o`0Booooo`;o003oC_ooool00ol0003oooooooooo`0Dooooo`00:?ooool00ol0003oooooooooo`1<
ooooo`03o`00oooooooo003o01?ooooo00?o0000ooooooooool04Oooool00ol00?ooooooo`00o`1>
ooooo`03o`000?oooooooooo02Cooooo0_l0001<ooooo`03ool00?oooooooooo02_ooooo00?oo`00
ooooooooool0COooool2o`0002gooooo00?o0000ooooooooool0Boooool00ol00?ooooooo`00o`0C
ooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool05?ooool002Sooooo00?o0000oooo
ooooool0C_ooool00ol00?ooooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o003ooooo
ooooool0C_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo04_ooooo00?oo`00oooo
ooooool0:oooool00ooo003oooooooooo`1>ooooo`03o`000?oooooooooo02_ooooo00?o0000oooo
ooooool0C?ooool2o`00oa?ooooo00?o0000ooooooooool04_ooool2o`00odkooooo00?o0000oooo
ooooool05?ooool002Sooooo0_l0001=ooooo`03o`00oooooooo003o01?ooooo00?o0000oooooooo
ool04Oooool00ol00?ooooooo`00o`1=ooooo`;o00009_ooool00ol0003oooooooooo`1;ooooo`03
ool00?oooooooooo02_ooooo00?oo`00ooooooooool0C_ooool00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo04gooooo00?o003oooooooooool04Oooool00ol0003oooooooooo`0Booooo`;o
003oCOooool2o`0001Kooooo000Xooooo`03o`000?oooooooooo04cooooo00?o003oooooooooool0
4oooool00ol0003oooooooooo`0Cooooo`03o`00oooooooooooo04cooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`1;ooooo`03ool00?oooooooooo02_ooooo00?oo`00ooooooooool0
C_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo04cooooo00?o003oooooooooool0
4_ooool00ol0003oooooooooo`0Booooo`;o003oC_ooool00ol0003oooooooooo`0Dooooo`00:?oo
ool00ol0003oooooooooo`1<ooooo`;o003o5?ooool00ol0003oooooooooo`0Aooooo`03o`00oooo
oooo003o04kooooo00?o0000ooooooooool05oooool3o`0000Cooooo0_l00004ooooo`03o`000?oo
oooooooo04_ooooo00?oo`00ooooooooool0:oooool00ooo003oooooooooo`1>ooooo`03o`000?oo
oooooooo02_ooooo00?o0000ooooooooool0C?ooool2o`00oa?ooooo00?o0000ooooooooool0H_oo
ool00ol0003oooooooooo`0Dooooo`00:?ooool00ol0003oooooooooo`1=ooooo`03o`00oooooooo
oooo01;ooooo00?o0000ooooooooool04Oooool00ol00?ooooooooooo`1>ooooo`03o`000?oooooo
oooo01Kooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo
00?o0000ooooooooool0Boooool00ooo003oooooooooo`0[ooooo`03ool00?oooooooooo04kooooo
00?o0000ooooooooool0:oooool00ol0003oooooooooo`1<ooooo`;o003o4oooool00ol0003ooooo
ooooo`0Booooo`;o003oC_ooool00ol0003oooooooooo`0Dooooo`00:?ooool00ol0003ooooooooo
o`1<ooooo`;o003o5?ooool00ol0003oooooooooo`0Aooooo`03o`00oooooooo003o04kooooo00?o
0000ooooooooool05_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo
00000oooool00ol0003oooooooooo`1;ooooo`03ool00?oooooooooo02_ooooo00?oo`00oooooooo
ool0C_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo04gooooo00?o003ooooooooo
ool04Oooool00ol0003oooooooooo`0Booooo`;o003oC_ooool00ol0003oooooooooo`0Dooooo`00
:?ooool2o`0004gooooo00?o003oooooooooool04oooool00ol0003oooooooooo`0Cooooo`03o`00
oooooooooooo04_ooooo0_l0000Iooooo`?o00000oooool01?l0003oooooooooool00003ooooo`?o
0000Boooool00ooo003oooooooooo`0[ooooo`03ool00?oooooooooo04gooooo0_l0000]ooooo`03
o`000?oooooooooo04cooooo00?o003oooooooooool04_ooool00ol0003oooooooooo`0Booooo`;o
003oCOooool2o`0001Kooooo000Xooooo`03o`000?oooooooooo04cooooo0_l00?lDooooo`03o`00
0?oooooooooo017ooooo0_l00?m?ooooo`03o`000?oooooooooo01Kooooo00Go0000oooooooooooo
ooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0Boooool00ooo
003oooooooooo`0[ooooo`03ool00?oooooooooo04kooooo00?o0000ooooooooool0:oooool00ol0
003oooooooooo`1<ooooo`;o003o4oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo
01Cooooo000Eooooo`?o00000_ooool5o`0000?ooooo0_l00004ooooo`03o`000?oooooooooo04go
oooo00?o003oooooooooool04_ooool00ol0003oooooooooo`0Aooooo`03o`00oooooooooooo04ko
oooo00?o0000ooooooooool05_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooo
oooooooo00000oooool00ol0003oooooooooo`1;ooooo`03ool00?oooooooooo02_ooooo00?oo`00
ooooooooool0C_ooool00ol0003oooooooooo`0Gooooo`?o00000_ooool5o`0000?ooooo0_l00005
ooooo`03o`000?oooooooooo04cooooo0_l00?lCooooo`03o`000?oooooooooo01;ooooo0_l00?m>
ooooo`03o`000?oooooooooo01Cooooo000Fooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo04cooooo0_l0
0?lDooooo`03o`000?oooooooooo017ooooo0_l00?m?ooooo`03o`000?oooooooooo01Oooooo0ol0
0004ooooo`;o00001?ooool00ol0003oooooooooo`1;ooooo`03ool00?oooooooooo02_ooooo00?o
o`00ooooooooool0C_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo04go
oooo00?o003oooooooooool04Oooool00ol0003oooooooooo`0Booooo`;o003oC_ooool00ol0003o
ooooooooo`0Dooooo`005_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00000oooool00ol0003oooooooooo`1<ooooo`03o`00oooooooooooo01?o
oooo00?o0000ooooooooool04_ooool00ol00?ooooooooooo`1=ooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool0Boooool00ooo003oooooooooo`0[ooooo`03ool00?oooooooooo04ko
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1<ooooo`03o`00oooooooooooo
01;ooooo00?o0000ooooooooool04_ooool2o`00odkooooo00?o0000ooooooooool05?ooool001Ko
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooo
oooooooooooo0_l0001=ooooo`;o003o5?ooool00ol0003oooooooooo`0Booooo`03o`00oooooooo
oooo04_ooooo0ol0000Vooooo`03o`000?oooooooooo04_ooooo00?oo`00ooooooooool0:oooool0
0ooo003oooooooooo`1>ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01?ooool0
1Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool00_ooool2o`0004gooooo0_l0
0?lCooooo`03o`000?oooooooooo067ooooo0_l0000Fooooo`005_ooool01Ol0003ooooooooooooo
oooo000000?ooooo00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo000004oo
oooo00?o003oooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`00oooooooooooo04go
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1;ooooo`03ool00?oooooooooo02_o
oooo00?oo`00ooooooooool0C_ooool00ol0003oooooooooo`0Hooooo`05o`000?oooooooooooooo
ool000000oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0C?ooool2o`00oa?ooooo00?o0000ooooooooool04_ooool2o`00odkooooo00?o0000
ooooooooool05?ooool001Gooooo0_l00003ooooo`05o`000?ooooooooooooooool000000_ooool0
1?l0003oooooooooool00003ooooo`03o`000?oooooooooo04gooooo00?o003oooooooooool04_oo
ool00ol0003oooooooooo`0Booooo`03o`00oooooooooooo04gooooo00?o0000ooooooooool09?oo
ool2o`0004_ooooo0ooo000[ooooo`?oo`00C_ooool2o`0001Wooooo0_l00003ooooo`05o`000?oo
ooooooooooooool000000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo04co
oooo0_l00?lCooooo`03o`000?oooooooooo01;ooooo0_l00?m>ooooo`03o`000?oooooooooo01Co
oooo000Fooooo`03o`000?oooooooooo00;ooooo0ol00004ooooo`;o00001?ooool00ol0003ooooo
ooooo`1Rooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`1:ooooo`?oo`00:oooool3ool004oooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`02ooooo`?o00001?ooool2o`0000Gooooo00?o0000ooooooooool0HOooool00ol0003ooooo
ooooo`1Rooooo`03o`000?oooooooooo01Cooooo000Xooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`1:ooooo`?oo`00:oooool3ool004oooooo00?o
0000ooooooooool0:oooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Cooooo000Xoooool_o00009_oo
ool00ol0003oooooo`000009ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0[oooool[o00005_ooool00?oooooo6_ooooo>o`000?oooooo3_ooool0
0?ooooooooooooofooooo`00ooooooooooooooKooooo003ooooooooooooom_ooool00001\
\>"],
  ImageRangeCache->{{{0, 755}, {145, 0}} -> {-0.0839304, -0.0144882, \
0.00419585, 0.00419585}, {{20, 243.438}, {141.5, 3.4375}} -> {-14.7187, \
-18.564, 0.104106, 1.02316}, {{265.75, 489.188}, {141.5, 3.4375}} -> \
{-38.5921, -12.8928, 0.100886, 0.713447}, {{511.562, 734.938}, {141.5, \
3.4375}} -> {-65.9107, -19.5175, 0.104139, 1.03022}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .19314 
%%ImageSize: 756 146.011 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.00459847 0.31746 [
[ 0 0 0 0 ]
[ 1 .19314 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .19314 L
0 .19314 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00459847 0.321429 0.188537 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.047619 0.0140438 0.00908109 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01404 -6 -4.5 ]
[-0.0125 .01404 0 4.5 ]
[-0.0125 .10485 -12 -4.5 ]
[-0.0125 .10485 0 4.5 ]
[-0.0125 .19567 -12 -4.5 ]
[-0.0125 .19567 0 4.5 ]
[-0.0125 .28648 -12 -4.5 ]
[-0.0125 .28648 0 4.5 ]
[-0.0125 .37729 -12 -4.5 ]
[-0.0125 .37729 0 4.5 ]
[-0.0125 .4681 -12 -4.5 ]
[-0.0125 .4681 0 4.5 ]
[-0.0125 .55891 -12 -4.5 ]
[-0.0125 .55891 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01404 m
.00625 .01404 L
s
[(0)] -0.0125 .01404 1 0 Mshowa
0 .10485 m
.00625 .10485 L
s
[(10)] -0.0125 .10485 1 0 Mshowa
0 .19567 m
.00625 .19567 L
s
[(20)] -0.0125 .19567 1 0 Mshowa
0 .28648 m
.00625 .28648 L
s
[(30)] -0.0125 .28648 1 0 Mshowa
0 .37729 m
.00625 .37729 L
s
[(40)] -0.0125 .37729 1 0 Mshowa
0 .4681 m
.00625 .4681 L
s
[(50)] -0.0125 .4681 1 0 Mshowa
0 .55891 m
.00625 .55891 L
s
[(60)] -0.0125 .55891 1 0 Mshowa
.125 Mabswid
0 .03221 m
.00375 .03221 L
s
0 .05037 m
.00375 .05037 L
s
0 .06853 m
.00375 .06853 L
s
0 .08669 m
.00375 .08669 L
s
0 .12302 m
.00375 .12302 L
s
0 .14118 m
.00375 .14118 L
s
0 .15934 m
.00375 .15934 L
s
0 .1775 m
.00375 .1775 L
s
0 .21383 m
.00375 .21383 L
s
0 .23199 m
.00375 .23199 L
s
0 .25015 m
.00375 .25015 L
s
0 .26831 m
.00375 .26831 L
s
0 .30464 m
.00375 .30464 L
s
0 .3228 m
.00375 .3228 L
s
0 .34096 m
.00375 .34096 L
s
0 .35913 m
.00375 .35913 L
s
0 .39545 m
.00375 .39545 L
s
0 .41361 m
.00375 .41361 L
s
0 .43177 m
.00375 .43177 L
s
0 .44994 m
.00375 .44994 L
s
0 .48626 m
.00375 .48626 L
s
0 .50442 m
.00375 .50442 L
s
0 .52258 m
.00375 .52258 L
s
0 .54075 m
.00375 .54075 L
s
0 .57707 m
.00375 .57707 L
s
0 .59523 m
.00375 .59523 L
s
0 .6134 m
.00375 .6134 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01404 m
1 .01404 L
s
.99375 .10485 m
1 .10485 L
s
.99375 .19567 m
1 .19567 L
s
.99375 .28648 m
1 .28648 L
s
.99375 .37729 m
1 .37729 L
s
.99375 .4681 m
1 .4681 L
s
.99375 .55891 m
1 .55891 L
s
.125 Mabswid
.99625 .03221 m
1 .03221 L
s
.99625 .05037 m
1 .05037 L
s
.99625 .06853 m
1 .06853 L
s
.99625 .08669 m
1 .08669 L
s
.99625 .12302 m
1 .12302 L
s
.99625 .14118 m
1 .14118 L
s
.99625 .15934 m
1 .15934 L
s
.99625 .1775 m
1 .1775 L
s
.99625 .21383 m
1 .21383 L
s
.99625 .23199 m
1 .23199 L
s
.99625 .25015 m
1 .25015 L
s
.99625 .26831 m
1 .26831 L
s
.99625 .30464 m
1 .30464 L
s
.99625 .3228 m
1 .3228 L
s
.99625 .34096 m
1 .34096 L
s
.99625 .35913 m
1 .35913 L
s
.99625 .39545 m
1 .39545 L
s
.99625 .41361 m
1 .41361 L
s
.99625 .43177 m
1 .43177 L
s
.99625 .44994 m
1 .44994 L
s
.99625 .48626 m
1 .48626 L
s
.99625 .50442 m
1 .50442 L
s
.99625 .52258 m
1 .52258 L
s
.99625 .54075 m
1 .54075 L
s
.99625 .57707 m
1 .57707 L
s
.99625 .59523 m
1 .59523 L
s
.99625 .6134 m
1 .6134 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
0 0 1 r
.5 Mabswid
[ .01 ] 0 setdash
.02381 .0184 m
.02395 .0184 L
.02408 .0184 L
.02423 .01839 L
.02437 .01838 L
.02462 .01835 L
.02489 .01831 L
.02519 .01825 L
.02551 .01817 L
.02608 .01798 L
.02722 .01748 L
.02847 .01674 L
.02973 .01586 L
.03043 .01537 L
.03077 .01514 L
.03109 .01496 L
.03125 .01489 L
.03139 .01483 L
.03147 .01481 L
.03156 .01479 L
.03171 .01477 L
.03179 .01477 L
.03188 .01478 L
.03197 .01479 L
.03206 .01482 L
.03221 .01487 L
.03238 .01495 L
.03299 .01532 L
.03355 .01571 L
.03476 .01657 L
.03605 .01736 L
.03714 .01788 L
.03777 .01811 L
.03805 .01819 L
.03836 .01826 L
.03863 .01832 L
.03892 .01836 L
.03908 .01838 L
.03923 .01839 L
.03938 .0184 L
.03952 .01841 L
.03965 .01841 L
.03978 .01841 L
.0399 .01841 L
.04003 .0184 L
.04017 .01839 L
.04031 .01838 L
.04058 .01834 L
.04089 .01829 L
.04122 .01822 L
Mistroke
.04183 .01803 L
.04243 .0178 L
.04298 .01755 L
.04525 .01613 L
.04644 .01528 L
.04673 .01509 L
.04705 .01492 L
.04722 .01485 L
.04731 .01482 L
.04739 .0148 L
.04746 .01479 L
.04755 .01478 L
.0477 .01478 L
.04778 .01478 L
.04786 .0148 L
.04802 .01484 L
.04819 .01492 L
.04836 .015 L
.04905 .01545 L
.05029 .01634 L
.05155 .01716 L
.05217 .0175 L
.05273 .01777 L
.05326 .01799 L
.05383 .01818 L
.05415 .01826 L
.05444 .01832 L
.05472 .01837 L
.05487 .01839 L
.05501 .0184 L
.05517 .01842 L
.05531 .01842 L
.05546 .01843 L
.05555 .01843 L
.05563 .01843 L
.05576 .01843 L
.05591 .01842 L
.05606 .01841 L
.0562 .0184 L
.05653 .01835 L
.05683 .0183 L
.05716 .01822 L
.05751 .01812 L
.05866 .01766 L
.05989 .01698 L
.0621 .01544 L
.0627 .01505 L
.063 .01489 L
.06309 .01486 L
.06318 .01483 L
Mistroke
.06326 .01481 L
.06334 .01479 L
.06342 .01478 L
.06351 .01478 L
.0636 .01478 L
.06369 .01479 L
.06378 .01482 L
.06387 .01484 L
.06403 .01491 L
.06434 .01507 L
.06467 .01528 L
.06583 .01611 L
.0671 .01698 L
.06827 .01764 L
.0689 .01793 L
.06951 .01815 L
.06984 .01825 L
.0702 .01833 L
.07052 .01839 L
.07068 .01841 L
.07082 .01843 L
.07096 .01844 L
.07111 .01846 L
.07119 .01846 L
.07127 .01846 L
.07142 .01847 L
.07158 .01846 L
.07172 .01846 L
.0718 .01846 L
.07188 .01845 L
.07205 .01844 L
.0722 .01842 L
.07233 .0184 L
.07264 .01835 L
.07294 .01828 L
.07326 .0182 L
.07437 .01777 L
.07504 .01743 L
.07568 .01706 L
.07688 .01625 L
.07804 .01541 L
.07837 .01518 L
.07868 .015 L
.07882 .01493 L
.07897 .01486 L
.07912 .01481 L
.07927 .01479 L
.07941 .01478 L
.07954 .01479 L
.07968 .01483 L
Mistroke
.07982 .01487 L
.08006 .01499 L
.08033 .01515 L
.08149 .01597 L
.08262 .01677 L
.08383 .01752 L
.08453 .01786 L
.08517 .01812 L
.08547 .01822 L
.08581 .01832 L
.0861 .01839 L
.08642 .01844 L
.08658 .01847 L
.08674 .01848 L
.08689 .0185 L
.08704 .01851 L
.08718 .01851 L
.08731 .01852 L
.08745 .01851 L
.08761 .01851 L
.08769 .0185 L
.08777 .0185 L
.08795 .01848 L
.08811 .01847 L
.08827 .01844 L
.08856 .01839 L
.08888 .01832 L
.08944 .01814 L
.09006 .0179 L
.09116 .01733 L
.09353 .01571 L
.09418 .01524 L
.09454 .01502 L
.09471 .01493 L
.09487 .01486 L
.09503 .01482 L
.0951 .0148 L
.09519 .01479 L
.09527 .01479 L
.09536 .0148 L
.09545 .01481 L
.09553 .01483 L
.09567 .01488 L
.09583 .01495 L
.09612 .01511 L
.09863 .0169 L
.09972 .01757 L
.1009 .01812 L
.10154 .01834 L
.10182 .01841 L
Mistroke
.10212 .01848 L
.10241 .01852 L
.10255 .01854 L
.10268 .01856 L
.10283 .01857 L
.10297 .01858 L
.10312 .01858 L
.10328 .01858 L
.10343 .01858 L
.10358 .01857 L
.10366 .01856 L
.10374 .01856 L
.10391 .01854 L
.10424 .01849 L
.10459 .01842 L
.10517 .01826 L
.10581 .01802 L
.10705 .01738 L
.10817 .01664 L
.10949 .01567 L
.11007 .01525 L
.11037 .01506 L
.11054 .01496 L
.1107 .01489 L
.11085 .01484 L
.11101 .01481 L
.11115 .0148 L
.11128 .01481 L
.11141 .01484 L
.11155 .01489 L
.11169 .01495 L
.11183 .01502 L
.11302 .01586 L
.11424 .01677 L
.11553 .01759 L
.11669 .01816 L
.11735 .0184 L
.11766 .01848 L
.11796 .01855 L
.11823 .0186 L
.11837 .01862 L
.11852 .01863 L
.11865 .01865 L
.11879 .01866 L
.11892 .01866 L
.11904 .01866 L
.11919 .01866 L
.11933 .01866 L
.11945 .01865 L
.11959 .01864 L
Mistroke
.11974 .01863 L
.1199 .01861 L
.12019 .01856 L
.1205 .01849 L
.12084 .0184 L
.12143 .0182 L
.12207 .01791 L
.12277 .01753 L
.12405 .0167 L
.12521 .01582 L
.12578 .01539 L
.12609 .01518 L
.12641 .01498 L
.12655 .01492 L
.1267 .01486 L
.12678 .01484 L
.12686 .01482 L
.12701 .01481 L
.12714 .01482 L
.12728 .01485 L
.12742 .0149 L
.12756 .01496 L
.1282 .01537 L
.12878 .0158 L
.13008 .01679 L
.13121 .01755 L
.1324 .01818 L
.13302 .01842 L
.13335 .01853 L
.1337 .01862 L
.13403 .01868 L
.13432 .01873 L
.13447 .01874 L
.13462 .01875 L
.13477 .01876 L
.1349 .01876 L
.13506 .01876 L
.13514 .01876 L
.13522 .01876 L
.13538 .01875 L
.13552 .01874 L
.13569 .01872 L
.13584 .0187 L
.13618 .01864 L
.13648 .01857 L
.1368 .01847 L
.13739 .01826 L
.13855 .01767 L
.13963 .01697 L
.14072 .01615 L
Mistroke
.14189 .01526 L
.14223 .01504 L
.1424 .01495 L
.14256 .01489 L
.1427 .01485 L
.14285 .01483 L
.14294 .01483 L
.14302 .01484 L
.14317 .01487 L
.14332 .01492 L
.14347 .015 L
.14375 .01516 L
.14437 .01562 L
.1456 .01659 L
.14677 .01743 L
.1479 .0181 L
.1484 .01834 L
.14895 .01855 L
.1495 .01871 L
.1498 .01878 L
.15008 .01883 L
.15023 .01885 L
.15038 .01886 L
.15052 .01888 L
.15067 .01888 L
.15082 .01889 L
.15091 .01889 L
.15099 .01889 L
.15115 .01888 L
.1513 .01887 L
.15145 .01886 L
.15161 .01884 L
.15193 .01878 L
.15223 .01872 L
.15251 .01864 L
.15314 .01842 L
.15382 .01811 L
.1562 .01652 L
.15746 .01552 L
.15782 .01525 L
.158 .01513 L
.15816 .01503 L
.15831 .01496 L
.15847 .01489 L
.15855 .01487 L
.15863 .01486 L
.15871 .01485 L
.1588 .01485 L
.15888 .01485 L
.15896 .01487 L
Mistroke
.15912 .01491 L
.1592 .01495 L
.15928 .01499 L
.15947 .01509 L
.1601 .01554 L
.16128 .01651 L
.16239 .01735 L
.16359 .01812 L
.16416 .01841 L
.16478 .01867 L
.16512 .01878 L
.16542 .01886 L
.16573 .01893 L
.16587 .01896 L
.16603 .01898 L
.16616 .019 L
.1663 .01901 L
.16645 .01902 L
.16658 .01903 L
.16672 .01903 L
.16685 .01903 L
.16697 .01903 L
.1671 .01902 L
.16725 .01901 L
.16739 .01899 L
.1677 .01895 L
.16799 .01889 L
.16826 .01882 L
.16882 .01863 L
.16944 .01836 L
.17069 .01764 L
.17292 .0159 L
.17355 .01539 L
.17387 .01517 L
.174 .01508 L
.17415 .015 L
.17429 .01494 L
.17442 .0149 L
.17455 .01487 L
.17469 .01487 L
.17485 .01489 L
.175 .01494 L
.17513 .015 L
.17528 .01508 L
.17659 .0161 L
.1778 .01711 L
.17908 .01802 L
.1797 .01838 L
.18028 .01867 L
.18079 .01887 L
Mistroke
.18136 .01904 L
.18165 .01911 L
.18192 .01915 L
.18207 .01917 L
.18221 .01919 L
.18237 .0192 L
.18252 .0192 L
.18266 .0192 L
.18281 .0192 L
.18295 .01919 L
.18307 .01918 L
.18322 .01917 L
.18337 .01915 L
.18369 .0191 L
.184 .01902 L
.18433 .01893 L
.18492 .0187 L
.18609 .01808 L
.18714 .01734 L
.18827 .01642 L
.18946 .01541 L
.18976 .01519 L
.18992 .01509 L
.19008 .015 L
.19017 .01496 L
.19026 .01493 L
.19035 .01491 L
.19043 .01489 L
.19052 .01489 L
.19059 .01489 L
.19068 .01491 L
.19076 .01493 L
.19091 .01498 L
.19106 .01506 L
.19134 .01524 L
.19197 .01574 L
.1932 .01682 L
.19437 .01775 L
.1955 .0185 L
.196 .01877 L
.19655 .01901 L
.1971 .0192 L
.1974 .01928 L
.19768 .01933 L
.19783 .01936 L
.19799 .01938 L
.19812 .01939 L
.19827 .0194 L
.19835 .0194 L
.19843 .0194 L
Mistroke
.19852 .01941 L
.1986 .0194 L
.19875 .0194 L
.19891 .01939 L
.19906 .01938 L
.19921 .01936 L
.19955 .0193 L
.19987 .01922 L
.20022 .01911 L
.20085 .01886 L
.20143 .01856 L
.20262 .01778 L
.20373 .01688 L
.20502 .01573 L
.20533 .01547 L
.20565 .01522 L
.20593 .01505 L
.20609 .01498 L
.20623 .01493 L
.20637 .01492 L
.20651 .01493 L
.20663 .01495 L
.20675 .015 L
.2069 .01507 L
.20705 .01516 L
.20731 .01536 L
.20848 .01639 L
.20968 .01746 L
.21096 .01843 L
.2116 .01882 L
.21219 .01913 L
.21273 .01935 L
.21304 .01944 L
.21332 .01952 L
.21361 .01957 L
.21374 .01959 L
.21388 .01961 L
.21402 .01963 L
.21416 .01964 L
.21431 .01964 L
.21439 .01964 L
.21447 .01964 L
.2146 .01964 L
.21473 .01963 L
.21485 .01962 L
.21498 .01961 L
.21526 .01957 L
.21553 .01951 L
.21609 .01935 L
.21669 .0191 L
Mistroke
.21778 .01847 L
.21908 .01748 L
.22027 .0164 L
.22084 .01586 L
.22115 .01558 L
.22145 .01533 L
.22173 .01514 L
.22188 .01505 L
.22203 .01499 L
.22215 .01496 L
.22228 .01495 L
.22242 .01496 L
.22255 .015 L
.2227 .01507 L
.22287 .01517 L
.22318 .0154 L
.22375 .01592 L
.22505 .01716 L
.22627 .01822 L
.22743 .01903 L
.22806 .01938 L
.2284 .01953 L
.22875 .01966 L
.22905 .01975 L
.22938 .01983 L
.22952 .01986 L
.22968 .01988 L
.22982 .0199 L
.22996 .01991 L
.2301 .01992 L
.23023 .01992 L
.23038 .01992 L
.23054 .01992 L
.23062 .01991 L
.2307 .01991 L
.23086 .01989 L
.23101 .01987 L
.23116 .01984 L
.23144 .01978 L
.23169 .01971 L
.23226 .01949 L
.23288 .01919 L
.23355 .01877 L
.23477 .01782 L
.23601 .01665 L
.23717 .01552 L
.23747 .01528 L
.23762 .01517 L
.23776 .01509 L
.23791 .01503 L
Mistroke
.238 .015 L
.23809 .01499 L
.23823 .01499 L
.23838 .01503 L
.23847 .01506 L
.23856 .0151 L
.23871 .0152 L
.23907 .01548 L
.23971 .0161 L
.24095 .01735 L
.24212 .01842 L
.24326 .01927 L
.24376 .01957 L
.24431 .01984 L
.24486 .02005 L
.24516 .02013 L
.24544 .02019 L
.2456 .02021 L
.24575 .02023 L
.24589 .02024 L
.24603 .02025 L
.24612 .02025 L
.24619 .02026 L
.24628 .02025 L
.24636 .02025 L
.24651 .02024 L
.24667 .02023 L
.24683 .02021 L
.24698 .02018 L
.24731 .02011 L
.24764 .02001 L
.24799 .01987 L
.24862 .01956 L
.2492 .01921 L
.2517 .017 L
.2528 .01585 L
.2531 .01556 L
.25342 .01529 L
.25357 .01518 L
.25373 .0151 L
.25386 .01505 L
.25401 .01503 L
.25416 .01504 L
.2543 .01509 L
.25443 .01515 L
.25457 .01524 L
.25517 .01577 L
.25625 .01693 L
.25748 .01821 L
.25863 .01923 L
Mistroke
.25978 .02 L
.26038 .02029 L
.26072 .02042 L
.26103 .02051 L
.26119 .02055 L
.26136 .02058 L
.2615 .02061 L
.26166 .02063 L
.26174 .02063 L
.26182 .02064 L
.26198 .02065 L
.26206 .02065 L
.26215 .02065 L
.26225 .02064 L
.26234 .02064 L
.26241 .02063 L
.2625 .02062 L
.26265 .02061 L
.2628 .02058 L
.26293 .02055 L
.26324 .02047 L
.26357 .02036 L
.26417 .0201 L
.26471 .01979 L
.26593 .01885 L
.26814 .01656 L
.26871 .01592 L
.26903 .0156 L
.26932 .01533 L
.26946 .01524 L
.2696 .01515 L
.26976 .0151 L
.2699 .01508 L
.27003 .01509 L
.27015 .01513 L
.27028 .0152 L
.27043 .01529 L
.27075 .01557 L
.2711 .01594 L
.27173 .01666 L
.27293 .01803 L
.27416 .01927 L
.27531 .02019 L
.27589 .02054 L
.27652 .02083 L
.27685 .02095 L
.27704 .021 L
.27721 .02103 L
.27737 .02106 L
.27751 .02108 L
Mistroke
.27759 .02109 L
.27767 .0211 L
.27776 .0211 L
.27784 .02111 L
.27799 .02111 L
.27813 .02111 L
.27829 .0211 L
.27843 .02108 L
.27857 .02106 L
.2787 .02104 L
.27899 .02097 L
.27931 .02087 L
.27959 .02075 L
.28024 .02042 L
.28087 .01999 L
.28155 .01943 L
.28278 .01819 L
.28403 .01672 L
.28464 .016 L
.2849 .0157 L
.28519 .01542 L
.28535 .0153 L
.28549 .01521 L
.28563 .01516 L
.28577 .01513 L
.28593 .01515 L
.28607 .01521 L
.28623 .01531 L
.2864 .01545 L
.28773 .017 L
.29011 .01973 L
.29076 .02032 L
.29145 .02084 L
.29211 .02122 L
.29239 .02135 L
.2927 .02146 L
.293 .02155 L
.29316 .02158 L
.29332 .02161 L
.29346 .02163 L
.29359 .02164 L
.29374 .02165 L
.29388 .02165 L
.29404 .02165 L
.29411 .02164 L
.2942 .02163 L
.29435 .02161 L
.2945 .02159 L
.29482 .02151 L
.29516 .0214 L
Mistroke
.29575 .02112 L
.29637 .02073 L
.29749 .01979 L
.29872 .01842 L
.29989 .01694 L
.3004 .01628 L
.30094 .01564 L
.30122 .01538 L
.3013 .01532 L
.30138 .01527 L
.30153 .01522 L
.30168 .0152 L
.30182 .01523 L
.30194 .01528 L
.30208 .01537 L
.30239 .01567 L
.30267 .01599 L
.3033 .01682 L
.30444 .01835 L
.30576 .01994 L
.30633 .02054 L
.30697 .0211 L
.30751 .02151 L
.3081 .02185 L
.30842 .02199 L
.30871 .0221 L
.30885 .02214 L
.30901 .02217 L
.30914 .0222 L
.30929 .02222 L
.30944 .02224 L
.30959 .02225 L
.30967 .02225 L
.30976 .02225 L
.30992 .02225 L
.31 .02224 L
.31009 .02223 L
.31024 .02221 L
.31043 .02217 L
.31059 .02213 L
.31089 .02203 L
.31121 .0219 L
.3118 .02157 L
.31239 .02114 L
.31294 .02065 L
.3142 .01926 L
.3155 .01752 L
.31614 .01662 L
.31646 .01619 L
.31674 .01584 L
Mistroke
.31701 .01554 L
.31717 .01542 L
.31731 .01533 L
.31746 .01528 L
.31753 .01528 L
.31762 .01529 L
.31777 .01534 L
.31791 .01544 L
.31808 .01558 L
.31823 .01575 L
.31853 .01612 L
.31919 .01705 L
.32142 .02014 L
.32259 .02139 L
.32318 .02189 L
.32383 .02232 L
.32438 .02258 L
.3247 .02269 L
.32484 .02273 L
.32498 .02275 L
.32511 .02278 L
.32524 .02279 L
.32539 .0228 L
.32553 .02281 L
.32566 .0228 L
.3258 .0228 L
.32593 .02278 L
.32606 .02276 L
.32621 .02273 L
.32635 .0227 L
.32662 .02261 L
.32691 .02249 L
.32723 .02233 L
.3278 .02195 L
.32832 .02152 L
.32953 .02024 L
.33082 .01852 L
.33195 .01685 L
.33254 .01602 L
.33284 .01568 L
.33292 .0156 L
.33301 .01552 L
.33316 .01543 L
.33331 .01538 L
.3334 .01537 L
.33347 .01538 L
.33362 .01544 L
.33377 .01553 L
.3339 .01565 L
.33403 .01579 L
Mistroke
.33431 .01614 L
.33537 .01767 L
.33761 .0207 L
.33822 .02134 L
.33887 .0219 L
.33949 .02231 L
.33976 .02245 L
.34005 .02257 L
.34021 .02263 L
.34038 .02268 L
.34054 .02272 L
.34068 .02274 L
.34077 .02276 L
.34085 .02277 L
.34094 .02277 L
.34103 .02278 L
.34112 .02278 L
.34121 .02278 L
.34136 .02277 L
.34151 .02276 L
.34167 .02273 L
.34182 .0227 L
.34195 .02267 L
.34227 .02256 L
.3426 .02241 L
.3432 .02205 L
.34376 .02162 L
.34503 .02033 L
.34729 .01731 L
.34791 .01647 L
.34825 .01606 L
.34841 .01589 L
.34857 .01575 L
.34869 .01565 L
.34884 .01556 L
.34898 .0155 L
.34913 .01548 L
.34928 .0155 L
.34936 .01552 L
.34944 .01555 L
.3496 .01564 L
.34974 .01575 L
.35039 .01639 L
.35098 .01707 L
.35232 .01848 L
.35293 .01899 L
.3535 .01937 L
.35381 .01954 L
.3541 .01967 L
.35441 .01978 L
Mistroke
.35459 .01982 L
.35475 .01986 L
.35489 .01988 L
.35504 .0199 L
.35518 .0199 L
.35531 .01991 L
.35546 .0199 L
.35554 .0199 L
.35562 .01989 L
.35577 .01987 L
.35592 .01985 L
.35608 .01981 L
.35625 .01976 L
.35657 .01965 L
.35716 .01937 L
.35772 .01902 L
.35832 .01858 L
.35938 .01767 L
.36062 .01657 L
.36178 .0157 L
.36283 .01512 L
.36311 .01498 L
.36342 .01485 L
.36354 .0148 L
.36368 .01476 L
.36383 .01473 L
.36397 .01472 L
.36411 .01473 L
.36425 .01477 L
.3644 .01485 L
.36449 .01491 L
.36456 .01498 L
.36489 .01534 L
.36519 .0158 L
.36573 .01686 L
.36632 .0184 L
.36696 .02056 L
.36763 .02347 L
.36884 .03048 L
.36998 .03944 L
.3712 .0519 L
.37341 .08254 L
.37597 .13158 L
.37839 .19082 L
.38301 .32722 L
.38791 .47435 L
.39019 .53009 L
.39138 .55406 L
.39264 .57461 L
.39329 .58309 L
Mistroke
.39399 .59073 L
.39463 .59614 L
.39523 .59983 L
.39555 .60125 L
.3957 .60181 L
.39585 .60226 L
.39597 .60258 L
.39611 .60288 L
.39626 .6031 L
.39641 .60325 L
.39649 .6033 L
.39657 .60332 L
.39672 .60329 L
.3968 .60325 L
.39688 .60318 L
.39696 .60308 L
.39706 .60294 L
.39722 .60262 L
.39737 .60222 L
.39766 .60125 L
.39795 .59997 L
.39822 .5985 L
.39884 .59418 L
.39944 .5887 L
.40008 .58148 L
.40231 .54641 L
.40487 .48987 L
.4073 .42483 L
.41192 .28737 L
.41683 .14624 L
.41927 .08355 L
.42047 .0549 L
.42099 .0428 L
.42157 .02993 L
.42183 .02419 L
.42198 .02121 L
.42212 .01877 L
.42225 .01755 L
.42239 .01845 L
.42251 .02053 L
.42263 .02279 L
.42375 .04607 L
.42612 .09317 L
.43086 .17808 L
.43543 .24612 L
.43778 .27355 L
.43908 .28592 L
.44029 .29522 L
.44151 .30229 L
.44216 .30504 L
Mistroke
.44249 .30618 L
.44285 .30719 L
.44319 .30796 L
.44334 .30823 L
.4435 .30848 L
.44365 .30867 L
.4438 .30882 L
.44389 .30889 L
.44396 .30894 L
.44412 .309 L
.44426 .30903 L
.4444 .30901 L
.44455 .30896 L
.44471 .30886 L
.44485 .30874 L
.44498 .3086 L
.44527 .30816 L
.44556 .30756 L
.44584 .30687 L
.44646 .30481 L
.44706 .30215 L
.44771 .29862 L
.44888 .29046 L
.44994 .2812 L
.45476 .22177 L
.45941 .15204 L
.46176 .11826 L
.46435 .08551 L
.46683 .05988 L
.4691 .04232 L
.46968 .03889 L
.47031 .03574 L
.47059 .03453 L
.4709 .03342 L
.47119 .03257 L
.47145 .03196 L
.47161 .03167 L
.47178 .03144 L
.47187 .03135 L
.47195 .03129 L
.47204 .03124 L
.47213 .03121 L
.47221 .0312 L
.4723 .03121 L
.47239 .03124 L
.47247 .03129 L
.47262 .03142 L
.47277 .03162 L
.47292 .03186 L
.47307 .03216 L
Mistroke
.47334 .03285 L
.47397 .03499 L
.4746 .03784 L
.47519 .041 L
.47652 .04971 L
.47894 .07056 L
.48142 .09824 L
.48366 .1283 L
.48849 .20217 L
.49314 .26823 L
.49555 .29315 L
.49676 .30216 L
.49745 .30609 L
.49809 .30895 L
.49869 .3109 L
.49903 .31168 L
.49919 .31197 L
.49935 .3122 L
.49949 .31237 L
.49962 .31249 L
.49977 .31258 L
.49993 .31262 L
.50007 .31263 L
.50023 .31258 L
.50031 .31254 L
.50039 .31248 L
.50054 .31233 L
.50069 .31215 L
.50083 .31193 L
.50114 .31131 L
.50142 .31059 L
.50171 .30967 L
.50278 .3049 L
.50337 .3013 L
.50392 .29745 L
.50514 .28692 L
.50735 .26217 L
.51214 .19223 L
.51676 .1224 L
.51933 .08922 L
.52166 .06476 L
.52283 .05466 L
.5241 .04541 L
.52529 .03837 L
.52587 .03567 L
.52639 .03367 L
.52666 .03284 L
.52696 .03211 L
.52712 .03179 L
.52727 .03156 L
Mistroke
.52741 .03139 L
.52757 .03127 L
.5277 .03121 L
.52784 .0312 L
.52797 .03124 L
.52809 .03132 L
.52822 .03145 L
.52837 .03164 L
.52852 .03191 L
.52866 .0322 L
.52899 .03307 L
.5293 .03411 L
.52987 .03656 L
.53116 .04401 L
.53358 .06365 L
.5358 .08724 L
.54056 .15157 L
.54514 .22034 L
.54768 .25492 L
.55001 .28069 L
.55116 .29075 L
.55177 .29523 L
.55241 .29933 L
.55298 .30234 L
.5536 .30502 L
.55387 .30598 L
.55416 .30687 L
.55444 .30757 L
.5547 .30809 L
.55498 .30855 L
.55514 .30873 L
.55529 .30887 L
.55543 .30895 L
.55556 .309 L
.5557 .30903 L
.55585 .30901 L
.556 .30896 L
.55608 .30891 L
.55616 .30885 L
.55631 .30872 L
.55645 .30855 L
.55676 .30805 L
.55711 .3073 L
.55775 .30538 L
.55843 .30256 L
.55965 .29557 L
.56089 .28611 L
.56224 .27342 L
.56467 .24479 L
.56962 .17003 L
Mistroke
.57208 .12687 L
.57438 .08352 L
.57659 .03884 L
.5769 .03247 L
.57723 .02558 L
.57738 .02251 L
.57747 .0209 L
.57754 .01951 L
.57768 .01773 L
.57783 .01813 L
.57797 .02029 L
.57812 .02315 L
.57838 .02869 L
.57896 .0418 L
.58356 .15689 L
.58846 .29859 L
.59317 .43789 L
.59557 .50064 L
.59684 .52926 L
.59817 .55529 L
.59937 .57427 L
.6 .58254 L
.60068 .58995 L
.60131 .59535 L
.60188 .5991 L
.60215 .60048 L
.60245 .60168 L
.60259 .60212 L
.60274 .60251 L
.60287 .60281 L
.603 .60303 L
.60315 .60321 L
.60323 .60327 L
.60331 .60331 L
.6034 .60332 L
.60349 .6033 L
.60365 .6032 L
.6038 .60302 L
.60393 .60279 L
.60408 .60245 L
.60424 .60199 L
.60457 .60076 L
.60488 .59924 L
.60559 .59446 L
.6062 .58885 L
.60676 .58254 L
.60802 .56443 L
.61031 .51894 L
.61281 .45434 L
.61771 .30495 L
Mistroke
.62243 .16957 L
.62501 .11116 L
.62619 .08921 L
.62744 .06944 L
.62859 .05427 L
.62986 .0409 L
.63101 .0315 L
.63209 .02489 L
.63269 .022 L
.63335 .01946 L
.63397 .01759 L
.63454 .01628 L
.63506 .01542 L
.6352 .01523 L
.63535 .01506 L
.63549 .01493 L
.63563 .01484 L
.63577 .01476 L
.63592 .01472 L
.63607 .01472 L
.63623 .01474 L
.63638 .01478 L
.63652 .01483 L
.63678 .01493 L
.63795 .01553 L
.63919 .01641 L
.64142 .01836 L
.64255 .0192 L
.64288 .01939 L
.64319 .01955 L
.64347 .01967 L
.64378 .01977 L
.64392 .01981 L
.64406 .01984 L
.6442 .01987 L
.64432 .01988 L
.64444 .0199 L
.64457 .0199 L
.64469 .01991 L
.64483 .0199 L
.64498 .01989 L
.64512 .01988 L
.64528 .01985 L
.64543 .01982 L
.64569 .01974 L
.64598 .01963 L
.64657 .01933 L
.64712 .01895 L
.64837 .01779 L
.64961 .0164 L
Mistroke
.64991 .01607 L
.65023 .01577 L
.65041 .01563 L
.6505 .01558 L
.65058 .01554 L
.65066 .01551 L
.65075 .01549 L
.65091 .01548 L
.65105 .01551 L
.6512 .01558 L
.65134 .01567 L
.65147 .01578 L
.65209 .01647 L
.65334 .0182 L
.65443 .01966 L
.65558 .021 L
.65614 .02154 L
.65677 .02204 L
.65734 .02238 L
.65759 .0225 L
.65787 .02261 L
.65818 .0227 L
.65835 .02273 L
.6585 .02276 L
.65865 .02277 L
.65878 .02278 L
.65893 .02278 L
.65908 .02277 L
.65924 .02276 L
.65931 .02274 L
.6594 .02273 L
.6597 .02266 L
.65987 .0226 L
.66005 .02253 L
.66038 .02238 L
.66101 .02199 L
.6616 .02151 L
.66293 .02006 L
.66409 .01848 L
.66535 .01661 L
.66567 .01616 L
.66601 .01574 L
.66615 .0156 L
.6663 .01548 L
.66639 .01543 L
.66647 .0154 L
.66662 .01537 L
.66678 .0154 L
.66692 .01547 L
.66708 .01559 L
Mistroke
.66724 .01576 L
.66782 .01651 L
.67007 .01974 L
.6712 .02106 L
.67179 .02163 L
.67242 .02211 L
.67297 .02243 L
.67328 .02257 L
.67357 .02267 L
.67371 .02271 L
.67384 .02274 L
.67395 .02276 L
.67408 .02278 L
.67421 .0228 L
.67434 .0228 L
.67447 .02281 L
.67462 .0228 L
.67478 .02279 L
.67492 .02277 L
.67508 .02274 L
.67525 .0227 L
.67557 .0226 L
.67585 .02249 L
.67643 .02217 L
.67697 .02177 L
.67818 .0206 L
.67949 .01895 L
.68074 .01716 L
.68134 .01629 L
.68161 .01594 L
.6819 .01561 L
.68205 .01546 L
.6822 .01536 L
.68234 .0153 L
.68248 .01528 L
.68264 .01531 L
.68278 .01538 L
.68294 .0155 L
.68311 .01567 L
.68444 .01744 L
.68559 .019 L
.68682 .02041 L
.68752 .02107 L
.68816 .02155 L
.68847 .02174 L
.6888 .02191 L
.68912 .02204 L
.68941 .02213 L
.68969 .0222 L
.68984 .02222 L
Mistroke
.68999 .02224 L
.69014 .02225 L
.69023 .02225 L
.69031 .02225 L
.69046 .02225 L
.69062 .02224 L
.69077 .02222 L
.69093 .02219 L
.69123 .02211 L
.69158 .02199 L
.6919 .02185 L
.69243 .02154 L
.69302 .02112 L
.6942 .02 L
.69551 .01842 L
.69676 .01674 L
.6973 .01603 L
.69759 .01568 L
.69787 .01541 L
.69802 .01531 L
.69817 .01523 L
.69826 .01521 L
.69834 .0152 L
.6985 .01523 L
.69865 .01529 L
.69878 .01538 L
.69908 .01566 L
.70151 .0187 L
.7027 .01996 L
.70379 .02084 L
.70437 .02119 L
.70466 .02133 L
.70498 .02145 L
.70515 .0215 L
.7053 .02154 L
.70545 .02158 L
.70559 .0216 L
.70576 .02163 L
.70585 .02164 L
.70594 .02164 L
.7061 .02165 L
.70618 .02165 L
.70627 .02165 L
.7064 .02164 L
.70654 .02163 L
.70669 .02161 L
.70683 .02158 L
.70708 .02153 L
.70735 .02145 L
.70796 .02119 L
Mistroke
.70851 .02086 L
.70972 .0199 L
.71083 .01875 L
.71212 .01719 L
.71276 .01639 L
.71334 .01571 L
.71361 .01545 L
.71375 .01533 L
.7139 .01523 L
.71404 .01516 L
.71417 .01514 L
.71431 .01514 L
.71443 .01517 L
.71457 .01525 L
.71472 .01535 L
.71499 .01559 L
.7156 .01627 L
.7168 .01771 L
.71809 .0191 L
.71873 .01967 L
.71934 .02014 L
.71992 .02051 L
.72047 .02078 L
.72098 .02096 L
.72124 .02102 L
.72139 .02105 L
.72153 .02107 L
.72168 .02109 L
.72182 .0211 L
.72196 .02111 L
.72205 .02111 L
.72212 .02111 L
.72226 .0211 L
.72239 .02109 L
.72254 .02108 L
.72268 .02105 L
.72297 .02099 L
.72324 .02092 L
.72386 .02067 L
.72446 .02034 L
.7251 .01989 L
.72733 .01774 L
.72856 .01633 L
.7292 .01562 L
.72953 .01532 L
.72962 .01526 L
.72972 .0152 L
.72981 .01515 L
.72989 .01511 L
.73004 .01508 L
Mistroke
.73012 .01508 L
.73021 .01509 L
.7303 .01511 L
.73039 .01515 L
.73055 .01524 L
.73084 .01547 L
.73115 .01578 L
.73232 .01707 L
.73355 .01837 L
.73471 .01938 L
.73534 .01982 L
.73592 .02014 L
.73656 .02041 L
.73692 .02052 L
.73708 .02056 L
.73725 .02059 L
.73741 .02061 L
.73756 .02063 L
.73771 .02064 L
.73786 .02065 L
.738 .02065 L
.73812 .02064 L
.73826 .02063 L
.73841 .02062 L
.73857 .0206 L
.73874 .02056 L
.73906 .02049 L
.73936 .02039 L
.73964 .02028 L
.74072 .01969 L
.74186 .01881 L
.74302 .0177 L
.74424 .0164 L
.74475 .01586 L
.74528 .01535 L
.74544 .01523 L
.74559 .01514 L
.74573 .01507 L
.74587 .01504 L
.74601 .01503 L
.74616 .01506 L
.74628 .0151 L
.74642 .01518 L
.74673 .0154 L
.747 .01566 L
.74763 .01629 L
.74876 .01746 L
.75007 .01866 L
.75064 .01909 L
.75128 .0195 L
Mistroke
.75181 .01978 L
.75239 .02002 L
.75271 .02011 L
.75285 .02014 L
.753 .02018 L
.75313 .0202 L
.75328 .02022 L
.75343 .02024 L
.75357 .02025 L
.75366 .02025 L
.75374 .02025 L
.7539 .02025 L
.75398 .02025 L
.75406 .02025 L
.75415 .02024 L
.75425 .02023 L
.75442 .02021 L
.75458 .02019 L
.75488 .02012 L
.75518 .02004 L
.75545 .01994 L
.75608 .01966 L
.75669 .01931 L
.75735 .01885 L
.75855 .01783 L
.75971 .01668 L
.7608 .0156 L
.76108 .01535 L
.76135 .01515 L
.7615 .01507 L
.76158 .01504 L
.76166 .01501 L
.7618 .01499 L
.76194 .01499 L
.76209 .01503 L
.76218 .01506 L
.76225 .0151 L
.76254 .01529 L
.7632 .01588 L
.76452 .01717 L
.76574 .01825 L
.76685 .01903 L
.76747 .01937 L
.76803 .01961 L
.76833 .01971 L
.76864 .0198 L
.76881 .01983 L
.76899 .01987 L
.76916 .01989 L
.76931 .01991 L
Mistroke
.76947 .01992 L
.76962 .01992 L
.76975 .01992 L
.7699 .01992 L
.77005 .01991 L
.77014 .0199 L
.77022 .01989 L
.77038 .01987 L
.77052 .01985 L
.77081 .01979 L
.77111 .0197 L
.77174 .01947 L
.77228 .0192 L
.77285 .01886 L
.77536 .01677 L
.77659 .0156 L
.77693 .01531 L
.77712 .01518 L
.77729 .01507 L
.77744 .01501 L
.7776 .01496 L
.77769 .01495 L
.77777 .01495 L
.77785 .01496 L
.77793 .01498 L
.77801 .015 L
.7781 .01504 L
.77825 .01512 L
.77854 .01532 L
.77919 .01589 L
.78036 .01698 L
.7816 .01803 L
.78276 .01881 L
.78335 .01911 L
.78397 .01937 L
.78433 .01948 L
.78467 .01955 L
.78482 .01958 L
.78497 .0196 L
.78505 .01961 L
.78514 .01962 L
.7853 .01963 L
.78545 .01964 L
.78559 .01964 L
.78574 .01964 L
.78582 .01964 L
.7859 .01963 L
.78605 .01962 L
.78622 .0196 L
.78637 .01958 L
Mistroke
.78652 .01955 L
.78706 .01941 L
.78733 .01932 L
.78763 .0192 L
.78893 .0185 L
.79015 .0176 L
.7914 .0165 L
.79202 .01593 L
.79259 .01543 L
.79286 .01522 L
.79311 .01506 L
.79325 .015 L
.7934 .01494 L
.79354 .01492 L
.79366 .01492 L
.7938 .01494 L
.79393 .01499 L
.79408 .01505 L
.79423 .01514 L
.79483 .0156 L
.79722 .01766 L
.79788 .01814 L
.79857 .01857 L
.79917 .01887 L
.79949 .01901 L
.79982 .01913 L
.80012 .01922 L
.80044 .0193 L
.80058 .01932 L
.80073 .01935 L
.80087 .01937 L
.801 .01938 L
.80115 .01939 L
.8013 .0194 L
.80144 .01941 L
.80158 .0194 L
.80171 .0194 L
.80183 .01939 L
.80197 .01938 L
.80211 .01936 L
.80243 .01931 L
.80279 .01923 L
.80312 .01913 L
.80343 .01902 L
.80463 .01843 L
.80579 .01764 L
.80688 .01675 L
.80809 .0157 L
.80841 .01543 L
.80875 .01518 L
Mistroke
.80891 .01507 L
.80907 .01499 L
.80921 .01493 L
.80936 .0149 L
.8095 .01489 L
.80965 .01491 L
.80973 .01493 L
.80981 .01496 L
.80996 .01502 L
.81025 .0152 L
.81052 .0154 L
.81179 .01647 L
.81287 .01735 L
.81402 .01814 L
.81464 .01849 L
.81521 .01875 L
.81578 .01896 L
.81603 .01903 L
.81631 .0191 L
.81661 .01915 L
.81678 .01917 L
.81694 .01919 L
.81708 .0192 L
.81721 .0192 L
.81737 .0192 L
.81751 .0192 L
.81767 .01919 L
.81775 .01919 L
.81783 .01918 L
.81799 .01916 L
.81813 .01914 L
.81846 .01909 L
.81881 .019 L
.81941 .0188 L
.81996 .01855 L
.82123 .01782 L
.82254 .01684 L
.82377 .0158 L
.82435 .01534 L
.82466 .01512 L
.82481 .01503 L
.82496 .01496 L
.82511 .0149 L
.82519 .01488 L
.82527 .01487 L
.82536 .01487 L
.82544 .01487 L
.82553 .01488 L
.82562 .01491 L
.8257 .01493 L
Mistroke
.82579 .01497 L
.82595 .01505 L
.82624 .01524 L
.82848 .01704 L
.82973 .0179 L
.83089 .01851 L
.83148 .01874 L
.83178 .01883 L
.8321 .01891 L
.83229 .01895 L
.83246 .01897 L
.83262 .01899 L
.83271 .019 L
.8328 .01901 L
.83296 .01902 L
.83311 .01903 L
.83319 .01903 L
.83328 .01903 L
.83343 .01903 L
.83358 .01902 L
.83367 .01901 L
.83374 .01901 L
.83388 .01899 L
.83404 .01897 L
.8343 .01893 L
.83459 .01886 L
.83522 .01867 L
.83582 .01842 L
.83689 .01783 L
.83803 .01704 L
.83926 .01606 L
.83991 .01554 L
.84026 .01527 L
.84059 .01505 L
.84073 .01498 L
.84088 .01491 L
.84096 .01489 L
.84104 .01487 L
.84119 .01485 L
.84128 .01485 L
.84136 .01485 L
.84145 .01487 L
.84153 .01489 L
.84169 .01495 L
.84185 .01504 L
.84246 .01545 L
.84302 .0159 L
.8442 .01683 L
.84547 .01771 L
.84609 .01806 L
Mistroke
.84667 .01834 L
.84725 .01856 L
.84777 .01872 L
.84805 .01878 L
.84832 .01883 L
.84845 .01884 L
.8486 .01886 L
.84875 .01887 L
.8489 .01888 L
.84902 .01889 L
.84916 .01889 L
.84929 .01888 L
.8494 .01888 L
.84954 .01887 L
.84968 .01886 L
.84982 .01884 L
.84995 .01882 L
.85023 .01877 L
.8505 .01871 L
.85111 .01853 L
.8517 .01829 L
.85233 .01798 L
.8547 .01635 L
.85596 .01537 L
.85632 .01512 L
.8565 .01502 L
.85666 .01493 L
.85681 .01488 L
.85697 .01484 L
.85712 .01483 L
.85721 .01483 L
.8573 .01485 L
.85745 .01489 L
.85754 .01492 L
.85762 .01496 L
.85792 .01513 L
.85849 .01553 L
.85977 .01653 L
.86088 .01732 L
.86208 .01801 L
.86274 .01831 L
.86304 .01842 L
.86336 .01852 L
.86364 .0186 L
.86394 .01866 L
.86411 .01869 L
.86426 .01871 L
.86441 .01873 L
.86456 .01875 L
.8647 .01876 L
Mistroke
.86485 .01876 L
.86498 .01876 L
.86511 .01876 L
.86526 .01876 L
.8654 .01875 L
.86548 .01875 L
.86556 .01874 L
.86571 .01872 L
.86599 .01868 L
.86628 .01862 L
.86681 .01848 L
.86745 .01824 L
.86805 .01797 L
.86939 .01717 L
.87065 .01625 L
.87126 .01577 L
.87182 .01535 L
.87209 .01517 L
.87238 .01499 L
.87252 .01493 L
.87266 .01487 L
.87278 .01484 L
.87291 .01482 L
.87307 .01482 L
.87321 .01484 L
.87336 .01488 L
.87344 .01491 L
.87352 .01495 L
.87409 .0153 L
.87539 .01628 L
.87658 .01713 L
.87771 .0178 L
.87831 .01809 L
.87894 .01833 L
.87927 .01843 L
.87962 .01852 L
.87994 .01858 L
.88024 .01863 L
.8804 .01864 L
.88055 .01865 L
.88069 .01866 L
.88084 .01866 L
.88092 .01866 L
.881 .01866 L
.88108 .01866 L
.88117 .01866 L
.88131 .01865 L
.88147 .01863 L
.88162 .01862 L
.88176 .0186 L
Mistroke
.88207 .01854 L
.88262 .01841 L
.88327 .01818 L
.88388 .01791 L
.8851 .01721 L
.88642 .01628 L
.88701 .01583 L
.88765 .01536 L
.88795 .01516 L
.88826 .01498 L
.88838 .01491 L
.88852 .01486 L
.88867 .01482 L
.88881 .0148 L
.88897 .01481 L
.88905 .01482 L
.88913 .01484 L
.88928 .01489 L
.88944 .01496 L
.89002 .01531 L
.89134 .01629 L
.89249 .01709 L
.89371 .01779 L
.8943 .01806 L
.89486 .01827 L
.89537 .01841 L
.89565 .01847 L
.89592 .01852 L
.89606 .01854 L
.89621 .01855 L
.89634 .01856 L
.89648 .01857 L
.89663 .01858 L
.89671 .01858 L
.89679 .01858 L
.89694 .01858 L
.89708 .01857 L
.89721 .01857 L
.89735 .01855 L
.8976 .01852 L
.89787 .01848 L
.89817 .01842 L
.89878 .01824 L
.89945 .01798 L
.90065 .01736 L
.90303 .0157 L
.90368 .01524 L
.90404 .01501 L
.90421 .01492 L
.90429 .01489 L
Mistroke
.90437 .01486 L
.90453 .01481 L
.90461 .0148 L
.90469 .01479 L
.90477 .01479 L
.90485 .0148 L
.90494 .01481 L
.90503 .01483 L
.90518 .01488 L
.90531 .01494 L
.90562 .01511 L
.9079 .01674 L
.90911 .01749 L
.90974 .01781 L
.91041 .01809 L
.91102 .01829 L
.91137 .01837 L
.91169 .01843 L
.91184 .01846 L
.91198 .01848 L
.91211 .01849 L
.91225 .0185 L
.9124 .01851 L
.91254 .01851 L
.91269 .01852 L
.91278 .01851 L
.91286 .01851 L
.913 .01851 L
.91315 .01849 L
.9133 .01848 L
.91343 .01846 L
.91369 .01843 L
.91396 .01837 L
.91458 .0182 L
.91515 .018 L
.91636 .01741 L
.91748 .01671 L
.91878 .01578 L
.91941 .01532 L
.91969 .01514 L
.91999 .01496 L
.92013 .0149 L
.92028 .01484 L
.92041 .0148 L
.92055 .01478 L
.92069 .01478 L
.92083 .0148 L
.92096 .01484 L
.92109 .01489 L
.92138 .01503 L
Mistroke
.92169 .01522 L
.92226 .01562 L
.92357 .01657 L
.92476 .01732 L
.92534 .01763 L
.92598 .01792 L
.92653 .01813 L
.92713 .0183 L
.92746 .01837 L
.92777 .01841 L
.92794 .01843 L
.92809 .01845 L
.92818 .01845 L
.92827 .01846 L
.92836 .01846 L
.92845 .01846 L
.92859 .01847 L
.92872 .01846 L
.92887 .01846 L
.92896 .01845 L
.92903 .01845 L
.92934 .01841 L
.92949 .01839 L
.92966 .01836 L
.93029 .01821 L
.93089 .01801 L
.93202 .01749 L
.93323 .01676 L
.93455 .01584 L
.9351 .01544 L
.93569 .01505 L
.93586 .01496 L
.93602 .01488 L
.93617 .01483 L
.93626 .01481 L
.93633 .01479 L
.93649 .01478 L
.93663 .01478 L
.93671 .0148 L
.93679 .01482 L
.93694 .01487 L
.9371 .01494 L
.93725 .01502 L
.93758 .01522 L
.93826 .0157 L
.93948 .01656 L
.94074 .01735 L
.94136 .01767 L
.94194 .01792 L
.94245 .01811 L
Mistroke
.94301 .01826 L
.9433 .01832 L
.94357 .01837 L
.94371 .01839 L
.94386 .0184 L
.94394 .01841 L
.94403 .01842 L
.94417 .01843 L
.94425 .01843 L
.94433 .01843 L
.94448 .01843 L
.94464 .01843 L
.94473 .01842 L
.94481 .01842 L
.94496 .01841 L
.9451 .01839 L
.94541 .01835 L
.94569 .0183 L
.94599 .01823 L
.94654 .01806 L
.94718 .01782 L
.94785 .01749 L
.94907 .01677 L
.95031 .0159 L
.95097 .01543 L
.95133 .01519 L
.95166 .01499 L
.95181 .01492 L
.95195 .01486 L
.95203 .01483 L
.95212 .01481 L
.95226 .01478 L
.95234 .01477 L
.95243 .01477 L
.95252 .01478 L
.95261 .0148 L
.95276 .01484 L
.95293 .01491 L
.95324 .01508 L
.95354 .01527 L
.95409 .01566 L
.95534 .01654 L
.95651 .01727 L
.95756 .0178 L
.95815 .01803 L
.9587 .0182 L
.95897 .01826 L
.95925 .01832 L
.95941 .01834 L
.95956 .01836 L
Mistroke
.9597 .01838 L
.95985 .01839 L
.96001 .0184 L
.96015 .01841 L
.96031 .01841 L
.9604 .01841 L
.96048 .01841 L
.96063 .0184 L
.96076 .01839 L
.96091 .01838 L
.96107 .01836 L
.96137 .01832 L
.9617 .01825 L
.96228 .01809 L
.96297 .01784 L
.9636 .01754 L
.96611 .01596 L
.96721 .01518 L
.96751 .015 L
.96768 .01492 L
.96784 .01485 L
.96798 .01481 L
.96807 .01479 L
.96814 .01478 L
.96828 .01477 L
.96842 .01478 L
.96858 .01482 L
.96872 .01487 L
.96903 .01503 L
.96961 .01539 L
.97068 .01616 L
.97191 .01698 L
.97306 .01762 L
.97378 .01793 L
.97455 .01818 L
.97476 .01824 L
.97499 .01828 L
.9752 .01832 L
.97541 .01835 L
.9756 .01837 L
.97571 .01838 L
.97582 .01839 L
.97592 .0184 L
.97601 .0184 L
.9761 .0184 L
.97619 .0184 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.00459847 0.64881 0.188537 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.491929 0.0484262 0.0147151 0.0110062 [
[.00767 -0.0125 -9 -9 ]
[.00767 -0.0125 9 0 ]
[.2498 -0.0125 -6 -9 ]
[.2498 -0.0125 6 0 ]
[.49193 -0.0125 -3 -9 ]
[.49193 -0.0125 3 0 ]
[.73406 -0.0125 -3 -9 ]
[.73406 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .12478 -12 -4.5 ]
[-0.0125 .12478 0 4.5 ]
[-0.0125 .23484 -12 -4.5 ]
[-0.0125 .23484 0 4.5 ]
[-0.0125 .3449 -12 -4.5 ]
[-0.0125 .3449 0 4.5 ]
[-0.0125 .45496 -12 -4.5 ]
[-0.0125 .45496 0 4.5 ]
[-0.0125 .56503 -12 -4.5 ]
[-0.0125 .56503 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.00767 0 m
.00767 .00625 L
s
[(-10)] .00767 -0.0125 0 1 Mshowa
.2498 0 m
.2498 .00625 L
s
[(-5)] .2498 -0.0125 0 1 Mshowa
.49193 0 m
.49193 .00625 L
s
[(0)] .49193 -0.0125 0 1 Mshowa
.73406 0 m
.73406 .00625 L
s
[(5)] .73406 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05609 0 m
.05609 .00375 L
s
.10452 0 m
.10452 .00375 L
s
.15295 0 m
.15295 .00375 L
s
.20137 0 m
.20137 .00375 L
s
.29822 0 m
.29822 .00375 L
s
.34665 0 m
.34665 .00375 L
s
.39508 0 m
.39508 .00375 L
s
.4435 0 m
.4435 .00375 L
s
.54036 0 m
.54036 .00375 L
s
.58878 0 m
.58878 .00375 L
s
.63721 0 m
.63721 .00375 L
s
.68563 0 m
.68563 .00375 L
s
.78249 0 m
.78249 .00375 L
s
.83091 0 m
.83091 .00375 L
s
.87934 0 m
.87934 .00375 L
s
.92776 0 m
.92776 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .12478 m
.00625 .12478 L
s
[(10)] -0.0125 .12478 1 0 Mshowa
0 .23484 m
.00625 .23484 L
s
[(20)] -0.0125 .23484 1 0 Mshowa
0 .3449 m
.00625 .3449 L
s
[(30)] -0.0125 .3449 1 0 Mshowa
0 .45496 m
.00625 .45496 L
s
[(40)] -0.0125 .45496 1 0 Mshowa
0 .56503 m
.00625 .56503 L
s
[(50)] -0.0125 .56503 1 0 Mshowa
.125 Mabswid
0 .03673 m
.00375 .03673 L
s
0 .05874 m
.00375 .05874 L
s
0 .08075 m
.00375 .08075 L
s
0 .10276 m
.00375 .10276 L
s
0 .14679 m
.00375 .14679 L
s
0 .1688 m
.00375 .1688 L
s
0 .19081 m
.00375 .19081 L
s
0 .21283 m
.00375 .21283 L
s
0 .25685 m
.00375 .25685 L
s
0 .27886 m
.00375 .27886 L
s
0 .30088 m
.00375 .30088 L
s
0 .32289 m
.00375 .32289 L
s
0 .36691 m
.00375 .36691 L
s
0 .38893 m
.00375 .38893 L
s
0 .41094 m
.00375 .41094 L
s
0 .43295 m
.00375 .43295 L
s
0 .47698 m
.00375 .47698 L
s
0 .49899 m
.00375 .49899 L
s
0 .521 m
.00375 .521 L
s
0 .54301 m
.00375 .54301 L
s
0 .58704 m
.00375 .58704 L
s
0 .60905 m
.00375 .60905 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.00767 .61178 m
.00767 .61803 L
s
.2498 .61178 m
.2498 .61803 L
s
.49193 .61178 m
.49193 .61803 L
s
.73406 .61178 m
.73406 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.05609 .61428 m
.05609 .61803 L
s
.10452 .61428 m
.10452 .61803 L
s
.15295 .61428 m
.15295 .61803 L
s
.20137 .61428 m
.20137 .61803 L
s
.29822 .61428 m
.29822 .61803 L
s
.34665 .61428 m
.34665 .61803 L
s
.39508 .61428 m
.39508 .61803 L
s
.4435 .61428 m
.4435 .61803 L
s
.54036 .61428 m
.54036 .61803 L
s
.58878 .61428 m
.58878 .61803 L
s
.63721 .61428 m
.63721 .61803 L
s
.68563 .61428 m
.68563 .61803 L
s
.78249 .61428 m
.78249 .61803 L
s
.83091 .61428 m
.83091 .61803 L
s
.87934 .61428 m
.87934 .61803 L
s
.92776 .61428 m
.92776 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .12478 m
1 .12478 L
s
.99375 .23484 m
1 .23484 L
s
.99375 .3449 m
1 .3449 L
s
.99375 .45496 m
1 .45496 L
s
.99375 .56503 m
1 .56503 L
s
.125 Mabswid
.99625 .03673 m
1 .03673 L
s
.99625 .05874 m
1 .05874 L
s
.99625 .08075 m
1 .08075 L
s
.99625 .10276 m
1 .10276 L
s
.99625 .14679 m
1 .14679 L
s
.99625 .1688 m
1 .1688 L
s
.99625 .19081 m
1 .19081 L
s
.99625 .21283 m
1 .21283 L
s
.99625 .25685 m
1 .25685 L
s
.99625 .27886 m
1 .27886 L
s
.99625 .30088 m
1 .30088 L
s
.99625 .32289 m
1 .32289 L
s
.99625 .36691 m
1 .36691 L
s
.99625 .38893 m
1 .38893 L
s
.99625 .41094 m
1 .41094 L
s
.99625 .43295 m
1 .43295 L
s
.99625 .47698 m
1 .47698 L
s
.99625 .49899 m
1 .49899 L
s
.99625 .521 m
1 .521 L
s
.99625 .54301 m
1 .54301 L
s
.99625 .58704 m
1 .58704 L
s
.99625 .60905 m
1 .60905 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .01472 m
.02381 .02001 L
s
.03995 .01472 m
.03995 .02003 L
s
.05609 .01472 m
.05609 .02007 L
s
.07224 .01472 m
.07224 .02013 L
s
.08838 .01472 m
.08838 .02021 L
s
.10452 .01472 m
.10452 .02031 L
s
.12066 .01472 m
.12066 .02044 L
s
.1368 .01472 m
.1368 .02058 L
s
.15295 .01472 m
.15295 .02076 L
s
.16909 .01472 m
.16909 .02097 L
s
.18523 .01472 m
.18523 .02121 L
s
.20137 .01472 m
.20137 .0215 L
s
.21751 .01472 m
.21751 .02184 L
s
.23366 .01472 m
.23366 .02224 L
s
.2498 .01472 m
.2498 .02271 L
s
.26594 .01472 m
.26594 .02327 L
s
.28208 .01472 m
.28208 .02393 L
s
.29822 .01472 m
.29822 .02466 L
s
.31437 .01472 m
.31437 .02533 L
s
.33051 .01472 m
.33051 .0253 L
s
.34665 .01472 m
.34665 .02118 L
s
.36279 .01472 m
.36279 .0901 L
s
.37893 .01472 m
.37893 .60332 L
s
.39508 .01472 m
.39508 .59466 L
s
.41122 .01472 m
.41122 .05953 L
s
.42736 .01472 m
.42736 .31219 L
s
.4435 .01472 m
.4435 .30568 L
s
.45964 .01472 m
.45964 .05608 L
s
.47579 .01472 m
.47579 .16134 L
s
.49193 .01472 m
.49193 .3766 L
s
.50807 .01472 m
.50807 .16134 L
s
.52421 .01472 m
.52421 .05608 L
s
.54036 .01472 m
.54036 .30568 L
s
.5565 .01472 m
.5565 .31219 L
s
.57264 .01472 m
.57264 .05953 L
s
.58878 .01472 m
.58878 .59466 L
s
.60492 .01472 m
.60492 .60332 L
s
.62107 .01472 m
.62107 .0901 L
s
.63721 .01472 m
.63721 .02118 L
s
.65335 .01472 m
.65335 .0253 L
s
.66949 .01472 m
.66949 .02533 L
s
.68563 .01472 m
.68563 .02466 L
s
.70178 .01472 m
.70178 .02393 L
s
.71792 .01472 m
.71792 .02327 L
s
.73406 .01472 m
.73406 .02271 L
s
.7502 .01472 m
.7502 .02224 L
s
.76634 .01472 m
.76634 .02184 L
s
.78249 .01472 m
.78249 .0215 L
s
.79863 .01472 m
.79863 .02121 L
s
.81477 .01472 m
.81477 .02097 L
s
.83091 .01472 m
.83091 .02076 L
s
.84705 .01472 m
.84705 .02058 L
s
.8632 .01472 m
.8632 .02044 L
s
.87934 .01472 m
.87934 .02031 L
s
.89548 .01472 m
.89548 .02021 L
s
.91162 .01472 m
.91162 .02013 L
s
.92776 .01472 m
.92776 .02007 L
s
.94391 .01472 m
.94391 .02003 L
s
.96005 .01472 m
.96005 .02001 L
s
.97619 .01472 m
.97619 .02 L
s
.015 w
.02381 .02001 Mdot
.03995 .02003 Mdot
.05609 .02007 Mdot
.07224 .02013 Mdot
.08838 .02021 Mdot
.10452 .02031 Mdot
.12066 .02044 Mdot
.1368 .02058 Mdot
.15295 .02076 Mdot
.16909 .02097 Mdot
.18523 .02121 Mdot
.20137 .0215 Mdot
.21751 .02184 Mdot
.23366 .02224 Mdot
.2498 .02271 Mdot
.26594 .02327 Mdot
.28208 .02393 Mdot
.29822 .02466 Mdot
.31437 .02533 Mdot
.33051 .0253 Mdot
.34665 .02118 Mdot
.36279 .0901 Mdot
.37893 .60332 Mdot
.39508 .59466 Mdot
.41122 .05953 Mdot
.42736 .31219 Mdot
.4435 .30568 Mdot
.45964 .05608 Mdot
.47579 .16134 Mdot
.49193 .3766 Mdot
.50807 .16134 Mdot
.52421 .05608 Mdot
.54036 .30568 Mdot
.5565 .31219 Mdot
.57264 .05953 Mdot
.58878 .59466 Mdot
.60492 .60332 Mdot
.62107 .0901 Mdot
.63721 .02118 Mdot
.65335 .0253 Mdot
.66949 .02533 Mdot
.68563 .02466 Mdot
.70178 .02393 Mdot
.71792 .02327 Mdot
.73406 .02271 Mdot
.7502 .02224 Mdot
.76634 .02184 Mdot
.78249 .0215 Mdot
.79863 .02121 Mdot
.81477 .02097 Mdot
.83091 .02076 Mdot
.84705 .02058 Mdot
.8632 .02044 Mdot
.87934 .02031 Mdot
.89548 .02021 Mdot
.91162 .02013 Mdot
.92776 .02007 Mdot
.94391 .02003 Mdot
.96005 .02001 Mdot
.97619 .02 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.00459847 0.97619 0.188537 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.047619 0.0147151 0.00907075 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .10542 -12 -4.5 ]
[-0.0125 .10542 0 4.5 ]
[-0.0125 .19613 -12 -4.5 ]
[-0.0125 .19613 0 4.5 ]
[-0.0125 .28684 -12 -4.5 ]
[-0.0125 .28684 0 4.5 ]
[-0.0125 .37754 -12 -4.5 ]
[-0.0125 .37754 0 4.5 ]
[-0.0125 .46825 -12 -4.5 ]
[-0.0125 .46825 0 4.5 ]
[-0.0125 .55896 -12 -4.5 ]
[-0.0125 .55896 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .10542 m
.00625 .10542 L
s
[(10)] -0.0125 .10542 1 0 Mshowa
0 .19613 m
.00625 .19613 L
s
[(20)] -0.0125 .19613 1 0 Mshowa
0 .28684 m
.00625 .28684 L
s
[(30)] -0.0125 .28684 1 0 Mshowa
0 .37754 m
.00625 .37754 L
s
[(40)] -0.0125 .37754 1 0 Mshowa
0 .46825 m
.00625 .46825 L
s
[(50)] -0.0125 .46825 1 0 Mshowa
0 .55896 m
.00625 .55896 L
s
[(60)] -0.0125 .55896 1 0 Mshowa
.125 Mabswid
0 .03286 m
.00375 .03286 L
s
0 .051 m
.00375 .051 L
s
0 .06914 m
.00375 .06914 L
s
0 .08728 m
.00375 .08728 L
s
0 .12356 m
.00375 .12356 L
s
0 .14171 m
.00375 .14171 L
s
0 .15985 m
.00375 .15985 L
s
0 .17799 m
.00375 .17799 L
s
0 .21427 m
.00375 .21427 L
s
0 .23241 m
.00375 .23241 L
s
0 .25055 m
.00375 .25055 L
s
0 .2687 m
.00375 .2687 L
s
0 .30498 m
.00375 .30498 L
s
0 .32312 m
.00375 .32312 L
s
0 .34126 m
.00375 .34126 L
s
0 .3594 m
.00375 .3594 L
s
0 .39569 m
.00375 .39569 L
s
0 .41383 m
.00375 .41383 L
s
0 .43197 m
.00375 .43197 L
s
0 .45011 m
.00375 .45011 L
s
0 .48639 m
.00375 .48639 L
s
0 .50454 m
.00375 .50454 L
s
0 .52268 m
.00375 .52268 L
s
0 .54082 m
.00375 .54082 L
s
0 .5771 m
.00375 .5771 L
s
0 .59524 m
.00375 .59524 L
s
0 .61338 m
.00375 .61338 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .10542 m
1 .10542 L
s
.99375 .19613 m
1 .19613 L
s
.99375 .28684 m
1 .28684 L
s
.99375 .37754 m
1 .37754 L
s
.99375 .46825 m
1 .46825 L
s
.99375 .55896 m
1 .55896 L
s
.125 Mabswid
.99625 .03286 m
1 .03286 L
s
.99625 .051 m
1 .051 L
s
.99625 .06914 m
1 .06914 L
s
.99625 .08728 m
1 .08728 L
s
.99625 .12356 m
1 .12356 L
s
.99625 .14171 m
1 .14171 L
s
.99625 .15985 m
1 .15985 L
s
.99625 .17799 m
1 .17799 L
s
.99625 .21427 m
1 .21427 L
s
.99625 .23241 m
1 .23241 L
s
.99625 .25055 m
1 .25055 L
s
.99625 .2687 m
1 .2687 L
s
.99625 .30498 m
1 .30498 L
s
.99625 .32312 m
1 .32312 L
s
.99625 .34126 m
1 .34126 L
s
.99625 .3594 m
1 .3594 L
s
.99625 .39569 m
1 .39569 L
s
.99625 .41383 m
1 .41383 L
s
.99625 .43197 m
1 .43197 L
s
.99625 .45011 m
1 .45011 L
s
.99625 .48639 m
1 .48639 L
s
.99625 .50454 m
1 .50454 L
s
.99625 .52268 m
1 .52268 L
s
.99625 .54082 m
1 .54082 L
s
.99625 .5771 m
1 .5771 L
s
.99625 .59524 m
1 .59524 L
s
.99625 .61338 m
1 .61338 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
0 0 1 r
.5 Mabswid
[ .01 ] 0 setdash
.02381 .01907 m
.02395 .01907 L
.02408 .01906 L
.02423 .01905 L
.02437 .01904 L
.02462 .01901 L
.02489 .01897 L
.02519 .01891 L
.02551 .01883 L
.02608 .01865 L
.02722 .01815 L
.02847 .01741 L
.02973 .01653 L
.03043 .01604 L
.03077 .01581 L
.03109 .01563 L
.03125 .01556 L
.03139 .0155 L
.03147 .01548 L
.03156 .01546 L
.03171 .01544 L
.03179 .01544 L
.03188 .01545 L
.03197 .01546 L
.03206 .01549 L
.03221 .01554 L
.03238 .01562 L
.03299 .01599 L
.03355 .01638 L
.03476 .01723 L
.03605 .01803 L
.03714 .01855 L
.03777 .01877 L
.03805 .01885 L
.03836 .01893 L
.03863 .01898 L
.03892 .01903 L
.03908 .01905 L
.03923 .01906 L
.03938 .01907 L
.03952 .01907 L
.03965 .01908 L
.03978 .01908 L
.0399 .01907 L
.04003 .01907 L
.04017 .01906 L
.04031 .01904 L
.04058 .01901 L
.04089 .01896 L
.04122 .01888 L
Mistroke
.04183 .0187 L
.04243 .01847 L
.04298 .01821 L
.04525 .0168 L
.04644 .01595 L
.04673 .01576 L
.04705 .01559 L
.04722 .01552 L
.04731 .01549 L
.04739 .01547 L
.04746 .01546 L
.04755 .01545 L
.0477 .01545 L
.04778 .01546 L
.04786 .01547 L
.04802 .01552 L
.04819 .01559 L
.04836 .01567 L
.04905 .01612 L
.05029 .017 L
.05155 .01783 L
.05217 .01817 L
.05273 .01844 L
.05326 .01866 L
.05383 .01885 L
.05415 .01893 L
.05444 .01899 L
.05472 .01904 L
.05487 .01906 L
.05501 .01907 L
.05517 .01908 L
.05531 .01909 L
.05546 .0191 L
.05555 .0191 L
.05563 .0191 L
.05576 .01909 L
.05591 .01909 L
.05606 .01908 L
.0562 .01906 L
.05653 .01902 L
.05683 .01897 L
.05716 .01889 L
.05751 .01879 L
.05866 .01833 L
.05989 .01765 L
.0621 .01611 L
.0627 .01572 L
.063 .01556 L
.06309 .01553 L
.06318 .0155 L
Mistroke
.06326 .01548 L
.06334 .01546 L
.06342 .01545 L
.06351 .01545 L
.0636 .01545 L
.06369 .01546 L
.06378 .01549 L
.06387 .01551 L
.06403 .01558 L
.06434 .01574 L
.06467 .01595 L
.06583 .01678 L
.0671 .01765 L
.06827 .01831 L
.0689 .0186 L
.06951 .01882 L
.06984 .01891 L
.0702 .019 L
.07052 .01906 L
.07068 .01908 L
.07082 .0191 L
.07096 .01911 L
.07111 .01912 L
.07119 .01913 L
.07127 .01913 L
.07142 .01913 L
.07158 .01913 L
.07172 .01913 L
.0718 .01912 L
.07188 .01912 L
.07205 .0191 L
.0722 .01909 L
.07233 .01907 L
.07264 .01902 L
.07294 .01895 L
.07326 .01886 L
.07437 .01844 L
.07504 .0181 L
.07568 .01773 L
.07688 .01692 L
.07804 .01608 L
.07837 .01585 L
.07868 .01567 L
.07882 .0156 L
.07897 .01553 L
.07912 .01548 L
.07927 .01546 L
.07941 .01545 L
.07954 .01547 L
.07968 .0155 L
Mistroke
.07982 .01555 L
.08006 .01566 L
.08033 .01582 L
.08149 .01664 L
.08262 .01744 L
.08383 .01818 L
.08453 .01853 L
.08517 .01879 L
.08547 .01889 L
.08581 .01898 L
.0861 .01905 L
.08642 .01911 L
.08658 .01913 L
.08674 .01915 L
.08689 .01916 L
.08704 .01917 L
.08718 .01918 L
.08731 .01918 L
.08745 .01918 L
.08761 .01918 L
.08769 .01917 L
.08777 .01917 L
.08795 .01915 L
.08811 .01913 L
.08827 .01911 L
.08856 .01906 L
.08888 .01898 L
.08944 .01881 L
.09006 .01857 L
.09116 .018 L
.09353 .01637 L
.09418 .01591 L
.09454 .01569 L
.09471 .0156 L
.09487 .01553 L
.09503 .01549 L
.0951 .01547 L
.09519 .01546 L
.09527 .01546 L
.09536 .01547 L
.09545 .01548 L
.09553 .0155 L
.09567 .01555 L
.09583 .01562 L
.09612 .01578 L
.09863 .01757 L
.09972 .01824 L
.1009 .01879 L
.10154 .01901 L
.10182 .01908 L
Mistroke
.10212 .01914 L
.10241 .01919 L
.10255 .01921 L
.10268 .01922 L
.10283 .01923 L
.10297 .01924 L
.10312 .01925 L
.10328 .01925 L
.10343 .01924 L
.10358 .01924 L
.10366 .01923 L
.10374 .01922 L
.10391 .01921 L
.10424 .01916 L
.10459 .01909 L
.10517 .01892 L
.10581 .01868 L
.10705 .01805 L
.10817 .01731 L
.10949 .01634 L
.11007 .01592 L
.11037 .01573 L
.11054 .01564 L
.1107 .01556 L
.11085 .01551 L
.11101 .01548 L
.11115 .01547 L
.11128 .01548 L
.11141 .01551 L
.11155 .01556 L
.11169 .01562 L
.11183 .01569 L
.11302 .01653 L
.11424 .01743 L
.11553 .01826 L
.11669 .01883 L
.11735 .01906 L
.11766 .01915 L
.11796 .01922 L
.11823 .01926 L
.11837 .01928 L
.11852 .0193 L
.11865 .01931 L
.11879 .01932 L
.11892 .01933 L
.11904 .01933 L
.11919 .01933 L
.11933 .01933 L
.11945 .01932 L
.11959 .01931 L
Mistroke
.11974 .01929 L
.1199 .01927 L
.12019 .01923 L
.1205 .01916 L
.12084 .01907 L
.12143 .01886 L
.12207 .01858 L
.12277 .0182 L
.12405 .01736 L
.12521 .01649 L
.12578 .01606 L
.12609 .01585 L
.12641 .01565 L
.12655 .01559 L
.1267 .01553 L
.12678 .01551 L
.12686 .0155 L
.12701 .01548 L
.12714 .01549 L
.12728 .01552 L
.12742 .01557 L
.12756 .01563 L
.1282 .01603 L
.12878 .01647 L
.13008 .01746 L
.13121 .01822 L
.1324 .01884 L
.13302 .01909 L
.13335 .01919 L
.1337 .01928 L
.13403 .01935 L
.13432 .01939 L
.13447 .01941 L
.13462 .01942 L
.13477 .01943 L
.1349 .01943 L
.13506 .01943 L
.13514 .01943 L
.13522 .01943 L
.13538 .01942 L
.13552 .01941 L
.13569 .01939 L
.13584 .01937 L
.13618 .0193 L
.13648 .01923 L
.1368 .01914 L
.13739 .01892 L
.13855 .01834 L
.13963 .01764 L
.14072 .01682 L
Mistroke
.14189 .01593 L
.14223 .01571 L
.1424 .01562 L
.14256 .01556 L
.1427 .01552 L
.14285 .0155 L
.14294 .0155 L
.14302 .01551 L
.14317 .01554 L
.14332 .01559 L
.14347 .01567 L
.14375 .01583 L
.14437 .01629 L
.1456 .01726 L
.14677 .0181 L
.1479 .01877 L
.1484 .019 L
.14895 .01922 L
.1495 .01938 L
.1498 .01945 L
.15008 .01949 L
.15023 .01951 L
.15038 .01953 L
.15052 .01954 L
.15067 .01955 L
.15082 .01955 L
.15091 .01955 L
.15099 .01955 L
.15115 .01955 L
.1513 .01954 L
.15145 .01952 L
.15161 .0195 L
.15193 .01945 L
.15223 .01938 L
.15251 .01931 L
.15314 .01908 L
.15382 .01877 L
.1562 .01719 L
.15746 .01619 L
.15782 .01592 L
.158 .0158 L
.15816 .0157 L
.15831 .01563 L
.15847 .01556 L
.15855 .01554 L
.15863 .01553 L
.15871 .01552 L
.1588 .01552 L
.15888 .01552 L
.15896 .01554 L
Mistroke
.15912 .01558 L
.1592 .01562 L
.15928 .01566 L
.15947 .01576 L
.1601 .01621 L
.16128 .01717 L
.16239 .01802 L
.16359 .01878 L
.16416 .01908 L
.16478 .01933 L
.16512 .01945 L
.16542 .01953 L
.16573 .0196 L
.16587 .01962 L
.16603 .01965 L
.16616 .01966 L
.1663 .01968 L
.16645 .01969 L
.16658 .01969 L
.16672 .0197 L
.16685 .0197 L
.16697 .01969 L
.1671 .01969 L
.16725 .01967 L
.16739 .01966 L
.1677 .01961 L
.16799 .01955 L
.16826 .01948 L
.16882 .0193 L
.16944 .01903 L
.17069 .0183 L
.17292 .01657 L
.17355 .01606 L
.17387 .01584 L
.174 .01575 L
.17415 .01567 L
.17429 .01561 L
.17442 .01557 L
.17455 .01554 L
.17469 .01554 L
.17485 .01556 L
.175 .01561 L
.17513 .01567 L
.17528 .01575 L
.17659 .01677 L
.1778 .01777 L
.17908 .01868 L
.1797 .01905 L
.18028 .01933 L
.18079 .01954 L
Mistroke
.18136 .01971 L
.18165 .01977 L
.18192 .01982 L
.18207 .01984 L
.18221 .01985 L
.18237 .01986 L
.18252 .01987 L
.18266 .01987 L
.18281 .01987 L
.18295 .01986 L
.18307 .01985 L
.18322 .01984 L
.18337 .01982 L
.18369 .01976 L
.184 .01969 L
.18433 .01959 L
.18492 .01937 L
.18609 .01875 L
.18714 .01801 L
.18827 .01709 L
.18946 .01608 L
.18976 .01586 L
.18992 .01576 L
.19008 .01567 L
.19017 .01563 L
.19026 .0156 L
.19035 .01558 L
.19043 .01556 L
.19052 .01556 L
.19059 .01556 L
.19068 .01558 L
.19076 .0156 L
.19091 .01565 L
.19106 .01573 L
.19134 .01591 L
.19197 .01641 L
.1932 .01748 L
.19437 .01842 L
.1955 .01917 L
.196 .01944 L
.19655 .01968 L
.1971 .01986 L
.1974 .01994 L
.19768 .02 L
.19783 .02002 L
.19799 .02004 L
.19812 .02005 L
.19827 .02006 L
.19835 .02007 L
.19843 .02007 L
Mistroke
.19852 .02007 L
.1986 .02007 L
.19875 .02007 L
.19891 .02006 L
.19906 .02004 L
.19921 .02002 L
.19955 .01996 L
.19987 .01989 L
.20022 .01978 L
.20085 .01953 L
.20143 .01923 L
.20262 .01845 L
.20373 .01755 L
.20502 .0164 L
.20533 .01614 L
.20565 .01589 L
.20593 .01572 L
.20609 .01565 L
.20623 .0156 L
.20637 .01559 L
.20651 .0156 L
.20663 .01562 L
.20675 .01567 L
.2069 .01574 L
.20705 .01583 L
.20731 .01603 L
.20848 .01706 L
.20968 .01812 L
.21096 .0191 L
.2116 .01949 L
.21219 .01979 L
.21273 .02001 L
.21304 .02011 L
.21332 .02018 L
.21361 .02024 L
.21374 .02026 L
.21388 .02028 L
.21402 .02029 L
.21416 .0203 L
.21431 .02031 L
.21439 .02031 L
.21447 .02031 L
.2146 .0203 L
.21473 .0203 L
.21485 .02029 L
.21498 .02027 L
.21526 .02023 L
.21553 .02018 L
.21609 .02001 L
.21669 .01976 L
Mistroke
.21778 .01914 L
.21908 .01815 L
.22027 .01707 L
.22084 .01653 L
.22115 .01625 L
.22145 .016 L
.22173 .01581 L
.22188 .01572 L
.22203 .01566 L
.22215 .01563 L
.22228 .01562 L
.22242 .01563 L
.22255 .01567 L
.2227 .01574 L
.22287 .01584 L
.22318 .01607 L
.22375 .01659 L
.22505 .01782 L
.22627 .01889 L
.22743 .01969 L
.22806 .02004 L
.2284 .02019 L
.22875 .02032 L
.22905 .02042 L
.22938 .02049 L
.22952 .02052 L
.22968 .02055 L
.22982 .02056 L
.22996 .02058 L
.2301 .02058 L
.23023 .02059 L
.23038 .02059 L
.23054 .02058 L
.23062 .02058 L
.2307 .02057 L
.23086 .02055 L
.23101 .02053 L
.23116 .02051 L
.23144 .02044 L
.23169 .02037 L
.23226 .02016 L
.23288 .01985 L
.23355 .01944 L
.23477 .01849 L
.23601 .01732 L
.23717 .01619 L
.23747 .01595 L
.23762 .01584 L
.23776 .01576 L
.23791 .0157 L
Mistroke
.238 .01567 L
.23809 .01566 L
.23823 .01566 L
.23838 .0157 L
.23847 .01573 L
.23856 .01577 L
.23871 .01587 L
.23907 .01615 L
.23971 .01677 L
.24095 .01802 L
.24212 .01909 L
.24326 .01994 L
.24376 .02024 L
.24431 .02051 L
.24486 .02071 L
.24516 .0208 L
.24544 .02085 L
.2456 .02088 L
.24575 .0209 L
.24589 .02091 L
.24603 .02092 L
.24612 .02092 L
.24619 .02092 L
.24628 .02092 L
.24636 .02092 L
.24651 .02091 L
.24667 .02089 L
.24683 .02087 L
.24698 .02085 L
.24731 .02077 L
.24764 .02067 L
.24799 .02054 L
.24862 .02023 L
.2492 .01987 L
.2517 .01767 L
.2528 .01652 L
.2531 .01623 L
.25342 .01596 L
.25357 .01585 L
.25373 .01577 L
.25386 .01572 L
.25401 .0157 L
.25416 .01571 L
.2543 .01576 L
.25443 .01582 L
.25457 .01591 L
.25517 .01644 L
.25625 .0176 L
.25748 .01888 L
.25863 .01989 L
Mistroke
.25978 .02066 L
.26038 .02096 L
.26072 .02108 L
.26103 .02118 L
.26119 .02121 L
.26136 .02125 L
.2615 .02127 L
.26166 .02129 L
.26174 .0213 L
.26182 .0213 L
.26198 .02131 L
.26206 .02131 L
.26215 .02131 L
.26225 .02131 L
.26234 .0213 L
.26241 .0213 L
.2625 .02129 L
.26265 .02127 L
.2628 .02125 L
.26293 .02122 L
.26324 .02114 L
.26357 .02103 L
.26417 .02076 L
.26471 .02045 L
.26593 .01952 L
.26814 .01723 L
.26871 .01659 L
.26903 .01627 L
.26932 .016 L
.26946 .01591 L
.2696 .01582 L
.26976 .01577 L
.2699 .01575 L
.27003 .01576 L
.27015 .0158 L
.27028 .01587 L
.27043 .01596 L
.27075 .01624 L
.2711 .01661 L
.27173 .01733 L
.27293 .01869 L
.27416 .01994 L
.27531 .02085 L
.27589 .02121 L
.27652 .02149 L
.27685 .02161 L
.27704 .02166 L
.27721 .0217 L
.27737 .02173 L
.27751 .02175 L
Mistroke
.27759 .02175 L
.27767 .02176 L
.27776 .02177 L
.27784 .02177 L
.27799 .02177 L
.27813 .02177 L
.27829 .02176 L
.27843 .02174 L
.27857 .02172 L
.2787 .0217 L
.27899 .02163 L
.27931 .02153 L
.27959 .02141 L
.28024 .02108 L
.28087 .02065 L
.28155 .0201 L
.28278 .01885 L
.28403 .01739 L
.28464 .01666 L
.2849 .01637 L
.28519 .01609 L
.28535 .01597 L
.28549 .01588 L
.28563 .01583 L
.28577 .0158 L
.28593 .01582 L
.28607 .01588 L
.28623 .01598 L
.2864 .01612 L
.28773 .01767 L
.29011 .0204 L
.29076 .02098 L
.29145 .0215 L
.29211 .02188 L
.29239 .02201 L
.2927 .02212 L
.293 .02221 L
.29316 .02225 L
.29332 .02227 L
.29346 .02229 L
.29359 .0223 L
.29374 .02231 L
.29388 .02231 L
.29404 .02231 L
.29411 .0223 L
.2942 .02229 L
.29435 .02228 L
.2945 .02225 L
.29482 .02218 L
.29516 .02206 L
Mistroke
.29575 .02179 L
.29637 .0214 L
.29749 .02045 L
.29872 .01909 L
.29989 .0176 L
.3004 .01694 L
.30094 .01631 L
.30122 .01605 L
.3013 .01599 L
.30138 .01594 L
.30153 .01589 L
.30168 .01587 L
.30182 .0159 L
.30194 .01595 L
.30208 .01604 L
.30239 .01633 L
.30267 .01666 L
.3033 .01749 L
.30444 .01902 L
.30576 .02061 L
.30633 .0212 L
.30697 .02177 L
.30751 .02217 L
.3081 .02251 L
.30842 .02265 L
.30871 .02276 L
.30885 .0228 L
.30901 .02284 L
.30914 .02286 L
.30929 .02289 L
.30944 .0229 L
.30959 .02291 L
.30967 .02291 L
.30976 .02291 L
.30992 .02291 L
.31 .0229 L
.31009 .02289 L
.31024 .02287 L
.31043 .02283 L
.31059 .02279 L
.31089 .0227 L
.31121 .02256 L
.3118 .02224 L
.31239 .02181 L
.31294 .02132 L
.3142 .01993 L
.3155 .01819 L
.31614 .01729 L
.31646 .01686 L
.31674 .01651 L
Mistroke
.31701 .01621 L
.31717 .01609 L
.31731 .016 L
.31746 .01595 L
.31753 .01595 L
.31762 .01596 L
.31777 .01601 L
.31791 .01611 L
.31808 .01625 L
.31823 .01642 L
.31853 .01679 L
.31919 .01772 L
.32142 .0208 L
.32259 .02206 L
.32318 .02255 L
.32383 .02298 L
.32438 .02325 L
.3247 .02335 L
.32484 .02339 L
.32498 .02342 L
.32511 .02344 L
.32524 .02345 L
.32539 .02347 L
.32553 .02347 L
.32566 .02347 L
.3258 .02346 L
.32593 .02344 L
.32606 .02342 L
.32621 .02339 L
.32635 .02336 L
.32662 .02327 L
.32691 .02315 L
.32723 .02299 L
.3278 .02262 L
.32832 .02218 L
.32953 .0209 L
.33082 .01918 L
.33195 .01751 L
.33254 .01669 L
.33284 .01634 L
.33292 .01627 L
.33301 .01619 L
.33316 .0161 L
.33331 .01605 L
.3334 .01604 L
.33347 .01605 L
.33362 .0161 L
.33377 .0162 L
.3339 .01632 L
.33403 .01645 L
Mistroke
.33431 .01681 L
.33537 .01834 L
.33761 .02136 L
.33822 .022 L
.33887 .02256 L
.33949 .02297 L
.33976 .02311 L
.34005 .02323 L
.34021 .02329 L
.34038 .02334 L
.34054 .02338 L
.34068 .0234 L
.34077 .02342 L
.34085 .02343 L
.34094 .02343 L
.34103 .02344 L
.34112 .02344 L
.34121 .02344 L
.34136 .02343 L
.34151 .02342 L
.34167 .02339 L
.34182 .02336 L
.34195 .02333 L
.34227 .02322 L
.3426 .02307 L
.3432 .02272 L
.34376 .02229 L
.34503 .021 L
.34729 .01798 L
.34791 .01714 L
.34825 .01673 L
.34841 .01656 L
.34857 .01642 L
.34869 .01632 L
.34884 .01623 L
.34898 .01617 L
.34913 .01615 L
.34928 .01617 L
.34936 .01619 L
.34944 .01622 L
.3496 .01631 L
.34974 .01642 L
.35039 .01706 L
.35098 .01774 L
.35232 .01914 L
.35293 .01966 L
.3535 .02004 L
.35381 .02021 L
.3541 .02033 L
.35441 .02044 L
Mistroke
.35459 .02049 L
.35475 .02052 L
.35489 .02054 L
.35504 .02056 L
.35518 .02057 L
.35531 .02057 L
.35546 .02057 L
.35554 .02056 L
.35562 .02056 L
.35577 .02054 L
.35592 .02051 L
.35608 .02047 L
.35625 .02043 L
.35657 .02032 L
.35716 .02004 L
.35772 .01969 L
.35832 .01925 L
.35938 .01833 L
.36062 .01724 L
.36178 .01637 L
.36283 .01579 L
.36311 .01565 L
.36342 .01552 L
.36354 .01547 L
.36368 .01543 L
.36383 .0154 L
.36397 .01539 L
.36411 .0154 L
.36425 .01544 L
.3644 .01552 L
.36449 .01558 L
.36456 .01565 L
.36489 .01601 L
.36519 .01647 L
.36573 .01753 L
.36632 .01906 L
.36696 .02123 L
.36763 .02413 L
.36884 .03114 L
.36998 .04008 L
.3712 .05253 L
.37341 .08313 L
.37597 .13212 L
.37839 .19129 L
.38301 .32753 L
.38791 .4745 L
.39019 .53018 L
.39138 .55412 L
.39264 .57465 L
.39329 .58311 L
Mistroke
.39399 .59075 L
.39463 .59615 L
.39523 .59983 L
.39555 .60125 L
.3957 .60182 L
.39585 .60226 L
.39597 .60259 L
.39611 .60288 L
.39626 .6031 L
.39641 .60325 L
.39649 .6033 L
.39657 .60332 L
.39672 .60329 L
.3968 .60325 L
.39688 .60318 L
.39696 .60308 L
.39706 .60294 L
.39722 .60262 L
.39737 .60222 L
.39766 .60125 L
.39795 .59997 L
.39822 .5985 L
.39884 .59419 L
.39944 .58872 L
.40008 .5815 L
.40231 .54648 L
.40487 .49 L
.4073 .42503 L
.41192 .28773 L
.41683 .14676 L
.41927 .08414 L
.42047 .05553 L
.42099 .04344 L
.42157 .03058 L
.42183 .02485 L
.42198 .02187 L
.42212 .01944 L
.42225 .01821 L
.42239 .01912 L
.42251 .0212 L
.42263 .02345 L
.42375 .04671 L
.42612 .09375 L
.43086 .17857 L
.43543 .24653 L
.43778 .27393 L
.43908 .28628 L
.44029 .29557 L
.44151 .30264 L
.44216 .30538 L
Mistroke
.44249 .30652 L
.44285 .30753 L
.44319 .3083 L
.44334 .30857 L
.4435 .30882 L
.44365 .309 L
.4438 .30916 L
.44389 .30922 L
.44396 .30927 L
.44412 .30934 L
.44426 .30936 L
.4444 .30935 L
.44455 .3093 L
.44471 .3092 L
.44485 .30908 L
.44498 .30893 L
.44527 .30849 L
.44556 .3079 L
.44584 .30721 L
.44646 .30515 L
.44706 .30249 L
.44771 .29897 L
.44888 .29082 L
.44994 .28157 L
.45476 .22221 L
.45941 .15255 L
.46176 .11881 L
.46435 .0861 L
.46683 .0605 L
.4691 .04296 L
.46968 .03953 L
.47031 .03638 L
.47059 .03517 L
.4709 .03407 L
.47119 .03322 L
.47145 .03261 L
.47161 .03233 L
.47178 .0321 L
.47187 .03201 L
.47195 .03194 L
.47204 .03189 L
.47213 .03186 L
.47221 .03185 L
.4723 .03186 L
.47239 .03189 L
.47247 .03194 L
.47262 .03207 L
.47277 .03227 L
.47292 .03251 L
.47307 .03281 L
Mistroke
.47334 .0335 L
.47397 .03564 L
.4746 .03849 L
.47519 .04164 L
.47652 .05034 L
.47894 .07117 L
.48142 .09882 L
.48366 .12884 L
.48849 .20263 L
.49314 .26861 L
.49555 .2935 L
.49676 .3025 L
.49745 .30643 L
.49809 .30928 L
.49869 .31123 L
.49903 .31202 L
.49919 .31231 L
.49935 .31253 L
.49949 .3127 L
.49962 .31282 L
.49977 .31291 L
.49993 .31296 L
.50007 .31296 L
.50023 .31291 L
.50031 .31287 L
.50039 .31281 L
.50054 .31267 L
.50069 .31248 L
.50083 .31226 L
.50114 .31164 L
.50142 .31093 L
.50171 .31001 L
.50278 .30524 L
.50337 .30165 L
.50392 .2978 L
.50514 .28728 L
.50735 .26256 L
.51214 .1927 L
.51676 .12295 L
.51933 .0898 L
.52166 .06537 L
.52283 .05528 L
.5241 .04605 L
.52529 .03902 L
.52587 .03631 L
.52639 .03432 L
.52666 .03349 L
.52696 .03276 L
.52712 .03244 L
.52727 .03221 L
Mistroke
.52741 .03204 L
.52757 .03192 L
.5277 .03186 L
.52784 .03185 L
.52797 .03189 L
.52809 .03197 L
.52822 .0321 L
.52837 .03229 L
.52852 .03256 L
.52866 .03285 L
.52899 .03372 L
.5293 .03476 L
.52987 .0372 L
.53116 .04465 L
.53358 .06427 L
.5358 .08783 L
.54056 .15208 L
.54514 .22078 L
.54768 .25532 L
.55001 .28106 L
.55116 .2911 L
.55177 .29558 L
.55241 .29968 L
.55298 .30268 L
.5536 .30536 L
.55387 .30632 L
.55416 .30721 L
.55444 .30791 L
.5547 .30843 L
.55498 .30888 L
.55514 .30907 L
.55529 .3092 L
.55543 .30929 L
.55556 .30934 L
.5557 .30936 L
.55585 .30935 L
.556 .30929 L
.55608 .30924 L
.55616 .30919 L
.55631 .30905 L
.55645 .30889 L
.55676 .30839 L
.55711 .30764 L
.55775 .30572 L
.55843 .3029 L
.55965 .29592 L
.56089 .28647 L
.56224 .2738 L
.56467 .2452 L
.56962 .17053 L
Mistroke
.57208 .12742 L
.57438 .08412 L
.57659 .03948 L
.5769 .03312 L
.57723 .02624 L
.57738 .02317 L
.57747 .02157 L
.57754 .02017 L
.57768 .0184 L
.57783 .01879 L
.57797 .02095 L
.57812 .02381 L
.57838 .02934 L
.57896 .04244 L
.58356 .1574 L
.58846 .29894 L
.59317 .43808 L
.59557 .50075 L
.59684 .52935 L
.59817 .55535 L
.59937 .57431 L
.6 .58256 L
.60068 .58996 L
.60131 .59536 L
.60188 .5991 L
.60215 .60049 L
.60245 .60168 L
.60259 .60212 L
.60274 .60252 L
.60287 .60281 L
.603 .60303 L
.60315 .60321 L
.60323 .60327 L
.60331 .60331 L
.6034 .60332 L
.60349 .6033 L
.60365 .6032 L
.6038 .60303 L
.60393 .60279 L
.60408 .60245 L
.60424 .602 L
.60457 .60076 L
.60488 .59924 L
.60559 .59447 L
.6062 .58886 L
.60676 .58257 L
.60802 .56447 L
.61031 .51904 L
.61281 .45451 L
.61771 .30529 L
Mistroke
.62243 .17006 L
.62501 .11172 L
.62619 .0898 L
.62744 .07005 L
.62859 .0549 L
.62986 .04154 L
.63101 .03215 L
.63209 .02554 L
.63269 .02266 L
.63335 .02013 L
.63397 .01826 L
.63454 .01695 L
.63506 .01609 L
.6352 .0159 L
.63535 .01573 L
.63549 .0156 L
.63563 .01551 L
.63577 .01544 L
.63592 .01539 L
.63607 .01539 L
.63623 .01541 L
.63638 .01545 L
.63652 .0155 L
.63678 .0156 L
.63795 .0162 L
.63919 .01708 L
.64142 .01903 L
.64255 .01987 L
.64288 .02006 L
.64319 .02022 L
.64347 .02033 L
.64378 .02044 L
.64392 .02048 L
.64406 .02051 L
.6442 .02053 L
.64432 .02055 L
.64444 .02056 L
.64457 .02057 L
.64469 .02057 L
.64483 .02057 L
.64498 .02056 L
.64512 .02054 L
.64528 .02052 L
.64543 .02048 L
.64569 .02041 L
.64598 .0203 L
.64657 .02 L
.64712 .01962 L
.64837 .01845 L
.64961 .01707 L
Mistroke
.64991 .01674 L
.65023 .01644 L
.65041 .0163 L
.6505 .01625 L
.65058 .01621 L
.65066 .01618 L
.65075 .01616 L
.65091 .01615 L
.65105 .01618 L
.6512 .01625 L
.65134 .01634 L
.65147 .01645 L
.65209 .01714 L
.65334 .01887 L
.65443 .02032 L
.65558 .02166 L
.65614 .0222 L
.65677 .0227 L
.65734 .02304 L
.65759 .02317 L
.65787 .02327 L
.65818 .02336 L
.65835 .0234 L
.6585 .02342 L
.65865 .02343 L
.65878 .02344 L
.65893 .02344 L
.65908 .02343 L
.65924 .02342 L
.65931 .02341 L
.6594 .02339 L
.6597 .02332 L
.65987 .02326 L
.66005 .0232 L
.66038 .02304 L
.66101 .02265 L
.6616 .02217 L
.66293 .02073 L
.66409 .01914 L
.66535 .01728 L
.66567 .01683 L
.66601 .01641 L
.66615 .01627 L
.6663 .01615 L
.66639 .0161 L
.66647 .01607 L
.66662 .01604 L
.66678 .01607 L
.66692 .01614 L
.66708 .01626 L
Mistroke
.66724 .01643 L
.66782 .01718 L
.67007 .0204 L
.6712 .02173 L
.67179 .02229 L
.67242 .02277 L
.67297 .02309 L
.67328 .02323 L
.67357 .02333 L
.67371 .02337 L
.67384 .0234 L
.67395 .02343 L
.67408 .02344 L
.67421 .02346 L
.67434 .02347 L
.67447 .02347 L
.67462 .02346 L
.67478 .02345 L
.67492 .02343 L
.67508 .0234 L
.67525 .02336 L
.67557 .02326 L
.67585 .02315 L
.67643 .02283 L
.67697 .02244 L
.67818 .02126 L
.67949 .01962 L
.68074 .01783 L
.68134 .01696 L
.68161 .01661 L
.6819 .01628 L
.68205 .01613 L
.6822 .01603 L
.68234 .01597 L
.68248 .01595 L
.68264 .01598 L
.68278 .01605 L
.68294 .01617 L
.68311 .01634 L
.68444 .01811 L
.68559 .01966 L
.68682 .02108 L
.68752 .02173 L
.68816 .02221 L
.68847 .0224 L
.6888 .02257 L
.68912 .0227 L
.68941 .02279 L
.68969 .02286 L
.68984 .02288 L
Mistroke
.68999 .0229 L
.69014 .02291 L
.69023 .02291 L
.69031 .02291 L
.69046 .02291 L
.69062 .0229 L
.69077 .02288 L
.69093 .02285 L
.69123 .02278 L
.69158 .02265 L
.6919 .02251 L
.69243 .0222 L
.69302 .02178 L
.6942 .02066 L
.69551 .01908 L
.69676 .01741 L
.6973 .0167 L
.69759 .01635 L
.69787 .01608 L
.69802 .01598 L
.69817 .0159 L
.69826 .01588 L
.69834 .01587 L
.6985 .0159 L
.69865 .01596 L
.69878 .01605 L
.69908 .01633 L
.70151 .01936 L
.7027 .02063 L
.70379 .02151 L
.70437 .02185 L
.70466 .02199 L
.70498 .02211 L
.70515 .02216 L
.7053 .02221 L
.70545 .02224 L
.70559 .02227 L
.70576 .02229 L
.70585 .0223 L
.70594 .02231 L
.7061 .02231 L
.70618 .02231 L
.70627 .02231 L
.7064 .0223 L
.70654 .02229 L
.70669 .02227 L
.70683 .02225 L
.70708 .02219 L
.70735 .02211 L
.70796 .02185 L
Mistroke
.70851 .02153 L
.70972 .02057 L
.71083 .01942 L
.71212 .01785 L
.71276 .01706 L
.71334 .01638 L
.71361 .01612 L
.71375 .016 L
.7139 .0159 L
.71404 .01583 L
.71417 .01581 L
.71431 .01581 L
.71443 .01584 L
.71457 .01591 L
.71472 .01602 L
.71499 .01626 L
.7156 .01694 L
.7168 .01838 L
.71809 .01976 L
.71873 .02034 L
.71934 .0208 L
.71992 .02118 L
.72047 .02144 L
.72098 .02162 L
.72124 .02169 L
.72139 .02172 L
.72153 .02174 L
.72168 .02176 L
.72182 .02177 L
.72196 .02177 L
.72205 .02177 L
.72212 .02177 L
.72226 .02177 L
.72239 .02176 L
.72254 .02174 L
.72268 .02172 L
.72297 .02166 L
.72324 .02158 L
.72386 .02133 L
.72446 .021 L
.7251 .02056 L
.72733 .01841 L
.72856 .017 L
.7292 .01629 L
.72953 .01599 L
.72962 .01593 L
.72972 .01587 L
.72981 .01582 L
.72989 .01578 L
.73004 .01575 L
Mistroke
.73012 .01575 L
.73021 .01576 L
.7303 .01578 L
.73039 .01582 L
.73055 .01591 L
.73084 .01614 L
.73115 .01645 L
.73232 .01774 L
.73355 .01904 L
.73471 .02005 L
.73534 .02049 L
.73592 .02081 L
.73656 .02108 L
.73692 .02118 L
.73708 .02122 L
.73725 .02125 L
.73741 .02128 L
.73756 .02129 L
.73771 .0213 L
.73786 .02131 L
.738 .02131 L
.73812 .02131 L
.73826 .0213 L
.73841 .02128 L
.73857 .02126 L
.73874 .02123 L
.73906 .02115 L
.73936 .02105 L
.73964 .02094 L
.74072 .02036 L
.74186 .01948 L
.74302 .01837 L
.74424 .01706 L
.74475 .01653 L
.74528 .01602 L
.74544 .0159 L
.74559 .01581 L
.74573 .01575 L
.74587 .01571 L
.74601 .0157 L
.74616 .01573 L
.74628 .01577 L
.74642 .01585 L
.74673 .01607 L
.747 .01633 L
.74763 .01696 L
.74876 .01813 L
.75007 .01932 L
.75064 .01976 L
.75128 .02017 L
Mistroke
.75181 .02045 L
.75239 .02068 L
.75271 .02077 L
.75285 .02081 L
.753 .02084 L
.75313 .02086 L
.75328 .02089 L
.75343 .0209 L
.75357 .02091 L
.75366 .02092 L
.75374 .02092 L
.7539 .02092 L
.75398 .02092 L
.75406 .02091 L
.75415 .02091 L
.75425 .0209 L
.75442 .02088 L
.75458 .02085 L
.75488 .02078 L
.75518 .0207 L
.75545 .0206 L
.75608 .02033 L
.75669 .01997 L
.75735 .01951 L
.75855 .01849 L
.75971 .01735 L
.7608 .01627 L
.76108 .01602 L
.76135 .01582 L
.7615 .01574 L
.76158 .01571 L
.76166 .01568 L
.7618 .01566 L
.76194 .01566 L
.76209 .0157 L
.76218 .01573 L
.76225 .01577 L
.76254 .01596 L
.7632 .01654 L
.76452 .01784 L
.76574 .01892 L
.76685 .0197 L
.76747 .02004 L
.76803 .02028 L
.76833 .02038 L
.76864 .02046 L
.76881 .0205 L
.76899 .02053 L
.76916 .02056 L
.76931 .02057 L
Mistroke
.76947 .02058 L
.76962 .02059 L
.76975 .02059 L
.7699 .02058 L
.77005 .02057 L
.77014 .02057 L
.77022 .02056 L
.77038 .02054 L
.77052 .02051 L
.77081 .02045 L
.77111 .02037 L
.77174 .02013 L
.77227 .01987 L
.77285 .01952 L
.77536 .01744 L
.77659 .01627 L
.77693 .01598 L
.77712 .01585 L
.77729 .01574 L
.77744 .01568 L
.7776 .01563 L
.77769 .01562 L
.77777 .01562 L
.77785 .01563 L
.77793 .01565 L
.77801 .01567 L
.7781 .01571 L
.77825 .01579 L
.77854 .01599 L
.77919 .01656 L
.78036 .01765 L
.7816 .0187 L
.78276 .01948 L
.78335 .01978 L
.78397 .02003 L
.78433 .02014 L
.78467 .02022 L
.78482 .02024 L
.78497 .02027 L
.78505 .02028 L
.78514 .02029 L
.7853 .0203 L
.78545 .02031 L
.78559 .02031 L
.78574 .02031 L
.78582 .0203 L
.7859 .0203 L
.78605 .02029 L
.78622 .02027 L
.78637 .02024 L
Mistroke
.78652 .02022 L
.78706 .02008 L
.78733 .01999 L
.78763 .01987 L
.78893 .01917 L
.79015 .01827 L
.7914 .01717 L
.79202 .0166 L
.79259 .0161 L
.79286 .01589 L
.79311 .01573 L
.79325 .01567 L
.7934 .01561 L
.79354 .01559 L
.79366 .01559 L
.7938 .01561 L
.79393 .01566 L
.79408 .01572 L
.79423 .01581 L
.79483 .01627 L
.79722 .01833 L
.79788 .0188 L
.79857 .01923 L
.79917 .01954 L
.79949 .01967 L
.79982 .01979 L
.80012 .01988 L
.80044 .01996 L
.80058 .01999 L
.80073 .02001 L
.80087 .02003 L
.801 .02005 L
.80115 .02006 L
.8013 .02007 L
.80144 .02007 L
.80158 .02007 L
.80171 .02006 L
.80183 .02006 L
.80197 .02005 L
.80211 .02003 L
.80243 .01998 L
.80279 .0199 L
.80312 .0198 L
.80343 .01969 L
.80463 .01909 L
.80579 .01831 L
.80688 .01742 L
.80809 .01636 L
.80841 .0161 L
.80875 .01585 L
Mistroke
.80891 .01574 L
.80907 .01566 L
.80921 .01561 L
.80936 .01557 L
.8095 .01556 L
.80965 .01558 L
.80973 .0156 L
.80981 .01563 L
.80996 .01569 L
.81025 .01587 L
.81052 .01607 L
.81179 .01714 L
.81287 .01802 L
.81402 .01881 L
.81464 .01916 L
.81521 .01942 L
.81578 .01962 L
.81603 .0197 L
.81631 .01976 L
.81661 .01981 L
.81678 .01984 L
.81694 .01985 L
.81708 .01986 L
.81721 .01987 L
.81737 .01987 L
.81751 .01987 L
.81767 .01986 L
.81775 .01985 L
.81783 .01985 L
.81799 .01983 L
.81813 .01981 L
.81846 .01975 L
.81881 .01966 L
.81941 .01946 L
.81996 .01922 L
.82123 .01848 L
.82254 .0175 L
.82377 .01647 L
.82435 .01601 L
.82466 .01579 L
.82481 .0157 L
.82496 .01563 L
.82511 .01557 L
.82519 .01555 L
.82527 .01554 L
.82536 .01554 L
.82544 .01554 L
.82553 .01555 L
.82562 .01558 L
.8257 .0156 L
Mistroke
.82579 .01564 L
.82595 .01572 L
.82624 .01591 L
.82848 .0177 L
.82973 .01857 L
.83089 .01918 L
.83148 .0194 L
.83178 .01949 L
.8321 .01957 L
.83229 .01961 L
.83246 .01964 L
.83262 .01966 L
.83271 .01967 L
.8328 .01968 L
.83296 .01969 L
.83311 .0197 L
.83319 .0197 L
.83328 .0197 L
.83343 .01969 L
.83358 .01969 L
.83367 .01968 L
.83374 .01967 L
.83388 .01966 L
.83404 .01964 L
.8343 .01959 L
.83459 .01953 L
.83522 .01933 L
.83582 .01909 L
.83689 .0185 L
.83803 .01771 L
.83926 .01673 L
.83991 .01621 L
.84026 .01594 L
.84059 .01572 L
.84073 .01565 L
.84088 .01558 L
.84096 .01556 L
.84104 .01554 L
.84119 .01552 L
.84128 .01552 L
.84136 .01552 L
.84145 .01554 L
.84153 .01556 L
.84169 .01562 L
.84185 .01571 L
.84246 .01612 L
.84302 .01656 L
.8442 .0175 L
.84547 .01837 L
.84609 .01872 L
Mistroke
.84667 .01901 L
.84725 .01923 L
.84777 .01938 L
.84805 .01945 L
.84832 .01949 L
.84845 .01951 L
.8486 .01953 L
.84875 .01954 L
.8489 .01955 L
.84902 .01955 L
.84916 .01955 L
.84929 .01955 L
.8494 .01955 L
.84954 .01954 L
.84968 .01952 L
.84982 .01951 L
.84995 .01949 L
.85023 .01944 L
.8505 .01938 L
.85111 .0192 L
.8517 .01896 L
.85233 .01864 L
.8547 .01702 L
.85596 .01604 L
.85632 .01579 L
.8565 .01569 L
.85666 .0156 L
.85681 .01555 L
.85697 .01551 L
.85712 .0155 L
.85721 .0155 L
.8573 .01552 L
.85745 .01556 L
.85754 .01559 L
.85762 .01563 L
.85792 .0158 L
.85849 .0162 L
.85977 .0172 L
.86088 .01799 L
.86208 .01868 L
.86274 .01898 L
.86304 .01908 L
.86336 .01919 L
.86364 .01926 L
.86394 .01933 L
.86411 .01936 L
.86426 .01938 L
.86441 .0194 L
.86456 .01941 L
.8647 .01942 L
Mistroke
.86485 .01943 L
.86498 .01943 L
.86511 .01943 L
.86526 .01943 L
.8654 .01942 L
.86548 .01941 L
.86556 .0194 L
.86571 .01939 L
.86599 .01935 L
.86628 .01929 L
.86681 .01915 L
.86745 .01891 L
.86805 .01863 L
.86939 .01783 L
.87065 .01692 L
.87126 .01644 L
.87182 .01602 L
.87209 .01584 L
.87238 .01566 L
.87252 .0156 L
.87266 .01554 L
.87278 .01551 L
.87291 .01549 L
.87307 .01549 L
.87321 .01551 L
.87336 .01555 L
.87344 .01558 L
.87352 .01562 L
.87409 .01597 L
.87539 .01695 L
.87658 .0178 L
.87771 .01847 L
.87831 .01876 L
.87894 .019 L
.87927 .0191 L
.87962 .01919 L
.87994 .01925 L
.88024 .01929 L
.8804 .01931 L
.88055 .01932 L
.88069 .01933 L
.88084 .01933 L
.88092 .01933 L
.881 .01933 L
.88108 .01933 L
.88117 .01932 L
.88131 .01931 L
.88147 .0193 L
.88162 .01928 L
.88176 .01926 L
Mistroke
.88207 .01921 L
.88262 .01907 L
.88327 .01885 L
.88388 .01857 L
.8851 .01788 L
.88642 .01695 L
.88701 .0165 L
.88765 .01603 L
.88795 .01583 L
.88826 .01565 L
.88838 .01558 L
.88852 .01553 L
.88867 .01549 L
.88881 .01547 L
.88897 .01548 L
.88905 .01549 L
.88913 .01551 L
.88928 .01556 L
.88944 .01563 L
.89002 .01598 L
.89134 .01696 L
.89249 .01776 L
.89371 .01846 L
.8943 .01873 L
.89486 .01893 L
.89537 .01908 L
.89565 .01914 L
.89592 .01918 L
.89606 .0192 L
.89621 .01922 L
.89634 .01923 L
.89648 .01924 L
.89663 .01925 L
.89671 .01925 L
.89679 .01925 L
.89694 .01925 L
.89708 .01924 L
.89721 .01923 L
.89735 .01922 L
.8976 .01919 L
.89787 .01915 L
.89817 .01908 L
.89878 .01891 L
.89945 .01865 L
.90065 .01803 L
.90303 .01637 L
.90368 .01591 L
.90404 .01568 L
.90421 .01559 L
.90429 .01556 L
Mistroke
.90437 .01553 L
.90453 .01548 L
.90461 .01547 L
.90469 .01546 L
.90477 .01546 L
.90485 .01547 L
.90494 .01548 L
.90503 .0155 L
.90518 .01555 L
.90531 .01561 L
.90562 .01578 L
.9079 .01741 L
.90911 .01815 L
.90974 .01848 L
.91041 .01876 L
.91102 .01895 L
.91137 .01904 L
.91169 .0191 L
.91184 .01912 L
.91198 .01914 L
.91211 .01916 L
.91225 .01917 L
.9124 .01918 L
.91254 .01918 L
.91269 .01918 L
.91278 .01918 L
.91286 .01918 L
.913 .01917 L
.91315 .01916 L
.9133 .01915 L
.91343 .01913 L
.91369 .01909 L
.91396 .01904 L
.91458 .01887 L
.91515 .01867 L
.91636 .01808 L
.91748 .01738 L
.91878 .01645 L
.91941 .01599 L
.91969 .01581 L
.91999 .01563 L
.92013 .01557 L
.92028 .01551 L
.92041 .01547 L
.92055 .01545 L
.92069 .01545 L
.92083 .01547 L
.92096 .01551 L
.92109 .01556 L
.92138 .0157 L
Mistroke
.92169 .01589 L
.92226 .01629 L
.92357 .01723 L
.92476 .01799 L
.92534 .0183 L
.92598 .01859 L
.92653 .01879 L
.92713 .01896 L
.92746 .01903 L
.92777 .01908 L
.92794 .0191 L
.92809 .01911 L
.92818 .01912 L
.92827 .01913 L
.92836 .01913 L
.92845 .01913 L
.92859 .01913 L
.92872 .01913 L
.92887 .01912 L
.92896 .01912 L
.92903 .01911 L
.92934 .01908 L
.92949 .01906 L
.92966 .01903 L
.93029 .01888 L
.93089 .01868 L
.93202 .01816 L
.93323 .01743 L
.93455 .01651 L
.9351 .01611 L
.93569 .01572 L
.93586 .01563 L
.93602 .01555 L
.93617 .0155 L
.93626 .01548 L
.93633 .01546 L
.93649 .01545 L
.93663 .01546 L
.93671 .01547 L
.93679 .01549 L
.93694 .01554 L
.9371 .01561 L
.93725 .01569 L
.93758 .01589 L
.93826 .01637 L
.93948 .01723 L
.94074 .01802 L
.94136 .01834 L
.94194 .01859 L
.94245 .01877 L
Mistroke
.94301 .01893 L
.9433 .01899 L
.94357 .01904 L
.94371 .01905 L
.94386 .01907 L
.94394 .01908 L
.94403 .01908 L
.94417 .01909 L
.94425 .01909 L
.94433 .0191 L
.94448 .0191 L
.94464 .01909 L
.94473 .01909 L
.94481 .01908 L
.94496 .01907 L
.9451 .01906 L
.94541 .01902 L
.94569 .01896 L
.94599 .01889 L
.94654 .01873 L
.94718 .01848 L
.94785 .01816 L
.94907 .01744 L
.95031 .01657 L
.95097 .0161 L
.95133 .01586 L
.95166 .01566 L
.95181 .01559 L
.95195 .01553 L
.95203 .0155 L
.95212 .01548 L
.95226 .01545 L
.95234 .01544 L
.95243 .01544 L
.95252 .01545 L
.95261 .01547 L
.95276 .01551 L
.95293 .01558 L
.95324 .01575 L
.95354 .01594 L
.95409 .01633 L
.95534 .01721 L
.95651 .01794 L
.95756 .01847 L
.95815 .0187 L
.9587 .01886 L
.95897 .01893 L
.95925 .01898 L
.95941 .01901 L
.95956 .01903 L
Mistroke
.9597 .01905 L
.95985 .01906 L
.96001 .01907 L
.96015 .01907 L
.96031 .01908 L
.9604 .01908 L
.96048 .01907 L
.96063 .01907 L
.96076 .01906 L
.96091 .01905 L
.96107 .01903 L
.96137 .01898 L
.9617 .01892 L
.96228 .01876 L
.96297 .0185 L
.9636 .01821 L
.96611 .01663 L
.96721 .01585 L
.96751 .01567 L
.96768 .01559 L
.96784 .01552 L
.96798 .01548 L
.96807 .01546 L
.96814 .01545 L
.96828 .01544 L
.96842 .01546 L
.96858 .01549 L
.96872 .01554 L
.96903 .0157 L
.96961 .01606 L
.97068 .01683 L
.97191 .01765 L
.97306 .01829 L
.97378 .0186 L
.97455 .01885 L
.97476 .0189 L
.97499 .01895 L
.9752 .01899 L
.97541 .01902 L
.9756 .01904 L
.97571 .01905 L
.97582 .01906 L
.97592 .01906 L
.97601 .01907 L
.9761 .01907 L
.97619 .01907 L
Mfstroke
1 0 0 r
[ ] 0 setdash
.03968 .01472 m
.03968 .01908 L
s
.05556 .01472 m
.05556 .0191 L
s
.07143 .01472 m
.07143 .01913 L
s
.0873 .01472 m
.0873 .01918 L
s
.10317 .01472 m
.10317 .01925 L
s
.11905 .01472 m
.11905 .01933 L
s
.13492 .01472 m
.13492 .01943 L
s
.15079 .01472 m
.15079 .01955 L
s
.16667 .01472 m
.16667 .0197 L
s
.18254 .01472 m
.18254 .01987 L
s
.19841 .01472 m
.19841 .02007 L
s
.21429 .01472 m
.21429 .02031 L
s
.23016 .01472 m
.23016 .02059 L
s
.24603 .01472 m
.24603 .02092 L
s
.2619 .01472 m
.2619 .02131 L
s
.27778 .01472 m
.27778 .02177 L
s
.29365 .01472 m
.29365 .02231 L
s
.30952 .01472 m
.30952 .02291 L
s
.3254 .01472 m
.3254 .02347 L
s
.34127 .01472 m
.34127 .02344 L
s
.35714 .01472 m
.35714 .02005 L
s
.37302 .01472 m
.37302 .07684 L
s
.38889 .01472 m
.38889 .49981 L
s
.40476 .01472 m
.40476 .49268 L
s
.42063 .01472 m
.42063 .05165 L
s
.43651 .01472 m
.43651 .25988 L
s
.45238 .01472 m
.45238 .25452 L
s
.46825 .01472 m
.46825 .0488 L
s
.48413 .01472 m
.48413 .13555 L
s
.5 .01472 m
.5 .31296 L
s
.51587 .01472 m
.51587 .13555 L
s
.53175 .01472 m
.53175 .0488 L
s
.54762 .01472 m
.54762 .25452 L
s
.56349 .01472 m
.56349 .25988 L
s
.57937 .01472 m
.57937 .05165 L
s
.59524 .01472 m
.59524 .49268 L
s
.61111 .01472 m
.61111 .49981 L
s
.62698 .01472 m
.62698 .07684 L
s
.64286 .01472 m
.64286 .02005 L
s
.65873 .01472 m
.65873 .02344 L
s
.6746 .01472 m
.6746 .02347 L
s
.69048 .01472 m
.69048 .02291 L
s
.70635 .01472 m
.70635 .02231 L
s
.72222 .01472 m
.72222 .02177 L
s
.7381 .01472 m
.7381 .02131 L
s
.75397 .01472 m
.75397 .02092 L
s
.76984 .01472 m
.76984 .02059 L
s
.78571 .01472 m
.78571 .02031 L
s
.80159 .01472 m
.80159 .02007 L
s
.81746 .01472 m
.81746 .01987 L
s
.83333 .01472 m
.83333 .0197 L
s
.84921 .01472 m
.84921 .01955 L
s
.86508 .01472 m
.86508 .01943 L
s
.88095 .01472 m
.88095 .01933 L
s
.89683 .01472 m
.89683 .01925 L
s
.9127 .01472 m
.9127 .01918 L
s
.92857 .01472 m
.92857 .01913 L
s
.94444 .01472 m
.94444 .0191 L
s
.96032 .01472 m
.96032 .01908 L
s
.97619 .01472 m
.97619 .01907 L
s
.015 w
.03968 .01908 Mdot
.05556 .0191 Mdot
.07143 .01913 Mdot
.0873 .01918 Mdot
.10317 .01925 Mdot
.11905 .01933 Mdot
.13492 .01943 Mdot
.15079 .01955 Mdot
.16667 .0197 Mdot
.18254 .01987 Mdot
.19841 .02007 Mdot
.21429 .02031 Mdot
.23016 .02059 Mdot
.24603 .02092 Mdot
.2619 .02131 Mdot
.27778 .02177 Mdot
.29365 .02231 Mdot
.30952 .02291 Mdot
.3254 .02347 Mdot
.34127 .02344 Mdot
.35714 .02005 Mdot
.37302 .07684 Mdot
.38889 .49981 Mdot
.40476 .49268 Mdot
.42063 .05165 Mdot
.43651 .25988 Mdot
.45238 .25452 Mdot
.46825 .0488 Mdot
.48413 .13555 Mdot
.5 .31296 Mdot
.51587 .13555 Mdot
.53175 .0488 Mdot
.54762 .25452 Mdot
.56349 .25988 Mdot
.57937 .05165 Mdot
.59524 .49268 Mdot
.61111 .49981 Mdot
.62698 .07684 Mdot
.64286 .02005 Mdot
.65873 .02344 Mdot
.6746 .02347 Mdot
.69048 .02291 Mdot
.70635 .02231 Mdot
.72222 .02177 Mdot
.7381 .02131 Mdot
.75397 .02092 Mdot
.76984 .02059 Mdot
.78571 .02031 Mdot
.80159 .02007 Mdot
.81746 .01987 Mdot
.83333 .0197 Mdot
.84921 .01955 Mdot
.86508 .01943 Mdot
.88095 .01933 Mdot
.89683 .01925 Mdot
.9127 .01918 Mdot
.92857 .01913 Mdot
.94444 .0191 Mdot
.96032 .01908 Mdot
.97619 .01907 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{756, 146},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000;d0000TR000`400?l00000o`00003ooooooooo
ooooooKooooo003ooooooooooooom_ooool00?ooooooooooooofooooo`00ooooooooooooooKooooo
003ooooooooooooom_ooool002Kooooo0ol00004ooooo`;o0000:oooool3o`0002cooooo0_l0000^
ooooo`?o0000:_ooool3o`0000Cooooo0_l0000Zooooo`?o00001?ooool2o`0002_ooooo0ol0000]
ooooo`;o0000;oooool3o`0002_ooooo0ol00004ooooo`;o0000;Oooool3o`0000Cooooo0_l0000[
ooooo`?o0000:oooool2o`0002kooooo0ol0000[ooooo`?o00001?ooool2o`0001Wooooo000Woooo
o`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000:Oooool01Ol0003ooooooooooooo
oooo000002[ooooo00Co0000oooooooooooo0000;?ooool01Ol0003ooooooooooooooooo000002[o
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Zooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo0000:Oooool01Ol0003ooooooooooooooooo000002_ooooo00Co
0000oooooooooooo0000;Oooool01Ol0003ooooooooooooooooo000002_ooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool0000]ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo0000:Oooool01Ol0003ooooooooooooooooo000002Wooooo00Co0000oooooooooooo0000
;?ooool01Ol0003ooooooooooooooooo000002_ooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool0000Hooooo`007oooool5o`0000?ooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool0000Sooooo`Go00001Oooool00ol0003oooooooooo`0Xooooo`04o`000?oooooooooo
o`00033ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0002;ooooo1Ol00003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000
8oooool5o`0000Gooooo00?o0000ooooooooool0:Oooool01?l0003oooooooooool0000aooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Uoooo
o`Go00000oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0002?ooooo1Ol00005
ooooo`03o`000?oooooooooo02Oooooo00Co0000oooooooooooo0000<?ooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00006?ooool002Oooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool0000]ooooo`03o`000?oooooooooo02Sooooo
00Co0000oooooooooooo0000<?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo0000:_ooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0002gooooo00?o0000ooooooooool0:Oooool01?l0003oooooooooool0000aooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000]ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo0000;Oooool00ol0003oooooooooo`0Wooooo`04
o`000?ooooooooooo`00033ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0001Sooooo000Wooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo0000:Oooool4o`0002_ooooo00Co0000oooooooooooo0000;?ooool4o`0002_ooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool0000Zooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo0000:Oooool4o`0002cooooo00Co0000oooooooooooo0000;Oooool4o`00
02cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000]ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo0000:Oooool4o`0002[ooooo00Co0000oooooooooooo0000
;?ooool4o`0002cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Hooooo`00
9_ooool2o`0000Cooooo00Co0000oooooooooooo0000:Oooool00ol0003oooooooooo`0/ooooo`04
o`000?ooooooooooo`0002cooooo00?o0000ooooooooool0:oooool2o`0000Cooooo00Co0000oooo
oooooooo0000:Oooool2o`0000Cooooo00Co0000oooooooooooo0000:Oooool00ol0003ooooooooo
o`0]ooooo`04o`000?ooooooooooo`0002gooooo00?o0000ooooooooool0;?ooool2o`0000Cooooo
00Co0000oooooooooooo0000;?ooool2o`0000Cooooo00Co0000oooooooooooo0000:Oooool00ol0
003oooooooooo`0[ooooo`04o`000?ooooooooooo`0002cooooo00?o0000ooooooooool0;?ooool2
o`0000Cooooo00Co0000oooooooooooo00006?ooool002Oooooo00?o0000ooooooooool00oooool2
o`0002[ooooo1Ol0000[ooooo`;o0000;Oooool5o`0002[ooooo00?o0000ooooooooool00oooool2
o`0002_ooooo00?o0000ooooooooool00oooool2o`0002[ooooo1Ol0000/ooooo`;o0000;_ooool5
o`0002_ooooo00?o0000ooooooooool00oooool2o`0002kooooo00?o0000ooooooooool00oooool2
o`0002[ooooo1Ol0000Zooooo`;o0000;Oooool5o`0002_ooooo00?o0000ooooooooool00oooool2
o`0001Wooooo003ooooooooooooom_ooool00?ooooooooooooofooooo`00ooooooooooooooKooooo
003ooooooooooooom_ooool001gooooo0_l00005ooooolgo00008_ooool2o`0000Coooooc_l0000R
ooooo`;o00001?ooooo>o`0001Oooooo000Looooo`04o`000?ooooooooooo`0000Cooooo00Go0000
ooooooooooooooooo`00000`ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0;_oo
ool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07ooo
ool01?l0003oooooooooool00003ooooo`03o`000?oooooo0000033ooooo00?o0000ooooooooool0
;oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0Oooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02gooooo00?o0000oooooooo
ool0;_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool05Oooool001cooooo00Co0000oooooooooooo00001?ooool2o`0003Sooooo00?o003ooooooooo
ool0:Oooool00ol0003oooooooooo`0Vooooo`03o`00oooooooooooo01[ooooo00?o003ooooooooo
ool07?ooool2o`00027ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`3:oooo
o`03o`000?oooooooooo01oooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`04
ooooo`Koo`0000?oooooool00?oo00001ooo001?ooooo`03o`000?oooooooooo04kooooo3?oo0000
0oooooooo`00ool00004ool000?ooooo00?o0000ooooooooool05Oooool001cooooo00Co0000oooo
oooooooo00001?ooool01?l0003oooooooooooooool3o`00o`04ooooool00?oo003oooooo`?o003o
00Coooooo`00ool00?oooooo0_l00?l2ooooo`co003o00?oooooo`00ool00?l04ol00?l2ooooo`03
o`00oooooooooooo00;o003o00Coooooo`00ool00?oooooo0_l00?l3ooooo`?o003o2oooool00ol0
0?ooooooooooo`0=ooooo`03o`000?oooooooooo01Sooooo0_l00?l00ooooooo003oo`00o`02oooo
o`06o`00ooooooooooooooooool00?oooooo0_l00?l2ooooo`;o003o0_ooool01Ol00?oooooooooo
ool00?oooooo00;o003o00Koooooo`00ool00?ooooooo`00ooooool:o`00o`05ooooool00?oo003o
o`00ooooool01Ol00?l00ooooooo003oo`00o`04o`00o`03ooooool00?oo003o00Go003o00?ooooo
o`00ooooool00oooool00ol0003oooooooooo`0Oooooo`04o`000?ooooooooooo`0000?ooooo0ol0
00001Oooooooo`00ool00?oo003ooooo00coo`0000?oooooool00?oo00001ooo00000oooooooo`00
ool00007ool00003oooooooo003oo`0000[oo`0000?oooooool00?oo00001?oo00000oooooooo`00
ooooo`02ooooo`05ool00?ooooooooooool00?ooool00ooo0002ooooo`04ool00?ooooooooooool0
00;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?ooooooooooool000;ooooo00Go
o`00ooooooooooooooooool00002ooooo`04ool00?ooooooooooool000?ooooo00Coo`00oooooooo
ooooo`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`000_oo
ool00ooo003oooooooooo`03ool00005oooooooo003ooooooooooooo00000oooool00ooo003ooooo
ool00005ool00003oooooooo003oo`0000Ooo`0000?oooooool00?oo00002_oo00000oooooooo`00
ool00007ool00003oooooooo003oo`0000Ooo`0000?oooooool00?oo00001ooo0002ooooo`;o0000
8Oooool01?l0003oooooooooool00003ooooo`;o00000oooool2o`00o`Koo`0000?o003oool00?oo
00002_oo00000ol00?ooo`00ool0000:ool00003oooooooo003oo`0000[oo`0000?o003oool00?oo
00002_oo00000ol00?ooo`00ool00007ool00003o`00oooo003ooooo00;ooooo00Coo`00oooooooo
ooooo`000_ooool01?oo003ooooooooooooo0003ooooo`04ool00?ooooooooooool000;ooooo00Co
o`00ooooooooooooo`000oooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool0
00?ooooo00Coo`00ooooooooooooo`000_ooool01_oo003ooooooooooooo003oooooo`00o`coo`00
00?o003oool00?oo00002_oo00000ol00?ooo`00ool0000:ool00003o`00oooo003oo`0000[oo`00
00?o003oool00?oo00002_oo00000ol00?ooo`00ool00004ool000;ooooo0_l0000Gooooo`007?oo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo02Gooooo00?o003oooooooooool0
0_l00?l01?oooooo003oo`00ooooool2o`00o`;ooooo0_l00?l01?oooooo003oo`00ooooool2o`00
o`;ooooo0_l00?l2ooooo`06o`00oooooooo003oo`00oooooooo003o3Oooool00ol00?oooooooooo
o`0=ooooo`03o`000?oooooooooo00gooooo00?o003oooooooooool02?ooool00ol00?oooooooooo
o`02ooooo`;o003o00?oooooo`00ool00?l01?l00?l01?oooooo003oo`00ooooool2o`00o`04oooo
ool00?oo003oooooo`;o003o0_ooool2o`00o`04ooooool00?oo003oooooo`;o003o9oooool00ol0
003oooooooooo`0Oooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooooooo0ooo
00000oooooooo`00ool0000:ool00003oooooooo003oo`0000Ooo`0000?oooooool00?oo00001ooo
00000oooooooo`00ool0000:ool00003oooooooo003oo`0000Ooo`0000?oooooool00?oo00001ooo
0002ooooo`04ool00?ooooooooooool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04
ool00?ooooooooooool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?oooooo
ooooool000?ooooo00Coo`00ooooooooooooo`000_ooool01Ooo003oooooooooooooooooo`0000;o
oooo00Coo`00ooooooooooooo`000_ooool00ooo003oooooooooo`09ool00003oooooooo003oo`00
00Ooo`0000?oooooool00?oo00001ooo00000oooooooo`00ool0000:ool00003oooooooo003oo`00
00Ooo`0000?oooooool00?oo00001ooo00000oooooooo`00ool00007ool000?ooooo00?o0000oooo
ooooool07oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Cooooo1_oo0000
0oooooooo`00ool0000:ool00003oooooooo003oo`0000[oo`0000?oooooool00?oo00002_oo0000
0oooooooo`00ool0000:ool00003oooooooo003oo`0000Ooo`0000?oooooool00?ooool00_ooool0
1?oo003ooooooooooooo0002ooooo`04ool00?l00?ooooooool000?ooooo00Coo`00oooooooooooo
o`000_ooool01?oo003ooooooooooooo0003ooooo`04ool00?ooooooooooool000;ooooo00Coo`00
ooooooooooooo`000_ooool01Ol00?ooo`00ooooooooooooo`0000;ooooo00Coo`00oooooooooooo
o`000_ooool<ool00003oooooooo003oo`0000[oo`0000?oooooool00?oo00002_oo00000ooooooo
o`00ool0000:ool00003oooooooo003oo`0000[oo`0000?oooooool00?oo00001?oo0003ooooo`03
o`000?oooooooooo01Gooooo000Looooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool0B?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00gooooo00?o0000oooooooo
ool03Oooool00ol00?ooooooooooo`1Cooooo`03o`000?oooooooooo01oooooo00Co0000oooooooo
oooo00000oooool01?l0003oooooooooooooool3ool00003oooooooo003oo`0000[oo`0000?ooooo
ool00?oo00001ooo00000oooooooo`00ool00007ool00003oooooooo003oo`0000[oo`0000?ooooo
ool00?oo00001ooo00000oooooooo`00ool00007ool000;ooooo00Coo`00ooooooooooooo`000_oo
ool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`000_ooool01Ooo003o
ooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`000oooool01?oo003ooooooooooooo
0002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo0002ooooo`03
ool00?oooooooooo00Woo`0000?oooooool00?oo00001ooo00000oooooooo`00ool00007ool00003
oooooooo003oo`0000[oo`0000?oooooool00?oo00001ooo00000oooooooo`00ool00007ool00003
oooooooo003oo`0000Ooo`000oooool00ol0003oooooooooo`0Oooooo`04o`000?ooooooooooo`00
00?ooooo00?o0000ooooooooool05?ooool3ool00003oooooooo003oo`0000[oo`0000?oooooool0
0?oo00002_oo00000oooooooo`00ool0000:ool00003oooooooo003oo`0000Ooo`0000?o003oool0
0?ooool00_ooool01?oo003ooooooooooooo0002ooooo`04ool00?l00?ooooooool000?ooooo00Co
o`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0003ooooo`04ool00?ooooooooooool0
00;ooooo00Coo`00ooooooooooooo`000_ooool01Ol00?ooo`00ooooooooooooo`0000;ooooo00Ko
o`00ooooooooooooo`00ooooool00?l<ool00003oooooooo003oo`0000[oo`0000?oooooool00?oo
00002_oo00000oooooooo`00ool0000:ool001Oooooo00?o0000ooooooooool05Oooool001gooooo
0_l00005ooooo`03o`000?oooooooooo04Sooooo00?o003oooooooooool02?ooool00ol00?oooooo
ooooo`07ooooo`03o`00oooooooooooo00?ooooo00?o0000ooooooooool00_ooool2o`00o`Wooooo
00?o003oooooooooool02?ooool00ol00?ooooooooooo`18ooooo`03o`000?oooooooooo023ooooo
0_l00004ooooo`03o`000?oooooooooo03Wooooo0ooo00000oooooooo`00ool00004ool000Gooooo
00Coo`00ooooooooooooo`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00oooo
ooooooooo`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`00
0oooool01?oo003ooooooooooooo0002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo
003ooooooooooooo0002ooooo`03ool00?oooooooooo00?ooooo1_oo00001?ooooooo`00ool00?oo
000nooooo`03o`000?oooooooooo023ooooo0_l00004ooooo`;o0000B_ooool01Ooo003ooooooooo
ooooooooo`0000;ooooo00Ooo`00ooooooooooooo`00o`00ooooooooo`0000?ooooo00Ooo`00oooo
ooooooooo`00o`00ooooooooo`0000;ooooo00Soo`00ooooooooooooooooool00?oooooo003oool0
00;ooooo00Coo`00ooooooooooooo`000_ooool01Ol00?ooo`00ooooooooooooo`0000;ooooo00Go
o`00ooooooooooooo`00o`00o`1:ooooo`;o00005oooool002Cooooo00?o0000ooooooooool0B?oo
ool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Oooooo0_l00?l4ooooo`03o`000?oo
oooooooo00;ooooo0_l00?l9ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool0B?oo
ool00ol0003oooooooooo`0Vooooo`;o0000BOooool01?oo003ooooooooooooo0002ooooo`05ool0
0?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo0002ooooo`05ool00?oooooooooo
oooooooo00000_ooool01?oo003ooooooooooooo0003ooooo`04ool00?ooooooooooool000;ooooo
00Goo`00ooooooooooooooooool00002ooooo`04ool00?ooooooooooool000;ooooo00?oo`00oooo
ooooool0B_ooool2o`0002Sooooo00?o0000ooooooooool0BOooool01Ooo003ooooooooooooooooo
o`0000;ooooo00Coo`00ooooooooooooo`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo
00Coo`00o`00ooooooooo`000_ooool02?oo003oooooooooooooooooo`00ooooool00?ooo`000_oo
ool01?oo003ooooooooooooo0003ooooo`04ool00?ooooooooooool000;ooooo00Goo`00oooooooo
ooooo`00o`00o`1;ooooo`03o`000?oooooooooo01Gooooo000Tooooo`03o`000?oooooooooo05?o
oooo00?o003oooooooooool03Oooool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo00So
oooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`18ooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool0B?ooool01?oo003ooooooooooooo0002ooooo`05ool00?oooooooooo
oooooooo00000_ooool01?oo003ooooooooooooo0002ooooo`05ool00?oooooooooooooooooo0000
0_ooool01?oo003ooooooooooooo0003ooooo`04ool00?ooooooooooool000;ooooo00Goo`00oooo
ooooooooooooool00002ooooo`04ool00?ooooooooooool000;ooooo00?oo`00ooooooooool0Booo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo04Wooooo00Goo`00oooooooooooooooo
ool00002ooooo`07ool00?ooooooooooool00?l00?ooooooool00003ooooo`07ool00?oooooooooo
ool00?l00?ooooooool00002ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooo
oooooooo0002ooooo`05ool00?ooooooooooo`00oooo00000_ooool01?oo003ooooooooooooo0002
ooooo`03ool00?oooooooooo04[ooooo00?o0000ooooooooool05Oooool002Cooooo00?o0000oooo
ooooool0B?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Oooooo0_l00?l4oooo
o`03o`000?oooooooooo00?ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`1Coooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0B?ooool01?oo003ooooooooooooo0002
ooooo`05ool00?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo0002ooooo`05ool0
0?oooooooooooooooooo00000_ooool01?oo003ooooooooooooo0003ooooo`04ool00?oooooooooo
ool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`04ool00?ooooooooooool000;ooooo
00?oo`00ooooooooool0Boooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo04Wooooo
00Goo`00ooooooooooooooooool00002ooooo`03ool00?ooooooo`0000;oo`0000?oooooool00?oo
ool00_ooool00ooo003oooooool00002ool00005oooooooo003ooooooooooooo00000oooool00ooo
003o003oool00002ool00005oooooooo003ooooooooooooo00000_ooool3ool00005oooooooo003o
oooooooooooo00000_ooool00ooo003o003oooooo`1:ooooo`03o`000?oooooooooo01Gooooo000T
ooooo`03o`000?oooooooooo04Wooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`07
ooooo`;o003o1?ooool00ol0003oooooooooo`02ooooo`;o003o2Oooool00ol00?ooooooooooo`07
ooooo`03o`00oooooooooooo04Wooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`18
ooooo`04ool00?ooooooooooool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`05ool0
0?ooooooooooool00?ooool00ooo0002ooooo`04ool00?ooooooooooool000;ooooo00?oo`00oooo
ooooool00ooo00001Oooooooo`00ooooooooooooo`0000?ooooo00Coo`00ooooooooooooo`000_oo
ool01?oo003ooooooooooooo001=ooooo`03o`000?oooooooooo02Kooooo0_l0001:ooooo`05ool0
0?oooooooooooooooooo00000_ooool00ooo003oooooool00002ool00003oooooooo003ooooo00;o
oooo00?oo`00oooooooo00000_oo00001Ol00?ooo`00ooooooooooooo`0000?ooooo00?oo`00o`00
oooo00000_oo00001Oooooooo`00ooooooooooooo`0000;ooooo0ooo00001Oooooooo`00oooooooo
ooooo`0000;ooooo00?oo`00o`00ooooool0BOooool2o`0001Oooooo000Tooooo`03o`000?oooooo
oooo04Wooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
003o00Cooooo00?o0000ooooooooool00_ooool00ol00?ooooooo`00o`07ooooo`03o`00oooooooo
oooo00Sooooo00?o003oooooooooool0BOooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo04Sooooo00Coo`00ooooooooooooo`000_ooool00ooo003oooooooooo`03ool00006oooooooo
003ooooooooooooo003ooooo0ooo0002ooooo`04ool00?ooooooooooool000;ooooo00?oo`00oooo
ooooool00ooo00001Oooooooo`00ooooooooooooo`0000;ooooo0ooo00001Oooooooo`00oooooooo
ooooo`0000;ooooo00?oo`00ooooooooool0Boooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooooooo04Wooooo00Goo`00ooooooooooooooooool00002ooooo`03ool00?ooooooo`0000;oo`00
00?oooooool00?ooool00_ooool00ooo003oooooool00002ool00005o`00oooo003ooooooooooooo
00000oooool00ooo003o003oool00002ool00005oooooooo003ooooooooooooo00000_ooool3ool0
0005oooooooo003ooooooooooooo00000_ooool00ooo003o003oooooo`1:ooooo`03o`000?oooooo
oooo01Gooooo000Tooooo`03o`000?oooooooooo05?ooooo00?o003oooooooooool03Oooool01Ol0
003ooooooooooooooooo003o00_ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`19
ooooo`03o`000?oooooooooo02Kooooo0_l00019ooooo`04ool00?ooooooooooool000;ooooo00?o
o`00ooooooooool00ooo00001_ooooooo`00ooooooooooooo`00ooooo`?oo`000_ooool01?oo003o
oooooooooooo0002ooooo`03ool00?oooooooooo00?oo`0000Goooooool00?ooooooooooool00002
ooooo`?oo`0000Goooooool00?ooooooooooool00002ooooo`03ool00?oooooooooo04[ooooo0_l0
000Xooooo`03o`000?oooooooooo04Wooooo00Goo`00ooooooooooooooooool00002ooooo`07ool0
0?ooooooooooooooool00?ooooooool00003ooooo`07ool00?ooooooooooo`00oooooooo003oool0
0002ooooo`05ool00?oooooooooooooooooo00001Oooool01?oo003ooooooooooooo0002ooooo`05
o`00oooooooooooooooooooo00000_ooool01?oo003ooooooooooooo001<ooooo`03o`000?oooooo
oooo01Gooooo000Tooooo`03o`000?oooooooooo04Wooooo00?o003oooooooooool01oooool00ol0
0?ooooooooooo`06ooooo`04o`00ooooooooooooo`00o`?ooooo00?o0000ooooooooool01?ooool0
0ol00?ooooooooooo`05ooooo`;o003oEOooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo04Sooooo00Coo`00ooooooooooooo`000_ooool00ooo003oooooooooo`03ool00005oooooooo
003ooooooooooooo00001_ooool01?oo003ooooooooooooo0002ooooo`03ool00?oooooooooo00Co
oooo00Coo`00ooooooooooooo`000_ooool3ool00005oooooooo003ooooooooooooo00000_ooool0
0ooo003oooooooooo`1;ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0BOooool0
1Ooo003oooooooooooooooooo`0000;ooooo00?oo`00ooooooooool00_l00?l00oooooooo`00oooo
o`02ooooo`04ool00?ooooooooooo`00o`;ooooo00Coo`00ooooooooooooo`000oooool01?oo003o
003oooooool00?l2ooooo`04ool00?ooooooooooool000;ooooo0_l00?l2ooooo`04ool00?oooooo
ooooool000;ooooo00?oo`00o`00ooooool0B_ooool00ol0003oooooooooo`0Eooooo`009?ooool0
0ol0003oooooooooo`19ooooo`03o`00oooooooooooo00Oooooo0_l00?l7ooooo`04o`00oooooooo
ooooo`00o`?ooooo00Go0000ooooooooooooooooo`00o`02ooooo`03o`00oooooooooooo00Gooooo
0_l00?l9ooooo`03o`00oooooooooooo04Wooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`18ooooo`04ool00?ooooooooooool000;ooooo00?oo`00ooooooooool01?ooool01?oo003o
oooooooooooo0006ooooo`04ool00?ooooooooooool000;ooooo00?oo`00ooooooooool01?ooool0
1?oo003ooooooooooooo0006ooooo`04ool00?ooooooooooool000;ooooo00?oo`00ooooooooool0
Boooool00ol0003oooooooooo`0Vooooo`;o0000BOooool3ool000;ooooo00Coo`00oooooooooooo
o`000_ooool2o`00o`03oooooooo003ooooo00;ooooo00?oo`00ooooool00?l00_ooool01Ol00?oo
o`00ooooooooooooo`0000?ooooo00Coo`00o`00oooooooo003o0_ooool01?oo003ooooooooooooo
0002ooooo`;o003o0_ooool01Ooo003ooooooooooooo003ooooo00?oo`00B_ooool2o`0001Oooooo
000Tooooo`03o`000?oooooooooo04Wooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`07ooooo`04o`00ooooooooooooo`00o`?ooooo00Go0000ooooooooooooooooo`00o`02ooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`19ooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool0B?ooool01?oo003ooooooooooooo0002oooo
o`03ool00?oooooooooo00Cooooo00Coo`00ooooooooooooo`001_ooool01?oo003ooooooooooooo
0002ooooo`03ool00?oooooooooo00Cooooo00Coo`00ooooooooooooo`001_ooool01?oo003ooooo
oooooooo0002ooooo`03ool00?oooooooooo04_ooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`18ooooo`?oo`000_ooool01?oo003ooooooooooooo0002ooooo`04o`00oooooooooooo
ool000?ooooo00?oo`00ooooooooool00_ooool01Ol00?ooo`00ooooooooooooo`0000?ooooo00Oo
o`00o`00ooooooooooooo`00ooooooooo`0000;ooooo00Goo`00ooooooooooooooooo`00o`02oooo
o`05ool00?ooooooooooool00?ooool00ooo001;ooooo`03o`000?oooooooooo01Gooooo000Toooo
o`03o`000?oooooooooo05Cooooo00?o003oooooooooool03?ooool01Ol0003ooooooooooooooooo
003o00_ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`19ooooo`03o`000?oooooo
oooo02Kooooo0_l00019ooooo`04ool00?ooooooooooool000;ooooo00?oo`00ooooooooool01?oo
ool01?oo003ooooooooooooo0006ooooo`04ool00?ooooooooooool000;ooooo00?oo`00oooooooo
ool01?ooool01?oo003ooooooooooooo0006ooooo`04ool00?ooooooooooool000;ooooo00?oo`00
ooooooooool0B_ooool2o`0002Sooooo00?o0000ooooooooool0B?ooool3ool000;ooooo00Coo`00
ooooooooooooo`000oooool00ol00?ooooooool00003ooooo`03ool00?oooooo003o00;ooooo00Go
003oool00?ooooooooooool00003ooooo`03ool00?oooooooooo00?ooooo00Coo`00oooooooooooo
o`000_ooool01Ol00?ooooooooooooooooooo`0000;ooooo00?oo`00oooooooo00000_oo001;oooo
o`03o`000?oooooooooo01Gooooo000Tooooo`03o`000?oooooooooo04Wooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooo`00o`07ooooo`04o`00ooooooooooooo`00o`?ooooo00?o0000oooo
ooooool01?ooool00ol00?ooooooooooo`05ooooo`;o003oEOooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo04Oooooo0ooo00001Oooooooo`00ooooooooooooo`0000Kooooo00Coo`00
ooooooooooooo`001_ooool01?oo003ooooooooooooo0002ooooo`03ool00?oooooooooo00Cooooo
00Coo`00ooooooooooooo`001_ooool01Ooo003ooooooooooooo003ooooo00?oo`00C?ooool00ol0
003oooooooooo`0Vooooo`;o0000C_ooool01?oo003ooooooooooooo0002ooooo`;o003o00?ooooo
ool00?ooool00_ooool00ooo003oooooo`00o`03ooooo`04ool00?ooooooooooool000?ooooo00Oo
o`00ooooooooooooooooo`00ooooooooo`0000;ooooo00?oo`00ooooooooool00_l00?l2ooooo`04
ool00?ooooooooooool000;ooooo00?o003oooooooooool0BOooool2o`0001Oooooo000Tooooo`03
o`000?oooooooooo04Wooooo00?o003oooooooooool01_ooool00ol00?ooooooo`00o`07ooooo`04
o`00ooooooooooooo`00o`?ooooo00Go0000ooooooooooooooooo`00o`02ooooo`03o`00oooooooo
oooo00Gooooo0_l00?l9ooooo`03o`00oooooooooooo04Wooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`17ooooo`?oo`0000Goooooool00?ooooooooooool00006ooooo`04ool00?oo
ooooooooool000Kooooo00Coo`00ooooooooooooo`000_ooool00ooo003oooooooooo`04ooooo`04
ool00?ooooooooooool000Kooooo00Goo`00ooooooooooooo`00ooooo`03ool004cooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`1:ooooo`04o`00ooooooooooooool000;ooooo00?o
o`00ooooooooool00_l00?l00oooooooo`00ooooo`02ooooo`03ool00?oooooo003o00;ooooo00Go
003oool00?ooooooooooool00003ooooo`07ool00?ooooooooooooooool00?ooooooool00002oooo
o`03ool00?oooooooooo00;o003o0_ooool01?oo003ooooooooooooo0002ooooo`03o`00oooooooo
oooo04[ooooo00?o0000ooooooooool05Oooool001Kooooo0ol00004ooooo`;o00001Oooool00ol0
003oooooooooo`19ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go0000ooooooooooooooooo`00o`02ooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`19ooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool0Aoooool3ool00005oooooooo003ooooooooooooo0000
1_ooool01?oo003ooooooooooooo0006ooooo`04ool00?ooooooooooool000;ooooo00?oo`00oooo
ooooool01?ooool01?oo003ooooooooooooo0006ooooo`05ool00?ooooooooooool00?ooool00ooo
001<ooooo`03o`000?oooooooooo01Wooooo0ol00004ooooo`;o00001?ooool00ol0003ooooooooo
o`1:ooooo`04o`00ooooooooooooool000;ooooo00Coo`00oooooooooooo003o0_ooool01Ooo003o
ooooooooooooooooo`0000Cooooo00Go003oool00?ooooooooooool00003ooooo`07ool00?oooooo
ooooooooool00?ooooooool00002ooooo`05ool00?ooooooooooooooool00?l00_ooool01?oo003o
oooooooooooo0002ooooo`03o`00oooooooooooo04[ooooo00?o0000ooooooooool05Oooool001Oo
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo
05Cooooo00?o003oooooooooool03?ooool01Ol0003ooooooooooooooooo003o00cooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`19ooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool0Boooool01?oo003ooooooooooooo0006ooooo`04ool00?ooooooooooool000Kooooo
00Coo`00ooooooooooooo`000_ooool00ooo003oooooooooo`04ooooo`04ool00?ooooooooooool0
00Kooooo00Coo`00ooooooooooooo`00D?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`1:ooooo`04o`00oooo
ooooooooool000;ooooo00Ooo`00ooooooooooooooooo`00ooooooooo`0000?ooooo00?oo`00oooo
ool00?l00oooool01?oo003ooooooooooooo0003ooooo`03ool00?oooooooooo00?ooooo00Coo`00
ooooooooooooo`000_ooool01Ol00?ooooooooooooooooooo`0000;ooooo00?oo`00ooooooooool0
COooool00ol0003oooooooooo`0Eooooo`005oooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0000Cooooo0_l0001:ooooo`03o`00oooooooooooo00Kooooo00?o003oooooool00?l0
1_ooool00ol00?ooooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o003oooooooooool0
1Oooool00ol00?ooooooo`00o`1Cooooo`;o0000:?ooool2o`0004cooooo00Coo`00oooooooooooo
o`001_ooool01?oo003ooooooooooooo0006ooooo`04ool00?ooooooooooool000;ooooo00?oo`00
ooooooooool01?ooool01?oo003ooooooooooooo0006ooooo`04ool00?ooooooooooool004oooooo
0_l0000Looooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000oooool2o`0004ko
oooo00Coo`00ooooooooooooo`000_ooool2o`00o`03oooooooo003ooooo00;ooooo00?oo`00oooo
ool00?l00oooool01?oo003ooooooooooooo0003ooooo`03ool00?oooooooooo00?ooooo00Coo`00
ooooooooooooo`000_ooool2o`00o`;ooooo00Coo`00ooooooooooooo`000_ooool00ol00?oooooo
ooooo`19ooooo`;o00005oooool001Oooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo04Wooooo00?o003oooooooooool01_ooool00ol00?oooooo
o`00o`06ooooo`05o`00ooooooooooooooooool00?l00oooool01?l0003oooooooooool00?l3oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooool00?l02?ooool00ol00?ooooooooooo`19oooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0Boooool01?oo003ooooooooooooo0006
ooooo`04ool00?ooooooooooool000Kooooo00Coo`00ooooooooooooo`000_ooool00ooo003ooooo
ooooo`04ooooo`04ool00?ooooooooooool000Kooooo00Coo`00ooooooooooooo`00D?ooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000oooool0
0ol0003oooooooooo`1:ooooo`04o`00ooooooooooooool000;ooooo00Ooo`00oooooooooooo003o
ooooool00?ooo`0000?ooooo00?oo`00ooooool00?l00oooool01?oo003ooooooooooooo0003oooo
o`07ool00?ooooooooooooooool00?ooooooool00002ooooo`05ool00?oooooo003oooooool00?l0
0_ooool01?oo003ooooooooooooo0002ooooo`03o`00oooooooooooo04[ooooo00?o0000oooooooo
ool05Oooool001Oooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo04Wooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`05
o`00ooooooooooooooooool00?l00oooool01?l0003oooooooooool00?l4ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`19ooooo`03o`000?oooooo
oooo01Wooooo0ol00004ooooo`;o00001?ooool00ol0003oooooooooo`1;ooooo`04ool00?oooooo
ooooool000Kooooo00Coo`00ooooooooooooo`001_ooool01?oo003ooooooooooooo0002ooooo`03
ool00?oooooooooo00Cooooo00Coo`00ooooooooooooo`001_ooool01?oo003ooooooooooooo001@
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0003ooooo`03o`000?oooooooooo04[ooooo00Co003oooooooooooooo`000_ooool01?oo003ooooo
ooooool00?l2ooooo`05ool00?oooooooooooooooooo00001Oooool01?oo003ooooooooooooo0003
ooooo`07ool00?ooooooooooooooool00?ooooooool00002ooooo`05ool00?ooooooooooooooool0
0?l00_ooool01?oo003ooooooooooooo0002ooooo`03o`00oooooooooooo04[ooooo00?o0000oooo
ooooool05Oooool001Kooooo0_l00004ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooo
ooooool0E?ooool00ol00?ooooooooooo`08ooooo`05o`00ooooooooooooooooool000000_ooool0
0ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0B_ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000ooo
ool00ol0003oooooooooo`1;ooooo`04ool00?ooooooooooool000Kooooo00Coo`00oooooooooooo
o`001_ooool01?oo003ooooooooooooo0002ooooo`03ool00?oooooooooo00Cooooo00Coo`00oooo
ooooooooo`001_ooool01?oo003ooooooooooooo001@ooooo`03o`000?oooooooooo01Wooooo0_l0
0004ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0B_ooool01?l00?oooooo
oooooooo0002ooooo`03ool00?oooooooooo00;ooooo00?o003oool00?ooool00_ooool00ooo003o
ooooo`00o`03ooooo`04ool00?ooooooooooool000?ooooo00Ooo`00ooooooooooooooooo`00oooo
ooooo`0000;ooooo00?oo`00ooooool00?l01?ooool01?oo003ooooooooooooo001?ooooo`03o`00
0?oooooooooo01Gooooo000Gooooo`03o`000?oooooooooo00?ooooo0_l00005ooooo`03o`000?oo
oooooooo04Wooooo00?o003oooooooooool01_ooool00ol00?ooooooo`00o`06ooooo`03o`00oooo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooo003o05Cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0000?ooooo0ol0001;ooooo`04ool00?ooooooooooool000Kooooo00Coo`00oooooooo
ooooo`001_ooool01?oo003ooooooooooooo0002ooooo`03ool00?oooooooooo00Cooooo00Coo`00
ooooooooooooo`001_ooool01?oo003ooooooooooooo001?ooooo`;o00007?ooool00ol0003ooooo
ooooo`03ooooo`;o00001?ooool2o`0004kooooo00Coo`00ooooooooooooo`000_ooool01?l00?oo
ooooo`00oooo0003ooooo`03ool00?oooooo003o00?ooooo00Coo`00ooooooooooooo`000oooool0
0ooo003oooooooooo`03ooooo`08ool00?ooooooooooool00?oooooo003oooooool00?l2ooooo`04
ool00?ooooooooooool000;ooooo00?o003oooooooooool0BOooool2o`0001Oooooo000Tooooo`03
o`000?oooooooooo04[ooooo00?o003oooooooooool01Oooool00ol00?ooooooo`00o`06ooooo`03
o`00oooooooooooo00;ooooo00Co003ooooooooooooo00000_ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooool00?l01oooool00ol00?ooooooooooo`1:oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003
ooooo`03o`000?oooooooooo04_ooooo00Coo`00ooooooooooooo`001_ooool01?oo003ooooooooo
oooo0006ooooo`04ool00?ooooooooooool000;ooooo00?oo`00ooooooooool01?ooool01?oo003o
oooooooooooo0006ooooo`04ool00?ooooooooooool0053ooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`1:ooooo`04o`00ooooooooooooool000;ooooo00Ooo`00oooooooooooo003o
ooooool00?ooo`0000?ooooo00?oo`00o`00ooooool00_ooool3ool00004oooooooo003ooooooooo
o`?oo`000_ooool00ol00?ooooooool00002ooooo`05ool00?oooooo003oooooool00?l00_ooool0
1?oo003ooooooooooooo0002ooooo`03o`00oooooooooooo04[ooooo00?o0000ooooooooool05Ooo
ool002Cooooo00?o0000ooooooooool0B_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00002ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`07ooooo`03o`00oooo
oooooooo04[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool0Boooool01?oo003ooooooooooooo0006ooooo`04
ool00?ooooooooooool000Kooooo00Coo`00ooooooooooooo`000_ooool00ooo003oooooooooo`04
ooooo`04ool00?ooooooooooool000Kooooo00Coo`00ooooooooooooo`00D?ooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo04[ooooo00Co003oooooooooooooo`000_ooool01ooo003o
ooooooooool00?ooooooo`00oooo00000oooool00ooo003o003oooooo`02ooooo`?oo`0000Cooooo
ool00?oooooooooo0ooo0002ooooo`03o`00ooooooooo`0000;ooooo00Goo`00oooooooooooooooo
o`00o`02ooooo`04ool00?ooooooooooool000;ooooo00?o003oooooooooool0B_ooool00ol0003o
ooooooooo`0Eooooo`009?ooool00ol0003oooooooooo`1Booooo`03o`00oooooooo003o00_ooooo
00Co003ooooooooooooo00000_ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool0B_ooool00ol0003oooooooooo`0Iooooo`;o00001?ooool01?l0003o
ooooooooool00003ooooo`03o`000?oooooooooo04_ooooo00Coo`00ooooooooooooo`001_ooool0
1?oo003ooooooooooooo0006ooooo`04ool00?ooooooooooool000;ooooo00?oo`00ooooooooool0
1?ooool01?oo003ooooooooooooo0006ooooo`04ool00?ooooooooooool0053ooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`1:ooooo`04o`00ooooooooooooool000;ooooo00?oo`00
ooooooooool00oooool01Ooo003oooooooooooooooooo`0000Cooooo0ooo00001?ooooooo`00oooo
ooooool3ool000?ooooo00Oo003oool00?ooooooooooool00?oooooo003o00Cooooo00Coo`00oooo
ooooooooo`00Coooool00ol0003oooooooooo`0Eooooo`009?ooool00ol0003oooooooooo`1:oooo
o`03o`00oooooooooooo00Oooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05oooo
o`04o`000?ooooooooooo`00o`Cooooo00?o003oooooooooool00oooool01?l00?ooooooooooool0
0?mDooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool00oooool2o`0000Cooooo00?o
0000ooooooooool0Boooool01?oo003ooooooooooooo0006ooooo`04ool00?ooooooooooool000Ko
oooo00Coo`00ooooooooooooo`000_ooool00ooo003oooooooooo`04ooooo`04ool00?oooooooooo
ool000Kooooo00Coo`00ooooooooooooo`00D?ooool00ol0003oooooooooo`0Vooooo`;o0000C_oo
ool01_oo003ooooooooooooo003oooooo`00o`;ooooo00?o003oool00?ooool00_ooool00ooo003o
003oooooo`06ooooo`03ool00?oooooooooo00Oooooo00Koo`00ooooooooooooo`00ooooool00?l4
ooooo`04ool00?ooooooooooool000;ooooo00?o003oooooooooool0BOooool2o`0001Oooooo000T
ooooo`03o`000?oooooooooo04[ooooo00?o003oooooooooool01Oooool00ol00?ooooooo`00o`06
ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo00001oooool00ol00?oooooooooo
o`03ooooo`04o`00ooooooooooooo`00o`Oooooo00?o003oooooooooool0B_ooool00ol0003ooooo
ooooo`0Vooooo`;o0000C?ooool01?oo003ooooooooooooo0006ooooo`04ool00?ooooooooooool0
00Kooooo00Coo`00ooooooooooooo`000_ooool00ooo003oooooooooo`04ooooo`04ool00?oooooo
ooooool000Kooooo00Coo`00ooooooooooooo`00Coooool2o`0002Sooooo00?o0000ooooooooool0
B_ooool01?l00?oooooooooooooo0002ooooo`03ool00?oooooo003o00;ooooo00?o003oool00?oo
ool00_ooool00ooo003o003oooooo`06ooooo`05ool00?ooooooooooooooool00?l01?ooool02Ol0
0?ooo`00ooooooooooooo`00ooooool00?ooooooo`00o`02ooooo`04ool00?ooooooooooool000;o
oooo00?o003oooooooooool0B_ooool00ol0003oooooooooo`0Eooooo`009?ooool00ol0003ooooo
ooooo`1:ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`02ooooo`04o`00ooooooooooooo`0000;ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool0B_ooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo04_ooooo00Coo`00ooooooooooooo`001_ooool01?oo
003ooooooooooooo0006ooooo`04ool00?ooooooooooool000;ooooo00?oo`00ooooooooool01?oo
ool01?oo003ooooooooooooo0006ooooo`04ool00?ooooooooooool0053ooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`1:ooooo`04o`00ooooooooooooool000;ooooo00?oo`00oooo
ool00?l00_ooool00ol00?ooo`00ooooo`02ooooo`03ool00?l00?oooooo00?ooooo00Co003ooooo
ooooooooo`000oooool00ol00?ooooooooooo`02ooooo`05o`00oooo003ooooooooooooo00000ooo
ool01?l00?oooooooooooooo0002ooooo`04ool00?ooooooooooo`00odcooooo00?o0000oooooooo
ool05Oooool002Cooooo00?o0000ooooooooool0B_ooool00ol00?ooooooooooo`05ooooo`04o`00
ooooooooooooo`00o`[ooooo00Co003ooooooooooooo00000_ooool00ol00?ooooooooooo`0;oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool0B_ooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo04_ooooo00Coo`00ooooooooooooo`001_ooool01?oo003ooooooooooooo
0005ooooo`?oo`0000?oooooool00?ooool00ooo0005ooooo`04ool00?ooooooooooool000Kooooo
00Coo`00ooooooooooooo`00D?ooool00ol0003oooooooooo`0Vooooo`;o0000Boooool01?l00?oo
oooooooooooo0002ooooo`03ool00?oooooooooo00?ooooo00Goo`00ooooooooooooooooool00005
ooooo`04o`00ooooooooooooool000;ooooo00?o003oooooooooool00oooool01ol00?ooo`00oooo
ooooooooo`00ooooool00?l00_ooool00ol00?ooooooool00002ooooo`03ool00?oooooooooo04co
oooo0_l0000Gooooo`009?ooool00ol0003oooooooooo`1Eooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool01_ooool01?l0003oooooooooool00?l4ooooo`03o`00oooooooooooo00?o
oooo00Co003ooooooooooooo003oE?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
04_ooooo00Coo`00ooooooooooooo`001_ooool01?oo003ooooooooooooo0005ooooo`?oo`0000?o
ooooool00?ooool00ooo0005ooooo`04ool00?ooooooooooool000Kooooo00Coo`00oooooooooooo
o`00D?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo04gooooo00Koo`00oooooooo
ooooo`00ooooool00?l2ooooo`03o`00oooo003ooooo00;ooooo00?oo`00o`00ooooool01?ooool0
0ol00?ooooooool00009ooooo`06ool00?ooooooooooool00?oooooo003o1?ooool01?oo003ooooo
oooooooo0002ooooo`03o`00oooooooooooo04[ooooo00?o0000ooooooooool05Oooool002Cooooo
00?o0000ooooooooool0B_ooool00ol00?ooooooooooo`05ooooo`04o`00ooooooooooooo`00o`Co
oooo00?o003oooooooooool00oooool01?l00?ooooooooooool00007ooooo`03o`00oooooooooooo
00?ooooo00Co003ooooooooooooo003o1oooool00ol00?ooooooooooo`1:ooooo`03o`000?oooooo
oooo02Kooooo0_l0001<ooooo`04ool00?ooooooooooool000Kooooo00Coo`00ooooooooooooo`00
1Oooool3ool00003oooooooo003ooooo00?oo`001Oooool01?oo003ooooooooooooo0006ooooo`04
ool00?ooooooooooool004oooooo0_l0000Xooooo`03o`000?oooooooooo04[ooooo00Co003ooooo
ooooooooo`000_ooool00ooo003oooooo`00o`02ooooo`03o`00oooo003ooooo00;ooooo00?oo`00
o`00ooooool01_ooool01?oo003oooooooooool00?l5ooooo`07o`00oooo003ooooooooooooo003o
ooooo`00o`02ooooo`03o`00ooooooooo`0000;ooooo00Coo`00oooooooooooo003oC?ooool00ol0
003oooooooooo`0Eooooo`009?ooool00ol0003oooooooooo`1:ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`03ooooo`04o`00ooooooooooooo`00
00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
00Sooooo00?o003oooooooooool0B_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
04_ooooo00Coo`00ooooooooooooo`001_ooool01?oo003ooooooooooooo0009ooooo`03ool00?oo
oooooooo00Oooooo00Coo`00ooooooooooooo`001_ooool01?oo003ooooooooooooo001@ooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool0B_ooool01?l00?oooooooooooooo0002oooo
o`03ool00?oooooo003o00;ooooo00?o003oool00?ooool00_ooool00ooo003o003oooooo`04oooo
o`03o`00ooooooooo`0000;ooooo00?o003oooooooooool00oooool01ol00?ooo`00oooooooooooo
o`00ooooool00?l00_ooool00ol00?ooooooool00002ooooo`03ool00?oooooo003o04gooooo00?o
0000ooooooooool05Oooool002Cooooo00?o0000ooooooooool0B_ooool00ol00?ooooooooooo`05
ooooo`04o`00ooooooooooooo`00o`[ooooo00Co003ooooooooooooo00000_ooool00ol00?oooooo
ooooo`08ooooo`04o`00ooooooooooooo`00o`Oooooo00?o003oooooooooool0B_ooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo04_ooooo00Coo`00ooooooooooooo`001_ooool01?oo
003ooooooooooooo0009ooooo`03ool00?oooooooooo00Oooooo00Coo`00ooooooooooooo`001_oo
ool01?oo003ooooooooooooo001@ooooo`03o`000?oooooooooo02Kooooo0_l0001;ooooo`04o`00
ooooooooooooool000;ooooo00?oo`00ooooooooool00oooool01Ooo003oooooooooooooooooo`00
00Kooooo00?o003ooooooooo00000_ooool00ol00?ooooooooooo`03ooooo`05o`00oooo003ooooo
oooooooo00001?ooool00ol00?ooooooool00002ooooo`03ool00?oooooooooo04cooooo0_l0000G
ooooo`005Oooool5o`0000?ooooo0_l00005ooooo`03o`000?oooooooooo05Gooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`06ooooo`04o`000?ooooooooooo`00o`Gooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`1Booooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool0Boooool01?oo003ooooooooooooo0006ooooo`04ool00?ooooooooooool000Wooooo
00?oo`00ooooooooool01oooool01?oo003ooooooooooooo0006ooooo`04ool00?ooooooooooool0
053ooooo00?o0000ooooooooool06?ooool5o`0000?ooooo0_l00004ooooo`03o`000?oooooooooo
04gooooo00Koo`00ooooooooooooo`00ooooool00?l2ooooo`03o`00oooo003ooooo00;ooooo00?o
o`00o`00ooooool01?ooool00ol00?ooooooool00009ooooo`05ool00?ooooooooooool00?l00?l0
1Oooool01_oo003ooooooooooooo003oooooo`00odgooooo00?o0000ooooooooool05Oooool001Ko
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooo
oooo04[ooooo00?o003oooooooooool01Oooool01?l00?ooooooooooool00?l4ooooo`03o`00oooo
oooooooo00?ooooo00Co003ooooooooooooo00002?ooool00ol00?ooooooooooo`02ooooo`04o`00
ooooooooooooo`00o`Oooooo00?o003oooooooooool0B_ooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo04_ooooo00Coo`00ooooooooooooo`001_ooool01?oo003ooooooooooooo0009
ooooo`03ool00?oooooooooo00Oooooo00Coo`00ooooooooooooo`001_ooool01?oo003ooooooooo
oooo001@ooooo`03o`000?oooooooooo01Wooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00003ooooo`03o`000?oooooooooo04_ooooo00?o003ooooooooo00000_ooool00ooo
003oooooo`00o`02ooooo`03o`00oooo003ooooo00;ooooo00?oo`00o`00ooooool01_ooool01?oo
003oooooooooool00?l5ooooo`06o`00oooo003ooooooooooooo003o003o0oooool00ol00?oooooo
ool00002ooooo`03ool00?oooooo003o04gooooo00?o0000ooooooooool05Oooool001Oooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo04[ooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00?ooooo
00Ko003ooooooooooooo0000ooooool00?l6ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool02?ooool00ol00?ooooooooooo`1:ooooo`03o`000?oooooooooo02Kooooo0_l0001<oooo
o`04ool00?ooooooooooool000Kooooo00Coo`00ooooooooooooo`002Oooool00ooo003ooooooooo
o`07ooooo`04ool00?ooooooooooool000Kooooo00Coo`00ooooooooooooo`00Coooool2o`0001co
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo
04_ooooo00?o003ooooooooo00000_ooool00ooo003oooooo`00o`02ooooo`03o`00oooo003ooooo
00;ooooo00?oo`00o`00ooooool01?ooool00ol00?ooooooool00002ooooo`03o`00oooooooooooo
00?ooooo00Ko003oool00?ooooooooooool00?l00?l3ooooo`03o`00ooooooooo`0000;ooooo00?o
o`00ooooool00?l0COooool00ol0003oooooooooo`0Eooooo`006?ooool01Ol0003ooooooooooooo
oooo000000;ooooo00?o0000ooooooooool00_ooool2o`0004_ooooo00?o003oooooooooool01Ooo
ool01?l00?ooooooooooool00?l:ooooo`06o`00ooooooooooooo`000?oooooo003o2oooool01?l0
0?ooooooooooool00?l7ooooo`03o`00oooooooooooo04Wooooo0_l0000Xooooo`03o`000?oooooo
oooo04_ooooo00Coo`00ooooooooooooo`001_ooool01?oo003ooooooooooooo0009ooooo`03ool0
0?oooooooooo00Oooooo00Coo`00ooooooooooooo`001_ooool01?oo003ooooooooooooo001@oooo
o`03o`000?oooooooooo01_ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo
ooooooooo`;o0000C?ooool00ol00?ooooooool00002ooooo`03ool00?oooooooooo00?ooooo00Go
o`00ooooooooooooooooool00006ooooo`03o`00ooooooooo`0000;ooooo00?o003oooooooooool0
0oooool01Ol00?ooo`00ooooooooooooo`0000Cooooo00?o003ooooooooo00000_ooool00ooo003o
ooooooooo`1<ooooo`;o00005oooool001Gooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0EOooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo00Kooooo00?o0000ooooool00?l01_ooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo05;ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1;oooo
o`04ool00?ooooooooooool000Kooooo00Coo`00ooooooooooooo`002Oooool00ooo003ooooooooo
o`07ooooo`04ool00?ooooooooooool000Kooooo00Coo`00ooooooooooooo`00D?ooool00ol0003o
ooooooooo`0Hooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00003
ooooo`03o`000?oooooooooo04gooooo00Koo`00ooooooooooooo`00ooooool00?l3ooooo`05ool0
0?oooooooooooooooooo00001_ooool00ol00?ooooooool00009ooooo`04ool00?ooooooooooool0
00Kooooo00Koo`00ooooooooooooo`00ooooool00?m=ooooo`03o`000?oooooooooo01Gooooo000E
ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00004ooooo`03o`00
0?oooooooooo04[ooooo00?o003oooooooooool01?ooool01Ol00?oooooooooooooooooo003o00Co
oooo00?o003oooooooooool01?ooool00ol00?ooooooo`000008ooooo`03o`00oooooooooooo00;o
oooo00Co003ooooooooooooo003o1oooool00ol00?ooooooooooo`1:ooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool0Boooool01?oo003ooooooooooooo0006ooooo`04ool00?oooooo
ooooool000Wooooo00?oo`00ooooooooool01oooool01?oo003ooooooooooooo0006ooooo`04ool0
0?ooooooooooool0053ooooo00?o0000ooooooooool06?ooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`1;ooooo`03o`00oooooooo
o`0000;ooooo00?oo`00ooooool00?l00oooool01Ooo003oooooooooooooooooo`0000Sooooo00Co
o`00oooooooooooo003o1_ooool01Ooo003ooooooooooooo003o003o00?ooooo00?o003ooooooooo
00000_ooool00ooo003oooooo`00o`1=ooooo`03o`000?oooooooooo01Gooooo000Fooooo`?o0000
1?ooool2o`0000Gooooo00?o0000ooooooooool0B_ooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool01?ooool01Ol00?ooooooo`000?oooooo003o00Ko
oooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l7ooooo`03o`00oooooooooooo
04[ooooo00?o0000ooooooooool09_ooool2o`0004cooooo00Coo`00ooooooooooooo`001_ooool0
1?oo003ooooooooooooo0009ooooo`03ool00?oooooooooo00Oooooo00Coo`00ooooooooooooo`00
1_ooool01?oo003ooooooooooooo001?ooooo`;o00006oooool3o`0000Cooooo0_l00004ooooo`;o
0000C?ooool00ol00?ooooooool00002ooooo`03ool00?oooooo003o00?ooooo00Goo`00oooooooo
ooooooooool00006ooooo`03o`00ooooooooo`0000;ooooo00?o003oooooooooool01?ooool01Ooo
003ooooooooooooo003o003o00?ooooo00?o003ooooooooo00000_ooool00ooo003oooooo`00o`1<
ooooo`;o00005oooool002Cooooo00?o0000ooooooooool0B_ooool00ol00?ooooooooooo`04oooo
o`05o`00ooooooooooooooooool00?l02oooool01Ol00?ooooooo`000?oooooo003o00[ooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`1:ooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool0Boooool01?oo003ooooooooooooo0006ooooo`04ool00?ooooooooooool000Wo
oooo00?oo`00ooooooooool01oooool01?oo003ooooooooooooo0006ooooo`04ool00?oooooooooo
ool0053ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1;ooooo`03o`00oooooooo
o`0000;ooooo00?oo`00ooooooooool00oooool01Ooo003oooooooooooooooooo`0000Kooooo00?o
003ooooooooo00000_ooool00ol00?ooooooooooo`04ooooo`05ool00?ooooooooooool00?l00?l0
0oooool00ol00?ooooooool00002ooooo`03ool00?oooooooooo04gooooo00?o0000ooooooooool0
5Oooool002Cooooo00?o0000ooooooooool0EOooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo00Kooooo00?o0000ooooool00?l01_ooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo05;ooooo00?o0000ooooooooool06?ooool5o`0000?ooooo0_l00004ooooo`03o`000?oo
oooooooo04_ooooo00Coo`00ooooooooooooo`001_ooool01?oo003ooooooooooooo0009ooooo`03
ool00?oooooooooo00Oooooo00Coo`00ooooooooooooo`001_ooool01?oo003ooooooooooooo001@
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0COooool01_oo003ooooooooooooo
003oooooo`00o`?ooooo00Goo`00ooooooooooooooooool00006ooooo`03o`00ooooooooo`0000Wo
oooo00Coo`00ooooooooooooo`001_ooool01_oo003ooooooooooooo003oooooo`00odgooooo00?o
0000ooooooooool05Oooool002Cooooo00?o0000ooooooooool0B_ooool00ol00?ooooooooooo`04
ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooo000000Sooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo05;ooooo
00?o0000ooooooooool06Oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00?ooooo00?o0000ooooooooool0Boooool01?oo003ooooooooooooo0006ooooo`04ool00?oooooo
ooooool000Wooooo00?oo`00ooooooooool01oooool01?oo003ooooooooooooo0006ooooo`04ool0
0?ooooooooooool0053ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1;ooooo`03
o`00ooooooooo`0000;ooooo00?oo`00ooooool00?l00oooool01Ooo003oooooooooooooooooo`00
00Sooooo00?oo`00ooooool00?l01oooool01Ooo003ooooooooooooo003o003o00?ooooo00?o003o
oooooooo00000_ooool00ooo003oooooo`00o`1=ooooo`03o`000?oooooooooo01Gooooo000Toooo
o`03o`000?oooooooooo04[ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00Gooooo00Go003oooooool0003oooooo`00o`06ooooo`05o`00oooooooo
ooooooooool00?l01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo04[ooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo
00?o0000ooooooooool0Boooool01?oo003ooooooooooooo0006ooooo`04ool00?ooooooooooool0
00Wooooo00?oo`00ooooooooool01oooool01?oo003ooooooooooooo0006ooooo`04ool00?oooooo
ooooool0053ooooo00?o0000ooooooooool09_ooool2o`0004cooooo00?o003ooooooooo00000_oo
ool00ooo003oooooo`00o`03ooooo`05ool00?oooooooooooooooooo00001_ooool01Ol00?oooooo
ool00?oooooo003o00Oooooo00Goo`00ooooooooooooo`00o`00o`03ooooo`03o`00ooooooooo`00
00;ooooo00?oo`00ooooool00?l0C?ooool2o`0001Oooooo000Tooooo`03o`000?oooooooooo04[o
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00So
oooo00Go003oooooool0003oooooo`00o`0:ooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool0B_ooool00ol0003oooooooooo`0Kooooo`05o`000?ooooooooooooooool000000_ooool0
1?l0003oooooooooooooool3o`0004_ooooo00Coo`00ooooooooooooo`001_ooool01?oo003ooooo
oooooooo0009ooooo`03ool00?oooooooooo00Oooooo00Coo`00ooooooooooooo`001_ooool01?oo
003ooooooooooooo001?ooooo`;o0000:?ooool00ol0003oooooooooo`1;ooooo`03o`00oooooooo
o`0000;ooooo00?oo`00ooooool00?l00oooool01Ooo003oooooooooooooooooo`0000Kooooo00Go
003ooooooooo003oooooo`00o`07ooooo`05ool00?ooooooooooool00?l00?l00oooool00ol00?oo
ooooool00002ooooo`03ool00?oooooooooo04gooooo00?o0000ooooooooool05Oooool002Cooooo
00?o0000ooooooooool0E_ooool01?l00?ooooooooooool00?l9ooooo`03o`000?oooooo003o00Ko
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo04_o
oooo00?o0000ooooooooool06?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooo
oooooooo00000oooool00ol0003oooooooooo`1;ooooo`04ool00?ooooooooooool000Kooooo00Co
o`00ooooooooooooo`002Oooool00ooo003oooooooooo`07ooooo`04ool00?ooooooooooool000Ko
oooo00Coo`00ooooooooooooo`00D?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
04gooooo00Coo`00ooooooooooooo`001Oooool01Ooo003oooooooooooooooooo`0000Oooooo00?o
003oool00?ooool02?ooool01Ooo003ooooooooooooo003o003o00Gooooo00Koo`00oooooooooooo
o`00ooooool00?m=ooooo`03o`000?oooooooooo01Gooooo000Tooooo`03o`000?oooooooooo04[o
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00
o`Oooooo00?o003oooooool000002?ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003o
ooooooooool0DOooool00ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo04_ooooo00Coo`00oooooooooooo
o`001_ooool01?oo003ooooooooooooo0009ooooo`03ool00?oooooooooo00Oooooo00Coo`00oooo
ooooooooo`001_ooool01?oo003ooooooooooooo001@ooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool0Boooool00ol00?ooooooool00002ooooo`03ool00?oooooo003o00?ooooo00Go
o`00ooooooooooooooooool00008ooooo`03ool00?oooooo003o00Oooooo00Goo`00oooooooooooo
o`00o`00o`03ooooo`03o`00ooooooooo`0000;ooooo00?oo`00ooooool00?l0COooool00ol0003o
ooooooooo`0Eooooo`009?ooool00ol0003oooooooooo`1:ooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`05ooooo`05o`00oooooooo0000ooooool0
0?l01oooool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooooooo00?ooooo00?o003ooooo
ooooool0Boooool00ol0003oooooooooo`0Iooooo`?o00001?ooool2o`0000Cooooo00?o0000oooo
ooooool0Boooool01?oo003ooooooooooooo0006ooooo`04ool00?ooooooooooool000Wooooo00?o
o`00ooooooooool01oooool01?oo003ooooooooooooo0006ooooo`04ool00?ooooooooooool0053o
oooo00?o0000ooooooooool09_ooool2o`0004cooooo00?o003ooooooooo00000_ooool00ooo003o
ooooo`00o`03ooooo`03ool00?oooooooooo00?oo`001_ooool01?l00?ooo`00ooooool00?l6oooo
o`?oo`0000?oooooool00?l00?l00oooool00ol00?ooooooool00002ooooo`03ool00?oooooo003o
04cooooo0_l0000Gooooo`009?ooool00ol0003oooooooooo`1:ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l7ooooo`05o`00oooooooo0000
ooooool00?l02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo04_ooooo00?o0000
ooooooooool09_ooool2o`0004cooooo00Coo`00ooooooooooooo`001_ooool01?oo003ooooooooo
oooo0009ooooo`03ool00?oooooooooo00Oooooo00Coo`00ooooooooooooo`001_ooool01?oo003o
oooooooooooo001?ooooo`;o0000:?ooool00ol0003oooooooooo`1;ooooo`03o`00ooooooooo`00
00;ooooo00?oo`00ooooool00?l00_ooool3ool00004oooooooo003oo`00ool000Kooooo00Co003o
ool00?oooooo003o1_ooool6ool000?ooooo00?o003ooooooooo00000_ooool00ooo003oooooo`00
o`1=ooooo`03o`000?oooooooooo01Gooooo000Tooooo`03o`000?oooooooooo05Kooooo00?o003o
ooooooooool02_ooool00ol0003o003oooooo`07ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool00oooool00ol00?ooooooooooo`1;ooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool0Boooool01?oo003ooooooooooooo0006ooooo`04ool00?ooooooooooool000Wooooo
00?oo`00ooooooooool01oooool01?oo003ooooooooooooo0006ooooo`04ool00?ooooooooooool0
053ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1=ooooo`04ool00?oooooooooo
ool000Cooooo0ooo00001?ooooooo`00ool00?oo0006ooooo`03o`00oooo003ooooo00Oooooo1_oo
0005ooooo`04ool00?ooooooooooool004oooooo00?o0000ooooooooool05Oooool002Cooooo00?o
0000ooooooooool0Boooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00;ooooo00Co
003ooooooooooooo003o1oooool2o`00o`03o`000?oooooooooo00Oooooo00Co003ooooooooooooo
003o1?ooool00ol00?ooooooooooo`1Aooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool0Boooool01?oo003ooooooooooooo0006ooooo`04ool00?ooooooooooool000Wooooo00?oo`00
ooooooooool01oooool01?oo003ooooooooooooo0006ooooo`04ool00?ooooooooooool0053ooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`1;ooooo`03o`00ooooooooo`0000;ooooo
00?oo`00ooooool00?l00_ooool3ool000;ooooo00?o003oooooooooool01_ooool00ooo003ooooo
o`00o`07ooooo`03o`00ooooooooo`0000;oo`000oooool00ol00?ooooooool00002ooooo`03ool0
0?oooooo003o04gooooo00?o0000ooooooooool05Oooool002Cooooo00?o0000ooooooooool0Booo
ool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_oo
ool00ol00?oo0000o`00o`08ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool0
0oooool00ol00?ooooooooooo`1;ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
Boooool01?oo003ooooooooooooo0006ooooo`04ool00?ooooooooooool000Wooooo00?oo`00oooo
ooooool01oooool01?oo003ooooooooooooo0006ooooo`04ool00?ooooooooooool0053ooooo00?o
0000ooooooooool09_ooool2o`0004cooooo00?o003ooooooooo00000_ooool00ooo003oooooo`00
o`04ooooo`03o`00oooooooo003o00Sooooo00Co003oool00?oooooo003o1oooool01?l00?oooooo
ooooool00?l4ooooo`03o`00ooooooooo`0000;ooooo00?oo`00ooooool00?l0C?ooool2o`0001Oo
oooo000Fooooo`?o00001?ooool2o`0000Gooooo00?o0000ooooooooool0Boooool00ol00?oooooo
ooooo`03ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_ooool00ol00?oo0000
o`00o`0;ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool0Boooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo04_ooooo00Coo`00ooooooooooooo`001_ooool01?oo003o
oooooooooooo0009ooooo`03ool00?oooooooooo00Oooooo00Coo`00ooooooooooooo`001_ooool0
1?oo003ooooooooooooo001@ooooo`03o`000?oooooooooo01Wooooo0ol00004ooooo`;o00001?oo
ool00ol0003oooooooooo`1;ooooo`03o`00ooooooooo`0000;ooooo00?oo`00ooooool00?l03ooo
ool01?l00?ooo`00ooooool00?l8ooooo`03o`00oooooooo003o00Cooooo00?o003ooooooooo0000
0_ooool00ooo003oooooo`00o`1=ooooo`03o`000?oooooooooo01Gooooo000Eooooo`05o`000?oo
ooooooooooooool000000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo05Ko
oooo00?o003oooooooooool02_ooool00ol0003o003oooooo`07ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool00oooool00ol00?ooooooooooo`1;ooooo`03o`000?oooooooooo02Ko
oooo0_l0001<ooooo`04ool00?ooooooooooool000Kooooo00Coo`00ooooooooooooo`002Oooool0
0ooo003oooooooooo`07ooooo`04ool00?ooooooooooool000Kooooo00Coo`00ooooooooooooo`00
Coooool2o`0001[ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`00
00?ooooo00?o0000ooooooooool0Boooool00ol00?ooooooool00002ooooo`03ool00?oooooooooo
00Cooooo00?o003oooooool00?l02?ooool00ol00?ooo`00ooooo`0Booooo`04ool00?oooooooooo
ool004oooooo00?o0000ooooooooool05Oooool001Wooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`02ooooo`;o0000C?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo
oooo00;ooooo00Co003ooooooooooooo003o2?ooool00ol00?oo0000ooooo`08ooooo`03o`00oooo
oooo003o00Gooooo00?o003oooooooooool0D?ooool2o`0002Sooooo00?o0000ooooooooool0Booo
ool01?oo003ooooooooooooo0006ooooo`04ool00?ooooooooooool000Wooooo00?oo`00oooooooo
ool01oooool01?oo003ooooooooooooo0006ooooo`04ool00?ooooooooooool0053ooooo00?o0000
ooooooooool07?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooooooo`;o0000
C_ooool01Ooo003ooooooooooooo003o003o00Gooooo00?o003oooooool00?l02Oooool00ooo003o
ooooo`00o`08ooooo`03o`00oooooooo003o00Cooooo00?o003ooooooooo00000_ooool00ooo003o
ooooo`00o`1<ooooo`;o00005oooool001Oooooo0_l00003ooooo`04o`000?ooooooooooo`0000Co
oooo00?o0000ooooooooool0Boooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooool00?l02Oooool00ol00?oo0000o`00o`08ooooo`03o`00oooooooo003o00Go
oooo00?o003oooooooooool00oooool00ol00?ooooooooooo`1;ooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool0Boooool01?oo003ooooooooooooo0006ooooo`04ool00?oooooooooo
ool000Wooooo00?oo`00ooooooooool01oooool01?oo003ooooooooooooo0006ooooo`04ool00?oo
ooooooooool0053ooooo00?o0000ooooooooool06_ooool2o`0000?ooooo00Co0000oooooooooooo
00000oooool00ol0003oooooooooo`1;ooooo`03o`00ooooooooo`0000;ooooo00?oo`00o`00oooo
ool01?ooool00ol00?ooooooo`00o`08ooooo`04o`00oooo003oooooo`00o`Sooooo00?o003ooooo
ool00?l01?ooool00ol00?ooooooool00002ooooo`03ool00?oooooo003o04gooooo00?o0000oooo
ooooool05Oooool001Wooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo04_ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00Oooooo00?o003oo`000?l00?l02?ooool00ol00?ooooooo`00o`0;oooo
o`03o`00oooooooooooo04_ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1;oooo
o`04ool00?ooooooooooool000Kooooo00Coo`00ooooooooooooo`002Oooool00ooo003ooooooooo
o`07ooooo`04ool00?ooooooooooool000Kooooo00Coo`00ooooooooooooo`00D?ooool00ol0003o
ooooooooo`0Looooo`04o`000?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`00001=
ooooo`03o`00ooooooooo`0000;ooooo00?oo`00o`00ooooool04?ooool00ooo003o003oooooo`08
ooooo`03o`00oooooooo003o00Gooooo00Oo003oool00?ooooooooooool00?oooooo003o04gooooo
00?o0000ooooooooool05Oooool001Gooooo00Go0000ooooooooooooooooo`000002ooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool0Eoooool00ol00?ooooooooooo`09ooooo`03
o`000?l00?oooooo00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`1;ooooo`03
o`000?oooooooooo02Kooooo0_l0001<ooooo`04ool00?ooooooooooool000Kooooo00?oo`00oooo
oooo00000_oo0008ooooo`03ool00?oooooooooo00Kooooo0ooo00000oooooooo`00ooooo`05oooo
o`04ool00?ooooooooooool004oooooo0_l0000Jooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo04_ooooo00?o003ooooooooo0000
0_ooool00ooo003oooooooooo`04ooooo`03o`00oooooooo003o00Wooooo00?oo`00ooooooooool0
4Oooool01?oo003ooooooooooooo001?ooooo`03o`000?oooooooooo01Gooooo000Fooooo`?o0000
1?ooool2o`0000Gooooo00?o0000ooooooooool0Boooool00ol00?ooooooooooo`03ooooo`03o`00
oooooooooooo00?ooooo0_l00?l9ooooo`03o`00ool0003ooooo00Wooooo0_l00?l5ooooo`03o`00
oooooooooooo00?ooooo00?o003oooooooooool0Boooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo04_ooooo00Coo`00ooooooooooooo`001Oooool6ool000Sooooo00?oo`00oooooooo
ool01_ooool6ool000Gooooo00Coo`00ooooooooooooo`00D?ooool00ol0003oooooooooo`0Ioooo
o`?o00001?ooool2o`0000Cooooo0_l0001>ooooo`05ool00?ooooooooooool00?l00?l01Oooool3
o`00o`Wooooo00?oo`00o`00ooooool02?ooool2o`00o`Kooooo00Oo003oool00?ooooooooooool0
0?oooooo003o04cooooo0_l0000Gooooo`009?ooool00ol0003oooooooooo`1;ooooo`03o`00oooo
oooooooo00?ooooo00?o003oooooooooool00oooool2o`00o`[ooooo00?o003oooooooooool02?oo
ool2o`00o`Gooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`1;ooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool0Boooool01?oo003ooooooooooooo0005ooooo`Koo`00
2?ooool00ooo003oooooooooo`06ooooo`Koo`001Oooool01?oo003ooooooooooooo001@ooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool0Boooool00ol00?ooooooool00002ooooo`03
ool00?l00?oooooo00Gooooo00?o003oooooooooool01oooool3ool000[ooooo00?o003ooooooooo
ool01?ooool01_l00?ooo`00ooooooooooooo`00o`00odkooooo00?o0000ooooooooool05Oooool0
02Cooooo00?o0000ooooooooool0Boooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
00oooooo00?o003oooooooooool0Hoooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
04_ooooo00Coo`00ooooooooooooo`001Oooool3ool000_ooooo00?oo`00ooooooooool02Oooool3
ool000Gooooo00Coo`00ooooooooooooo`00D?ooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooooooo04_ooooo00?o003ooooooooo00000_ooool00ooo003o003oooooo`0?ooooo`?oo`004Ooo
ool01_l00?ooo`00ooooooooooooo`00o`00odkooooo00?o0000ooooooooool05Oooool002Cooooo
00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo
00?o003oooooooooool0Boooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo04_ooooo
00Coo`00ooooooooooooo`004oooool00ooo003oooooooooo`0Aooooo`04ool00?ooooooooooool0
053ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1;ooooo`03o`00ooooooooo`00
00;ooooo00?oo`00ooooooooool03oooool3ool001;ooooo00Goo`00ooooooooooooo`00o`00o`1>
ooooo`03o`000?oooooooooo01Gooooo000Tooooo`03o`000?oooooooooo04_ooooo00?o003ooooo
ooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`000?oooooooooo00oooooo00?o003ooooo
ooooool00oooool00ol00?ooooooooooo`1;ooooo`03o`000?oooooooooo02Kooooo0_l0001<oooo
o`04ool00?ooooooooooool001?ooooo00?oo`00ooooooooool04Oooool01?oo003ooooooooooooo
001?ooooo`;o0000:?ooool2o`0004kooooo00Goo`00ooooooooooooo`00o`00o`0Aooooo`03o`00
0?oooooooooo013ooooo00Go003oool00?ooooooooooool0001>ooooo`;o00005oooool002Cooooo
00?o0000ooooooooool0Boooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00oooooo
00?o0000ooooooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo04_ooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`1;ooooo`04ool00?ooooooooooool001?o
oooo00?oo`00ooooooooool04Oooool01?oo003ooooooooooooo001@ooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool0C?ooool01_l00?ooo`00ooooooooooooo`00o`00oa7ooooo00?o
0000ooooooooool04?ooool01Ol00?ooo`00ooooooooooooo`0004oooooo00?o0000ooooooooool0
5Oooool002Cooooo00?o0000ooooooooool0Boooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooooooo00oooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0Iooooo`?o00001?oo
ool2o`0000Cooooo00?o0000ooooooooool0Boooool01?oo003ooooooooooooo000Cooooo`03ool0
0?oooooooooo017ooooo00Coo`00ooooooooooooo`00D?ooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo04cooooo00Ko003oool00?ooooooooooool00?l00?lAooooo`03o`000?oooooo
oooo013ooooo00Ko003oool00?ooooooooooool00?l00?m>ooooo`03o`000?oooooooooo01Gooooo
000Tooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool03oooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo04_ooooo00?o0000ooooooooool06?ooool01Ol0003ooooooooo
oooooooo000000;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`1;ooooo`04
ool00?ooooooooooool001?ooooo00?oo`00ooooooooool04Oooool01?oo003ooooooooooooo001@
ooooo`03o`000?oooooooooo02Kooooo0_l0001=ooooo`05o`00oooo003ooooooooooooo00004_oo
ool00ol0003oooooooooo`0Aooooo`05ool00?ooooooooooool00?l00?l0COooool2o`0001Oooooo
000Tooooo`03o`000?oooooooooo04_ooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`0@ooooo`03o`000?oooooooooo00oooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`1;ooooo`03o`000?oooooooooo01cooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooooooool3o`0004_ooooo00Coo`00ooooooooooooo`004oooool00ooo003oooooooooo`0Aoooo
o`04ool00?ooooooooooool004oooooo0_l0000Xooooo`03o`000?oooooooooo04gooooo00Goo`00
ooooooooooooo`00o`00o`0Aooooo`03o`000?oooooooooo013ooooo00Ko003oool00?oooooooooo
ool00?l00?m>ooooo`03o`000?oooooooooo01Gooooo000Tooooo`03o`000?oooooooooo04_ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`0@ooooo`03o`000?oooooooooo00oooooo
00?o003oooooooooool00oooool00ol00?ooooooooooo`1;ooooo`03o`000?oooooooooo01[ooooo
0_l00003ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0Boooool01?oo003o
oooooooooooo000Cooooo`03ool00?oooooooooo017ooooo00Coo`00ooooooooooooo`00D?ooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo04cooooo00Ko003oool00?ooooooooooool0
0?l00?lAooooo`03o`000?oooooooooo013ooooo00Go003oool00?ooooooooooool0001?ooooo`03
o`000?oooooooooo01Gooooo000Tooooo`03o`000?oooooooooo04_ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`0@ooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool0
7?ooool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool00000COooool01?oo
003ooooooooooooo000Cooooo`03ool00?oooooooooo017ooooo00Coo`00ooooooooooooo`00D?oo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo04cooooo00Ko003oool00?oooooooooo
ool00?l00?lAooooo`03o`000?oooooooooo013ooooo00Ko003oool00?ooooooooooool00?l00?m>
ooooo`03o`000?oooooooooo01Gooooo000Tooooo`03o`000?oooooooooo053ooooo00?o003ooooo
ooooool04?ooool00ol0003oooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o003ooooo
ooooool0Boooool00ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool000000_ooool0
1?l0003oooooooooool00003ooooo`03o`000?oooooooooo04_ooooo00Coo`00ooooooooooooo`00
4oooool00ooo003oooooooooo`0Aooooo`04ool00?ooooooooooool0053ooooo00?o0000oooooooo
ool09_ooool2o`0004gooooo00Go003oool00?ooooooooooool0000Booooo`03o`000?oooooooooo
017ooooo00Goo`00ooooooooooooo`00o`00o`1=ooooo`;o00005oooool001Oooooo0ol00003oooo
o`;o00001Oooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo00oooooo00?o003ooooo
ooooool00oooool00ol00?ooooooooooo`1;ooooo`03o`000?oooooooooo01Wooooo0ol00004oooo
o`;o00001?ooool00ol0003oooooooooo`1;ooooo`04ool00?ooooooooooool001?ooooo00?oo`00
ooooooooool04Oooool01?oo003ooooooooooooo001@ooooo`03o`000?oooooooooo01[ooooo0ol0
0003ooooo`;o00001?ooool00ol0003oooooooooo`1=ooooo`05ool00?ooooooooooool00?l00?l0
4Oooool00ol0003oooooooooo`0Aooooo`05ool00?ooooooooooool00?l00?l0C_ooool00ol0003o
ooooooooo`0Eooooo`006?ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`1;ooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool04?ooool00ol0003oooooooooo`0@ooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool0Boooool00ol0003oooooooooo`0Vooooo`;o0000C?ooool01?oo003ooooooooooooo000Coooo
o`03ool00?oooooooooo017ooooo00Coo`00ooooooooooooo`00Coooool2o`0001gooooo00Go0000
ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool00000C_ooool01_l00?ooo`00
ooooooooooooo`00o`00oa7ooooo00?o0000ooooooooool04?ooool01Ol00?ooo`00oooooooooooo
o`0004oooooo00?o0000ooooooooool05Oooool001Gooooo1Ol00002ooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooooooool0Boooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo013ooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo04_ooooo00Coo`00ooooooooooooo`004_ooool3ool001;ooooo00Coo`00ooooooooooooo`00
D?ooool00ol0003oooooooooo`0Hooooo`Go00000_ooool01?l0003oooooooooool00003ooooo`03
o`000?oooooooooo04cooooo00Ko003oool00?ooooooooooool00?l00?lAooooo`03o`000?oooooo
oooo013ooooo00Ko003oool00?ooooooooooool00?l00?m>ooooo`03o`000?oooooooooo01Gooooo
000Eooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00001?ooool2o`0004co
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0@ooooo`03o`000?oooooooooo013o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1:ooooo`;o0000:?ooool00ol0003o
ooooooooo`1;ooooo`04ool00?ooooooooooool001;ooooo0ooo000Booooo`04ool00?oooooooooo
ool0053ooooo00?o0000ooooooooool06?ooool01?l0003oooooooooool00003ooooo`04o`000?oo
ooooooooo`0000?ooooo0_l0001=ooooo`05o`00oooo003ooooooooooooo00004_ooool00ol0003o
ooooooooo`0@ooooo`06o`00oooo003ooooooooooooo003o003oCOooool2o`0001Oooooo000Foooo
o`03o`000?oooooo000000?ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1S
ooooo`03o`000?oooooooooo013ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1;
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0Boooool01?oo003ooooooooooooo
000Booooo`?oo`004_ooool01?oo003ooooooooooooo001@ooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooool000000oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo04go
oooo00Goo`00ooooooooooooo`00o`00o`0Aooooo`03o`000?oooooooooo017ooooo00Goo`00oooo
ooooooooo`00o`00o`1>ooooo`03o`000?oooooooooo01Gooooo000Gooooo`;o00000oooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo04_ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00Go003oooooooooooooooooo`00
o`1>ooooo`03o`000?oooooooooo02Kooooo0_l0001<ooooo`04ool00?ooooooooooool002Oooooo
00Coo`00ooooooooooooo`00Coooool2o`0001cooooo0_l00003ooooo`04o`000?ooooooooooo`00
00?ooooo00?o0000ooooooooool0C?ooool01_l00?ooo`00ooooooooooooo`00o`00oa7ooooo00?o
0000ooooooooool04?ooool01Ol00?ooo`00ooooooooooooo`0004oooooo00?o0000ooooooooool0
5Oooool001Sooooo00?o0000ooooooooool00_ooool2o`0000Gooooo00?o0000ooooooooool0Booo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo013ooooo00?o0000ooooooooool0Hooo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo04_ooooo00Coo`00ooooooooooooo`00
9oooool01?oo003ooooooooooooo001@ooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool00_ooool2o`0000Cooooo00?o0000ooooooooool0C?ooool01_l00?ooo`00ooooooooooooo`00
o`00oa7ooooo00?o0000ooooooooool04?ooool01_l00?ooo`00ooooooooooooo`00o`00odkooooo
00?o0000ooooooooool05Oooool002Cooooo00?o0000ooooooooool0Boooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo013ooooo00?o0000ooooooooool04?ooool01Ol00?oooooooooo
oooooooo003o04kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1;ooooo`04ool0
0?ooooooooooool002Oooooo00Coo`00ooooooooooooo`00D?ooool00ol0003oooooooooo`0Voooo
o`;o0000COooool01Ol00?ooo`00ooooooooooooo`0001;ooooo00?o0000ooooooooool04?ooool0
1_l00?ooo`00ooooooooooooo`00o`00odgooooo0_l0000Gooooo`009?ooool00ol0003ooooooooo
o`1Sooooo`03o`000?oooooooooo013ooooo00Go003oooooooooooooooooo`00o`1>ooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool0Boooool01?oo003ooooooooooooo000Wooooo`04
ool00?ooooooooooool0053ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1=oooo
o`05ool00?ooooooooooool00?l00?l04Oooool00ol0003oooooooooo`0Aooooo`05ool00?oooooo
ooooool00?l00?l0C_ooool00ol0003oooooooooo`0Eooooo`009?ooool00ol0003oooooooooo`1;
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04?ooool00ol0003oooooooooo`0@
ooooo`05o`00ooooooooooooooooool00?l0C_ooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooooooo04_ooooo00Coo`00ooooooooooooo`009oooool01?oo003ooooooooooooo001@ooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool0C?ooool01_l00?ooo`00ooooooooooooo`00
o`00oa7ooooo00?o0000ooooooooool04?ooool01Ol00?ooo`00ooooooooooooo`0004oooooo00?o
0000ooooooooool05Oooool002Cooooo00?o0000ooooooooool0Boooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo013ooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0V
ooooo`;o0000C?ooool01?oo003ooooooooooooo000Wooooo`04ool00?ooooooooooool004oooooo
0_l0000Xooooo`;o0000COooool01_l00?ooo`00ooooooooooooo`00o`00oa7ooooo00?o0000oooo
ooooool04?ooool01_l00?ooo`00ooooooooooooo`00o`00odgooooo0_l0000Gooooo`009?ooool0
0ol0003oooooooooo`1<ooooo`05o`00ooooooooooooooooool00?l04_ooool00ol0003ooooooooo
o`0@ooooo`05o`00ooooooooooooooooool00?l0C_ooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo04_ooooo00Coo`00ooooooooooooo`009oooool01?oo003ooooooooooooo001@oooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0C?ooool01Ol00?ooo`00oooooooooooo
o`0001;ooooo00?o0000ooooooooool04?ooool01_l00?ooo`00ooooooooooooo`00o`00odkooooo
00?o0000ooooooooool05Oooool002Cooooo00?o0000ooooooooool0Hoooool00ol0003ooooooooo
o`0@ooooo`05o`00ooooooooooooooooool00?l0C_ooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo04_ooooo00Coo`00ooooooooooooo`009oooool01?oo003ooooooooooooo001@oooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0COooool01?oo003ooooooooooooo000B
ooooo`03o`000?oooooooooo017ooooo00Goo`00ooooooooooooo`00o`00o`1>ooooo`03o`000?oo
oooooooo01Gooooo000Tooooo`03o`000?oooooooooo04cooooo00Go003oooooooooooooooooo`00
o`0Booooo`03o`000?oooooooooo013ooooo00Go003oooooooooooooooooo`00o`1>ooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool0Boooool01?oo003ooooooooooooo000Wooooo`04
ool00?ooooooooooool0053ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1<oooo
o`05o`00oooo003ooooooooooooo00004_ooool00ol0003oooooooooo`0@ooooo`05o`00oooo003o
oooooooooooo0000Coooool00ol0003oooooooooo`0Eooooo`009?ooool00ol0003oooooooooo`1<
ooooo`05o`00ooooooooooooooooool00?l04_ooool00ol0003oooooooooo`0@ooooo`03o`00oooo
oooooooo053ooooo00?o0000ooooooooool09_ooool2o`0004cooooo00Coo`00ooooooooooooo`00
9oooool01?oo003ooooooooooooo001?ooooo`;o0000:?ooool2o`0004gooooo00Go003oool00?oo
ooooooooool0000Booooo`03o`000?oooooooooo013ooooo00Ko003oool00?ooooooooooool00?l0
0?m=ooooo`;o00005oooool002Cooooo00?o0000ooooooooool0C?ooool01Ol00?oooooooooooooo
oooo003o01;ooooo00?o0000ooooooooool05?ooool00ol00?ooooooooooo`1<ooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool0Boooool01?oo003ooooooooooooo000Wooooo`04ool0
0?ooooooooooool0053ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1<ooooo`05
o`00oooo003ooooooooooooo00004_ooool00ol0003oooooooooo`0@ooooo`06o`00oooo003ooooo
oooooooo003o003oC_ooool00ol0003oooooooooo`0Eooooo`009?ooool00ol0003oooooooooo`1S
ooooo`03o`000?oooooooooo013ooooo00Go003oooooooooooooooooo`00o`1>ooooo`03o`000?oo
oooooooo01[ooooo0ol00003ooooo`;o00001?ooool00ol0003oooooooooo`1;ooooo`04ool00?oo
ooooooooool002Oooooo00Coo`00ooooooooooooo`00D?ooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo04gooooo00Coo`00ooooooooooooo`004_ooool00ol0003oooooooooo`0Aoooo
o`05ool00?ooooooooooool00?l00?l0C_ooool00ol0003oooooooooo`0Eooooo`009?ooool00ol0
003oooooooooo`1<ooooo`05o`00ooooooooooooooooool00?l04_ooool00ol0003oooooooooo`0@
ooooo`05o`00ooooooooooooooooool00?l0C_ooool00ol0003oooooooooo`0Kooooo`05o`000?oo
ooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000004gooooo00Coo`00oooooooo
ooooo`009oooool01?oo003ooooooooooooo001@ooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool0C?ooool01Ol00?ooo`00ooooooooooooo`0001;ooooo00?o0000ooooooooool04Ooo
ool01?oo003ooooooooooooo001?ooooo`03o`000?oooooooooo01Gooooo000Tooooo`03o`000?oo
oooooooo04cooooo00Go003oooooooooooooooooo`00o`0Booooo`03o`000?oooooooooo013ooooo
00?o003oooooooooool0D?ooool00ol0003oooooooooo`0Hooooo`Go00000_ooool01?l0003ooooo
ooooool00003ooooo`03o`000?oooooooooo04_ooooo00Coo`00ooooooooooooo`009oooool01?oo
003ooooooooooooo001@ooooo`03o`000?oooooooooo02Kooooo0_l0001=ooooo`05o`00oooo003o
oooooooooooo00004_ooool00ol0003oooooooooo`0Aooooo`05ool00?ooooooooooool00?l00?l0
COooool2o`0001Oooooo000Fooooo`?o00001?ooool2o`0000Gooooo00?o0000ooooooooool0C?oo
ool01Ol00?oooooooooooooooooo003o01;ooooo00?o0000ooooooooool0Hoooool00ol0003ooooo
ooooo`0Hooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000oooool3o`00
04_ooooo00Coo`00ooooooooooooo`009oooool01?oo003ooooooooooooo001?ooooo`;o00006ooo
ool3o`0000Cooooo0_l00004ooooo`03o`000?oooooooooo04cooooo00Go003oool00?oooooooooo
ool0000Booooo`03o`000?oooooooooo017ooooo00Goo`00ooooooooooooo`00o`00o`1>ooooo`03
o`000?oooooooooo01Gooooo000Eooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00004ooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool04?ooool01Ol0
0?oooooooooooooooooo003o04kooooo00?o0000ooooooooool06Oooool00ol0003oooooo`000003
ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0Boooool01?oo003ooooooooo
oooo000Wooooo`04ool00?ooooooooooool0053ooooo00?o0000ooooooooool06?ooool01Ol0003o
oooooooooooooooo000000;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`1=
ooooo`04ool00?ooooooooooool001;ooooo00?o0000ooooooooool04Oooool01?oo003ooooooooo
oooo001?ooooo`03o`000?oooooooooo01Gooooo000Iooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooooooool00_ooool2o`0004gooooo00Go003oooooooooooooooooo`00o`0Booooo`03
o`000?oooooooooo013ooooo00Go003oooooooooooooooooo`00o`1=ooooo`;o00007?ooool2o`00
00?ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`1;ooooo`04ool00?oooooo
ooooool002Oooooo00Coo`00ooooooooooooo`00D?ooool00ol0003oooooooooo`0Looooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooooooo0_l0001=ooooo`05o`00oooo003ooooo
oooooooo00004_ooool00ol0003oooooooooo`0Aooooo`04ool00?ooooooooooool004kooooo0_l0
000Gooooo`006Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0C?ooool01Ol00?oooooooooooooooooo003o01;ooooo00?o0000ooooooooool0
4?ooool01Ol00?oooooooooooooooooo003o04kooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`02ooooo`;o00001?ooool00ol0003oooooooooo`1;ooooo`04ool00?ooooooooooool0
02Oooooo00Coo`00ooooooooooooo`00D?ooool00ol0003oooooooooo`0Looooo`04o`000?oooooo
ooooo`0000;ooooo00Go0000ooooooooooooooooo`00001>ooooo`05o`00oooo003ooooooooooooo
00004_ooool00ol0003oooooooooo`0Aooooo`04ool00?ooooooooooool004oooooo00?o0000oooo
ooooool05Oooool001Gooooo1?l00003ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooo
ooooool0C?ooool01Ol00?oooooooooooooooooo003o01;ooooo00?o0000ooooooooool0Hoooool0
0ol0003oooooooooo`0Vooooo`;o0000C?ooool01?oo003ooooooooooooo000Wooooo`04ool00?oo
ooooooooool004oooooo0_l0000Jooooo`Co00000oooool01?l0003oooooooooool00003ooooo`03
o`000?oooooooooo04gooooo00Coo`00ooooooooooooo`004_ooool00ol0003oooooooooo`0Aoooo
o`04ool00?ooooooooooool004oooooo00?o0000ooooooooool05Oooool001Gooooo00?o0000oooo
ooooool01?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo06?ooooo00?o0000
ooooooooool04?ooool01Ol00?oooooooooooooooooo003o04kooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`1;ooooo`04ool00?ooooooooooool002Oooooo00Coo`00oooooooooooo
o`00D?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooo
oooo00000oooool00ol0003oooooooooo`1=ooooo`04ool00?ooooooooooool001;ooooo00?o0000
ooooooooool04Oooool01?oo003ooooooooooooo001?ooooo`03o`000?oooooooooo01Gooooo000E
ooooo`Go00000oooool2o`0000Gooooo00?o0000ooooooooool0C?ooool01?l00?ooooooooooool0
0?lCooooo`03o`000?oooooooooo013ooooo00Go003oooooooooooooooooo`00o`1>ooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool0Boooool01?oo003ooooooooooooo000Wooooo`04
ool00?ooooooooooool0053ooooo00?o0000ooooooooool06?ooool5o`0000?ooooo0_l00004oooo
o`;o0000C_ooool00ooo003oooooool00002ool0017ooooo00?o0000ooooooooool04?ooool3ool0
0003oooooooo003ooooo04gooooo0_l0000Gooooo`009?ooool00ol0003oooooooooo`1<ooooo`04
o`00ooooooooooooo`00oa?ooooo00?o0000ooooooooool04?ooool01Ol00?oooooooooooooooooo
003o04kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1;ooooo`04ool00?oooooo
ooooool002Oooooo00Coo`00ooooooooooooo`00D?ooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo04gooooo00?oo`00oooooooo00000_oo000Aooooo`03o`000?oooooooooo013ooooo
0ooo00000oooooooo`00ooooo`1>ooooo`03o`000?oooooooooo01Gooooo000Tooooo`03o`000?oo
oooooooo04cooooo00Co003ooooooooooooo003o4oooool00ol0003oooooooooo`1Sooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool0Boooool01?oo003ooooooooooooo000Wooooo`04
ool00?ooooooooooool0053ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1<oooo
o`Koo`004Oooool00ol0003oooooooooo`0@ooooo`Koo`00C_ooool00ol0003oooooooooo`0Eoooo
o`009?ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo013ooooo00Go003ooooooooo
ooooooooo`00o`1>ooooo`03o`000?oooooooooo02Kooooo0_l0001<ooooo`04ool00?oooooooooo
ool002Oooooo00Coo`00ooooooooooooo`00Coooool2o`0002Sooooo00?o0000ooooooooool0C?oo
ool3ool001Cooooo00?o0000ooooooooool04oooool3ool004kooooo00?o0000ooooooooool05Ooo
ool002Cooooo00?o0000ooooooooool0C?ooool01?l00?ooooooooooool00?lCooooo`03o`000?oo
oooooooo013ooooo00Go003oooooooooooooooooo`00o`1>ooooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool0Boooool01?oo003ooooooooooooo000Wooooo`04ool00?ooooooooooool0
053ooooo00?o0000ooooooooool09_ooool2o`0004gooooo0ooo00000ooooooo003oooooo`0Aoooo
o`03o`000?oooooooooo017ooooo00?o003ooooooooo00000_oo001=ooooo`;o00005oooool002Co
oooo00?o0000ooooooooool0C?ooool01?l00?ooooooooooool00?lCooooo`03o`000?oooooooooo
017ooooo00Co003ooooooooooooo003oC_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo04_ooooo00Coo`00ooooooooooooo`009oooool01?oo003ooooooooooooo001@ooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool0COooool01?l00?ooooooooooool00?lBooooo`03
o`000?oooooooooo017ooooo00Co003ooooooooooooo003oCoooool00ol0003oooooooooo`0Eoooo
o`009?ooool00ol0003oooooooooo`1<ooooo`04o`00ooooooooooooo`00oa?ooooo00?o0000oooo
ooooool0Hoooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo04_ooooo00Coo`00oooo
ooooooooo`009oooool01?oo003ooooooooooooo001@ooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool0COooool01?l00?ooooooooooool00?lBooooo`03o`000?oooooooooo017ooooo
00Co003ooooooooooooo003oCoooool00ol0003oooooooooo`0Eooooo`009?ooool00ol0003ooooo
ooooo`1Sooooo`03o`000?oooooooooo017ooooo00Co003ooooooooooooo003oC_ooool00ol0003o
ooooooooo`0Vooooo`;o0000C?ooool01?oo003ooooooooooooo000Wooooo`04ool00?oooooooooo
ool004oooooo0_l0000Xooooo`03o`000?oooooooooo04gooooo00?o003oooooooooool04oooool0
0ol0003oooooooooo`0Dooooo`03o`00oooooooooooo04gooooo00?o0000ooooooooool05Oooool0
02Cooooo00?o0000ooooooooool0C?ooool01?l00?ooooooooooool00?lCooooo`03o`000?oooooo
oooo017ooooo00Co003ooooooooooooo003oC_ooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooooooo04_ooooo00Coo`00ooooooooooooo`009oooool01?oo003ooooooooooooo001@ooooo`03
o`000?oooooooooo02Kooooo0_l0001Aooooo`03o`00oooooooooooo013ooooo00?o0000oooooooo
ool04Oooool00ol00?ooooooooooo`1?ooooo`;o00005oooool002Cooooo00?o0000ooooooooool0
C?ooool01?l00?ooooooooooool00?lCooooo`03o`000?oooooooooo017ooooo00?o003oooooool0
0?l0Coooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo04_ooooo00Coo`00oooooooo
ooooo`009oooool01?oo003ooooooooooooo001@ooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool0COooool01?l00?ooooooooooool00?lBooooo`03o`000?oooooooooo017ooooo00Co
003ooooooooooooo003oCoooool00ol0003oooooooooo`0Eooooo`009?ooool00ol0003ooooooooo
o`1=ooooo`03o`00oooooooo003o01?ooooo00?o0000ooooooooool0Hoooool00ol0003ooooooooo
o`0Vooooo`03o`000?oooooooooo04_ooooo00Coo`00ooooooooooooo`009oooool01?oo003ooooo
oooooooo001@ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0COooool01?l00?oo
ooooooooool00?lBooooo`03o`000?oooooooooo017ooooo00Co003ooooooooooooo003oCoooool0
0ol0003oooooooooo`0Eooooo`009?ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo
017ooooo00?o003oooooool00?l0Coooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
04_ooooo00Coo`00ooooooooooooo`009oooool01?oo003ooooooooooooo001@ooooo`03o`000?oo
oooooooo02Kooooo0_l0001>ooooo`03o`00oooooooooooo01?ooooo00?o0000ooooooooool05?oo
ool00ol00?ooooooooooo`1<ooooo`;o00005oooool001Kooooo0ol00004ooooo`;o00001Oooool0
0ol0003oooooooooo`1=ooooo`03o`00oooooooo003o01?ooooo00?o0000ooooooooool04Oooool0
0ol00?ooooooo`00o`1?ooooo`03o`000?oooooooooo02Kooooo0_l0001<ooooo`04ool00?oooooo
ooooool002Oooooo00Coo`00ooooooooooooo`00Coooool2o`0001_ooooo0ol00004ooooo`;o0000
1?ooool00ol0003oooooooooo`1?ooooo`03o`00oooooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol00?ooooooooooo`1@ooooo`03o`000?oooooooooo01Gooooo000Eooooo`05o`000?oo
ooooooooooooool000000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo04go
oooo00?o003oooooool00?l04oooool00ol0003oooooooooo`0Aooooo`03o`00oooooooo003o04oo
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1;ooooo`04ool00?ooooooooooool0
02Oooooo00Coo`00ooooooooooooo`00D?ooool00ol0003oooooooooo`0Hooooo`05o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo04gooooo
00?o003oooooool00?l04oooool00ol0003oooooooooo`0Aooooo`03o`00oooooooooooo053ooooo
00?o0000ooooooooool05Oooool001Gooooo00Go0000ooooooooooooooooo`000002ooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool0COooool00ol00?ooooooo`00o`0Cooooo`03
o`000?oooooooooo06?ooooo00?o0000ooooooooool06Oooool3o`0000Cooooo0_l00004ooooo`03
o`000?oooooooooo04_ooooo00Coo`00ooooooooooooo`009oooool01?oo003ooooooooooooo001@
ooooo`03o`000?oooooooooo01Sooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool0COooool00ol00?ooooooo`00o`0Cooooo`03o`00
0?oooooooooo01;ooooo00?o003oooooool00?l0Coooool00ol0003oooooooooo`0Eooooo`005Ooo
ool4o`0000?ooooo00Co0000oooooooooooo00001?ooool2o`0006Cooooo00?o0000ooooooooool0
4Oooool00ol00?ooooooo`00o`1>ooooo`;o00006_ooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`1;ooooo`04ool00?oooooooooo
ool002Oooooo00Coo`00ooooooooooooo`00D?ooool00ol0003oooooooooo`0Hooooo`Co00000ooo
ool01?l0003oooooooooool00003ooooo`;o0000C_ooool00ol00?ooooooooooo`0Cooooo`03o`00
0?oooooooooo01Cooooo00?o003oooooooooool0C?ooool2o`0001Oooooo000Eooooo`03o`000?oo
oooooooo00Cooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1=ooooo`03o`00
oooooooo003o01?ooooo00?o0000ooooooooool04Oooool00ol00?ooooooo`00o`1?ooooo`03o`00
0?oooooooooo01cooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooooooool3o`00
04_ooooo00Coo`00ooooooooooooo`009oooool01?oo003ooooooooooooo001?ooooo`;o00006_oo
ool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0
Coooool00ol00?ooooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o003oooooool00?l0
Coooool00ol0003oooooooooo`0Eooooo`005_ooool00ol0003oooooooooo`03ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool0COooool00ol00?ooooooo`00o`0Cooooo`03o`00
0?oooooooooo017ooooo00?o003oooooool00?l0Coooool00ol0003oooooooooo`0Looooo`04o`00
0?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`00001=ooooo`04ool00?oooooooooo
ool002Oooooo00Coo`00ooooooooooooo`00D?ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo00?ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`1=ooooo`03o`00
oooooooo003o01?ooooo00?o0000ooooooooool04_ooool00ol00?ooooooooooo`1?ooooo`03o`00
0?oooooooooo01Gooooo000Gooooo`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool0COoo
ool00ol00?ooooooo`00o`0Cooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool06?oo
ool4o`0000?ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`1;ooooo`04ool0
0?ooooooooooool002Oooooo00Coo`00ooooooooooooo`00D?ooool00ol0003oooooooooo`0Joooo
o`;o00001?ooool2o`0000Cooooo00?o0000ooooooooool0COooool00ol00?ooooooo`00o`0Coooo
o`03o`000?oooooooooo01;ooooo0_l00?m@ooooo`03o`000?oooooooooo01Gooooo000Tooooo`03
o`000?oooooooooo06?ooooo00?o0000ooooooooool04Oooool00ol00?ooooooo`00o`1?ooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00003oooo
o`03o`000?oooooooooo04_ooooo00Coo`00ooooooooooooo`009oooool01?oo003ooooooooooooo
001@ooooo`03o`000?oooooooooo02Kooooo0_l0001?ooooo`03o`00oooooooooooo01;ooooo00?o
0000ooooooooool04oooool00ol00?ooooooooooo`1=ooooo`;o00005oooool002Cooooo00?o0000
ooooooooool0Hoooool00ol0003oooooooooo`0Aooooo`03o`00oooooooo003o04oooooo00?o0000
ooooooooool06?ooool5o`0000?ooooo0_l00004ooooo`03o`000?oooooooooo04_ooooo00Coo`00
ooooooooooooo`009oooool01?oo003ooooooooooooo001@ooooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool0C_ooool2o`00oa?ooooo00?o0000ooooooooool04oooool00ol00?oooooo
ooooo`1>ooooo`03o`000?oooooooooo01Gooooo000Tooooo`03o`000?oooooooooo04kooooo00?o
003oooooooooool04_ooool00ol0003oooooooooo`0Aooooo`03o`00oooooooo003o04oooooo00?o
0000ooooooooool09_ooool2o`0004cooooo00?oo`00oooooooo00000_oo000Uooooo`?oo`0000?o
ooooool00?ooool0C_ooool2o`0002Sooooo00?o0000ooooooooool0Coooool00ol00?oooooooooo
o`0Aooooo`03o`000?oooooooooo01;ooooo00?o003oooooooooool0Coooool00ol0003ooooooooo
o`0Eooooo`009?ooool00ol0003oooooooooo`1=ooooo`;o003o5?ooool00ol0003oooooooooo`1S
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0Boooool00ooo003oooooool00002
ool002Gooooo0ooo00000oooooooo`00ooooo`1?ooooo`03o`000?oooooooooo02Kooooo0_l0001?
ooooo`;o003o4oooool00ol0003oooooooooo`0Booooo`;o003oCoooool2o`0001Oooooo000Toooo
o`03o`000?oooooooooo04gooooo0_l00?lDooooo`03o`000?oooooooooo01;ooooo00?o003ooooo
ooooool0C_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo04[ooooo1_oo000Uoooo
o`Koo`00Coooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo04kooooo00?o003ooooo
ooooool04_ooool00ol0003oooooooooo`0Booooo`;o003oD?ooool00ol0003oooooooooo`0Eoooo
o`009?ooool00ol0003oooooooooo`1>ooooo`03o`00oooooooooooo01;ooooo00?o0000oooooooo
ool04_ooool00ol00?ooooooooooo`1>ooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool0B_ooool3ool002_ooooo0ooo001?ooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool0C_ooool00ol00?ooooooooooo`0Booooo`03o`000?oooooooooo01?ooooo00?o003ooooooooo
ool0C_ooool00ol0003oooooooooo`0Eooooo`009?ooool00ol0003oooooooooo`1Sooooo`03o`00
0?oooooooooo06?ooooo00?o0000ooooooooool09_ooool2o`0004_ooooo0ooo000[ooooo`?oo`00
C_ooool2o`0002Sooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`1Tooooo`03o`00
0?oooooooooo01Gooooo000Tooooo`05o`000?ooooooooooooooool000002Oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool09_ooool00ol0003ooooo
o`000009ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0Vooooo`;o00000oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00Co0000oooooooooooooooo0_l0000Gooooo`009?ooooo=o`0002Soooooc_l0000Xooooolko0000
5oooool00?ooooooooooooofooooo`00ooooooooooooooKooooo003ooooooooooooom_ooool00001
\
\>"],
  ImageRangeCache->{{{0, 755}, {145, 0}} -> {-0.0839304, -0.0144882, \
0.00419585, 0.00419585}, {{20, 243.438}, {141.5, 3.4375}} -> {-14.2028, \
-9.64816, 0.102596, 0.537987}, {{265.75, 489.188}, {141.5, 3.4375}} -> \
{-38.5921, -8.02158, 0.100886, 0.443887}, {{511.562, 734.938}, {141.5, \
3.4375}} -> {-64.6319, -9.73317, 0.102596, 0.538601}}]
}, Closed]]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Macintosh",
ScreenRectangle->{{0, 800}, {0, 578}},
ScreenStyleEnvironment->"Working",
WindowSize->{806, 677},
WindowMargins->{{0, Automatic}, {Automatic, 15}},
ShowSelection->True,
CellLabelAutoDelete->True,
Magnification->1,
StyleDefinitions -> "Classroom.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 48, 0, 62, "Title"],

Cell[CellGroupData[{
Cell[1778, 54, 99, 4, 59, "Section"],

Cell[CellGroupData[{
Cell[1902, 62, 60, 0, 49, "Subsection"],
Cell[1965, 64, 187, 3, 79, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2189, 72, 37, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[2251, 76, 59, 0, 43, "Subsubsection"],
Cell[2313, 78, 118, 2, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2468, 85, 67, 0, 43, "Subsubsection"],
Cell[2538, 87, 820, 15, 143, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3407, 108, 45, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[3477, 112, 62, 0, 43, "Subsubsection"],
Cell[3542, 114, 330, 6, 110, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3909, 125, 67, 0, 34, "Subsubsection"],
Cell[3979, 127, 227, 4, 45, "Text"],
Cell[4209, 133, 551, 10, 158, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4797, 148, 48, 0, 34, "Subsubsection"],
Cell[4848, 150, 367, 8, 64, "Text"],
Cell[5218, 160, 302, 4, 110, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5557, 169, 83, 1, 34, "Subsubsection"],
Cell[5643, 172, 683, 12, 190, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6363, 189, 83, 1, 34, "Subsubsection"],
Cell[6449, 192, 684, 12, 190, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[7182, 210, 39, 0, 32, "Subsection"],
Cell[7224, 212, 333, 7, 45, "Text"],
Cell[7560, 221, 541, 10, 142, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8138, 236, 41, 0, 32, "Subsection"],

Cell[CellGroupData[{
Cell[8204, 240, 45, 0, 42, "Subsubsection"],
Cell[8252, 242, 67, 1, 46, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8356, 248, 43, 0, 42, "Subsubsection"],
Cell[8402, 250, 58, 1, 46, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8497, 256, 104, 4, 42, "Subsubsection"],
Cell[8604, 262, 74, 1, 46, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[8727, 269, 109, 4, 32, "Subsection"],
Cell[8839, 275, 136, 3, 62, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9012, 283, 50, 0, 32, "Subsection"],
Cell[9065, 285, 181, 3, 62, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9283, 293, 48, 0, 32, "Subsection"],
Cell[9334, 295, 141, 2, 60, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9512, 302, 40, 0, 32, "Subsection"],
Cell[9555, 304, 396, 7, 121, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9988, 316, 39, 0, 32, "Subsection"],
Cell[10030, 318, 326, 6, 92, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10393, 329, 59, 0, 32, "Subsection"],
Cell[10455, 331, 131, 3, 46, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[10635, 340, 72, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[10732, 344, 55, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[10812, 348, 619, 10, 127, "Input"],
Cell[11434, 360, 88705, 1739, 176, 9587, 759, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[100188, 2105, 45, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[100258, 2109, 581, 10, 127, "Input"],
Cell[100842, 2121, 127240, 2217, 176, 9660, 762, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[228131, 4344, 51, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[228207, 4348, 649, 12, 126, "Input"],
Cell[228859, 4362, 58392, 1365, 70, 9587, 759, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[287300, 5733, 35, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[287360, 5737, 114, 2, 47, "Input"],
Cell[287477, 5741, 251624, 5037, 546, 28895, 2284, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[539150, 10784, 84, 1, 33, "Subsection"],

Cell[CellGroupData[{
Cell[539259, 10789, 305, 5, 78, "Input"],
Cell[539567, 10796, 38723, 2572, 70, 38601, 2568, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[578339, 13374, 70, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[578434, 13378, 256, 5, 62, "Input"],
Cell[578693, 13385, 8300, 658, 70, 8178, 654, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[587042, 14049, 52, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[587119, 14053, 338, 6, 78, "Input"],
Cell[587460, 14061, 41903, 2815, 70, 41781, 2811, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[629412, 16882, 31, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[629468, 16886, 130, 3, 46, "Input"],
Cell[629601, 16891, 87952, 5976, 70, 87901, 5974, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[717602, 22873, 82, 1, 33, "Subsection"],

Cell[CellGroupData[{
Cell[717709, 22878, 305, 5, 78, "Input"],
Cell[718017, 22885, 37734, 2514, 70, 37612, 2510, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[755800, 25405, 70, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[755895, 25409, 256, 5, 62, "Input"],
Cell[756154, 25416, 8872, 706, 70, 8750, 702, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[765075, 26128, 52, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[765152, 26132, 338, 6, 78, "Input"],
Cell[765493, 26140, 40891, 2757, 186, 40769, 2753, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[806433, 28903, 31, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[806489, 28907, 130, 3, 47, "Input"],
Cell[806622, 28912, 86523, 5908, 154, 86472, 5906, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[893194, 34826, 30, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[893249, 34830, 97, 2, 63, "Input"],

Cell[CellGroupData[{
Cell[893371, 34836, 176791, 7075, 154, 87901, 5974, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1070165, 41913, 157605, 6788, 154, 86472, 5906, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1227843, 48709, 98, 3, 59, "Section"],

Cell[CellGroupData[{
Cell[1227966, 48716, 55, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[1228046, 48720, 718, 13, 127, "Input"],
Cell[1228767, 48735, 72349, 1560, 176, 9900, 786, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1301165, 50301, 45, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[1301235, 50305, 581, 10, 127, "Input"],
Cell[1301819, 50317, 127240, 2217, 176, 9660, 762, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1429108, 52540, 51, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[1429184, 52544, 720, 13, 126, "Input"],
Cell[1429907, 52559, 57992, 1347, 176, 9406, 744, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1487948, 53912, 35, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[1488008, 53916, 114, 2, 47, "Input"],
Cell[1488125, 53920, 236848, 4865, 546, 29027, 2296, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1725022, 58791, 84, 1, 33, "Subsection"],

Cell[CellGroupData[{
Cell[1725131, 58796, 305, 5, 78, "Input"],
Cell[1725439, 58803, 83715, 3280, 69, 41746, 2757, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1809203, 62089, 70, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[1809298, 62093, 256, 5, 62, "Input"],
Cell[1809557, 62100, 65993, 1357, 69, 7997, 636, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1875599, 63463, 52, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[1875676, 63467, 338, 6, 78, "Input"],
Cell[1876017, 63475, 97543, 3654, 69, 44901, 3000, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1973609, 67135, 31, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[1973665, 67139, 130, 3, 46, "Input"],
Cell[1973798, 67144, 199694, 7642, 69, 93985, 6334, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2173541, 74792, 82, 1, 33, "Subsection"],

Cell[CellGroupData[{
Cell[2173648, 74797, 305, 5, 78, "Input"],
Cell[2173956, 74804, 74156, 2976, 69, 37750, 2522, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2248161, 77786, 70, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[2248256, 77790, 256, 5, 62, "Input"],
Cell[2248515, 77797, 52556, 1246, 69, 8643, 699, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2301120, 79049, 52, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[2301197, 79053, 338, 6, 78, "Input"],
Cell[2301538, 79061, 88772, 3360, 186, 40949, 2765, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2390359, 82427, 31, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[2390415, 82431, 130, 3, 47, "Input"],
Cell[2390548, 82436, 173126, 6998, 154, 86683, 5927, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2563723, 89440, 30, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[2563778, 89444, 97, 2, 63, "Input"],

Cell[CellGroupData[{
Cell[2563900, 89450, 199694, 7642, 154, 93985, 6334, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2763597, 97094, 173126, 6998, 154, 86683, 5927, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

